(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   8711060,     224271]*)
(*NotebookOutlinePosition[   8711719,     224294]*)
(*  CellTagsIndexPosition[   8711675,     224290]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Metric Analysis of Tapping Accuracy
for Triple Meter in Chopin Mazurkas\
\>", "Title"],

Cell["\<\
Craig Stuart Sapp <craig@ccrma.stanford.edu>
9-10 Jan 2006\
\>", "Subtitle"],

Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook examines the accuracy at which each type of metrical beat is \
tapped when reverse conducting to particular performances of Chopin Mazurkas. \
 The tapping accuracy for four performances of two mazurkas are analyzed \
below:\n    (1) Mazurka in A minor, Op. 7, No. 2 performed by Frederic Chiu \
in 1999\n    (2) Mazurka in A minor, Op. 7, No. 2 performance by Ignaz \
Friedman in 1930\n    (3) Mazurka in F minor, Op. 7, No. 3 performed by Ignaz \
Friedman in 1930\n    (4) Mazurka in F minor, Op. 7, No. 3 performed by \
Charles Rosen in 1989"
}], "Text"],

Cell["Necessary packages to load first:", "Text"],

Cell[BoxData[
    \(\(\( (*\ 
      needed\ for\ Histogram\ function\ *) \)\(\[IndentingNewLine]\)\(<< \ 
      Graphics`Graphics`\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      needed\ for\ DispersionReport\ and\ Mean\ functions\ *) \)\(\
\[IndentingNewLine]\)\(<< \ Statistics`ConfidenceIntervals`\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Off[General::spell1]\)\(\ \)\( (*\ 
      not\ interested\ in\ possible\ spelling\ errors\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell["Tapping accuracy for each beat (20-trial average)", "Section"],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2; Chiu 1999", "Subsection"],

Cell[BoxData[
    \(\(pid9048x06corrected\  = \ {1725, 2529, 3219, 3794, 4355, 4843, 5522, 
          6246, 6755, 7217, 7758, 8190, 8831, 9591, 10061, 10563, 11048, 
          11566, 12103, 12602, 13150, 13608, 14132, 14944, 16088, 16721, 
          17343, 17843, 18371, 18901, 19550, 20219, 20756, 21179, 21737, 
          22180, 22843, 23543, 24137, 24646, 25205, 26008, 26891, 27478, 
          28066, 28603, 29193, 30021, 30874, 31605, 32214, 32766, 33313, 
          33803, 34446, 35112, 35638, 36096, 36721, 37204, 37872, 38548, 
          38985, 39467, 39959, 40558, 41192, 41753, 42307, 42809, 43496, 
          44351, 45401, 46086, 46574, 47129, 47681, 48145, 48715, 49410, 
          49916, 50354, 50899, 51385, 52032, 52666, 53167, 53664, 54284, 
          55110, 55975, 57093, 57641, 58142, 58696, 59436, 60156, 60713, 
          61150, 61809, 62350, 62819, 63387, 64024, 64507, 65236, 65811, 
          66293, 66839, 67513, 67993, 68530, 69097, 69588, 70080, 70718, 
          71220, 71886, 72625, 73197, 73989, 74683, 75278, 75799, 76336, 
          76793, 77395, 78052, 78557, 79030, 79493, 79932, 80542, 81218, 
          81786, 82304, 82861, 83651, 84533, 85348, 85924, 86425, 87071, 
          87932, 88690, 89481, 89986, 90776, 91337, 91802, 92481, 93194, 
          93658, 94272, 94814, 95282, 95928, 96722, 97295, 97949, 98691, 
          99247, 99802, 100569, 101150, 101974, 102687, 103302, 104211, 
          104986, 105568, 106095, 106644, 107160, 107851, 108480, 109039, 
          109489, 109949, 110364, 111000, 111616, 112140, 112584, 113180, 
          113964, 114829, 115705, 116544, 117219, 118034, 118810, 119532, 
          120311, 120886, 121404, 121864, 122382, 122864, 123262, 123697, 
          124134, 124709, 125090, 125542, 125953, 126362, 126791, 127312, 
          127700, 128129, 128538, 128933, 129339, 129855, 130267, 130861, 
          131575, 132079, 132579, 133010, 133440, 133952, 134359, 134789, 
          135267, 135696, 136138, 136658, 137334, 137774, 138271, 138679, 
          139085, 139580, 140153, 140667, 141393, 142228, 143006, 143778, 
          144520, 145237, 145703, 146201, 146695, 147118, 147500, 147922, 
          148358, 148883, 149259, 149671, 150070, 150472, 150918, 151311, 
          151725, 152121, 152526, 152937, 153391, 153921, 154369, 154888, 
          155525, 156037, 156488, 156892, 157281, 157724, 158145, 158568, 
          158985, 159491, 159932, 160386, 161047, 161574, 162061, 162542, 
          162958, 163450, 164036, 164617, 165353, 165946, 166720, 167489, 
          168388, 169005, 169509, 169997, 170467, 170905, 171324, 171771, 
          172164, 172693, 173141, 173559, 173956, 174422, 174966, 175447, 
          175853, 176277, 176675, 177128, 177537, 178152, 178892, 180643, 
          181165, 181685, 182174, 182941, 183411, 184108, 184940, 185395, 
          185814, 186306, 186787, 187476, 188303, 188750, 189235, 189682, 
          190263, 191033, 191567, 192116, 192723, 193514, 194441, 195256, 
          196098, 196749, 197417, 198021, 198611, 199326, 200020, 200639, 
          201096, 201810, 202487, 203397, 204373, 204899, 205423, 206038, 
          206783, 207781, 208869, 209460, 210070, 210895, 211945, 
          213210};\)\)], "Input",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontSize->9],

Cell[BoxData[
    \(\(pid9048x06avg = {1912, 2557, 3174, 3775, 4431, 4913, 5542, 6289, 
          6802, 7217, 7813, 8307, 8934, 9553, 10056, 10543, 11059, 11613, 
          12176, 12677, 13203, 13668, 14216, 14944, 15960, 16736, 17276, 
          17865, 18400, 18876, 19565, 20294, 20770, 21229, 21684, 22212, 
          22872, 23605, 24086, 24621, 25173, 25930, 26891, 27682, 28118, 
          28617, 29206, 29980, 31020, 31585, 32209, 32766, 33360, 33856, 
          34510, 35212, 35685, 36142, 36667, 37280, 37932, 38597, 39023, 
          39499, 40011, 40520, 41182, 41784, 42347, 42844, 43457, 44315, 
          45417, 46144, 46653, 47135, 47712, 48224, 48822, 49389, 49913, 
          50387, 50854, 51390, 52040, 52693, 53167, 53647, 54198, 55001, 
          55975, 56847, 57688, 58207, 58757, 59469, 60274, 60758, 61159, 
          61701, 62368, 62864, 63492, 64059, 64500, 65084, 65819, 66319, 
          66922, 67488, 68031, 68586, 69124, 69608, 70139, 70646, 71256, 
          71819, 72520, 73243, 73944, 74696, 75245, 75831, 76374, 76855, 
          77457, 78120, 78578, 79082, 79543, 80013, 80584, 81244, 81742, 
          82290, 82884, 83543, 84533, 85412, 85973, 86478, 87024, 87843, 
          88834, 89348, 89972, 90593, 91352, 91843, 92461, 93180, 93660, 
          94256, 94860, 95329, 95905, 96653, 97275, 97908, 98614, 99247, 
          99868, 100480, 101144, 101812, 102711, 103329, 104114, 104986, 
          105559, 106126, 106714, 107205, 107851, 108585, 109032, 109535, 
          109989, 110477, 111083, 111735, 112140, 112606, 113148, 113917, 
          114829, 115680, 116326, 117105, 117932, 118772, 119524, 120280, 
          120913, 121381, 121884, 122355, 122864, 123301, 123697, 124161, 
          124611, 125111, 125542, 125964, 126362, 126840, 127276, 127708, 
          128160, 128562, 128962, 129409, 129818, 130282, 130795, 131511, 
          132122, 132579, 133088, 133454, 133927, 134443, 134853, 135267, 
          135768, 136128, 136645, 137334, 137866, 138276, 138759, 139106, 
          139572, 140123, 140734, 141393, 142071, 143053, 143888, 144595, 
          145152, 145733, 146208, 146704, 147187, 147578, 147974, 148402, 
          148867, 149319, 149729, 150112, 150494, 150924, 151399, 151750, 
          152167, 152552, 152952, 153414, 153914, 154425, 154962, 155586, 
          156066, 156546, 156988, 157323, 157774, 158213, 158622, 159067, 
          159464, 159932, 160440, 161033, 161574, 162069, 162526, 162975, 
          163450, 163982, 164679, 165353, 166023, 166733, 167489, 168295, 
          169016, 169533, 170017, 170481, 170942, 171340, 171767, 172244, 
          172656, 173138, 173613, 173989, 174422, 174908, 175447, 175885, 
          176331, 176722, 177128, 177616, 178103, 178871, 180522, 181353, 
          181763, 182271, 182856, 183506, 184085, 184857, 185392, 185849, 
          186411, 186868, 187551, 188243, 188762, 189248, 189764, 190272, 
          190927, 191693, 192177, 192665, 193462, 194441, 195432, 196029, 
          196716, 197304, 198086, 198611, 199366, 200110, 200639, 201185, 
          201676, 202387, 203305, 204238, 204899, 205423, 206038, 206880, 
          207781, 208688, 209533, 210109, 210826, 211871, 
          213210};\)\)], "Input",
  FontSize->9],

Cell["\<\
Calculate the differences between the average tap times and the corrected \
data, removing the extremities:\
\>", "Text"],

Cell[BoxData[{
    \(\(diffs1\  = \ 
        pid9048x06avg\  - \ pid9048x06corrected;\)\), "\[IndentingNewLine]", 
    \(\(diffs1\  = \ Drop[diffs1, \ 1];\)\  (*\ 
      drop\ the\ first\ pickup\ beat\ *) \), "\[IndentingNewLine]", 
    \(\(diffs1\  = \ Drop[diffs1, \ 3];\)\  (*\ 
      drop\ the\ first\ measure\ of\ the\ piece\ *) \), \
"\[IndentingNewLine]", 
    \(\(diffs1\  = \ Drop[diffs1, \ \(-3\)];\)\  (*\ 
      drop\ the\ last\ measure\ of\ the\ piece\ *) \), "\[IndentingNewLine]", \

    \(\(diffs1\  = \ N[diffs1\  - \ Mean[diffs1]];\)\  (*\ 
      estimate\ correction\ for\ alignment\ error\ *) \), \
"\[IndentingNewLine]", 
    \(\(beats1\  = \ Transpose[Partition[diffs1, \ 3]];\)\)}], "Input"],

Cell["\<\
First display a histogram of all metrical beat displacements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot1\  = \ 
        Histogram[diffs1, \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00949361 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -12 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(10)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(20)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(30)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(40)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(50)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(60)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0337 L
.04762 .0337 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0337 L
.04762 .0337 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .0432 L
.09524 .0432 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0432 L
.09524 .0432 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .05269 L
.14286 .05269 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05269 L
.14286 .05269 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .07168 L
.19048 .07168 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07168 L
.19048 .07168 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .10965 L
.2381 .10965 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10965 L
.2381 .10965 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .10016 L
.28571 .10016 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10016 L
.28571 .10016 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .13813 L
.33333 .13813 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .13813 L
.33333 .13813 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .21408 L
.38095 .21408 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21408 L
.38095 .21408 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .29952 L
.42857 .29952 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29952 L
.42857 .29952 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .52737 L
.52381 .52737 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52737 L
.52381 .52737 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .4799 L
.57143 .4799 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .4799 L
.57143 .4799 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .37547 L
.61905 .37547 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37547 L
.61905 .37547 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .29952 L
.66667 .29952 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .29952 L
.66667 .29952 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .11914 L
.71429 .11914 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11914 L
.71429 .11914 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .06218 L
.7619 .06218 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .06218 L
.7619 .06218 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0337 L
.80952 .0337 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0337 L
.80952 .0337 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0337 L
.90476 .0337 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0337 L
.90476 .0337 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02421 L
.95238 .02421 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02421 L
.95238 .02421 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool02P3oool00`000000Ogmo07moO`0907moO`h00000303oool00`000000oooo0?ooo`01
0?ooo`002P3oool2000000D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo00X0oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`010?ooo`004@3oool>000000`0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`h00000303oool=000001P0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool02P3oool>000000/0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01L0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
03d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000001P0oooo3@00000<07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`d00000?`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool08`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
903oool>000000`0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
0300oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`010?ooo`004@3oool200000340oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo04P0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0`0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0300oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0`0?oo
o`030000001oOgl0Ogmo00X0Ogmo3P00000;07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0300oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
04T0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo0`00000`0?ooo`h00000303oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`170?oo
o`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0BP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04X0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04X0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`h00000B`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000B`3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo04X0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0BP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1:0?ooo`d00000301oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3o
ool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool3000005H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1D0?ooo`<0
00000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0EP3oool>000000`0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000I03oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo
06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool3000006<0oooo3P00000;07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`h00000EP3oool3000000<0oooo00060?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000L@3oool00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool200000740oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo3@00001T0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo0700oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo00030?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<0
0000L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`1]0?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0040oooo00050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3o
ool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool200000740oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool2000000<0oooo000A0?ooo`030000003oool0
oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`010?ooo`004@3oool200000740oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool2000000<0oooo000A
0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0KP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl>00000740oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?oo
o`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`<00000L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0NP3oool3000000<0oooo00040?ooo`8000000`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?oo
o`3oool00@3oool000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<0
000007moO`1oOgl02@1oOgl>000007d0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
R@3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`280?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool0
0`000000Ogmo07moO`0907moO`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000003oool0oooo
08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000
Ogmo07moO`0907moO`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000003oool0oooo08T0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0R03oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`290?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00030?ooo`<00000
103oool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000
003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool300000700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`270?ooo`<000000`3oool000<0oooo0`0000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907mo
O`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00040?ooo`<0
00000`3oool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
L03oool00`000000Ogmo07moO`0907moO`030000003oool0oooo08T0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001a0?ooo`d00000RP3oool2000000<0oooo000A0?ooo`030000003oool0
oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?oo
o`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {563.375, 422.063}} -> {-280.554, \
202.587, 1.57972, 0.396186}}]
}, Open  ]],

Cell["\<\
Now display separate histograms for individual metrical position in the \
meter:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot11\  = \ 
        Histogram[beats1[\([1]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .17822 L
.2381 .17822 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17822 L
.2381 .17822 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .24362 L
.28571 .24362 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .24362 L
.28571 .24362 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .24362 L
.33333 .24362 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .24362 L
.33333 .24362 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .37442 L
.38095 .37442 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .37442 L
.38095 .37442 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .47252 L
.57143 .47252 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .47252 L
.57143 .47252 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .43982 L
.66667 .43982 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .43982 L
.66667 .43982 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00E03oool500000080oooo0P0000040?ooo`800000
<P3oool2000003D0oooo1@0000020?ooo`800000103oool2000002l0oooo100000030?ooo`800000
103oool2000000L0oooo001F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000=P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000060?ooo`00EP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000003H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool004h0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000=P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00@0oooo001F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000
=P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0/0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`00E@3oool2000000@0oooo0P0000040?ooo`800000<P3o
ool2000003H0oooo0P0000040?ooo`800000103oool200000300oooo0P0000040?ooo`800000103o
ool2000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000K0?ooool000001@0000010?ooo`006`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool100000040oooo000D0?ooo`80
00001@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00
4`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo0P00000001<0oooo
00@000000?ooo`3oool00000103ooooo000000D000000@3oool001<0oooo00@000000?ooo`3oool0
0000103oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo01D0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00T0oooo0@0000010?ooo`00
4`3oool010000000oooo0?ooo`0000040?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool05@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool02@3oool100000040oooo000D0?ooo`8000001@3oool00`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo00T0oooo0@0000010?ooo`006`3oool00`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo00P0oooo0P0000010?ooo`006`3oool00`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0
oooo01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo00T0oooo0@0000010?ooo`006`3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo
01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
00T0oooo0@0000010?ooo`006`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo01D0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00T0
oooo0@0000010?ooo`006`3ooolI000000`0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`0E0?oooaX000002P3oool200000040oooo000K0?ooo`030000003oool0oooo01D0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo03X0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0j0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool05@3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0>P3oool100000040oooo000K0?ooo`8000005P3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0>@3oool200000040oooo000K0?ooo`030000
003oool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo03X0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0j0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool05@3oool00`000000o`000?l0000:0?l000030000003oool0
oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0>P3oool100000040oooo000K0?ooo`030000003oool0oooo
01D0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo
03X0oooo0@0000010?ooo`006`3oool2000001H0oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o000>000003/0
oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0A`3oool100000040oooo00070?ooo`@000000`3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`170?ooo`4000000@3oool000L0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`170?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`8000005P3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo04H0oooo0P000001
0?ooo`002@3oool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0A`3oool100000040oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0A`3oool100000040oooo00080?ooo`80
00002P3oool3000000@0oooo00<000000?ooo`3oool05@3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo04L0oooo0@0000010?ooo`006`3oool2000001H0oooo3P00000;0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`160?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool0A`3oool100000040oooo000K0?ooo`030000003oool0
oooo02h0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo04L0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`170?ooo`4000000@3oool001/0
oooo0P00000_0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`160?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0A`3oool100000040oooo
000K0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo04L0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0^
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`17
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0A`3oool100000040oooo000K0?ooo`80
0000;`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000d00000B03oool200000040oooo000K0?ooo`030000
003oool0oooo02h0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`800000;`3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo0580oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`0^0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040
oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0D`3oool100000040oooo000C0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0;P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo
0@0000010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`800000;`3oool>000000/0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0580oooo0P00
00010?ooo`00503oool2000000D0oooo00<000000?ooo`3oool0>`3oool00`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C
0?ooo`4000000@3oool001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo05<0oooo0@0000010?ooo`00503oool3000000@0oooo00<000000?ooo`3o
ool0>`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo0P00000l0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo0580oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0
oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo
05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0
oooo0@0000010?ooo`006`3oool2000003`0oooo00<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0DP3oool200000040oooo
000K0?ooo`030000003oool0oooo03/0oooo00<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K
0?ooo`030000003oool0oooo03/0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?oo
o`030000003oool0oooo03/0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`80
0000?03oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1B0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0
>`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0>`3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0>`3oool0
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo0P00000l0?oooaT00000303o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1B0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0D`3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0D`3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`002@3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D`3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo0P00001D0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0DP3oool200000040oooo000:0?ooo`030000003oool0oooo00L0oooo0P000005
0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C
0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C
0?ooo`4000000@3oool000L0oooo100000090?ooo`<00000103oool00`000000oooo0?ooo`1C0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`03
0000003oool0oooo05<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`40
00000@3oool001/0oooo0P00001D0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
DP3oool200000040oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0D`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool10000
0040oooo000K0?ooo`800000E03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0580
oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`030000003oool0oooo05<0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0D`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@000001
0?ooo`006`3oool2000005@0oooo00<000000?l0003o00002P3o000I000000`0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0DP3oool200000040oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0D`3oool100000040oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
D`3oool100000040oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3o
ool100000040oooo000K0?ooo`800000E03oool00`000000o`000?l0000:0?l000030000003oool0
oooo01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1B0?ooo`8000000@3oool0
01/0oooo00<000000?ooo`3oool0D`3oool00`000000o`000?l0000:0?l000030000003oool0oooo
01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0D`3oool00`000000o`000?l0000:0?l000030000003oool0oooo01D0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool000d0oooo
1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool05@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo
0@0000010?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
5@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`003`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool2000005@0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0DP3oool200000040oooo000?0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
D`3oool100000040oooo000?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo05<0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`0E0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo
000>0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0D`3oool00`000000o`000?l0
000:0?l000030000003oool0oooo01D0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`1C0?ooo`4000000@3oool001/0oooo0P00001D0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool05@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0580oooo0P000001
0?ooo`006`3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool05@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool05@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
5@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`006`3o
ool2000005@0oooo3P00000G0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
000=000000`0o`0000<000000?ooo`3oool0DP3oool200000040oooo000K0?ooo`030000003oool0
oooo07P0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo00T0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1C0?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003oool0oooo
05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`800000N@3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l0000:0?l000030000003oool0oooo0580oooo0P0000010?ooo`006`3oool00`000000oooo0?oo
o`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K
0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1C
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo000K0?ooo`800000
N@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
2@3oool00`000000o`000?l0000:0?l000030000003oool0oooo0580oooo0P0000010?ooo`006`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3o
ool100000040oooo00000`3oool0000000000003000000030?ooo`0000000000008000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`1C0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0
000:0?l000030000003oool0oooo05<0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000007T0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00T0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`1B0?ooo`8000000@3oool000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`1h0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`090?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040oooo00030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003oool0oooo
05<0oooo0@0000010?ooo`000P3oool2000000@0oooo0P00000:0?ooo`<00000103oool00`000000
oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0D`3oool100000040
oooo000K0?ooo`800000N@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool02@3oool>000005@0oooo0P0000010?ooo`006`3oool00`000000oooo0?oo
o`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1/0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0K03oool100000040oooo000K0?oo
o`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003oool0oooo06`0oooo0@0000010?ooo`006`3oool2000007T0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06/0oooo0P0000010?ooo`00
6`3oool00`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1/0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0N03o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0K03o
ool100000040oooo000K0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo06`0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1/0?ooo`4000000@3oool001/0oooo0P00001i0?ooo`030000003o0000o`0000X0
o`003@00001]0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0N03oool00`000000o`00
0?l0000:0?l000030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`1h0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool100000040oooo000K
0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1h
0?ooo`4000000@3oool001/0oooo0P00001i0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool0M`3oool200000040oooo000K0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`1h0?ooo`4000000@3oool000d0oooo1@0000020?ooo`800000
1@3oool00`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
N03oool100000040oooo000?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`1h0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`800000N@3oool00`000000o`000?l0000:0?l000030000003oool0oooo07L0oooo0P00
00010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1h
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool100000040oooo000?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1h0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool100000040oooo000>0?ooo`80
0000103oool3000000@0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l00003
0000003oool0oooo07P0oooo0@0000010?ooo`006`3oool2000007T0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1g0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0N03o
ool00`000000o`000?l0000:0?l000030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool1
00000040oooo000K0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1h0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0N03oool00`000000
o`000?l0000:0?l000030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool2000007T0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1g0?ooo`8000000@3oool001/0oooo00<0
00000?ooo`3oool0N03oool00`000000o`000?l0000:0?l000030000003oool0oooo07P0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0N03oool100000040oooo000K0?ooo`030000003oool0oooo07P0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`1h0?ooo`4000000@3oool001/0oooo0P00001i0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0M`3oool200000040oooo000K0?ooo`030000
003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1h0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l000030000003o
ool0oooo07P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1h0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool0N03oool100000040oooo000K0?ooo`800000N@3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo07L0oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool100000040
oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`1h0?ooo`4000000@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000o`00
0?l0000:0?l000030000003oool0oooo07P0oooo0@0000010?ooo`000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000007T0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1g0?ooo`8000000@3oool000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`1h
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool100000040oooo00030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0N03oool00`000000o`000?l0000:0?l000030000003oool0
oooo07P0oooo0@0000010?ooo`000P3oool2000000<0oooo100000090?ooo`<00000103oool00`00
0000oooo0?ooo`1h0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0N03oool10000
0040oooo000K0?ooo`030000003oool0oooo07P0oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`1h0?ooo`4000000@3oool001/0oooo0P00001i0?ooo`h00000N@3oool200000040oooo
000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`4000000@3oool0
01/0ooooo`00000500000040oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {181.563, 40.25}} -> {-297.51, \
3.79655, 1.61944, 0.117914}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot12\  = \ 
        Histogram[beats1[\([2]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0189872 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -6 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(5)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(10)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(15)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(20)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(25)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(30)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .05269 L
.19048 .05269 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .05269 L
.19048 .05269 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .05269 L
.2381 .05269 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .05269 L
.2381 .05269 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .05269 L
.28571 .05269 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05269 L
.28571 .05269 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .05269 L
.33333 .05269 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .05269 L
.33333 .05269 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .16661 L
.38095 .16661 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16661 L
.38095 .16661 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .14763 L
.42857 .14763 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .14763 L
.42857 .14763 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .39446 L
.52381 .39446 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .39446 L
.52381 .39446 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .39446 L
.57143 .39446 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .39446 L
.57143 .39446 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .22357 L
.61905 .22357 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .22357 L
.61905 .22357 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .16661 L
.66667 .16661 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16661 L
.66667 .16661 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .05269 L
.71429 .05269 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .05269 L
.71429 .05269 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .05269 L
.7619 .05269 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05269 L
.7619 .05269 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08`3oool00`0000000?l0003o000:
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo03d0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0S0?ooo`0300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<000000?oo
o`3oool08`3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo03d0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`0000000?l0003o000:003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
0000003oool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000T0?ooo`030000
0000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0?03oool2000000<0oooo000A0?ooo`030000003o
ool0oooo02<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
02<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000903ooold000000`00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
6P00000n0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`002P00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`002P00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05D0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`002P3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00303oool00`000000oooo0?ooo`020?ooo`<0
0000EP3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05@0oooo0`0000030?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`002P00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000:003o00h0
00002`00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05D0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0
2P3oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l000X00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02P3oool0
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
00X00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0
oooo3P00000<0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l03P00001G0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06<0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06<0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000
003oool0oooo0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001`0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0H@3oool3000000<0oooo00050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0L03oool00`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00d00000I03oool2000000<0oooo
000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
KP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700
oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001a0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
000:003o00030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001a0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o000:003o00030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0040oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0`00001`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo06d0oooo0`0000030?ooo`001@3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`0300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo
0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00001a0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o000:003o00030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001a0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo06h0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06h0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
0000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool0
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool20000
00D0oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0040oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000L03oool00`00
00000?l0003o0009003o01/00000K`3oool3000000<0oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<00000003o
0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1`
0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`01
0?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0700oooo00<00000003o
0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000L@3oool00`0000000?l0003o0009003o00030000
003oool0oooo08P0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000
o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l0
00T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`010?ooo`004@3oool200000740oooo00<00000003o0000o`002@00o`000`000000oooo
0?ooo`280?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o
0009003o00030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0L03oool00`0000000?l0003o0009003o00030000003oool0oooo08T0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o
00030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0L03oool00`0000000?l0003o0009003o00030000003oool0oooo08T0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001a0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0
R03oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00
o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700
oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000L@3oool00`0000000?l0003o0009003o00030000003oool0oooo08P0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`01
0?ooo`000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo0700oooo00<00000003o
0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1`0?oo
o`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?oo
o`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00001`0?ooo`03
00000000o`000?l000T00?l000<000000?ooo`3oool0Q`3oool3000000<0oooo00050?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0700oooo00<00000003o0000o`00
2@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1`0?ooo`030000
0000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00
o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000L@3oool00`0000000?l0003o0009003o00030000003oool0oooo
08P0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T0
0?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool200000740oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`280?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o0003
0000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
L03oool00`0000000?l0003o0009003o00030000003oool0oooo08T0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0L03oool00`0000000?l0003o0009003o00030000003o
ool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool0
0`0000000?l0003o0009003o00030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001a0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R03oool20000
00<0oooo000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`000000
oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo
00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000
003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000L@3oool00`0000000?l0003o0009003o00030000003oool0oooo08P0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000
0000o`000?l000T00?l000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool300000700oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`270?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`290?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1`0?ooo`0300000000o`000?l000T00?l0
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0700oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<00000
003o0000o`002@00o`000`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000L@3oool=000008X0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool00140ooooo`00
000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {352.625, 211.313}} -> {-280.554, \
49.1082, 1.57972, 0.198093}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot13\  = \ 
        Histogram[beats1[\([3]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0267547 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -6 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(5)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(10)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(15)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(20)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04147 L
.04762 .04147 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04147 L
.04762 .04147 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .06822 L
.09524 .06822 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06822 L
.09524 .06822 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .04147 L
.14286 .04147 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04147 L
.14286 .04147 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .09498 L
.2381 .09498 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .09498 L
.2381 .09498 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .06822 L
.38095 .06822 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .06822 L
.38095 .06822 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .38928 L
.42857 .38928 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .38928 L
.42857 .38928 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .44279 L
.52381 .44279 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .44279 L
.52381 .44279 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .41604 L
.57143 .41604 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41604 L
.57143 .41604 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .44279 L
.61905 .44279 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .44279 L
.61905 .44279 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .25551 L
.66667 .25551 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25551 L
.66667 .25551 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04147 L
.7619 .04147 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04147 L
.7619 .04147 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0040oooo000:0?oo
o`8000001@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool02P3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool00@3oool00140oooo3P00000<0000o`d0000030000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o3@00000<0000o`030000003oool0
oooo00X0oooo3@00000H0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool02P3oool00`00
0000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`0:0000o`030000003oool0oooo0300oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0
oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo0300
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000003o
0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o
0000o`0:0000o`030000003oool0oooo0300oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo0300oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000003o0000o`0:
0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:
0000o`030000003oool0oooo0300oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool02P3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo0300oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000;0?ooo`h000002`3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`h0
000030000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`090?ooo`h00000<@3oool2000000<0oooo000A0?ooo`030000
003oool0oooo02<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool02P3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0
oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`0:0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0
003o00<000000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o
0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000903oool00`000000003o0000
o`0:0000o`h00000303oool00`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`180?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool08`3oool00`000000003o0000o`0:0000o`030000003oool0oooo01L0oooo00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool05`3oool00`000000003o0000o`090000
o`030000003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`0G0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3o
ool02P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`030000
003oool0oooo01L0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05`3o
ool00`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo02<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0G0?ooo`03000000000?l0
003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0
oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000T0?ooo`h000006@3oool=0000
00`0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`180?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?oo
o`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool000`0oooo00<000000?ooo`3oool00P3oool3000006<0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o3P0000190?ooo`<0
00000`3oool000X0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`002P3oool3
000000@0oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`h00000E`3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo0`00001S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1Q0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000I03oool>000000/0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0700oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700
oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040
oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
L03oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<00000L03o
ool00`000000003o0000o`090000o`03000000000?l0003o00X0003o3P00000;0000o`030000003o
ool0oooo0640oooo0`0000030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool0
0`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`<00000103oool00`000000
oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?oo
o`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<000000000
o`000?l02@000?l>000000`0oooo3@00001T0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000
003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03o
ool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000003oool0
oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`00
0000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`03000000000?l0003o00T0003o
00<000000?ooo`3oool0R03oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000
o`000?l02@000?l00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`290?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo0700oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000L@3oool00`000000003o0000o`090000o`030000003oool0
oooo08P0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o
00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1`0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?oo
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?oo
o`004@3oool200000740oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`280?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000
003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03o
ool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000003oool0
oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`00
0000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool000<0
oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0
003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0L03oool00`000000
003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000L03oool00`000000
003o0000o`090000o`030000003oool0oooo08L0oooo0`0000030?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`03
000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?oo
o`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`03
000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0
R@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`280?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`000000
003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000
o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0L03oool00`000000003o0000o`090000o`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`030000
003oool0oooo08T0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`d00000RP3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {523.688, 382.375}} -> {-280.554, \
64.9114, 1.57972, 0.140582}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{plot1, \ plot11, \ plot12, \ plot13}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00949361 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -12 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(10)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(20)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(30)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(40)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(50)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(60)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0337 L
.04762 .0337 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0337 L
.04762 .0337 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .0432 L
.09524 .0432 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0432 L
.09524 .0432 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .05269 L
.14286 .05269 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05269 L
.14286 .05269 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .07168 L
.19048 .07168 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07168 L
.19048 .07168 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .10965 L
.2381 .10965 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10965 L
.2381 .10965 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .10016 L
.28571 .10016 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10016 L
.28571 .10016 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .13813 L
.33333 .13813 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .13813 L
.33333 .13813 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .21408 L
.38095 .21408 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21408 L
.38095 .21408 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .29952 L
.42857 .29952 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29952 L
.42857 .29952 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .52737 L
.52381 .52737 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52737 L
.52381 .52737 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .4799 L
.57143 .4799 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .4799 L
.57143 .4799 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .37547 L
.61905 .37547 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37547 L
.61905 .37547 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .29952 L
.66667 .29952 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .29952 L
.66667 .29952 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .11914 L
.71429 .11914 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11914 L
.71429 .11914 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .06218 L
.7619 .06218 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .06218 L
.7619 .06218 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0337 L
.80952 .0337 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0337 L
.80952 .0337 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0337 L
.90476 .0337 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0337 L
.90476 .0337 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02421 L
.95238 .02421 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02421 L
.95238 .02421 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .17822 L
.2381 .17822 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17822 L
.2381 .17822 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .24362 L
.28571 .24362 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .24362 L
.28571 .24362 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .24362 L
.33333 .24362 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .24362 L
.33333 .24362 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .37442 L
.38095 .37442 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .37442 L
.38095 .37442 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .47252 L
.57143 .47252 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .47252 L
.57143 .47252 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .43982 L
.66667 .43982 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .43982 L
.66667 .43982 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0189872 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -6 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(5)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(10)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(15)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(20)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(25)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(30)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .05269 L
.19048 .05269 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .05269 L
.19048 .05269 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .05269 L
.2381 .05269 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .05269 L
.2381 .05269 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .05269 L
.28571 .05269 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05269 L
.28571 .05269 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .05269 L
.33333 .05269 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .05269 L
.33333 .05269 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .16661 L
.38095 .16661 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16661 L
.38095 .16661 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .14763 L
.42857 .14763 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .14763 L
.42857 .14763 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .39446 L
.52381 .39446 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .39446 L
.52381 .39446 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .39446 L
.57143 .39446 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .39446 L
.57143 .39446 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .22357 L
.61905 .22357 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .22357 L
.61905 .22357 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .16661 L
.66667 .16661 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16661 L
.66667 .16661 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .05269 L
.71429 .05269 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .05269 L
.71429 .05269 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .05269 L
.7619 .05269 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05269 L
.7619 .05269 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0267547 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -6 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(5)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(10)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(15)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(20)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04147 L
.04762 .04147 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04147 L
.04762 .04147 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .06822 L
.09524 .06822 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06822 L
.09524 .06822 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .04147 L
.14286 .04147 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04147 L
.14286 .04147 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .09498 L
.2381 .09498 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .09498 L
.2381 .09498 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .06822 L
.38095 .06822 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .06822 L
.38095 .06822 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .38928 L
.42857 .38928 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .38928 L
.42857 .38928 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .44279 L
.52381 .44279 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .44279 L
.52381 .44279 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .41604 L
.57143 .41604 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41604 L
.57143 .41604 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .44279 L
.61905 .44279 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .44279 L
.61905 .44279 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .25551 L
.66667 .25551 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25551 L
.66667 .25551 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04147 L
.7619 .04147 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04147 L
.7619 .04147 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{679, 97.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:W0000HB000`400?l00000o`00003oo`3ooooo
0?ooojT0oooo003o0?ooool0ooooZ@3oool00?l0ooooo`3ooonY0?ooo`00>`3oool500000080oooo
0P0000040?ooo`800000503oool2000001L0oooo1@0000020?ooo`800000103oool200000100oooo
100000030?ooo`800000103oool200000=d0oooo1@0000020?ooo`800000103oool2000001D0oooo
0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo
0P00000j0?ooo`D000000P3oool2000000@0oooo0P00000D0?ooo`8000005P3oool500000080oooo
0P0000040?ooo`8000004@3oool4000000<0oooo0P0000040?ooo`8000005`3oool003d0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000=h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000001H0oooo000m0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool00000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00003N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000F0?ooo`00=@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000H0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0e03oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0<@3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0503oool003d0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000440oooo1@0000020?ooo`800000103oool20000
0180oooo0P00000D0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool20000
00@0oooo0P00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F
0?ooo`00?03oool2000000@0oooo0P0000040?ooo`800000503oool2000001P0oooo0P0000040?oo
o`800000103oool200000140oooo0P0000040?ooo`800000103oool2000004@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3o
ool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000003T0oooo0P0000040?ooo`800000103o
ool2000001D0oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000103o
ool2000000@0oooo0P00000k0?ooo`800000103oool2000000@0oooo0P00000D0?ooo`8000005`3o
ool2000000@0oooo0P0000040?ooo`8000004P3oool2000000@0oooo0P0000040?ooo`8000005`3o
ool00>T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooo
GP3oool00>40oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000005@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0<0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0?l0ooooG03oool00>T0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000?l0ooooGP3oool00>P0oooo0P0000040?ooo`800000103oool20000
0180oooo0P00000E0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`800000103oool20000
00@0oooo0P00003o0?oooel0oooo000K0?ooo`800000103ooon400000;d0oooo0P0000040?oooh@0
00006P3oool2000000@0ooooQ000000G0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool001X0oooo00@000000?oo
o`3oool000000`3ooon500000;/0oooo00@000000?ooo`3oool000000`3ooon5000001P0oooo00@0
00000?ooo`3oool000000`3ooon4000001L0oooo000J0?ooo`040000003oool0oooo000000<0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl0101oOgl7000000D0oooo00<000000?ooo`3oool08`3oool2000000@0oooo
N@00000H0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool010000000
oooo0?ooo`0000030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0E0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`L000001@1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo1`0000050?ooo`P000002`3oool00`00
0000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000
0`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`040000o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5@3oool001/0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0ooooN@00000I0?ooo`800000
103oool00`000000oooo0?ooo`0@0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
1000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`800000103oool7000000D0003o1`0000060000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l8000000D0003o00<000000?ooo`3oool0
0`3oool8000000/0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool00`3o
ool7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo00T0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo00T0oooo2000000507moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool2000001l0oooo00<000000?ooo`3oool0
403ooolJ000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l03@00000N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
103oool00`000000003o0000o`030000o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5@3oool00240oooo00<000000?ooo`3oool0403oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl7000001h0oooo00<000000?ooo`3oool08`3o
ool2000000@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`090?ooo`030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`008@3oool0
0`000000oooo0?ooo`0@0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo0280oooo00<000000?ooo`3oool0:@3oool<000000D0o`0000<000000?ooo`3oool00`3oool0
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000oooo0?ooo`090?ooo``00000103oool2000001l0oooo00<000000?ooo`3oool0:@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`030?ooo`L000001@3oool00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`P000001@000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`040?ooo`L00000603oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`00
0000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`00
0000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo01H0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0280
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0I0?ooo`8000007`3oool00`000000
oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000000o`000?l010000?l00`000000
003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0E0?ooo`00503oool500000080oooo0P0000040?ooo`030000003oool0oooo01H0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0280oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo
0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000003o
0000o`040000o`L000001@3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo
000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001P0
oooo00<0000007moO`1oOgl00`1oOgl7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool4000000<0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`001P00000K0?ooo`800000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool03`3oool00`000000003o0000o`040000o`030000003oool0oooo
00T0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`L000001@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0Q0?ooo`800000603oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo01l0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`3oool2000002X0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`001000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool03`3oool00`000000003o0000o`040000o`030000003oool0oooo00T0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0280
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?oo
o`8000002@3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01h0oooo0P00000I0?oo
o`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000000
o`000?l010000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0103oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05@3oool001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000903oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo2000000T
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<00000
0?ooo`3oool0203oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01l0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool03`3oool8000000/0oooo1`0000060?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`005@3oool2000000@0oooo0P0000040?oo
o`030000003oool0oooo0280oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool7000000D0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01h0oooo0P00000I
0?ooo`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`800000103oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E
0?ooo`008@3oool00`000000oooo0?ooo`0R0?ooo`P000001@1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo01L0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0D0?oo
o`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
00030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo02T0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0503oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool07P3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o
00L000001P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo02P0oooo00<000000?oo
o`3oool06P3oool01@000000oooo0?ooo`3oool000000340oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o1`00000T0?ooo`8000005`3oool0
0240oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo
02P0oooo00<000000?ooo`3oool0603oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo02T0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0503oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000L00000803oool2000001l0
oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo02P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo
0?ooo`0Y0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0S0?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0903oool2000001l0oooo00<000000?ooo`3oool0:@3oool7000000D0oooo
00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`08000002X0oooo00<000000?ooo`3oool0603oool3000000<0oooo
00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo
000Q0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0D0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;`3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo02T0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02D0oooo00@0
00000?ooo`3oool0oooo0P00000E0?ooo`H000001@3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0903oool2000001l0oooo00<000000?ooo`3oool0
=@3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
5@3oool001@0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`800000103o
ool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02D0oooo00<000000?ooo`3oool0403o
ool500000080oooo0P0000040?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;`3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo000D0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`800000503o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000g0?ooo`03
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E0?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000Z0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool2000002D0oooo0`0000030?ooo`03
0000003oool0oooo01T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000003H0oooo00<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo000F0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo1`00
000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0T0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000g0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0E0?ooo`00503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=`3o
ool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`0700000340oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05@3oool001D0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003oool0oooo02@0oooo0P00000C0?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo01D0oooo000Q0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01T0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool06@3oool=000000D0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0903oool2000001l0
oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0
oooo000Q0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0U0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`80
00009P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo0P00000O0?ooo`03
0000003oool0oooo03D0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`L0
0000:`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`800000
103oool00`000000oooo0?ooo`0U0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo02@0oooo0P00000O0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000340oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool001D0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool05P3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo02D0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^
0?ooo`8000005`3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02D0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0T0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000g0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01D0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3o
ool200000300oooo1`00000507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`L00000:P3oool2000002/0oooo00<000000?ooo`3oool09@3o
ool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000=P3oool00`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000<@3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`005`3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000=`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0U
0?ooo`030000003o0000o`0000<0o`00300000050?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo0P00000D
0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03D0oooo00<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`00503oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0U0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0E0?ooo`005@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03D0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo1@000002
0?ooo`800000103oool00`000000oooo0?ooo`0U0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0203oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo0P00000C
0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E
0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000002L0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`080?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000
o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool00240oooo00<00000
0?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
0P00000V0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0203oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02@0oooo0P00000O0?ooo`030000003oool0oooo03D0oooo
00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02l0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo
00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0
oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000009`3oool00`000000o`000?l000030?l000030000003oool0oooo
00P0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`8000007`3oool00`00
0000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03D0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0U0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0
oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09@3oool7000000X0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000L000001@3o00000`000000oooo
0?ooo`0T0?ooo`8000007`3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo
000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo1`00000a0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0=P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo02D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000F
0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00003
0?l000030000003oool0oooo02@0oooo0P00000B0?ooo`@000000`3oool2000000@0oooo00<00000
0?ooo`3oool0=@3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`005`3oool010000000oooo0?ooo`000002
0?ooo`050000003oool0oooo0?ooo`000000=`3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0;`3oool7000000D0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0E0?ooo`00503oool5000000050?ooo`000000oooo0?ooo`000000
0`3oool2000003H0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool200000180oooo1@0000000`3oool00000
00000002000000<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0f0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool0903oool2000001<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`800000=P3oool00`0000000?l0003o0004003o00d0
0000=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03D0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000D0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0e0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
000000/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o
0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003L0oooo00<00000003o0000
o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0E0?ooo`005@3oool00`000000oooo000000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo0?ooo`800000=`3oool00`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo
02@0oooo0P00000B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000003L0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01D0oooo000F0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool0
=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0f0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000
003oool0oooo0440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000=`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o200000050000o`030000003oool0oooo02h0oooo0P00000G0?ooo`008@3oool00`000000oooo
0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03H0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003oool0oooo00<0oooo1`00000V0?ooo`8000007`3oool00`000000oooo0?ooo`0e0?ooo`03
00000000o`000?l000@00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03D0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000
003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`800000
103oool2000000X0oooo0`0000030?ooo`030000003oool0oooo03H0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003oool0oooo0340oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0`0?ooo`8000007`3o
ool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0B0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0=@3o
ool00`000000003o0000o`030000o`L000001P3oool700000340oooo00<000000?ooo`3oool05@3o
ool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0=P3oool00`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03D0oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0
oooo0480oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`00
0000o`000?l000030?l000H00000<P3oool2000001l0oooo00<000000?ooo`3oool0=@3oool00`00
00000?l0003o0004003o00030000003oool0oooo0440oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0f0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03D0
oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480
oooo00<000000?ooo`3oool05@3oool001D0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo03D0oooo00<000000?ooo`3oool0703oool500000080oooo
0P0000040?ooo`030000003oool0oooo03H0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`0e0?ooo`8000004P3oool4000000<0oooo0P0000040?ooo`030000003oool0oooo03D0oooo
00<00000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480oooo
00<000000?ooo`3oool05@3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`L00000=`3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000
o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3o
ool00`000000003o0000o`030000o`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3o
ool001L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000003H0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03X0oooo
0P00000P0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000g0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool2000001<0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`3oool2000003H0oooo00<00000003o0000o`001000o`000`00
0000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3oool00`00
0000003o0000o`030000o`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool001D0
oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo
03H0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0=@3oool00`00
00000?l0003o0004003o00030000003oool0oooo0440oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0E0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=@3oool200000180oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo00<00000003o0000o`001000o`00
0`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3oool0
0`000000003o0000o`030000o`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool0
01D0oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01d0oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0f0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool30000
00<0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000003oool0oooo
0440oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000
oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`000000
o`000?l000030?l000030000003oool0oooo03D0oooo0P00000O0?ooo`030000003oool0oooo03D0
oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480
oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo
07moO`0307moO`P00000?@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03H0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000003oool0oooo0440oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?oo
o`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo03H0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0e0?ooo`8000007`3oool00`000000oooo0?ooo`0e0?ooo`0300000000o`000?l000@00?l000<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000@0oooo00<0
00000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480oooo00<0
00000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo0480oooo00<000000?ooo`3oool0403oool5000000<0oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03H0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000003oool0oooo0440oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480oooo00<0
00000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo0480oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0f0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool2000001l0oooo00<0
00000?ooo`3oool0=@3oool00`0000000?l0003o0004003o00030000003oool0oooo0440oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0440oooo
0P00000G0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000003L0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0e0?ooo`8000007`3oool00`000000oooo0?ooo`0e0?ooo`030000
0000o`000?l000@00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003L0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`120?ooo`030000003oool0oooo01D0oooo000Q0?ooo`03
0000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`80
0000103oool00`000000oooo0?ooo`0f0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<00000003o0000
o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03D0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`120?ooo`030000003oool0oooo01D0oooo000D0?oo
o`<00000103oool2000000@0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0480oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03H0oooo1`00000g0?ooo`8000004`3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo03D0oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0
oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`00503oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?ooo`3oool04@3o
ool2000000<0oooo100000090?ooo`<000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`0000000?l0003o0004003o0003
0000003oool0oooo0440oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`00
503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00000f0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0@@3oool2000002/0ooooN@00000D0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000003H0oooo00<0
0000003o0000o`001000o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo0480oooo00<0
00000?ooo`3oool05@3oool001@0oooo0`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0]`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000=`3oool00`0000000?l0003o0004003o00030000003oool0oooo0440oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0E0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool7000004@0oooo00<000000?ooo`3o
ool0]03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0=@3oool8000004<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e
0?ooo`L00000A03oool00`000000oooo0?ooo`0E0?ooo`005@3oool3000000<0oooo0P0000040?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2e0?oo
o`800000103oool2000000@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01D0oooo000Q0?oooh@00000``3ooon400000200ooooQ000000G0?ooo`00
o`3ooooo0?ooojT0oooo003o0?ooool0ooooZ@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568.563}, {90.6875, 13.6875}} -> {-0.332101, \
0.0929347, 0.00627186, 0.00627186}, {{42.3125, 161}, {88.8125, 15.5}} -> \
{-415.072, 1.77168, 3.20795, 0.804538}, {{172.875, 291.5}, {88.8125, 15.5}} -> \
{-1049.27, -0.190707, 3.51535, 0.255958}, {{303.375, 422}, {88.8125, 15.5}} -> \
{-1461.79, 0.885839, 3.20795, 0.40227}, {{433.875, 552.563}, {88.8125, 15.5}} -> \
{-1983.11, 0.626905, 3.20454, 0.285178}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({DispersionReport[diffs1]}\  // \ Transpose\)\  // \ 
      TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 3882.8863254429352`\)},
          {\(StandardDeviation \[Rule] 62.312810283624145`\)},
          {\(SampleRange \[Rule] 450.`\)},
          {\(MeanDeviation \[Rule] 46.497079383318976`\)},
          {\(MedianDeviation \[Rule] 35.5`\)},
          {\(QuartileDeviation \[Rule] 34.5`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats1\  = \ 
        Map[DispersionReport, beats1]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats1]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 5211.6161813704175`\), \(Variance \[Rule] 
              2442.793278284803`\), \(Variance \[Rule] 
              4014.8205128205127`\)},
          {\(StandardDeviation \[Rule] 
              72.19152430424515`\), \(StandardDeviation \[Rule] 
              49.42462218656611`\), \(StandardDeviation \[Rule] 
              63.36261131630003`\)},
          {\(SampleRange \[Rule] 450.`\), \(SampleRange \[Rule] 
              335.`\), \(SampleRange \[Rule] 359.`\)},
          {\(MeanDeviation \[Rule] 
              56.703102556736575`\), \(MeanDeviation \[Rule] 
              36.00000000000001`\), \(MeanDeviation \[Rule] 
              47.067796610169495`\)},
          {\(MedianDeviation \[Rule] 48.5`\), \(MedianDeviation \[Rule] 
              27.`\), \(MedianDeviation \[Rule] 32.`\)},
          {\(QuartileDeviation \[Rule] 49.`\), \(QuartileDeviation \[Rule] 
              25.5`\), \(QuartileDeviation \[Rule] 32.`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, and \
the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(info1\  = \ 
      Transpose[{Range[3], \ 
            N[Map[Mean, \ 
                Abs[beats1]]], \[IndentingNewLine]Map[\((StandardDeviation\  \
/. \ #)\) &, \ stats1]}]\ \  // \ TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "56.09594943981614`", "72.19152430424515`"},
          {"2", "36.08014938236139`", "49.42462218656611`"},
          {"3", "47.31513932777937`", "63.36261131630003`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2; Friedman 1930", "Subsection"],

Cell[BoxData[
    \(\(pid5667230x09corrected\  = \ {1931, 2483, 2966, 3483, 3851, 4200, 
          4697, 4957, 5485, 5850, 6146, 6570, 6974, 7346, 7692, 8118, 8465, 
          8925, 9329, 9683, 10130, 10533, 11109, 11765, 12183, 12677, 13220, 
          13750, 14088, 14438, 14892, 15058, 15531, 15911, 16217, 16639, 
          17207, 17630, 17939, 18343, 18805, 19330, 19839, 20235, 20841, 
          21461, 22224, 22889, 23495, 23892, 24332, 24829, 25276, 25672, 
          26149, 26585, 26975, 27441, 27902, 28285, 28833, 29693, 30364, 
          30819, 31315, 31705, 32195, 32706, 33090, 33620, 34136, 34654, 
          35438, 36100, 36782, 37254, 37592, 37988, 38423, 38672, 39182, 
          39606, 39977, 40298, 40829, 41250, 41628, 42151, 42730, 43289, 
          43942, 44489, 45161, 45754, 46452, 47110, 47701, 48107, 48557, 
          49084, 49524, 49900, 50339, 50738, 51104, 51544, 51960, 52305, 
          52755, 53422, 54055, 54514, 55018, 55454, 55917, 56367, 56788, 
          57286, 57845, 58400, 59273, 60025, 60843, 61396, 61722, 62178, 
          62701, 62973, 63483, 63922, 64309, 64708, 65247, 65693, 66043, 
          66474, 66941, 67623, 68365, 69201, 69931, 70547, 71097, 71549, 
          72190, 72940, 73547, 73964, 74355, 74752, 75117, 75424, 75738, 
          76122, 76443, 76746, 77123, 77437, 77746, 78129, 78417, 78766, 
          79137, 79413, 79716, 80089, 80368, 80726, 81226, 81604, 82064, 
          82408, 82714, 83061, 83434, 83745, 84101, 84478, 84738, 85106, 
          85607, 86014, 86390, 86745, 87057, 87398, 87752, 88124, 88728, 
          89208, 89603, 90218, 90866, 91498, 92532, 92877, 93262, 93627, 
          94002, 94314, 94618, 95015, 95328, 95621, 95996, 96308, 96615, 
          97007, 97297, 97625, 98014, 98292, 98604, 99049, 99358, 99673, 
          100264, 100789, 101259, 101677, 102039, 102352, 102721, 103091, 
          103443, 103792, 104056, 104412, 104922, 105369, 105762, 106117, 
          106432, 106721, 107097, 107455, 108056, 108660, 109235, 110161, 
          111006, 112101, 112923, 113484, 113968, 114368, 114733, 115094, 
          115399, 115818, 116071, 116357, 116746, 117092, 117428, 117785, 
          118084, 118397, 118735, 119084, 119389, 119840, 120129, 120544, 
          121837, 122804, 123505, 124046, 124339, 124711, 125239, 125510, 
          126026, 126420, 126813, 127259, 127705, 128099, 128396, 128932, 
          129328, 129803, 130224, 130604, 131047, 131461, 132029, 132648, 
          133429, 134285, 134863, 135392, 135684, 136017, 136545, 136719, 
          137302, 137633, 137989, 138315, 138806, 139275, 139632, 140144, 
          140677, 141250, 141940, 142520, 143596, 144552, 145720, 146582, 
          148323};\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(pid5667230x09avg = {2177, 2652, 3041, 3441, 3893, 4254, 4715, 5131, 
          5485, 5847, 6203, 6566, 7057, 7425, 7704, 8102, 8529, 8925, 9370, 
          9782, 10198, 10582, 11104, 11773, 12424, 12780, 13241, 13671, 
          14154, 14498, 14926, 15299, 15614, 15913, 16238, 16613, 17116, 
          17652, 17970, 18332, 18754, 19287, 19890, 20440, 20891, 21393, 
          22025, 22931, 23622, 24029, 24395, 24841, 25323, 25715, 26144, 
          26617, 27012, 27445, 27912, 28354, 28800, 29576, 30248, 30855, 
          31346, 31763, 32184, 32678, 33155, 33601, 34142, 34662, 35503, 
          36100, 36811, 37237, 37670, 38051, 38545, 38904, 39245, 39600, 
          39967, 40388, 40789, 41274, 41621, 42065, 42667, 43342, 43962, 
          44613, 45200, 45754, 46381, 47180, 47792, 48239, 48627, 49084, 
          49590, 49987, 50427, 50830, 51180, 51591, 52016, 52400, 52819, 
          53445, 53932, 54533, 54990, 55454, 55917, 56408, 56817, 57280, 
          57806, 58400, 59307, 60091, 60799, 61307, 61799, 62150, 62701, 
          63175, 63562, 63893, 64336, 64725, 65215, 65707, 66050, 66456, 
          66926, 67497, 68260, 68938, 69883, 70483, 71087, 71597, 72114, 
          72779, 73608, 74003, 74385, 74802, 75171, 75505, 75816, 76139, 
          76498, 76806, 77138, 77478, 77796, 78141, 78508, 78807, 79160, 
          79514, 79796, 80120, 80500, 80778, 81210, 81732, 82104, 82455, 
          82803, 83092, 83458, 83813, 84175, 84519, 84867, 85125, 85660, 
          86064, 86444, 86812, 87141, 87445, 87800, 88198, 88788, 89287, 
          89708, 90285, 90988, 91667, 92381, 93012, 93334, 93694, 94045, 
          94381, 94709, 95027, 95380, 95696, 96040, 96370, 96678, 97034, 
          97386, 97681, 98032, 98382, 98669, 99034, 99446, 99795, 100276, 
          100826, 101280, 101662, 102054, 102379, 102733, 103110, 103491, 
          103832, 104162, 104436, 104941, 105380, 105762, 106117, 106477, 
          106783, 107133, 107531, 108130, 108660, 109209, 110161, 111006, 
          111907, 112992, 113468, 113944, 114421, 114792, 115124, 115443, 
          115796, 116163, 116460, 116778, 117096, 117428, 117791, 118164, 
          118469, 118811, 119134, 119440, 119851, 120264, 120662, 122107, 
          122847, 123511, 123999, 124458, 124794, 125256, 125704, 126050, 
          126411, 126838, 127259, 127830, 128200, 128515, 128866, 129379, 
          129803, 130251, 130685, 131140, 131532, 132029, 132726, 133356, 
          134065, 134922, 135375, 135797, 136140, 136559, 136957, 137302, 
          137652, 138030, 138424, 138839, 139285, 139670, 140074, 140611, 
          141250, 141940, 142705, 143579, 144503, 145677, 146830, 
          148323};\)\)], "Input",
  FontSize->9],

Cell["\<\
Calculate the differences between the average tap times and the corrected \
data, removing the extremities:\
\>", "Text"],

Cell[BoxData[{
    \(\(diffs2\  = \ 
        pid5667230x09avg\  - \ 
          pid5667230x09corrected;\)\), "\[IndentingNewLine]", 
    \(\(diffs2\  = \ Drop[diffs2, \ 1];\)\  (*\ 
      drop\ the\ first\ pickup\ beat\ *) \), "\[IndentingNewLine]", 
    \(\(diffs2\  = \ Drop[diffs2, \ 3];\)\  (*\ 
      drop\ the\ first\ measure\ of\ the\ piece\ *) \), \
"\[IndentingNewLine]", 
    \(\(diffs2\  = \ Drop[diffs2, \ \(-3\)];\)\  (*\ 
      drop\ the\ last\ measure\ of\ the\ piece\ *) \), "\[IndentingNewLine]", \

    \(\(diffs2\  = \ N[diffs2\  - \ Mean[diffs2]];\)\  (*\ 
      estimate\ correction\ for\ alignment\ error\ *) \), \
"\[IndentingNewLine]", 
    \(\(beats2\  = \ Transpose[Partition[diffs2, \ 3]];\)\)}], "Input"],

Cell["\<\
First display a histogram of all metrical beat displacements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot2\  = \ 
        Histogram[diffs2, \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0125235 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02724 L
.09524 .02724 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02724 L
.09524 .02724 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .05229 L
.14286 .05229 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05229 L
.14286 .05229 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06481 L
.19048 .06481 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06481 L
.19048 .06481 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1149 L
.2381 .1149 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1149 L
.2381 .1149 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .08986 L
.28571 .08986 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .08986 L
.28571 .08986 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .165 L
.33333 .165 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .165 L
.33333 .165 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .5908 L
.42857 .5908 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .5908 L
.42857 .5908 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .52818 L
.47619 .52818 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .52818 L
.47619 .52818 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .52818 L
.57143 .52818 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .52818 L
.57143 .52818 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .41547 L
.61905 .41547 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41547 L
.61905 .41547 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .13995 L
.66667 .13995 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13995 L
.66667 .13995 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .19004 L
.71429 .19004 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .19004 L
.71429 .19004 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .05229 L
.7619 .05229 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05229 L
.7619 .05229 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .03976 L
.80952 .03976 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .03976 L
.80952 .03976 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03976 L
.85714 .03976 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03976 L
.85714 .03976 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .03976 L
.90476 .03976 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03976 L
.90476 .03976 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .05229 L
1 .05229 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .05229 L
1 .05229 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<0000007mo
O`1oOgl02P1oOgl>000000/0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl>000000`0Ogmo00<000000?oo
o`3oool00@3oool00140oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0:0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool00@3oool00140oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
0@3oool00140oooo3P00000<0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
OglW000000`0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo0300oooo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`d00000301oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo3@00000b0?ooo`h000000`3oool00140oooo00<0
00000?ooo`3oool08`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000002@0oooo3P00000<07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0B03oool2000000<0oooo000A0?ooo`030000003oool0oooo0300oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0300oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000<@3oool00`000000Ogmo07moO`0:07moO`h000002`1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B03oool2000000<0oooo
000A0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`0:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0`0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0300oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000
003oool0oooo00X0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool200000340oooo3P00000<0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0BP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04X0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo
00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?oo
o`1:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0BP3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000BP3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`h00000301oOgl00`000000oooo0?ooo`170?ooo`<000000`3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0BP3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo04X0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool02P3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0BP3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo00X0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04X0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004/0oooo3@00000<07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0B03oool2000000<0oooo000A0?ooo`030000003oool0
oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0:07moO`030000003oool0
oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo00X0
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo
07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0:0?oo
o`h00000BP3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001G0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo0004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000005H0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0H@3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3o
ool>000000`0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0680
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001S0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1Q0?ooo`<000000`3oool000H0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool0
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`d00000I03oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0KP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00050?ooo`<000000P3o
ool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00030?ooo`D0000000D0oooo
0000003oool0oooo000000040?ooo`<00000H`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo06d0oooo0`0000030?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00050?ooo`8000000`3o
ool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000Ogmo07moO`0:07moO`d00000301oOgl>00000740oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000
003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo
07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo3P00000;0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo07`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo07`0oooo3P00001n0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00
4@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {268.625, 127.313}} -> {-280.554, \
42.919, 1.57972, 0.300334}}]
}, Open  ]],

Cell["\<\
Now display separate histograms for individual metrical position in the \
meter:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot21\  = \ 
        Histogram[beats2[\([1]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .4856 L
.57143 .4856 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .4856 L
.57143 .4856 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .0932 L
.90476 .0932 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0932 L
.90476 .0932 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0932 L
1 .0932 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0932 L
1 .0932 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0:
0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000o`000?l0000:0?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000T0o`0000<000000?oo
o`3oool02P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool00@3oool00140oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0:0?ooo`03
0000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0
2P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
0@3oool00140oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0:0?ooo`030000003o
0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool0
0140oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`00
00T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`0:0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo
3P00000<0?ooo`d00000303oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o000>000000`0o`0000<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0<03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0<03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0<03oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo0P00000a0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0`0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`010?ooo`002@3oool4000000@0oooo00<000000?ooo`3oool0<03oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?oo
o`040?ooo`<00000<03ooolK000000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l003<00000303oool>000000<0oooo000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0BP3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0BP3oool00`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`1:0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0BP3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
B`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`180?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0BP3o
ool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04X0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1:0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0BP3oool00`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000B`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`180?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0BP3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04X0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0BP3oool00`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000B`3oool00`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`180?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0BP3oool00`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04X0oooo00<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo
04T0oooo00<000000?ooo`3oool00@3oool000/0oooo0`0000030?ooo`030000003oool0oooo04X0
oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`00303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo04X0oooo00<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`010?ooo`002@3oool5000000<0oooo0`00001:0?oooaX00000303o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`170?ooo`<000000`3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`010?ooo`002P3oool00`000000oooo000000040?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000;0?oo
o`800000103oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`180?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo
04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B03oool2000000<0oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
I03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04P0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`002@3oool3000000D0oooo00<000000?ooo`3oool0H`3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000T0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo
0?ooo`0000040?ooo`<00000H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o000>000004T0oooo0`0000030?ooo`002@3oool3000000D0oooo
00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000:0?ooo`<00000103oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000I03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`003P00001G0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo06<0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo
000000@0oooo0`00001S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`1Q0?ooo`<000000`3oool000X0oooo0P0000050?ooo`030000003oool0oooo
06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000
oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool>
000000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo
0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3oool00`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1`0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000
003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`<00000L03oool00`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo0640oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3oool00`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1`0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool200000740oooo00<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
L03oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool0
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0L03oool00`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo00030?ooo`D0000000<0oooo0000000000000P000004
0?ooo`030000003oool0oooo0700oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`1`0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo0`00001`0?ooobL000002`3o00000`000000oooo0?ooo`1Q0?ooo`<000000`3oool000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09H0
oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040
oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo09H0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
UP3oool00`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l000090?l000030000003o
ool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00002G0?ooo`030000003o0000
o`0000T0o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo
09H0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo09H0oooo00<000000?l0003o00002@3o00000`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo09H0oooo
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo09H0oooo00<000000?l0003o00002@3o00000`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo09H0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000U`3oool00`000000o`000?l000090?l000030000003oool0oooo0680oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`2F0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`2F0?ooo`030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`2F0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`2F0?ooo`030000003o0000
o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
09L0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l000090?l000030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0UP3oool00`000000o`00
0?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000<0oooo1@00
00030?ooo`<000000`3oool00`000000oooo0?ooo`2F0?ooo`030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l00009
0?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00@000000?oo
o`3oool0oooo1@0000030?ooo`<00000UP3oool00`000000o`000?l000090?l000030000003oool0
oooo0640oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2F0?ooo`030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l000090?l0
00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000050?ooo`80
0000103oool00`000000oooo0?ooo`2F0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`2F0?ooo`030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000009L0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l000090?l000030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0UP3oool00`00
0000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0UP3oool00`000000o`000?l000090?l000030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0UP3oool00`000000o`00
0?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0UP3oool00`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00002G0?ooo`d00000I03oool2000000<0oooo000A0?oo
o`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {466.25, 324.938}} -> {-280.554, \
37.3759, 1.57972, 0.0958514}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot22\  = \ 
        Histogram[beats2[\([2]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0245252 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13734 -6 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13734 m
.00625 .13734 L
s
[(5)] -0.0125 .13734 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(10)] -0.0125 .25997 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(15)] -0.0125 .38259 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(20)] -0.0125 .50522 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .11282 m
.00375 .11282 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .21092 m
.00375 .21092 L
s
0 .23544 m
.00375 .23544 L
s
0 .28449 m
.00375 .28449 L
s
0 .30902 m
.00375 .30902 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .40712 m
.00375 .40712 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13734 m
1 .13734 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .50522 m
1 .50522 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .03924 L
.04762 .03924 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03924 L
.04762 .03924 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .06377 L
.14286 .06377 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .06377 L
.14286 .06377 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .03924 L
.28571 .03924 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .03924 L
.28571 .03924 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .06377 L
.38095 .06377 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .06377 L
.38095 .06377 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .43164 L
.42857 .43164 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .43164 L
.42857 .43164 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .28449 L
.47619 .28449 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .28449 L
.47619 .28449 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .50522 L
.52381 .50522 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .50522 L
.52381 .50522 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .08829 L
.66667 .08829 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .08829 L
.66667 .08829 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool05`3oool00`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o00030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`000000oooo0?ooo`0G0?ooo`0300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000003o
0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?oo
o`3oool05`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool05`3oool00`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
0000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
5`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo04T0oooo00<000000?ooo`3oool0
0@3oool00140oooo6`00000;003o00030000003oool0oooo01L0oooo3P00000;003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`180?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool05`3oool00`0000000?l0003o0009003o00030000003oool0
oooo02@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0G0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0903oool00`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01L0
oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo04T0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool00`0000000?l0
003o0009003o00030000003oool0oooo02@0oooo00<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`0300000000o`000?l000T00?l000<0
00000?ooo`3oool0903oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo01L0oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`0T
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o00030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000H0?oo
o`d000009P3oool00`0000000?l0003o0009003o00h000003000o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`180?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0BP3oool00`0000000?l0003o0009003o0003
0000003oool0oooo00X0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04X0oooo00<00000003o0000o`00
2@00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`0300000000
o`000?l000T00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003o
ool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0BP3oool0
0`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04X0oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004/0
oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`0>000000`00?l000<000000?ooo`3oool0B03oool2000000<0
oooo000A0?ooo`030000003oool0oooo04X0oooo00<00000003o0000o`002@00o`000`000000oooo
0?ooo`0:0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`0:0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`0300000000o`000?l000T00?l000<0
00000?ooo`3oool02P3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool02P3oool00`0000000?l0003o000:003o00030000003oool0oooo04T0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0BP3oool00`0000000?l0003o0009
003o00030000003oool0oooo00X0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo00X0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04X0oooo00<00000003o
0000o`002@00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000X00?l000<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1:0?ooo`03
00000000o`000?l000T00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o000:003o0003
0000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
BP3oool00`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000o`00
2P00o`000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000B`3o
ool=000000`0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003o
ool0oooo00X0oooo3P00001:0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000X0oooo
0P0000050?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000T0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000<0?ooo`030000003oool0oooo0080oooo0`00001S0?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1Q0?ooo`<000000`3oool000X0oooo0P000005
0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000:0?ooo`<0
0000103oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000I03oool00`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0
oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000I03oool00`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003o
ool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo0680oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
06@0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo
0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P000005
0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool3000006<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo0640oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
0000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000I03oool00`0000000?l0003o000:003o00d000003000o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0HP3oool2
000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`00
0000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0
oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
0000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:
003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`0=000006@0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
0000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3o
ool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`00
00000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X0
0?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo
00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l0
00<00000003o0000o`002P00o`000`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:
003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:
003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o
0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
0000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001T0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3o
ool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0KP3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`00
0`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000003o0000o`002P00o`000`000000
oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo
00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l0
00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o
000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o
000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3o
ool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00
o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<00000H`3oool0
0`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o00030000003oool0oooo06d0oooo0`0000030?ooo`001@3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l0
00X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0H`3oool00`000000
0?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo
0P0000040?ooo`<00000103oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l0
00<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l0
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000o`000?l000X00?l000<00000
0?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<00000003o
0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000
o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o00030000
003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00
o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o00030000003oool0
oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
00000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`00
00000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0
oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`h000002`3oool00`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<000000?ooo`3oool0KP3oool2000000<0oooo
000A0?ooo`030000003oool0oooo07`0oooo00<00000003o0000o`002P00o`000`0000000?l0003o
000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0O03oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?oo
o`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000003o0000
o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`0000000?l0003o000:003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000007d0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003o
ool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`0300000000o`00
0?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000003o0000o`002P00o`000`00
00000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0O03oool00`0000000?l0003o000:003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1l0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`0000000?l0003o000:
003o000300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000007d0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o
00030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0O03oool00`0000000?l0003o000:003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000`3oool4
000000<0oooo0P0000050?ooo`030000003oool0oooo07`0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo07`0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`<00000O03oool>000000`00?l000<000000?ooo`3oool0K@3oool3
000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`290?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo08T0oooo00<00000003o
0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`00
2P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000RP3o
ool00`0000000?l0003o000:003o00030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`290?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`290?ooo`0300000000o`000?l0
00X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`290?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`290?ooo`0300000000o`000?l000X00?l0
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`290?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`290?ooo`0300000000o`000?l000X00?l000<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000008X0oooo00<00000003o
0000o`002P00o`000`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0R@3oool00`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0R@3oool00`0000000?l0003o000:003o00030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0R@3o
ool00`0000000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0R@3oool00`0000000?l0003o000:003o00030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0R@3oool00`00
00000?l0003o000:003o00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00002:0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0KP3oool2000000<0
oooo000A0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo08T0oooo00<0
0000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo08T0oooo00<00000003o
0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo08T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo08T0oooo00<00000003o0000o`00
2P00o`000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000RP3o
ool>00000700oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool00140ooooo`00000=000000<0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {-280.554, \
0.133864, 1.57972, 0.153362}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot23\  = \ 
        Histogram[beats2[\([3]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .1913 L
.2381 .1913 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1913 L
.2381 .1913 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .10301 L
.28571 .10301 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10301 L
.28571 .10301 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .13244 L
.33333 .13244 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .13244 L
.33333 .13244 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .45617 L
.38095 .45617 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .45617 L
.38095 .45617 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .54446 L
.47619 .54446 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .54446 L
.47619 .54446 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .16187 L
.57143 .16187 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .16187 L
.57143 .16187 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .16187 L
.61905 .16187 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .16187 L
.61905 .16187 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .01472 L
.66667 .01472 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04415 L
.7619 .04415 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04415 L
.7619 .04415 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .04415 L
1 .04415 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04415 L
1 .04415 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003H0oooo1@0000020?oo
o`800000103oool200000340oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003L0oooo0P0000040?ooo`80
0000103oool200000380oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000B0?ooool00000
2`0000040?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0
oooo0080oooo000:0?ooo`040000003oool0oooo000000@0ooooo`00000;000000@0oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo0300oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`02
0?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02<0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`0`0?ooo`03000000000?l0003o00T0003o00<00000
0?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000003oool0oooo02<0oooo00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`0`0?ooo`03000000000?l0003o00T0003o00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
0000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo0300oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
2P3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0
<03oool00`000000003o0000o`090000o`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo02<0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0`0?ooo`0300000000
0?l0003o00T0003o00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo0300oooo00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`020?ooo`004P3oool2000002@0oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o3P00000b0?ooo`d00000103oool00180
oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0
oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo02<0oooo00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo
0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02<0oooo00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000T0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000
003oool0oooo04P0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
02<0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o
00T0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000
003o0000o`090000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool08`3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0oooo
00<000000000o`000?l02@000?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo02<0oooo00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00P3oool00180oooo0P00000T0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l>000000/0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000
o`030000003oool0oooo04P0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
8`3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0
2P3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo02<0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`004P3oool0
0`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool0
0`000000003o0000o`090000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo
00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo02<0oooo00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo04T0oooo
00<000000?ooo`3oool00P3oool00180oooo0P00000T0?ooo`d0000030000?l00`000000oooo0?oo
o`0:0?ooo`d0000030000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool02P3oool=000004X0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02l0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo0680oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo01H0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
5P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo02l0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo0680oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000003oool0
oooo02l0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0
oooo0680oooo00<000000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000003oool0oooo
0080oooo0`00000_0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000oaX00000H`3oool2000000@0oooo000;0?ooo`8000001@3oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`000000
003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool000/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool05P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo
00<000000?ooo`3oool00P3oool000/0oooo0`0000040?ooo`030000003oool0oooo02l0oooo00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`0:0000o`030000003oool0oooo01H0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
5P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000`0?ooo`h00000603oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo07X0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`02
0?ooo`004P3oool2000005H0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1j0?oo
o`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo
07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo
00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0NP3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`000000
003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`030000003oool0oooo07X0oooo0P0000040?ooo`004P3oool00`000000oooo
0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00
103oool500000080oooo0P0000050?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo00060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05D0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000
E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07X0oooo0P0000040?ooo`001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07X0oooo0P00
00040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1j0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
E@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00001F0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0NP3o
ool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1k0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo07X0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00103oool500000080oooo
0P0000050?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0080oooo00060?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05D0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo00060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000005D0oooo3P00000<0000o`0300000000
0?l0003o00T0003o3P00001l0?ooo`800000103oool000H0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo00<000000?ooo`3oool0HP3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0HP3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo0680
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo08P0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`280?ooo`030000003oool0oooo0080oooo000B
0?ooo`030000003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo08P0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0HP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`020?ooo`004P3oool2000006<0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo08L0oooo0P0000040?ooo`00
4P3oool00`000000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`280?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo0680oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`030000003oool0oooo08P0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0HP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1R0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`280?ooo`030000003oool0oooo0080oooo000B0?ooo`800000H`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0Q`3oool2000000@0oooo000B0?oo
o`030000003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0HP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`280?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`030000003oool0oooo08P0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0HP3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo0080oooo000B0?ooo`800000H`3oool00`000000
003o0000o`0:0000o`d00000R@3oool2000000@0oooo000B0?ooo`030000003oool0oooo0680oooo
00<000000000o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo0680oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000H`3oool0
0`000000003o0000o`0:0000o`030000003oool0oooo09<0oooo0P0000040?ooo`004P3oool00`00
0000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`02
0?ooo`00103oool4000000<0oooo0P0000050?ooo`030000003oool0oooo0680oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1R0?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00001R0?oo
o`h00000U@3oool2000000@0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`020?oo
o`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00050?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00180ooooo`00000;000000@0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {-281.593, \
27.5416, 1.58543, 0.128263}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{plot2, \ plot21, \ plot22, \ plot23}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0125235 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02724 L
.09524 .02724 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02724 L
.09524 .02724 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .05229 L
.14286 .05229 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05229 L
.14286 .05229 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06481 L
.19048 .06481 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06481 L
.19048 .06481 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1149 L
.2381 .1149 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1149 L
.2381 .1149 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .08986 L
.28571 .08986 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .08986 L
.28571 .08986 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .165 L
.33333 .165 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .165 L
.33333 .165 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .5908 L
.42857 .5908 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .5908 L
.42857 .5908 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .52818 L
.47619 .52818 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .52818 L
.47619 .52818 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .52818 L
.57143 .52818 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .52818 L
.57143 .52818 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .41547 L
.61905 .41547 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41547 L
.61905 .41547 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .13995 L
.66667 .13995 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13995 L
.66667 .13995 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .19004 L
.71429 .19004 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .19004 L
.71429 .19004 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .05229 L
.7619 .05229 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05229 L
.7619 .05229 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .03976 L
.80952 .03976 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .03976 L
.80952 .03976 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03976 L
.85714 .03976 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03976 L
.85714 .03976 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .03976 L
.90476 .03976 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03976 L
.90476 .03976 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .05229 L
1 .05229 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .05229 L
1 .05229 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .4856 L
.57143 .4856 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .4856 L
.57143 .4856 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .0932 L
.90476 .0932 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0932 L
.90476 .0932 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0932 L
1 .0932 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0932 L
1 .0932 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0245252 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13734 -6 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13734 m
.00625 .13734 L
s
[(5)] -0.0125 .13734 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(10)] -0.0125 .25997 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(15)] -0.0125 .38259 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(20)] -0.0125 .50522 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .11282 m
.00375 .11282 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .21092 m
.00375 .21092 L
s
0 .23544 m
.00375 .23544 L
s
0 .28449 m
.00375 .28449 L
s
0 .30902 m
.00375 .30902 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .40712 m
.00375 .40712 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13734 m
1 .13734 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .50522 m
1 .50522 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .03924 L
.04762 .03924 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03924 L
.04762 .03924 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .06377 L
.14286 .06377 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .06377 L
.14286 .06377 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .03924 L
.28571 .03924 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .03924 L
.28571 .03924 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .06377 L
.38095 .06377 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .06377 L
.38095 .06377 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .43164 L
.42857 .43164 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .43164 L
.42857 .43164 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .28449 L
.47619 .28449 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .28449 L
.47619 .28449 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .50522 L
.52381 .50522 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .50522 L
.52381 .50522 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .08829 L
.66667 .08829 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .08829 L
.66667 .08829 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .1913 L
.2381 .1913 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1913 L
.2381 .1913 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .10301 L
.28571 .10301 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10301 L
.28571 .10301 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .13244 L
.33333 .13244 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .13244 L
.33333 .13244 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .45617 L
.38095 .45617 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .45617 L
.38095 .45617 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .54446 L
.47619 .54446 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .54446 L
.47619 .54446 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .16187 L
.57143 .16187 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .16187 L
.57143 .16187 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .16187 L
.61905 .16187 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .16187 L
.61905 .16187 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .01472 L
.66667 .01472 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04415 L
.7619 .04415 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04415 L
.7619 .04415 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .04415 L
1 .04415 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04415 L
1 .04415 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00>`3oool500000080oooo
0P0000040?ooo`800000503oool2000001H0oooo1@0000020?ooo`800000103oool200000140oooo
100000030?ooo`800000103oool2000003T0oooo1@0000020?ooo`800000103oool2000001D0oooo
0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo
0P00000j0?ooo`D000000P3oool2000000@0oooo0P00000D0?ooo`8000005`3oool500000080oooo
0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`800000>P3oool500000080oooo
0P0000040?ooo`800000503oool2000001D0oooo1@0000020?ooo`800000103oool2000000l0oooo
100000030?ooo`800000103oool2000001T0oooo000m0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000603oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000H0?oo
o`00?@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0A0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo000001P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003o
ool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000603oool003D0oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo
00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0300oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0340oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0340oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0100oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01H0
oooo000m0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000k0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000k0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000H0?ooo`00?03oool2000000@0
oooo0P0000040?ooo`800000503oool2000001L0oooo0P0000040?ooo`800000103oool200000180
oooo0P0000040?ooo`800000103oool2000003X0oooo0P0000040?ooo`800000103oool2000001D0
oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000103oool2000000@0
oooo0P00000k0?ooo`800000103oool2000000@0oooo0P00000D0?ooo`800000603oool2000000@0
oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000>`3oool2000000@0
oooo0P0000040?ooo`800000503oool2000001H0oooo0P0000040?ooo`800000103oool200000100
oooo0P0000040?ooo`800000103oool2000001T0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3o
oonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool001/0oooo0P0000030?ooohD0
00006@3oool2000000@0ooooQ@00000I0?ooo`800000103ooon4000001`0oooo0P0000030?oooh00
00006@3oool001X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool001X0oooo00@00000
0?ooo`3oool000000P3ooon5000001P0oooo00@000000?ooo`3oool000000`3ooon5000001P0oooo
00@000000?ooo`3oool000000`3ooon4000001/0oooo00@000000?ooo`3oool000000P3ooon00000
01T0oooo000J0?ooo`040000003oool0oooo00000080oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`0000030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool0
0`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000040?l000030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo01D0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`030000
001oOgl0Ogmo00@0Ogmo1`00000507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo2000000507moO`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000o`000?l000030?l00003
0000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0F0?ooo`04
0000003oool0oooo000000<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
00030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool05`3oool001/0oooo0P0000030?oo
o`P000001@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo4`0000060?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?oo
o`3oool05`3oool2000000@0oooo3@000005003o00030000003oool0oooo00X0oooo1`000005003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01X0oooo0P0000030?ooo`030000003oool0oooo00l0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool05`3oool00200oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05P3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo01d0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0403oool00`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01l0oooo0P00000@0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`030000o`L000005`3oool7000001T0oooo000P0?ooo`030000
003oool0oooo00X0oooo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl8000001P0oooo1`00000O0?ooo`L000001P3oool7000000D0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`001`0000060?l000030000
003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000
003oool0oooo0100oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00803o
ool200000140oooo2000000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01H0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000040?l000030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3o
ool700000180oooo00<00000003o0000o`000`00o`08000000D00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool05P3oool00`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000
o`0000@0o`0000<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0
oooo0280oooo00<000000?ooo`3oool07`3oool200000100oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01H0oooo100000030?ooo`8000005`3oool00`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00@0o`0000<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo
0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo
0240oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool05`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0R0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0103oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o00030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0?0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`030000o`030000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool00200oooo
0P00000H0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool00`3oool2000001L0oooo3P0000050?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o000J000000D0oooo2000000O0?ooo`030000003oool0oooo0280oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`040?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`07000000H00?l000<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool0103oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0004003o00030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool200000100oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`P000001@000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0G
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0S0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0R0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0004003o00030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0?0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`040?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`030000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool00200oooo0P00000H
0?ooo`L000001@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo0P000004
0?ooo`800000903oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`8000007`3oool00`000000oooo0?ooo`0R
0?ooo`L000001P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool00`3oool8000002@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`04
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`030000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool001@0oooo1@0000020?oo
o`8000000`3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0S0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo00<000000?oo
o`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?oo
o`005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000009@3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo0P00000T0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0
oooo0280oooo0P00000H0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0O0?ooo`800000403oool7000000D0003o00<000000?ooo`3oool0103o
ool7000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo00<0oooo1`00000S0?ooo`030000003oool0oooo01L0oooo000F0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000002@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl7000000D0Ogmo00<000000?ooo`3oool08P3oool2000001l0oooo00<000000?ooo`3oool08`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0^0?ooo`8000008@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01L0oooo
000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000U0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3o
ool0;`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0J0?ooo`8000000`3oool00`000000oooo0?ooo`0E0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01L0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000U0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool20000
02@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool08P3oool2000001T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool02P3oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01L0oooo000E0?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01P0oooo0`0000020?ooo`030000003oool0oooo02<0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0G0?ooo`<000000`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool00P00000F0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`d00000;`3oool00`000000oooo0?ooo`0G0?oo
o`00803oool2000002@0oooo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0J0?ooo`8000000`3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
03T0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0F0?ooo`D000000P3oool2000002@0oooo3@0000050?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo0280
oooo0P00000O0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
0?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo02l0
oooo00<000000?ooo`3oool06P3oool300000080oooo0P00000F0?ooo`L00000303oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00200oooo
0P00000Z0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo00<0oooo1`00000U0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`0000000`3oool200000300oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0R0?ooo`8000007`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0:03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo
00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01P0oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000P
0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`800000:P3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool08P3oool2000001l0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?oo
o`800000:@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?oo
o`3oool05`3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0
:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo0P00000`0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool2000001l0oooo00<000000?ooo`3oool0
;`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003o
ool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0F0?ooo`<00000103o
ool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0G0?ooo`00803oool2000002X0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo00<000000?ooo`3oool0403o
ool500000080oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool07`3o
ool2000002T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01L0oooo000D0?ooo`@000000`3oool2000000<0oooo00<000000?ooo`3oool0:@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3o
ool200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`001`00000T0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0:03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool05`3oool001@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0F0?ooo`<0
0000103oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003oool0oooo02T0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^
0?ooo`8000008@3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo0P00000Z0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo0P00000I
0?ooo`030000003oool0oooo00<0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo02P0oooo0P00000D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0G0?ooo`005P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000:`3oool8000000D0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo0`0000030?ooo`03
0000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<00000
0?ooo`3oool07`3oool2000002T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01L0oooo000D0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l01`00
0005003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01<0oooo1@0000020?ooo`8000000`3oool00`000000oooo0?oo
o`0X0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0G0?ooo`005@3oool2000000@0oooo0P0000030?ooo`800000<@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M
0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`002000000Z
0?ooo`8000007`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002X0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003o
ool0oooo0300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000002T0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003o
ool0oooo0300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Z0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0G0?ooo`00803oool200000340oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02l0oooo
00<000000?ooo`3oool05`3oool2000000@0oooo0P00000`0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`8000007`3oool00`000000oooo
0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0
003o0003003o000300000000o`000?l000@00?l01`00000a0?ooo`030000003oool0oooo01D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002X0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000P0?ooo`03
0000003oool0oooo0300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?oo
o`800000103oool2000000<0oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3o
ool0<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo0P00000`0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?oo
o`8000007`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`800000:@3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3o
ool0<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
0000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0X0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0G0?ooo`00
803oool200000340oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02l0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo02P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01L0oooo000P0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
5`3oool2000000@0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0_0?ooo`8000007`3oool00`000000oooo0?ooo`0_0?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo01L0oooo000P0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3o
ool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0004003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3o
ool2000002T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01L0oooo000P0?ooo`800000<@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`800000<03oool7
000000H0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;`3oool200000180oooo1@0000020?ooo`800000103oool0
0`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000E0?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03D0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<@3o
ool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0004003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0G0?ooo`00503oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03D0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000340
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0d0?ooo`8000008@3oool00`000000
oooo0?ooo`0X0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0G0?ooo`005P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P00000a0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0^0?ooo`8000007`3oool2000003H0oooo00<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0_0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0O0?ooo`800000:@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0
oooo00<000000?ooo`3oool05`3oool001L0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000b0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`800000103oool00`00
0000oooo0?ooo`0e0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01L0oooo000D0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
=`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?ooo`3oool0
4@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
1000o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
:03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
5`3oool001D0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0`0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`80
0000=P3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo0P00000O0?ooo`03
0000003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01l0oooo0P00000Y0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0G0?ooo`00803oool200000340oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl700000340oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000g0?ooo`030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0:03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?oo
o`3oool05`3oool00200oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool0oooo0P00000f0?ooo`030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0;`3oool2000001l0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003
003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004
003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool500000080oooo0P000003
0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003oool0oooo0300oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0e0?ooo`030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo1`0000050?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000002X0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01L0oooo000P0?ooo`800000<@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo03D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0
oooo03D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00800000:@3oool7000000D0003o00<000000000o`000?l00`000?l7000003/0oooo00<00000
0?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo03D0oooo00<000000?ooo`3oool07@3oool2000003H0oooo00<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0_0?ooo`8000007`3oool00`000000oooo0?ooo`0k0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?oo
o`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0`0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03D0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo01L0oooo000P0?ooo`800000<@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo03D0oooo00<000000?ooo`3oool07@3oool2000003H0oooo00<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0_0?ooo`8000007`3oool00`000000oooo0?ooo`0k0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo01@0oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo01L0oooo000P0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0100oooo1@0000000`3oool000000000
0002000000<0oooo00<000000?ooo`3oool0=@3oool00`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0k0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01l0oooo0P00000_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003oool0
oooo0300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo03D0oooo00<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0>`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool05`3oool00200oooo0P00000a0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000003H0oooo500000050?l000030000003oool0oooo02l0oooo0P00000B
0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0>`3oool00`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo03l0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?oo
o`3oool0<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0B03oool00`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0>`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool05`3oool001H0oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`0`0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000004T0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`8000004`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>`3oool7000000H00?l0
00<000000?ooo`3oool0=03oool200000240oooo0P00000_0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01L0oooo
000G0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000<P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo04P0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000@`3oool00`0000000?l0003o0004003o00030000003oool0
oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo01L0oooo000D0?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`800000<@3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo0P00000O0?ooo`030000003oool0
oooo04P0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0440oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0G0?ooo`00503o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0<03oool00`000000Ogmo07moO`0307moO`L000001@1oOgl8000003L0oooo00<000000?ooo`3o
ool07@3oool2000004T0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`80
00004`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0440oooo00<00000003o0000
o`001000o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo0P00000_0?ooo`03
000000000?l0003o00<0003o1`0000110?ooo`030000003oool0oooo01L0oooo000E0?ooo`030000
003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`180?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0440oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool001H0oooo0P0000030?ooo`800000
0`3oool200000340oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04P0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0@@3oool00`0000000?l0003o0004003o00030000
003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00803o
ool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool0403o
ool5000000<0oooo0`0000020?ooo`800000B@3oool00`000000o`000?l000030?l000030000003o
ool0oooo02l0oooo0P00000O0?ooo`030000003oool0oooo0440oooo00<00000003o0000o`001000
o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;P3o
ool00`000000003o0000o`030000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool05`3o
ool00200oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000004X0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0@@3oool00`0000000?l0003o0004003o00030000003oool0oooo03D0oooo00<0
00000?ooo`3oool07`3oool2000002l0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01L0oooo000P0?ooo`800000<@3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0oooo1@0000020?ooo`800000B@3o
ool00`000000o`000?l000030?l000030000003oool0oooo02l0oooo0P00000O0?ooo`030000003o
ool0oooo0440oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0<03oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000BP3oool00`000000o`000?l000030?l000030000
003oool0oooo0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`110?ooo`030000
0000o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?ooo`@00000
0`3oool2000000<0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool00200oooo00<000000?ooo`3oool0<03o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo04P0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@@3o
ool00`0000000?l0003o0004003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;P3oool00`000000003o0000o`030000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
5`3oool00200oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0140oooo0P0000050?ooo`8000000`3oool2000004T0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0_0?ooo`8000007`3oool00`000000oooo0?ooo`110?ooo`0300000000
o`000?l000@00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool2000002l0oooo1`0000170?ooo`030000
003oool0oooo01L0oooo000P0?ooo`800000<@3oool7000000D0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0B03o
ool00`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`110?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`00803oool00`000000oooo0?ooo`0l0?ooo`L00000?P3oool00`000000oooo
0?ooo`0M0?ooo`800000B@3oool700000340oooo0P00000O0?ooo`030000003oool0oooo0440oooo
2000000g0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?oooh0000006@3oool00200oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000W03oool00200oooo
Q@00000O0?ooohD000007`3ooon400000;X0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX
0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 568}, {432.813, 355.813}} -> {-0.329896, \
2.77514, 0.00627186, 0.00627186}, {{42.0625, 160.688}, {430.938, 357.625}} -> \
{-413.508, 261.886, 3.20454, 0.609243}, {{172.563, 291.25}, {430.938, \
357.625}} -> {-936.374, 83.5806, 3.20454, 0.194439}, {{303.063, 421.75}, \
{430.938, 357.625}} -> {-1459.12, 133.729, 3.20454, 0.311103}, {{433.625, \
552.25}, {430.938, 357.625}} -> {-2047.13, 115.14, 3.31002, 0.267786}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({DispersionReport[diffs2]}\  // \ Transpose\)\  // \ 
      TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 4806.565305903784`\)},
          {\(StandardDeviation \[Rule] 69.32939712635459`\)},
          {\(SampleRange \[Rule] 533.`\)},
          {\(MeanDeviation \[Rule] 49.40142680165755`\)},
          {\(MedianDeviation \[Rule] 37.5`\)},
          {\(QuartileDeviation \[Rule] 35.`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats2\  = \ 
        Map[DispersionReport, beats2]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats2]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 7901.499902931468`\), \(Variance \[Rule] 
              2524.8581828771116`\), \(Variance \[Rule] 
              3578.662104445736`\)},
          {\(StandardDeviation \[Rule] 
              88.89038138590399`\), \(StandardDeviation \[Rule] 
              50.24796695267493`\), \(StandardDeviation \[Rule] 
              59.821919932795005`\)},
          {\(SampleRange \[Rule] 504.`\), \(SampleRange \[Rule] 
              274.`\), \(SampleRange \[Rule] 375.`\)},
          {\(MeanDeviation \[Rule] 
              62.33256439830833`\), \(MeanDeviation \[Rule] 
              37.13264129181081`\), \(MeanDeviation \[Rule] 
              41.59765474817378`\)},
          {\(MedianDeviation \[Rule] 39.`\), \(MedianDeviation \[Rule] 
              26.`\), \(MedianDeviation \[Rule] 28.5`\)},
          {\(QuartileDeviation \[Rule] 40.5`\), \(QuartileDeviation \[Rule] 
              30.5`\), \(QuartileDeviation \[Rule] 29.`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, and \
the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(info2\  = \ 
      Transpose[{Range[3], \ 
            N[Map[Mean, \ 
                Abs[beats2]]], \[IndentingNewLine]Map[\((StandardDeviation\  \
/. \ #)\) &, \ stats2]}]\ \  // \ TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "64.62360630526717`", "88.89038138590399`"},
          {"2", "37.88831218762012`", "50.24796695267493`"},
          {"3", "45.69236191208512`", "59.821919932795005`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3; Friedman 1930", "Subsection"],

Cell[BoxData[
    \(\(pid5667230x10corrected\  = \ {2262, 2859, 3250, 3559, 3897, 4205, 
          4575, 4941, 5285, 5582, 5935, 6297, 6664, 7020, 7306, 7579, 7956, 
          8318, 8615, 8870, 9242, 9624, 9997, 10386, 11103, 11860, 12188, 
          12483, 12736, 13118, 13378, 13678, 13961, 14296, 14566, 14843, 
          15200, 15489, 15724, 16025, 16245, 16583, 16930, 17280, 17505, 
          17804, 18154, 18512, 19505, 19960, 20270, 20516, 20783, 21181, 
          21486, 21763, 22025, 22360, 22568, 22921, 23268, 23509, 23792, 
          24080, 24331, 24675, 24932, 25186, 25462, 25697, 26146, 26427, 
          26883, 27268, 27625, 28049, 28265, 28604, 28884, 29170, 29428, 
          29704, 29978, 30217, 30527, 30872, 31187, 31397, 31619, 31959, 
          32207, 32526, 32801, 33026, 33258, 33613, 33857, 34084, 34466, 
          34703, 34979, 35307, 35545, 35766, 36123, 36286, 36597, 36839, 
          37152, 37526, 37937, 38181, 38412, 38798, 39043, 39252, 39609, 
          39855, 40062, 40409, 40705, 41036, 41363, 41693, 42067, 42441, 
          42759, 43049, 43399, 43728, 43994, 44307, 44597, 44912, 45248, 
          45533, 45864, 46246, 46569, 46906, 47272, 47543, 47824, 48192, 
          48491, 48825, 49133, 49439, 49806, 50164, 50463, 50778, 51133, 
          51456, 51698, 52042, 52333, 52659, 52989, 53267, 53607, 53965, 
          54222, 54607, 55039, 55422, 55880, 56337, 57093, 57662, 58319, 
          58605, 58839, 59358, 59669, 60007, 60345, 60682, 60992, 61387, 
          61742, 62047, 62382, 62634, 62876, 63252, 63526, 63877, 64212, 
          64573, 64951, 65227, 65639, 66011, 66434, 66698, 66941, 67283, 
          67574, 67930, 68281, 68614, 68909, 69320, 69672, 70018, 70396, 
          70615, 71006, 71411, 71778, 72170, 72533, 73005, 73452, 73862, 
          74473, 74995, 75833, 76442, 77007, 77448, 77908, 78369, 78724, 
          79113, 79551, 79943, 80254, 80678, 80995, 81285, 81686, 82030, 
          82292, 82831, 83111, 83335, 83652, 83981, 84308, 84638, 84947, 
          85172, 85569, 85836, 86195, 86526, 86855, 87190, 87511, 87907, 
          88599, 89405, 89741, 90029, 90270, 90636, 90923, 91187, 91486, 
          91830, 92027, 92408, 92743, 92988, 93283, 93573, 93792, 94117, 
          94441, 94737, 95033, 95309, 95697, 96134, 97342, 97956, 98260, 
          98513, 98779, 99176, 99484, 99691, 99998, 100315, 100511, 100915, 
          101208, 101446, 101723, 101990, 102215, 102569, 102861, 103170, 
          103408, 103681, 103874, 104250, 104585, 104847, 105094, 105396, 
          105581, 105895, 106374, 106539, 106711, 106984, 107473, 107918, 
          108605};\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(pid5667230x10avg = {2465, 2852, 3243, 3604, 3921, 4261, 4569, 4935, 
          5279, 5604, 5928, 6291, 6658, 7014, 7343, 7654, 7950, 8312, 8608, 
          8913, 9236, 9618, 9990, 10379, 11096, 11670, 12182, 12510, 12830, 
          13112, 13468, 13748, 14022, 14290, 14559, 14837, 15194, 15483, 
          15750, 16051, 16332, 16610, 16924, 17209, 17542, 17831, 18148, 
          18589, 19499, 19909, 20294, 20599, 20873, 21159, 21509, 21790, 
          22062, 22354, 22637, 22915, 23262, 23539, 23823, 24112, 24377, 
          24681, 25001, 25352, 25629, 25875, 26109, 26531, 26896, 27262, 
          27619, 28042, 28314, 28598, 28893, 29164, 29422, 29723, 29985, 
          30262, 30520, 30888, 31181, 31461, 31709, 31953, 32259, 32519, 
          32795, 33096, 33341, 33607, 33939, 34200, 34459, 34754, 34998, 
          35301, 35578, 35860, 36122, 36388, 36646, 36896, 37146, 37520, 
          37930, 38248, 38490, 38755, 39082, 39359, 39627, 39908, 40162, 
          40416, 40750, 41030, 41357, 41733, 42060, 42435, 42797, 43093, 
          43411, 43721, 44003, 44320, 44619, 44922, 45230, 45549, 45888, 
          46240, 46563, 46915, 47245, 47589, 47890, 48221, 48533, 48838, 
          49157, 49460, 49800, 50158, 50480, 50808, 51127, 51449, 51772, 
          52073, 52369, 52675, 52999, 53303, 53635, 53972, 54280, 54601, 
          54971, 55415, 55874, 56434, 57015, 57602, 58156, 58724, 59033, 
          59352, 59734, 60050, 60397, 60694, 61022, 61381, 61736, 62085, 
          62415, 62697, 62994, 63284, 63566, 63842, 64190, 64567, 64922, 
          65304, 65615, 65975, 66353, 66729, 67027, 67332, 67631, 67924, 
          68275, 68608, 68966, 69313, 69666, 70012, 70355, 70669, 71024, 
          71405, 71772, 72126, 72526, 72998, 73446, 73856, 74483, 74988, 
          75586, 76436, 76987, 77602, 78018, 78362, 78787, 79252, 79544, 
          79937, 80310, 80672, 81058, 81399, 81680, 82024, 82384, 82681, 
          83047, 83369, 83677, 83975, 84302, 84632, 84941, 85227, 85536, 
          85912, 86189, 86520, 86849, 87207, 87546, 87975, 88680, 89195, 
          89735, 90082, 90369, 90668, 90976, 91258, 91541, 91823, 92116, 
          92382, 92745, 93029, 93332, 93619, 93901, 94183, 94475, 94770, 
          95066, 95370, 95691, 96225, 97336, 97861, 98287, 98623, 98921, 
          99192, 99508, 99779, 100046, 100361, 100635, 100920, 101242, 
          101507, 101804, 102084, 102342, 102626, 102937, 103215, 103502, 
          103766, 104007, 104262, 104579, 104840, 105134, 105415, 105665, 
          105960, 106251, 106533, 106838, 107100, 107326, 107622, 107959, 
          108280, 108736};\)\)], "Input",
  FontSize->9],

Cell["\<\
Calculate the differences between the average tap times and the corrected \
data, removing the extremities:\
\>", "Text"],

Cell[BoxData[{
    \(\(diffs3\  = \ 
        Drop[pid5667230x10avg, \ \(-2\)]\  - \ 
          pid5667230x10corrected;\)\), "\[IndentingNewLine]", 
    \(\(diffs3\  = \ Drop[diffs3, \ 3];\)\  (*\ 
      drop\ the\ first\ measure\ of\ the\ piece\ *) \), \
"\[IndentingNewLine]", 
    \(\(diffs3\  = \ Drop[diffs3, \ \(-1\)];\)\  (*\ 
      drop\ the\ last\ measure\ of\ the\ piece\ *) \), "\[IndentingNewLine]", \

    \(\(diffs3\  = \ N[diffs3\  - \ Mean[diffs3]];\)\  (*\ 
      estimate\ correction\ for\ alignment\ error\ *) \), \
"\[IndentingNewLine]", 
    \(\(beats3\  = \ Transpose[Partition[diffs3, \ 3]];\)\)}], "Input"],

Cell["\<\
First display a histogram of all metrical beat displacements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot3\  = \ 
        Histogram[diffs3, \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00594549 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13362 -12 -4.5 ]
[-0.0125 .13362 0 4.5 ]
[-0.0125 .25253 -12 -4.5 ]
[-0.0125 .25253 0 4.5 ]
[-0.0125 .37144 -12 -4.5 ]
[-0.0125 .37144 0 4.5 ]
[-0.0125 .49035 -12 -4.5 ]
[-0.0125 .49035 0 4.5 ]
[-0.0125 .60926 -18 -4.5 ]
[-0.0125 .60926 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13362 m
.00625 .13362 L
s
[(20)] -0.0125 .13362 1 0 Mshowa
0 .25253 m
.00625 .25253 L
s
[(40)] -0.0125 .25253 1 0 Mshowa
0 .37144 m
.00625 .37144 L
s
[(60)] -0.0125 .37144 1 0 Mshowa
0 .49035 m
.00625 .49035 L
s
[(80)] -0.0125 .49035 1 0 Mshowa
0 .60926 m
.00625 .60926 L
s
[(100)] -0.0125 .60926 1 0 Mshowa
.125 Mabswid
0 .04444 m
.00375 .04444 L
s
0 .07417 m
.00375 .07417 L
s
0 .1039 m
.00375 .1039 L
s
0 .16335 m
.00375 .16335 L
s
0 .19308 m
.00375 .19308 L
s
0 .22281 m
.00375 .22281 L
s
0 .28226 m
.00375 .28226 L
s
0 .31199 m
.00375 .31199 L
s
0 .34172 m
.00375 .34172 L
s
0 .40117 m
.00375 .40117 L
s
0 .4309 m
.00375 .4309 L
s
0 .46063 m
.00375 .46063 L
s
0 .52008 m
.00375 .52008 L
s
0 .54981 m
.00375 .54981 L
s
0 .57954 m
.00375 .57954 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13362 m
1 .13362 L
s
.99375 .25253 m
1 .25253 L
s
.99375 .37144 m
1 .37144 L
s
.99375 .49035 m
1 .49035 L
s
.99375 .60926 m
1 .60926 L
s
.125 Mabswid
.99625 .04444 m
1 .04444 L
s
.99625 .07417 m
1 .07417 L
s
.99625 .1039 m
1 .1039 L
s
.99625 .16335 m
1 .16335 L
s
.99625 .19308 m
1 .19308 L
s
.99625 .22281 m
1 .22281 L
s
.99625 .28226 m
1 .28226 L
s
.99625 .31199 m
1 .31199 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .40117 m
1 .40117 L
s
.99625 .4309 m
1 .4309 L
s
.99625 .46063 m
1 .46063 L
s
.99625 .52008 m
1 .52008 L
s
.99625 .54981 m
1 .54981 L
s
.99625 .57954 m
1 .57954 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02066 L
.04762 .02066 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02066 L
.04762 .02066 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02661 L
.09524 .02661 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02661 L
.09524 .02661 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .02066 L
.14286 .02066 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .02066 L
.14286 .02066 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .03255 L
.2381 .03255 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .03255 L
.2381 .03255 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .0385 L
.28571 .0385 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0385 L
.28571 .0385 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .0385 L
.33333 .0385 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .0385 L
.33333 .0385 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .08606 L
.38095 .08606 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .08606 L
.38095 .08606 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .19903 L
.47619 .19903 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .19903 L
.47619 .19903 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .28821 L
.52381 .28821 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .28821 L
.52381 .28821 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .22281 L
.57143 .22281 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .22281 L
.57143 .22281 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .16335 L
.61905 .16335 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .16335 L
.61905 .16335 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .13957 L
.66667 .13957 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13957 L
.66667 .13957 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .07417 L
.71429 .07417 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .07417 L
.71429 .07417 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .05039 L
.7619 .05039 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05039 L
.7619 .05039 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .02066 L
.80952 .02066 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .02066 L
.80952 .02066 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03255 L
.85714 .03255 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03255 L
.85714 .03255 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02066 L
.90476 .02066 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02066 L
.90476 .02066 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00D03oool500000080oooo0P0000040?ooo`800000<`3oool2000003H0oooo1@0000020?oo
o`800000103oool2000002l0oooo100000030?ooo`800000103oool2000000T0oooo001B0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`00DP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0_0?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool004X0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo
001B0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`00D@3oool2000000@0oooo0P0000040?ooo`800000<`3oool2000003L0oooo0P0000040?ooo`80
0000103oool200000300oooo0P0000040?ooo`800000103oool2000000T0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000F0?ooool00000
2@0000020?ooo`005P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool100000040oooo0@3oool000l0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo1@3oool100000040oooo0@3oool000h0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`40oooo000>0?oo
o`040000003oool0oooo000000@0ooooo`00000900000080oooo000>0?ooo`040000003oool0oooo
000000@0oooo3P00000;07moO`h000002`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl>000000/0Ogmo3P00000H0?ooo`4000000@3oool1
0?ooo`003P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0S0?ooo`4000000@3oool10?ooo`003`3oool20000
00D0oooo00<000000?ooo`3oool02P3oool=000001P0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool02P3oool00`00
0000Ogmo07moO`0907moO`030000003oool0oooo02<0oooo0@0000010?ooo`40oooo000F0?ooo`03
0000003oool0oooo02l0oooo3P00000;07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool02P3oool=000002D0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo03`0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo
0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo03`0oooo6P00000;07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0l0?ooo`4000000@3o
ool10?ooo`005P3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo0@000001
0?ooo`40oooo000F0?ooo`800000EP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0k0?ooo`8000000P3oool001H0
oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo3@00000n0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1E0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`400000
0@3oool10?ooo`005P3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool10?ooo`005P3oool0
0`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`180?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?oo
o`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool10?ooo`00
5P3oool2000005H0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl>000004T0oooo0P0000020?ooo`005P3o
ool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0E@3o
ool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo05D0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo
05D0oooo3@00000<07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo05D0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0E@3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo05D0oooo0@0000010?ooo`40oooo000F0?ooo`800000HP3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1D0?ooo`8000000P3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo05D0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0E@3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo05D0oooo0@0000010?ooo`40oooo00080?ooo`@000000`3oool2000000D0
oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`00
203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0H@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00001Q0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05<0
oooo0`0000020?ooo`002P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05D0oooo0@0000010?ooo`40
oooo00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl=0000
05L0oooo0@0000010?ooo`40oooo00090?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0H@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0H@3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0H@3oool100000040oooo
0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0H@3oool100000040oooo0@3oool001H0oooo00<00000
0?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0H@3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0H@3oool10000
0040oooo0@3oool001H0oooo0P00001R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo3P00001R0?ooo`80
00000P3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo06h0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1^0?ooo`4000000@3oool10?ooo`005P3oool0
0`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0KP3oool1
00000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo06h0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1^0?ooo`4000000@3oool10?ooo`00
5P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
KP3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo06h0oooo0@0000010?ooo`40oooo000F0?ooo`800000HP3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo06d0oooo0P0000020?ooo`005P3oool00`00
0000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo3@00000<07moO`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3o
ool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06h0oooo0@0000010?ooo`40
oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1^0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo0@3oool001H0oooo00<00000
0?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06h0oooo0@000001
0?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1^0?ooo`4000000@3oool10?ooo`005P3oool200000680oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo3@00001_0?ooo`80
00000P3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000
003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1j0?ooo`400000
0@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07X0oooo0@00
00010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0NP3oool1
00000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1j0?oo
o`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07X0
oooo0@0000010?ooo`40oooo000:0?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0
H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1j0?ooo`4000000@3oool10?ooo`002`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo
07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`1j0?ooo`4000000@3oool10?ooo`00203oool5000000050?ooo`000000oooo0?ooo`000000
103oool300000640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0N03oool300000080oooo00080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1Q0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo07X0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool000000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07X0
oooo0@0000010?ooo`40oooo000:0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0
H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1j0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?oo
o`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo07X0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0
oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0NP3oool100000040oooo0@3oool001H0oooo00<000000?oo
o`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`1j0?ooo`4000000@3oool10?ooo`005P3oool00`000000
oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000
Ogmo07moO`0:07moO`030000003oool0oooo07X0oooo0@0000010?ooo`40oooo000F0?ooo`800000
HP3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1i0?ooo`8000000P3oool001H0oooo00<000000?ooo`3oool0H@3o
ool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1j0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool>000007`0oooo0@000001
0?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool001H0oooo
00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo
0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool0
01H0oooo0P00001R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0TP3oool20000
0080oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool001H0oooo00<0
00000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo0@00
00010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool001H0
oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0
oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool200000680oooo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2B0?ooo`8000000P3oool001H0oooo00<00000
0?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo0@000001
0?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool001H0oooo
00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo
0@0000010?ooo`40oooo00080?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0H@3o
ool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo0008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo
0@3oool000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`<0
0000H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo0940oooo0`0000020?ooo`00
203oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1Q0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0640
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`00
2@3oool3000000<0oooo0P0000050?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?oo
o`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3o
ool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0
oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000
oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040
oooo0@3oool001H0oooo0P00001R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
TP3oool200000080oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?ooo`1Q
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool0
01H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo
0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo
0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool20000
0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2B0?ooo`8000000P3oool001H0
oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0
oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo0?oo
o`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3o
ool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0
oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000
oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040
oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000
003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`800000HP3oool00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo0980oooo0P0000020?ooo`005P3oool00`000000oooo0?ooo`1Q
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool0
01H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool00`000000oooo
0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo
0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo09<0oooo0@0000010?ooo`40oooo00090?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo09<0oooo0@000001
0?ooo`40oooo00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3o
ool100000040oooo0@3oool000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`<00000H@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo0940oooo
0`0000020?ooo`002@3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool100000040oooo
0@3oool000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`40
00000@3oool10?ooo`002@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0640oooo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3o
ool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3o
ool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:
07moO`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo
0640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?oo
o`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0T`3oool100000040oooo0@3oool001H0oooo0P00001R0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0TP3oool200000080oooo000F0?ooo`030000003oool0oooo0640oooo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool0
0`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool1
00000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`00
5P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
T`3oool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`800000HP3oool0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo0980oooo0P0000020?ooo`005P3oool00`00
0000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool10000
0040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640oooo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3o
ool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3o
ool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:
07moO`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo
0640oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?oo
o`005P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0T`3oool100000040oooo0@3oool001H0oooo0P00001R0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0TP3oool200000080oooo000F0?ooo`030000003oool0oooo0640oooo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`005P3oool0
0`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0T`3oool1
00000040oooo0@3oool001H0oooo00<000000?ooo`3oool0H@3oool00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo09<0oooo0@0000010?ooo`40oooo000F0?ooo`030000003oool0oooo0640
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2C0?ooo`4000000@3oool10?ooo`00
5P3oool00`000000oooo0?ooo`1Q0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
T`3oool100000040oooo0@3oool00080oooo1@0000020?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0H@3oool>000009D0oooo0@0000010?ooo`40oooo00040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0o`3oool50?ooo`4000000@3oool10?ooo`00103oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<0
0000o`3oool30?ooo`<000000P3oool000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool100000040oooo0@3oool000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3ooooo000000T000000P3oool000<0oooo0P0000040?ooo`800000103oool20000
0?l0oooo403oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {511.625, 370.313}} -> {-289.183, \
286.379, 1.60072, 0.641029}}]
}, Open  ]],

Cell["\<\
Now display separate histograms for individual metrical position in the \
meter:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot31\  = \ 
        Histogram[beats3[\([1]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0189872 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -6 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(5)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(10)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(15)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(20)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(25)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(30)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .0337 L
.14286 .0337 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0337 L
.14286 .0337 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0337 L
.2381 .0337 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0337 L
.2381 .0337 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .0337 L
.38095 .0337 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .0337 L
.38095 .0337 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .24256 L
.47619 .24256 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .24256 L
.47619 .24256 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .35649 L
.52381 .35649 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .35649 L
.52381 .35649 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .31851 L
.57143 .31851 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .31851 L
.57143 .31851 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .20459 L
.61905 .20459 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .20459 L
.61905 .20459 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .12864 L
.66667 .12864 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .12864 L
.66667 .12864 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .10965 L
.71429 .10965 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .10965 L
.71429 .10965 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0337 L
.7619 .0337 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0337 L
.7619 .0337 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0337 L
.85714 .0337 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0337 L
.85714 .0337 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05`3oool00`000000o`000?l00009
0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0F
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool05`3oool00`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0F0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0040oooo000:0?oo
o`8000001@3oool00`000000oooo0?ooo`0G0?ooo`030000003o0000o`0000T0o`0000<000000?oo
o`3oool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo01H0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo02<0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool00`000000o`000?l000090?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0F0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000603oool=000000`0oooo3P00000H0?ooo`h00000
303o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o000=000000`0oooo3P00000T0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04T0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0B03oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003oool0oooo04P0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`180?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00090?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000`0oooo00<000000?ooo`3o
ool00P3oool3000006<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`003P0000190?ooo`<000000`3oool000X0oooo0P0000050?ooo`030000
003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool0H`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000h00000E`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3
000006<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o000=000006<0oooo0`0000030?ooo`001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`01
0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o0000
2P3o000=000000`0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo
00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo
06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000
o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06l0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0KP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo06<0
oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040
oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0040oooo00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool3000006<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1]0?ooo`<00000
0`3oool000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0H`3o
ool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo00040?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0
oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000h00000L03oool2000000<0oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003oool0oooo07`0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003oool0
oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`h00000O@3oool2000000<0oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
I03oool00`000000o`000?l0000:0?l000030000003oool0oooo09@0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`000`3oool40000
00<0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00001S0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0T`3oool3000000<0oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`01
0?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000
003oool0oooo09@0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`2D0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo09D0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo09D0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
U03oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000003oool0oooo09@0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`01
0?ooo`000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?oo
o`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00001S0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0T`3oool3000000<0oooo00050?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1S0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000003oool0oooo
09@0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2D0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000o`000?l0000:0?l000030000003oool0oooo09D0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000o`000?l0000:0?l000030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U03oool20000
00<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000I03oool00`000000o`000?l0000:0?l000030000003oool0oooo09@0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000006<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`2C0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000I03oool>000009H0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool00140ooooo`00
000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {-280.554, \
0.172908, 1.57972, 0.198093}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot32\  = \ 
        Histogram[beats3[\([2]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0196201 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .03434 L
.2381 .03434 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .03434 L
.2381 .03434 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .05396 L
.33333 .05396 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .05396 L
.33333 .05396 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .13244 L
.38095 .13244 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .13244 L
.38095 .13244 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .25016 L
.52381 .25016 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .25016 L
.52381 .25016 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .1913 L
.57143 .1913 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .1913 L
.57143 .1913 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .13244 L
.61905 .13244 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .13244 L
.61905 .13244 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .25016 L
.66667 .25016 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25016 L
.66667 .25016 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .03434 L
.85714 .03434 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03434 L
.85714 .03434 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .03434 L
.90476 .03434 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03434 L
.90476 .03434 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003H0oooo1@0000020?oo
o`800000103oool200000340oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003L0oooo0P0000040?ooo`80
0000103oool200000380oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000B0?ooool00000
2`0000040?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0
oooo0080oooo000:0?ooo`040000003oool0oooo000000@0ooooo`00000<000000<0oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`0000000?l0003o0009
003o00030000003oool0oooo01H0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<00000
003o0000o`002@00o`000`000000oooo0?ooo`0F0?ooo`0300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo00X0oooo00<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo01H0oooo00<00000
0?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<00000003o
0000o`002@00o`000`000000oooo0?ooo`0F0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo00X0oooo00<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo01H0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o0003
0000003oool0oooo01H0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
4P3oool2000000/0oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`0F0?ooo`h00000
3000o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00030000003oool0oooo00X0oooo6P00000G0?ooo`800000
103oool00180oooo00<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o00030000003o
ool0oooo02<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003o
ool0oooo03`0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool02P3oool0
0`0000000?l0003o0009003o00030000003oool0oooo02<0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o00030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o00030000003oool0oooo
02<0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool02P3oool00`000000
0?l0003o0009003o00030000003oool0oooo02<0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o00030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00180oooo
0P00000;0?ooo`d000009@3ooolJ000000`00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00030000003oool0oooo03/0oooo0P0000040?ooo`004P3oool00`000000oooo0?oo
o`1E0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0E@3oool00`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo03`0oooo00<000000?ooo`3o
ool00P3oool00180oooo0P00001F0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00030000003oool0oooo03/0oooo0P0000040?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`002P00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo03`0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o01X00000?@3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0080oooo000;0?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`00
2P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<00000003o0000
o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000
003oool0oooo0080oooo0`00001E0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
E03oool2000000@0oooo000;0?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`0300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`002`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000;0?ooo`<00000103oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo
3P00000<003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o000:003o00d000003000o`000`000000oooo0?ooo`1D0?ooo`800000103oool00180oooo00<0
00000?ooo`3oool0HP3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<0
0000003o0000o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B
0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`09
0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000X00?l000<000000?oo
o`3oool02@3oool00`0000000?l0003o000:003o00030000003oool0oooo05D0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`800000H`3oool00`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000
003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1D0?ooo`800000
103oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o000:003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o00030000003oool0oooo
05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000H`3oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo
0?ooo`1D0?ooo`800000103oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?oo
o`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o
00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0HP3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000
o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo0680oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`030000
0000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3o
ool2000006<0oooo00<00000003o0000o`002P00o`0=000000`00?l03P00000;0?ooo`0300000000
o`000?l000X00?l000<000000?ooo`3oool0E03oool2000000@0oooo000B0?ooo`030000003oool0
oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool05P3oool00`0000000?l0003o000:003o00030000003oool0
oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`00
00000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`00
0000oooo0?ooo`0F0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`020?ooo`00103oool500000080oooo0P0000050?ooo`030000003oool0oooo0680
oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X0
0?l000<000000?ooo`3oool05P3oool00`0000000?l0003o000:003o00030000003oool0oooo05D0
oooo00<000000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`0F0?ooo`03
00000000o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`00
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool300000680
oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X0
0?l000<000000?ooo`3oool05P3oool00`0000000?l0003o000:003o00030000003oool0oooo05@0
oooo0P0000040?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool02@3oool00`0000000?l0003o000:003o00030000003oool0oooo01H0oooo00<00000003o0000
o`002P00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0680
oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X0
0?l000<000000?ooo`3oool05P3oool00`0000000?l0003o000:003o00030000003oool0oooo05D0
oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0
003o000:003o00030000003oool0oooo01H0oooo00<00000003o0000o`002P00o`000`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<0
0000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool05P3oool00`0000000?l0003o000:003o00030000003oool0oooo05D0oooo00<0
00000?ooo`3oool00P3oool00180oooo0P00001S0?ooo`0300000000o`000?l000X00?l000<00000
0?ooo`3oool02@3oool00`0000000?l0003o000:003o00030000003oool0oooo01H0oooo00<00000
003o0000o`002P00o`000`000000oooo0?ooo`1D0?ooo`800000103oool00180oooo00<000000?oo
o`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o
0000o`002P00o`000`000000oooo0?ooo`0F0?ooo`0300000000o`000?l000X00?l000<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`03
00000000o`000?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o0003
0000003oool0oooo01H0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`00
2P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0
5P3oool00`0000000?l0003o000:003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`0F0?ooo`0300000000
o`000?l000X00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool2
000006<0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`090?ooo`h00000603oool>
000005H0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l0
00X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l0
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?oo
o`020?ooo`004P3oool2000006<0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2C
0?ooo`800000103oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o
00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000
003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3o
ool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0
oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001S0?ooo`0300000000o`000?l0
00X00?l000<000000?ooo`3oool0T`3oool2000000@0oooo000B0?ooo`030000003oool0oooo0680
oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo00<0
00000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<0
00000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003o
ool0oooo09@0oooo00<000000?ooo`3oool00P3oool000H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`<00000HP3oool00`0000000?l0003o000:003o00030000003oool0
oooo09<0oooo0P0000040?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0
oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`<00000103oool00`000000oooo
0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool2000006<0oooo00<00000
003o0000o`002P00o`000`000000oooo0?ooo`2C0?ooo`800000103oool00180oooo00<000000?oo
o`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o0003
0000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003o
ool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001S0?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool0T`3oool2000000@0oooo000B0?ooo`030000003oool0oooo
0680oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo
00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000
003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?oo
o`800000H`3oool00`0000000?l0003o000:003o00030000003oool0oooo09<0oooo0P0000040?oo
o`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`030000
0000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool20000
06<0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2C0?ooo`800000103oool00180
oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0
003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool000@0oooo1000
00030?ooo`8000001@3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o
000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool000D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000HP3oool00`0000000?l0003o
000:003o00030000003oool0oooo09<0oooo0P0000040?ooo`001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1R0?ooo`0300000000
o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`00103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool0
0P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1R0?ooo`0300000000
o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool0
0`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`020?ooo`004P3oool2000006<0oooo00<00000003o0000o`002P00o`000`00
0000oooo0?ooo`2C0?ooo`800000103oool00180oooo00<000000?ooo`3oool0HP3oool00`000000
0?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o
000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<00000
0?ooo`3oool00P3oool00180oooo0P00001S0?ooo`0300000000o`000?l000X00?l000<000000?oo
o`3oool0T`3oool2000000@0oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000
o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00
o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000H`3oool00`000000
0?l0003o000:003o00030000003oool0oooo09<0oooo0P0000040?ooo`004P3oool00`000000oooo
0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R
0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool2000006<0oooo00<00000003o0000
o`002P00o`000`000000oooo0?ooo`2C0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003o
ool0oooo09@0oooo00<000000?ooo`3oool00P3oool000@0oooo100000030?ooo`8000001@3oool0
0`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0
oooo09@0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`<00000HP3oool00`0000000?l0003o000:003o00030000003oool0oooo
09<0oooo0P0000040?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000
oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0
oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`<00000103oool00`000000oooo
0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool2000006<0oooo00<00000
003o0000o`002P00o`000`000000oooo0?ooo`2C0?ooo`800000103oool00180oooo00<000000?oo
o`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o0003
0000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003o
ool0oooo09@0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001S0?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool0T`3oool2000000@0oooo000B0?ooo`030000003oool0oooo
0680oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo
00<00000003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo0680oooo00<00000003o0000o`002P00o`000`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0680oooo00<00000
003o0000o`002P00o`000`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0080oooo000B0?oo
o`800000H`3oool00`0000000?l0003o000:003o00030000003oool0oooo09<0oooo0P0000040?oo
o`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`030000
0000o`000?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`004P3oool20000
06<0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`2C0?ooo`800000103oool00180
oooo00<000000?ooo`3oool0HP3oool00`0000000?l0003o000:003o00030000003oool0oooo09@0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0HP3oool00`0000000?l0
003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool000D0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1R0?ooo`0300000000o`000?l000X00?l000<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0HP3oool00`0000000?l0
003o000:003o00030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool000H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001R0?ooo`h00000
U@3oool2000000@0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool00P3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo000B0?ooool000002`0000040?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {-281.593, \
41.3125, 1.58543, 0.192395}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot33\  = \ 
        Histogram[beats3[\([3]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0154896 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -6 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -12 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -12 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -12 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -12 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(10)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(15)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(20)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(25)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(30)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(35)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .0302 L
.2381 .0302 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0302 L
.2381 .0302 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .04569 L
.28571 .04569 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .04569 L
.28571 .04569 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .04569 L
.33333 .04569 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04569 L
.33333 .04569 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .09216 L
.38095 .09216 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .09216 L
.38095 .09216 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .16961 L
.47619 .16961 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .16961 L
.47619 .16961 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .16961 L
.57143 .16961 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .16961 L
.57143 .16961 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .15412 L
.61905 .15412 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .15412 L
.61905 .15412 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .06118 L
.66667 .06118 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .06118 L
.66667 .06118 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .0302 L
.71429 .0302 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0302 L
.71429 .0302 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .0302 L
.7619 .0302 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0302 L
.7619 .0302 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0302 L
.80952 .0302 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0302 L
.80952 .0302 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .0302 L
.85714 .0302 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0302 L
.85714 .0302 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0S
0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0040oooo000:0?oo
o`8000001@3oool00`000000003o0000o`0:0000o`030000003oool0oooo02<0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo02<0oooo00<000000?oo
o`3oool00@3oool00140oooo3P00000U0?ooo`h0000030000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o=000000T0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
?@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03d0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0m0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000n0?oooaX0000030000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`h00000E`3oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1R0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000`0
oooo00<000000?ooo`3oool00P3oool3000005H0oooo3P00000<0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0H@3oool3000000<0oooo000:0?ooo`8000001@3oool00`000000oooo
0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`002P3oool3000000@0oooo00<00000
0?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000I03oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`d00000I03oool2000000<0oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo06l0oooo00<000000?oo
o`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo0`00001S0?ooo`03000000000?l0003o00X0003o3@00000<0000o`h00000K`3oool30000
00<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?oo
o`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`0300000000
0?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`00
0000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000
003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo
00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000
o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000I03oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00030?ooo`D00000
0P3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000
003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo
0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00
001S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000
o`0:0000o`030000003oool0oooo07X0oooo0`0000030?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo06<0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`090?ooo`h00000O@3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`030000003oool0oooo09@0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000
003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool2
000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool3000006<0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`2C0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000
00000?l0003o00X0003o00<000000?ooo`3oool0U03oool2000000<0oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000003o
0000o`0:0000o`030000003oool0oooo09@0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000
003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0
oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o
00X0003o00<000000?ooo`3oool0U03oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040
oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo
00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000006<0oooo00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`2C0?ooo`<000000`3oool000D0oooo00<00000
0?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00040?oo
o`800000103oool3000000@0oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03
000000000?l0003o00X0003o00<000000?ooo`3oool0U03oool2000000<0oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`030000003oool0oooo
09@0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`2D0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U03o
ool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000
003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`<00000H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09<0oooo0`0000030?oo
o`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?oo
o`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0U03oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`00
0000003o0000o`0:0000o`030000003oool0oooo09@0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2D
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000
003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0U03oool2000000<0oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`00
0000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0040oooo00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool30000
06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2C0?ooo`<000000`3oool000H0
oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1S0?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo06<0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
I03oool00`000000003o0000o`0:0000o`030000003oool0oooo09@0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`2D0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`030000003oool0oooo09D0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo09D0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001T0?ooo`h00000UP3oool2000000<0oooo000A0?ooo`030000
003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {-280.554, \
104.057, 1.57972, 0.242823}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{plot3, \ plot31, \ plot32, \ plot33}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00594549 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13362 -12 -4.5 ]
[-0.0125 .13362 0 4.5 ]
[-0.0125 .25253 -12 -4.5 ]
[-0.0125 .25253 0 4.5 ]
[-0.0125 .37144 -12 -4.5 ]
[-0.0125 .37144 0 4.5 ]
[-0.0125 .49035 -12 -4.5 ]
[-0.0125 .49035 0 4.5 ]
[-0.0125 .60926 -18 -4.5 ]
[-0.0125 .60926 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13362 m
.00625 .13362 L
s
[(20)] -0.0125 .13362 1 0 Mshowa
0 .25253 m
.00625 .25253 L
s
[(40)] -0.0125 .25253 1 0 Mshowa
0 .37144 m
.00625 .37144 L
s
[(60)] -0.0125 .37144 1 0 Mshowa
0 .49035 m
.00625 .49035 L
s
[(80)] -0.0125 .49035 1 0 Mshowa
0 .60926 m
.00625 .60926 L
s
[(100)] -0.0125 .60926 1 0 Mshowa
.125 Mabswid
0 .04444 m
.00375 .04444 L
s
0 .07417 m
.00375 .07417 L
s
0 .1039 m
.00375 .1039 L
s
0 .16335 m
.00375 .16335 L
s
0 .19308 m
.00375 .19308 L
s
0 .22281 m
.00375 .22281 L
s
0 .28226 m
.00375 .28226 L
s
0 .31199 m
.00375 .31199 L
s
0 .34172 m
.00375 .34172 L
s
0 .40117 m
.00375 .40117 L
s
0 .4309 m
.00375 .4309 L
s
0 .46063 m
.00375 .46063 L
s
0 .52008 m
.00375 .52008 L
s
0 .54981 m
.00375 .54981 L
s
0 .57954 m
.00375 .57954 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13362 m
1 .13362 L
s
.99375 .25253 m
1 .25253 L
s
.99375 .37144 m
1 .37144 L
s
.99375 .49035 m
1 .49035 L
s
.99375 .60926 m
1 .60926 L
s
.125 Mabswid
.99625 .04444 m
1 .04444 L
s
.99625 .07417 m
1 .07417 L
s
.99625 .1039 m
1 .1039 L
s
.99625 .16335 m
1 .16335 L
s
.99625 .19308 m
1 .19308 L
s
.99625 .22281 m
1 .22281 L
s
.99625 .28226 m
1 .28226 L
s
.99625 .31199 m
1 .31199 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .40117 m
1 .40117 L
s
.99625 .4309 m
1 .4309 L
s
.99625 .46063 m
1 .46063 L
s
.99625 .52008 m
1 .52008 L
s
.99625 .54981 m
1 .54981 L
s
.99625 .57954 m
1 .57954 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02066 L
.04762 .02066 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02066 L
.04762 .02066 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02661 L
.09524 .02661 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02661 L
.09524 .02661 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .02066 L
.14286 .02066 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .02066 L
.14286 .02066 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .03255 L
.2381 .03255 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .03255 L
.2381 .03255 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .0385 L
.28571 .0385 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0385 L
.28571 .0385 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .0385 L
.33333 .0385 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .0385 L
.33333 .0385 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .08606 L
.38095 .08606 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .08606 L
.38095 .08606 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .19903 L
.47619 .19903 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .19903 L
.47619 .19903 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .28821 L
.52381 .28821 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .28821 L
.52381 .28821 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .22281 L
.57143 .22281 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .22281 L
.57143 .22281 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .16335 L
.61905 .16335 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .16335 L
.61905 .16335 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .13957 L
.66667 .13957 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13957 L
.66667 .13957 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .07417 L
.71429 .07417 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .07417 L
.71429 .07417 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .05039 L
.7619 .05039 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05039 L
.7619 .05039 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .02066 L
.80952 .02066 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .02066 L
.80952 .02066 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03255 L
.85714 .03255 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03255 L
.85714 .03255 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02066 L
.90476 .02066 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02066 L
.90476 .02066 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0189872 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -6 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(5)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(10)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(15)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(20)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(25)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(30)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .0337 L
.14286 .0337 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0337 L
.14286 .0337 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0337 L
.2381 .0337 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0337 L
.2381 .0337 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .0337 L
.38095 .0337 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .0337 L
.38095 .0337 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .24256 L
.47619 .24256 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .24256 L
.47619 .24256 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .35649 L
.52381 .35649 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .35649 L
.52381 .35649 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .31851 L
.57143 .31851 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .31851 L
.57143 .31851 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .20459 L
.61905 .20459 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .20459 L
.61905 .20459 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .12864 L
.66667 .12864 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .12864 L
.66667 .12864 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .10965 L
.71429 .10965 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .10965 L
.71429 .10965 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0337 L
.7619 .0337 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0337 L
.7619 .0337 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0337 L
.85714 .0337 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0337 L
.85714 .0337 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0196201 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .03434 L
.2381 .03434 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .03434 L
.2381 .03434 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .05396 L
.33333 .05396 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .05396 L
.33333 .05396 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .13244 L
.38095 .13244 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .13244 L
.38095 .13244 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .25016 L
.52381 .25016 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .25016 L
.52381 .25016 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .1913 L
.57143 .1913 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .1913 L
.57143 .1913 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .13244 L
.61905 .13244 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .13244 L
.61905 .13244 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .25016 L
.66667 .25016 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25016 L
.66667 .25016 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .03434 L
.85714 .03434 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03434 L
.85714 .03434 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .03434 L
.90476 .03434 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03434 L
.90476 .03434 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0154896 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -6 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -12 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -12 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -12 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -12 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(10)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(15)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(20)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(25)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(30)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(35)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .0302 L
.2381 .0302 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0302 L
.2381 .0302 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .04569 L
.28571 .04569 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .04569 L
.28571 .04569 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .04569 L
.33333 .04569 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04569 L
.33333 .04569 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .09216 L
.38095 .09216 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .09216 L
.38095 .09216 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .16961 L
.47619 .16961 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .16961 L
.47619 .16961 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .16961 L
.57143 .16961 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .16961 L
.57143 .16961 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .15412 L
.61905 .15412 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .15412 L
.61905 .15412 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .06118 L
.66667 .06118 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .06118 L
.66667 .06118 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .0302 L
.71429 .0302 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0302 L
.71429 .0302 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .0302 L
.7619 .0302 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0302 L
.7619 .0302 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0302 L
.80952 .0302 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0302 L
.80952 .0302 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .0302 L
.85714 .0302 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0302 L
.85714 .0302 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00?`3oool500000080oooo
0P0000040?ooo`8000004`3oool2000001D0oooo1@0000020?ooo`800000103oool2000000l0oooo
100000030?ooo`800000103oool2000003T0oooo1@0000020?ooo`800000103oool2000001D0oooo
0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo
0P00000k0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005@3oool500000080oooo
0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`800000>`3oool500000080oooo
0P0000040?ooo`8000005@3oool2000001H0oooo1@0000020?ooo`800000103oool200000100oooo
100000030?ooo`800000103oool2000001L0oooo00110?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?oo
o`00@@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0A0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?03oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?oo
o`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000?03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`040000003o
ool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000005P3oool003T0oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0300oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0
oooo00110?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?ooo`00@03oool2000000@0
oooo0P0000040?ooo`8000004`3oool2000001H0oooo0P0000040?ooo`800000103oool200000100
oooo0P0000040?ooo`800000103oool2000003X0oooo0P0000040?ooo`800000103oool2000001D0
oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000103oool2000000@0
oooo0P00000l0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005P3oool2000000@0
oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000?03oool2000000@0
oooo0P0000040?ooo`8000005@3oool2000001L0oooo0P0000040?ooo`800000103oool200000140
oooo0P0000040?ooo`800000103oool2000001L0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3o
oonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00240oooo0P0000030?ooogl0
00006P3oool2000000<0ooooQ000000L0?ooo`800000103ooon0000001/0oooo0P0000040?oooh@0
00005`3oool00200oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01D0oooo000P0?ooo`040000003oool0oooo00000080ooooP000
000H0?ooo`040000003oool0oooo00000080ooooQ@00000J0?ooo`040000003oool0oooo000000<0
ooooP000000J0?ooo`040000003oool0oooo000000<0ooooQ@00000F0?ooo`00803oool010000000
oooo0?ooo`0000020?oooa<000001@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000000D0Ogmo1`00000;0?ooo`030000003oool0oooo
01L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0
oooo00X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003oool0
oooo00l0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`00803o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo1`00000507moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool700000140oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`8000002`3oool7000000D0oooo1`00000<0?ooo`L0
00001@3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o0007000000D0oooo2000000A0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool02@3oool7000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`030?oo
o`d000002P3oool2000001X0oooo00@000000?ooo`3oool000000`3oool700000180oooo1`000006
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?lJ00000140oooo00<00000
0?ooo`3oool05@3oool00240oooo0P0000030?ooo`030000003oool0oooo01/0oooo3@00000507mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01P0oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01T0oooo0P0000040?ooo`030000003oool0oooo01`0oooo00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`009P3oool2000002P0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`L000007@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00l0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
0000003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool2000001d0oooo3P0000050000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0
9`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0M0?ooo`800000<03oool00`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003oool0oooo0280oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`L00000
4@3oool=000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
003oool0oooo01X0oooo0P00000Q0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003o
ool0oooo02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`800000:P3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l01000
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l8000002X0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000X0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo1`00000S0?ooo`030000003oool0oooo01d0oooo0P00000`0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<000000?ooo`3oool06P3oool200000240oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo
02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo
0280oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo
01/0oooo00<000000?ooo`3oool06@3oool2000000@0oooo0P00000Z0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02l0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool09`3oool7000000D0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@0
0?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0H0?ooo`8000000`3oool200000300oooo00<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`0>000001`0oooo0P00000M0?ooo`040000003oool0oooo0?oo
o`800000:P3oool7000000D0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool06@3oool2000000@0oooo00<00000
0?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020000
0300oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`001`00000T0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000Y
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool09`3oool2000001/0oooo00<00000
0?ooo`3oool00`3oool200000300oooo00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool001X0oooo100000030?oo
o`8000000`3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0603oool2000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01X0oooo0P0000040?ooo`030000003oool0oooo02L0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo0`0000030?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0O0?ooo`800000<03oool00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000^0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02H0oooo0P00000J0?ooo`<000000P3oool200000300oooo00<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000P00000:P3oool00`000000oooo0?ooo`0J0?oo
o`<000000`3oool00`000000oooo0?ooo`0W0?ooo`L000001@00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`07000000D00?l000<000000?oo
o`3oool09`3oool200000240oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?oo
o`00703oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000;`3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000Y0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0O0?ooo`800000<03oool0
0`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0E0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`800000<03o
ool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool09`3o
ool200000240oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`006`3oool2
000000@0oooo0P0000030?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo1@0000020?ooo`800000103oool2
00000300oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l700000340oooo00<000000?ooo`3oool05@3oool0
02H0oooo0P00000^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000_0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0
oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0W0?ooo`8000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool0oooo0P00000`0?ooo`03000000000?l0003o00<0003o200000050000o`L00000
=`3oool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0103oool00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool05@3oool002H0oooo0P00000^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0M0?ooo`800000<03oool00`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02d0oooo00<00000003o0000o`000`00o`07000000D00?l01`0000050?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool09`3oool2000001H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo0?ooo`800000<03oool00`000000003o0000o`030000
o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1o
Ogl00`1oOgl7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0140oooo1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01<0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0]0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
4`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<@3oool00`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000002l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool07`3oool200000300oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000300oooo00<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
000700000340oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0W0?ooo`8000008@3oool00`000000oooo0?ooo`0_0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`L00000
=@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000a0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000002l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool07`3oool200000300oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo03T0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000002l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o0003
0000003oool0oooo02L0oooo0P00000Q0?ooo`030000003oool0oooo02l0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0E0?ooo`00703oool300000080oooo0P0000030?ooo`030000
003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0B0?ooo`800000
103oool2000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo03D0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000
003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool500000080oooo0P0000040?ooo`800000
<03oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000M0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000;`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000<@3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000J0?oo
o`D0000000D0oooo0000003oool0oooo000000020?ooo`800000;P3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0h
0?ooo`8000007`3oool200000300oooo00<000000?l0003o00000`3o0008000000D0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0;@3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1`00000;
0?ooo`L00000:@3oool2000001H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool200000300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`006P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
;`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`006`3o
ool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo0P00000`0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`150?ooo`800000
5P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
;`3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000L0?ooo`8000000`3o
ool2000000<0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o
ool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`800000103o
ool3000000<0oooo0P00000`0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103o
ool7000003d0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool7000003/0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;`3oool0
0`000000003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool0
02H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
04D0oooo00<000000?ooo`3oool04@3oool500000080oooo0P0000030?ooo`800000<03oool00`00
0000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool50000
0080oooo0P0000040?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`150?ooo`8000008@3oool200000300oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000340oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000;`3oool00`0000000?l0
003o0003003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0E0?ooo`009P3oool2000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002l0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`150?ooo`8000008@3oool200000300oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo
000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<0
00000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?oo
o`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`180?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<00000
003o0000o`000`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo10000003
0?ooo`800000103oool200000300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo0180oooo0P0000040?oo
o`<000000P3oool200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?oo
o`030000003o0000o`0000<0o`001`00000g0?ooo`030000003oool0oooo01@0oooo0P0000040?oo
o`<000000`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0A@3oool2000001@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo04D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l0
00030000003oool0oooo03/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000300oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000V0?oo
o`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`150?oo
o`030000003oool0oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool0103oool00`000000o`000?l000030?l000030000003oool0oooo03/0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0A@3oool2000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000<@3oool00`000000003o0000o`030000o`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05@3oool001X0oooo0`0000040?ooo`8000000`3oool00`000000oooo0?ooo`0]
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`04
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`800000<03oool00`000000003o0000o`030000o`030000003oool0oooo04P0oooo
00<000000?ooo`3oool05@3oool001X0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000
o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`000000
0?l0003o0003003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000J0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool2000002h0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`140?ooo`8000007`3oool200000300oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`040?ooo`L00000?@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`150?ooo`8000008@3oool20000
0300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01D0oooo000J0?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003oool0oooo
04P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01D0oooo000K0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0M0?ooo`800000<03oool00`000000o`000?l000030?l000030000003oool0oooo
04P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0A@3oool200000240oooo0P00000`0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0?ooo`006`3oool3000000<0
oooo0P0000030?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0140oooo100000030?ooo`8000000`3oool00`000000
oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0C0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0;@3oool00`000000
0?l0003o0003003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0E0?ooo`009P3oool2000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`150?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`180?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo100000030?ooo`800000103oool20000
0300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`800000<03oool00`000000o`000?l000030?l000030000003oool0oooo
04P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o00030000003oool0
oooo04D0oooo0P00000D0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000a0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000002l0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool200000300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo04D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0A@3oool2000001H0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo04D0oooo00<000000?ooo`3oool04P3oool2000000@0oooo
0P0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`180?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0B0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool200000300
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0
oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`00
0?l000030?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0C0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0;`3oool00`000000003o
0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool002H0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool07@3oool200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`180?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o
0003003o00030000003oool0oooo04D0oooo0P00000Q0?ooo`800000<03oool00`000000003o0000
o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`18
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E
0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0M0?ooo`800000<03oool00`000000o`000?l000030?l0
00030000003oool0oooo04P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0A@3oool200000240oooo0P00000`0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0?oo
o`006`3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02d0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0;`3oool00`000000o`000?l000030?l000030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02l0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000J0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`180?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o
00030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000040?oo
o`800000<03oool00`000000003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05@3oool001X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo04@0oooo0P00000C
0?ooo`@000000`3oool2000000<0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0C0?ooo`@000000`3oool2000000@0oooo00<00000
0?ooo`3oool0;@3oool00`0000000?l0003o0003003o00030000003oool0oooo04D0oooo0P00000D
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0E0?ooo`006`3oool2000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3o
ool200000300oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo01D0oooo000J0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0A@3oool2000001L0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000K0?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
04D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo
02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo
0180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000<03o
ool00`000000003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3o
ool002H0oooo0P00000^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0C0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`000000003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0`0000020?ooo`800000<03o
ool00`000000o`000?l000030?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool0503o
ool2000000@0oooo0`0000030?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`150?ooo`8000008@3oool200000300oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0
oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003oool0
oooo04P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0
oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
04D0oooo00<000000?ooo`3oool07@3oool200000300oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`180?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`00
00000?l0003o0003003o00030000003oool0oooo04D0oooo0P00000Q0?ooo`800000<03oool00`00
0000003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool002H0
oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo04D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02d0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo04D0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`160?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`800000103oool200000300oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo
000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`150?ooo`800000503oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000
003o0000o`030000o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool002H0oooo
0P00000^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`180?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0
003o0003003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooo`800000<03oool00`000000003o0000o`030000o`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
7@3oool200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`180?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o00030000
003oool0oooo04D0oooo0P00000G0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0E0?ooo`00503oool500000080oooo0P0000040?ooo`8000000`3oool00`000000oooo
0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`00
0?l000030?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool0503oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`160?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`800000<03oool00`000000003o0000o`030000o`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05@3oool001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000;`3oool7000004L0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003oool0oooo04P0oooo
00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o00030000003oool0oooo
04H0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo
02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01D0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo0P00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`180?ooo`030000003o
ool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000;`3oool7000004L0oooo0P00000Q0?ooo`800000<03oool00`000000003o0000o`030000o`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool001H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0O`00000F0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000<@3oool00`000000o`000?l0
00030?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0_0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0?ooo`00
5P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`2B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool200000300oooo1`00001:0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?oooh0000008@3oool200000300oooo1`00001:0?ooo`03
0000003oool0oooo01D0oooo000E0?ooo`800000103oool2000000@0oooo0P00002F0?ooo`800000
103oool2000000<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo0P0000040?ooo`800000Y@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00<@0ooooQ00000330?oooh@000005`3o
ool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 568}, {90.625, 13.6875}} -> {-0.331812, \
0.0930199, 0.00627702, 0.00627702}, {{42.25, 160.813}, {88.75, 15.5}} -> \
{-442.244, 3.14606, 3.34529, 1.33967}, {{172.688, 291.25}, {88.75, 15.5}} -> \
{-938.553, 0.88816, 3.21116, 0.402672}, {{303.063, 421.625}, {88.75, 15.5}} -> \
{-1508.3, 0.930993, 3.31334, 0.402082}, {{433.5, 552.063}, {88.75, 15.5}} -> \
{-1983.23, 1.08552, 3.20758, 0.493046}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({DispersionReport[diffs3]}\  // \ Transpose\)\  // \ 
      TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 3396.0124406337977`\)},
          {\(StandardDeviation \[Rule] 58.27531587759776`\)},
          {\(SampleRange \[Rule] 490.`\)},
          {\(MeanDeviation \[Rule] 41.25847027157236`\)},
          {\(MedianDeviation \[Rule] 25.`\)},
          {\(QuartileDeviation \[Rule] 30.625`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats3\  = \ 
        Map[DispersionReport, beats3]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats3]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 1939.2847896440126`\), \(Variance \[Rule] 
              4393.872453835903`\), \(Variance \[Rule] 3711.939843898724`\)},
          {\(StandardDeviation \[Rule] 
              44.03731133532124`\), \(StandardDeviation \[Rule] 
              66.28629159815702`\), \(StandardDeviation \[Rule] 
              60.92569116471904`\)},
          {\(SampleRange \[Rule] 301.`\), \(SampleRange \[Rule] 
              404.`\), \(SampleRange \[Rule] 463.`\)},
          {\(MeanDeviation \[Rule] 
              34.0169667263644`\), \(MeanDeviation \[Rule] 
              48.981053822226386`\), \(MeanDeviation \[Rule] 
              38.75633895748893`\)},
          {\(MedianDeviation \[Rule] 37.`\), \(MedianDeviation \[Rule] 
              27.`\), \(MedianDeviation \[Rule] 22.`\)},
          {\(QuartileDeviation \[Rule] 31.375`\), \(QuartileDeviation \[Rule] 
              37.875`\), \(QuartileDeviation \[Rule] 24.875`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, and \
the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(info3\  = \ 
      Transpose[{Range[3], \ 
            N[Map[Mean, \ 
                Abs[beats3]]], \[IndentingNewLine]Map[\((StandardDeviation\  \
/. \ #)\) &, \ stats3]}]\ \  // \ TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "34.34313633078833`", "44.03731133532124`"},
          {"2", "48.961416407452774`", "66.28629159815702`"},
          {"3", "40.47085807647596`", "60.92569116471904`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3; Rosen 1989", "Subsection"],

Cell[BoxData[
    \(\(pid52932x05corrected\  = \ {707, 1194, 1612, 2116, 2634, 3045, 3425, 
          3817, 4236, 4663, 5078, 5510, 5885, 6249, 6661, 7106, 7570, 7916, 
          8442, 8784, 9320, 9897, 10439, 11145, 12060, 12659, 13010, 13298, 
          13575, 14013, 14434, 14822, 15278, 15663, 15944, 16358, 16833, 
          17339, 17680, 18032, 18371, 18809, 19254, 19754, 20135, 20527, 
          21116, 21629, 22610, 23099, 23639, 24176, 24488, 25146, 25574, 
          25994, 26702, 27070, 27298, 27825, 28222, 28666, 29081, 29397, 
          29628, 30092, 30543, 31036, 31391, 31777, 32357, 33038, 33612, 
          34016, 34550, 34900, 35209, 35560, 35933, 36247, 36693, 36981, 
          37376, 37627, 38106, 38612, 38919, 39193, 39451, 39757, 40065, 
          40436, 40791, 41075, 41415, 41967, 42586, 43027, 43534, 43851, 
          44165, 44475, 44877, 45229, 45653, 45941, 46278, 46577, 46913, 
          47256, 47606, 47850, 48050, 48415, 48675, 49134, 49427, 49703, 
          49968, 50229, 50646, 51050, 51390, 51707, 52139, 52480, 52809, 
          53163, 53501, 53797, 54130, 54439, 54758, 55077, 55395, 55707, 
          56063, 56464, 56899, 57268, 57668, 58028, 58453, 58821, 59130, 
          59496, 59847, 60191, 60577, 60975, 61320, 61643, 62015, 62319, 
          62628, 62966, 63269, 63595, 63925, 64217, 64882, 65368, 65753, 
          66151, 66599, 67012, 67501, 68133, 68635, 69258, 69828, 70163, 
          70475, 70933, 71178, 71533, 71861, 72331, 72828, 73418, 73970, 
          74481, 74841, 75159, 75490, 75854, 76186, 76537, 76929, 77458, 
          77871, 78335, 78873, 79412, 79763, 80080, 80379, 80775, 81090, 
          81413, 81776, 82249, 82702, 83270, 83776, 84351, 84712, 85057, 
          85364, 85777, 86142, 86529, 86940, 87479, 87856, 88469, 89064, 
          89555, 90034, 90542, 91135, 91598, 92133, 92685, 93129, 93607, 
          94153, 94704, 95550, 96051, 96513, 96885, 97305, 97843, 98311, 
          98705, 99140, 99580, 100036, 100523, 100942, 101360, 101739, 
          102078, 102625, 103022, 103557, 104001, 104496, 105131, 105753, 
          106577, 107665, 108289, 108604, 108941, 109191, 109594, 110015, 
          110425, 110790, 111142, 111349, 111750, 112114, 112564, 112871, 
          113113, 113346, 113722, 114148, 114639, 114988, 115328, 116058, 
          116598, 117980, 118716, 119213, 119641, 119924, 120382, 121028, 
          121488, 121967, 122279, 122543, 123080, 123543, 123957, 124322, 
          124662, 124896, 125466, 125978, 126443, 126996, 127682, 127942, 
          128444, 128949, 129432, 130024, 130618, 130904, 131396, 132127, 
          132741, 133554, 134702, 135141, 135919, 136992, 
          137993};\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(pid52932x05avg\  = \ \ {911, 1218, 1612, 2023, 2541, 3030, 3463, 
          3796, 4193, 4663, 5060, 5485, 5911, 6230, 6661, 7047, 7551, 7942, 
          8353, 8799, 9297, 9844, 10428, 11164, 12066, 12646, 13018, 13379, 
          13653, 14074, 14479, 14832, 15159, 15675, 15963, 16409, 16811, 
          17298, 17660, 18011, 18306, 18814, 19301, 19749, 20135, 20537, 
          21128, 21734, 22656, 23163, 23499, 24166, 24480, 24971, 25666, 
          26043, 26406, 27139, 27454, 27899, 28337, 28702, 29054, 29512, 
          29731, 30143, 30596, 31036, 31402, 31806, 32308, 32923, 33589, 
          33984, 34461, 34916, 35209, 35560, 35890, 36268, 36608, 36965, 
          37313, 37659, 37958, 38517, 38879, 39193, 39492, 39767, 40080, 
          40420, 40772, 41046, 41415, 41854, 42527, 42986, 43404, 43871, 
          44159, 44489, 44784, 45184, 45551, 45920, 46253, 46577, 46899, 
          47314, 47606, 47891, 48159, 48415, 48720, 49028, 49413, 49703, 
          50013, 50342, 50695, 51013, 51390, 51748, 52105, 52480, 52832, 
          53163, 53501, 53814, 54115, 54455, 54770, 55092, 55418, 55742, 
          56111, 56464, 56811, 57268, 57629, 58016, 58402, 58870, 59209, 
          59496, 59838, 60182, 60577, 60975, 61320, 61681, 62003, 62339, 
          62660, 62989, 63304, 63625, 63973, 64293, 64747, 65368, 65817, 
          66179, 66550, 67012, 67494, 68036, 68642, 69121, 69688, 70181, 
          70508, 70902, 71259, 71561, 71898, 72268, 72744, 73262, 73937, 
          74432, 74878, 75187, 75497, 75859, 76186, 76537, 76920, 77363, 
          77849, 78256, 78785, 79288, 79794, 80113, 80409, 80775, 81116, 
          81455, 81796, 82202, 82665, 83144, 83751, 84227, 84750, 85083, 
          85409, 85745, 86105, 86529, 86933, 87391, 87841, 88307, 88925, 
          89523, 90054, 90559, 91025, 91598, 92026, 92589, 93153, 93581, 
          94050, 94633, 95567, 96037, 96513, 96953, 97337, 97727, 98268, 
          98683, 99140, 99566, 100002, 100435, 100942, 101322, 101798, 
          102201, 102582, 103033, 103535, 103961, 104436, 105005, 105741, 
          106604, 107650, 108312, 108658, 108967, 109247, 109665, 110071, 
          110425, 110777, 111142, 111413, 111845, 112182, 112530, 112874, 
          113196, 113392, 113790, 114167, 114610, 115004, 115323, 115881, 
          116598, 117989, 118620, 119125, 119776, 120002, 120446, 120884, 
          121560, 121956, 122413, 122628, 123080, 123577, 124006, 124384, 
          124710, 125003, 125466, 125956, 126516, 126891, 127697, 128009, 
          128504, 129000, 129476, 129948, 130749, 130994, 131466, 132021, 
          132732, 133337, 134721, 135246, 135986, 136823, 138080, 
          139413};\)\)], "Input",
  FontSize->9],

Cell["\<\
Calculate the differences between the average tap times and the corrected \
data, removing the extremities:\
\>", "Text"],

Cell[BoxData[{
    \(\(diffs4\  = \ 
        Drop[pid52932x05avg, \ \(-3\)]\  - \ 
          Drop[pid52932x05corrected, \ \(-2\)];\)\), "\[IndentingNewLine]", 
    \(\(diffs4\  = \ Drop[diffs4, \ 3];\)\  (*\ 
      drop\ the\ first\ measure\ of\ the\ piece\ *) \), \
"\[IndentingNewLine]", 
    \(\(diffs4\  = \ N[diffs4\  - \ Mean[diffs4]];\)\  (*\ 
      estimate\ correction\ for\ alignment\ error\ *) \), \
"\[IndentingNewLine]", 
    \(\(beats4\  = \ Transpose[Partition[diffs4, \ 3]];\)\)}], "Input"],

Cell["\<\
First display a histogram of all metrical beat displacements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot4\  = \ 
        Histogram[diffs4, \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0105108 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11982 -12 -4.5 ]
[-0.0125 .11982 0 4.5 ]
[-0.0125 .22493 -12 -4.5 ]
[-0.0125 .22493 0 4.5 ]
[-0.0125 .33004 -12 -4.5 ]
[-0.0125 .33004 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .54025 -12 -4.5 ]
[-0.0125 .54025 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11982 m
.00625 .11982 L
s
[(10)] -0.0125 .11982 1 0 Mshowa
0 .22493 m
.00625 .22493 L
s
[(20)] -0.0125 .22493 1 0 Mshowa
0 .33004 m
.00625 .33004 L
s
[(30)] -0.0125 .33004 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(40)] -0.0125 .43515 1 0 Mshowa
0 .54025 m
.00625 .54025 L
s
[(50)] -0.0125 .54025 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .0988 m
.00375 .0988 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .18289 m
.00375 .18289 L
s
0 .20391 m
.00375 .20391 L
s
0 .24595 m
.00375 .24595 L
s
0 .26697 m
.00375 .26697 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .35106 m
.00375 .35106 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .51923 m
.00375 .51923 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11982 m
1 .11982 L
s
.99375 .22493 m
1 .22493 L
s
.99375 .33004 m
1 .33004 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .54025 m
1 .54025 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03574 L
.09524 .03574 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03574 L
.09524 .03574 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04625 L
.14286 .04625 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04625 L
.14286 .04625 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .10931 L
.19048 .10931 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10931 L
.19048 .10931 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .11982 L
.2381 .11982 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .11982 L
.2381 .11982 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .20391 L
.28571 .20391 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .20391 L
.28571 .20391 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .06727 L
.33333 .06727 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .06727 L
.33333 .06727 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .14084 L
.38095 .14084 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .14084 L
.38095 .14084 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .288 L
.42857 .288 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .288 L
.42857 .288 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .47719 L
.47619 .47719 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .47719 L
.47619 .47719 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .47719 L
.57143 .47719 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .47719 L
.57143 .47719 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .24595 L
.66667 .24595 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24595 L
.66667 .24595 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .11982 L
.71429 .11982 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11982 L
.71429 .11982 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .06727 L
.80952 .06727 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06727 L
.80952 .06727 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02523 L
.85714 .02523 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02523 L
.85714 .02523 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02523 L
.90476 .02523 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02523 L
.90476 .02523 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0040oooo000:0?oo
o`8000001@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo6P00000I0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00X0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
2`3oool>000000/0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo02l0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo0300oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01L0oooo3@00000<07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo0300oooo00<000000?ooo`3oool00@3oool00140oooo0P00
000T0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`0_0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo3@00000<07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl>00000380oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
8`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000T0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0?03oool2000000<0oooo000A0?ooo`030000003oool0oooo
02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo3@00000o0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo02<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00000T0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo3P00000<07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`000`3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0<03oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool300000300oooo3P00000<07moO`030000003o
ool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl>000004T0oooo0`0000030?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0m0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3o
ool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0?@3oool00`000000Ogmo07moO`0:07moO`030000003oool0
oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03d0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000003h0oooo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`090?ooo`h00000301oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03d0oooo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo01H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool05P3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03d0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0F0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0?@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo01H0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003h0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05D0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool05P3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03d0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0F0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0?@3oool00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo01H0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool05P3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03d0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`0F0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
000n0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool05P3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000Ogmo07moO`0:
07moO`030000003oool0oooo01H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool05P3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03d0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0F0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
?@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo01H0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003h0oooo3P00000H0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo
0P0000050?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000006<0oooo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0E03oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`h00000E`3oool2
000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006@0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`h000002`1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo0640oooo0`0000030?ooo`001P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo0004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06<0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`d00000I03oool2000000<0oooo000A0?ooo`030000
003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000L@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool00@3oool000D0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1`0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`010?ooo`000`3oool5000000050?ooo`000000oooo0?ooo`000000
103oool300000700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K@3oool3000000<0oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1`0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0700oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`010?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000
003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00001a0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0700oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3oool=000000`0Ogmo3P00001`0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
O03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001m0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo07`0oooo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000O@3oool00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo07/0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`001P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001l0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0NP3oool3000000<0oooo00040?ooo`8000000`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`00103oool30000
00<0oooo0P0000050?ooo`030000003oool0oooo07`0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0
oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000O@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1l0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000007d0oooo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0O03oool0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000
Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0O03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001m
0?ooo`h00000O@3oool2000000<0oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d00000
0`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {181.563, 40.25}} -> {-280.554, \
12.1939, 1.57972, 0.357845}}]
}, Open  ]],

Cell["\<\
Now display separate histograms for individual metrical position in the \
meter:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot41\  = \ 
        Histogram[beats4[\([1]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04415 L
.14286 .04415 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04415 L
.14286 .04415 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .10301 L
.19048 .10301 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10301 L
.19048 .10301 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .07358 L
.2381 .07358 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07358 L
.2381 .07358 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .22073 L
.28571 .22073 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .22073 L
.28571 .22073 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .1913 L
.42857 .1913 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .1913 L
.42857 .1913 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .42674 L
.47619 .42674 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .42674 L
.47619 .42674 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .16187 L
.80952 .16187 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .16187 L
.80952 .16187 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003H0oooo1@0000020?oo
o`800000103oool200000340oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003L0oooo0P0000040?ooo`80
0000103oool200000380oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000B0?ooool00000
2`0000040?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0
oooo0080oooo000:0?ooo`040000003oool0oooo000000@0ooooo`00000<000000<0oooo000:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool000X0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<000000?oo
o`3oool05P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo02<0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool05P3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
5P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool05P3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool05P3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00000G0?ooo`h000002`3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000d00000903oool20000
00@0oooo000B0?ooo`030000003oool0oooo02<0oooo00<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000
o`000?l0000:0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool08`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`0S0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02<0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool00`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`090?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`0S0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000
903oool00`000000o`000?l000090?l000h00000303o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0;P3oool2000000@0oooo000B0?ooo`030000003o
ool0oooo02<0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08`3oool0
0`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`030000003o0000o`00
00T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo
00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo02<0oooo00<000000?l0003o00002@3o00000`000000
oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000
o`000?l0000:0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool08`3oool00`000000o`000?l000090?l000030000003oool0oooo00X0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`0S0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0
000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02<0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool00180oooo0P00000T0?ooo`d00000303oool00`000000o`000?l0000:0?l0
00030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0^0?oo
o`800000103oool00180oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03`0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0?03oool0
0`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
03`0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0l0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000
o`000?l0000:0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000?@3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`0^0?ooo`800000103oool00180oooo00<00000
0?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo03`0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`0l0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool02P3oool00`000000o`000?l0000:0?l000030000003oool0oooo02l0oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000
003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03`0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<000000?ooo`3oool0?03oool0
0`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0
oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo00X0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0080oooo000=0?ooo`030000003oool0oooo0080oooo0`00000l0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool02@3oool>000000`0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o000>0000
00/0o`0000<000000?ooo`3oool02P3oool>00000300oooo0P0000040?ooo`002`3oool2000000D0
oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0oooo01H0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0
oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0080
oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`000000o`00
0?l0000:0?l000030000003oool0oooo01H0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002@3o00000`000000oooo
0?ooo`190?ooo`030000003oool0oooo0080oooo000;0?ooo`<00000103oool00`000000oooo0?oo
o`0l0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool05P3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0
00090?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0oooo01H0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo03`0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0F0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000T0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`0l0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool05P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool02P3oool00`000000o`000?l000090?l000030000003oool0oooo04T0oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000
003oool0oooo01H0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo00X0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`190?ooo`030000
003oool0oooo0080oooo000B0?ooo`800000?@3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo01H0oooo3P00000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo3@00001:0?ooo`800000103o
ool00180oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000:0?l000030000003oool0
oooo02<0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo03`0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`0S0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0l0?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool08`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0?03oool00`000000o`00
0?l0000:0?l000030000003oool0oooo02<0oooo00<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03`0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`0S0?ooo`030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0l
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool08`3oool00`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo0P00000m0?oo
o`h000009@3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0640oooo0P0000040?oo
o`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`020?ooo`004P3oool200000700oooo00<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1Q0?ooo`800000103oool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0K`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
K`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0K`3oool0
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
0680oooo00<000000?ooo`3oool00P3oool00180oooo0P00001`0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0H@3oool2000000@0oooo000B0?ooo`030000003oool0oooo06l0oooo
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo06l0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo00040?ooo`D00000
0P3oool2000000D0oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo0680oooo00<000000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K`3oool00`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool000H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001_0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H@3oool2000000@0oooo00060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0K`3o
ool00`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0K`3oool00`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool00180oooo0P00
001`0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H@3oool2000000@0oooo000B
0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
0080oooo000B0?ooo`800000L03oool00`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0640
oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1_0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`004P3o
ool200000700oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`003@00001S0?ooo`800000103oool00180oooo00<000000?ooo`3oool0K`3oool0
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo06l0oooo00<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0K`3oool00`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo0080oooo000B0?ooo`800000L03oool=000000`0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1]0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
N`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1k0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`1k0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo
00<000000?ooo`3oool0N`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo0080oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool3000007/0oooo3P00000<0?l000030000003oool0oooo06d0oooo0P0000040?ooo`001P3oool0
0`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`280?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R03oool00`00
0000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool000D0
oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`280?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`28
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool2000008T0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`1]0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
R03oool00`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003o
ool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0R03oool0
0`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo
06h0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0R03oool00`000000
o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0R03oool00`000000o`000?l0
000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo0P000029
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0K@3oool2000000@0oooo000B0?oo
o`030000003oool0oooo08P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo08P0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo08P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo08P0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo08P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo08P0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000R@3oool00`000000
o`000?l0000:0?l000030000003oool0oooo06d0oooo0P0000040?ooo`004P3oool00`000000oooo
0?ooo`280?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`28
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`280?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`280?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`280?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`004P3oool2
000008T0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1]0?ooo`800000103oool0
0180oooo00<000000?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo
06h0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0R03oool00`000000
o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0R03oool00`000000o`000?l0
000:0?l000030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<00000
0?ooo`3oool00P3oool000@0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`280?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0R03oool00`000000o`000?l0000:0?l000030000003oool0oooo06h0oooo00<000000?oo
o`3oool00P3oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`<00000R03oool>000006l0oooo0P0000040?ooo`001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?oo
o`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`001@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000B0?ooool0
00002`0000040?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {379.188, 237.875}} -> {-281.593, \
36.0591, 1.58543, 0.128263}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot42\  = \ 
        Histogram[beats4[\([2]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .14552 L
.2381 .14552 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .14552 L
.2381 .14552 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .04742 L
.33333 .04742 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04742 L
.33333 .04742 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00E03oool500000080oooo0P0000040?ooo`800000
<P3oool2000003D0oooo1@0000020?ooo`800000103oool2000002l0oooo100000030?ooo`800000
103oool2000000L0oooo001F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000=P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000060?ooo`00EP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000003H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool004h0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000=P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00@0oooo001F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000
=P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0/0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`00E@3oool2000000@0oooo0P0000040?ooo`800000<P3o
ool2000003H0oooo0P0000040?ooo`800000103oool200000300oooo0P0000040?ooo`800000103o
ool2000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000K0?ooool000001@0000010?ooo`006`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool100000040oooo000D0?ooo`80
00001@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00
4`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`800000000C0?ooo`040000003oool0oooo000000@0
ooooo`00000500000040oooo000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool02@3oool00`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool05@3oool100000040oooo000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool02@3oool00`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3o
ool05@3oool100000040oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`030000
0000o`000?l000T00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
003oool0oooo01D0oooo00<00000003o0000o`002P00o`000`000000oooo0?ooo`0E0?ooo`400000
0@3oool001/0oooo0P00000:0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool02P3o
ool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo01D0oooo00<00000003o0000o`002P00
o`000`000000oooo0?ooo`0D0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool02@3oool0
0`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000X00?l000<000000?ooo`3oool05@3oool1
00000040oooo000K0?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`002@00o`000`00
0000oooo0?ooo`0:0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool05@3oool00`00
00000?l0003o000:003o00030000003oool0oooo01D0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`090?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool02P3oool00`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o00030000003oool0oooo01D0oooo00<00000003o0000o`002P00o`000`000000
oooo0?ooo`0E0?ooo`4000000@3oool001/0oooo0P00000:0?ooo`d00000303oool00`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`0=000000`00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo01D0oooo
3P00000F0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool08P3oool00`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo03X0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0R
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool0>P3oool100000040oooo000K0?oo
o`030000003oool0oooo0280oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`0j0?oo
o`4000000@3oool001/0oooo0P00000S0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0>@3oool200000040oooo000K0?ooo`030000003oool0oooo0280oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
2@3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`000000oooo0?ooo`0j0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool08P3o
ool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo03X0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0>P3oool1
00000040oooo000K0?ooo`030000003oool0oooo0280oooo00<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
0000oooo0?ooo`0j0?ooo`4000000@3oool001/0oooo0P00000S0?ooo`d000003000o`000`000000
0?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0>@3oool200000040
oooo000K0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0>P3oool100000040oooo
00070?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo02h0oooo00<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
00000?ooo`3oool0>P3oool100000040oooo00070?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo03X0oooo0@00
00010?ooo`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000_
0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`09
0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o00030000003oool0oooo03T0oooo0P0000010?ooo`002@3oool00`000000oooo0?ooo`080?oo
o`8000001@3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo03X0oooo0@0000010?oo
o`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0;P3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?oo
o`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`000000oooo0?ooo`0j0?ooo`4000000@3oool000P0oooo0P00000:0?ooo`<0
0000103oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo03X0oooo0@0000010?ooo`00
6`3oool2000002l0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0>@3oool200000040oooo000K0?ooo`030000003o
ool0oooo02h0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0>P3oool100000040oooo000K0?ooo`030000003oool0
oooo02h0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0
oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<000000?ooo`3oool0>P3oool100000040oooo000K0?ooo`030000003oool0oooo
02h0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo
00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<000000?ooo`3oool0>P3oool100000040oooo000K0?ooo`800000;`3oool00`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
oooo0?ooo`0i0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`0j0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?oo
o`0j0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`0j
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`0j0?oo
o`4000000@3oool001/0oooo0P00000_0?ooo`h000002`00o`000`000000oooo0?ooo`090?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l06P00000k0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0
>`3oool00`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0>`3o
ool00`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0>`3oool0
0`0000000?l0003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo0P00000l0?ooo`0300000000o`000?l0
00T00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo
0580oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`0300000000o`000?l000T0
0?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo05<0
oooo0@0000010?ooo`00503oool2000000D0oooo00<000000?ooo`3oool0>`3oool00`0000000?l0
003o0009003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`1C0?ooo`4000000@3oool001<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0k0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool02@3oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00030000003oool0oooo05<0oooo0@0000010?ooo`005P3oool00`000000oooo0?oo
o`020?ooo`800000?03oool=000000/0oooo3P00000;003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`000000oooo0?ooo`1B0?ooo`8000000@3oool001@0oooo0P000005
0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool0D`3oool100000040oooo000D0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1C0?oo
o`4000000@3oool001@0oooo0`0000040?ooo`030000003oool0oooo0600oooo00<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0D`3oool100000040oooo000K0?ooo`800000H@3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1B0?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1C0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1C0?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1C0?ooo`4000000@3oool001/0oooo
0P00001Q0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00030000003oool0oooo0580oooo0P0000010?ooo`006`3oool00`000000oooo0?oo
o`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o00030000003oool0oooo05<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
00030000003oool0oooo05<0oooo0@0000010?ooo`006`3oool200000640oooo00<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0DP3oool200000040oooo000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
D`3oool100000040oooo000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0D`3o
ool100000040oooo000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0D`3oool1
00000040oooo000K0?ooo`800000H@3oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l03P00001D0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040
oooo00090?ooo`030000003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`1P0?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o00030000003oool0oooo0600oooo0@0000010?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo0P00001Q0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1O0?ooo`8000000@3oool000X0oooo00<00000
0?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1P
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1P
0?ooo`4000000@3oool000L0oooo100000090?ooo`<00000103oool00`000000oooo0?ooo`1P0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1P0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040oooo000K0?ooo`800000
H@3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
G`3oool200000040oooo000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo0600oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`1P0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0H03oool10000
0040oooo000K0?ooo`800000H@3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<000000?ooo`3oool0G`3oool200000040oooo000K0?ooo`030000003oool0oooo0600oooo
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo0600oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1P0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0H03oool100000040oooo000K0?ooo`800000H@3oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0G`3oool200000040oooo000K0?ooo`03
0000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo0600oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1P0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040oooo000K0?ooo`800000H@3oool0
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0G`3oool2
00000040oooo000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00030000003oool0oooo0600oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`1P0?ooo`4000000@3oool000d0oooo1@0000020?ooo`8000001@3oool00`000000oooo
0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`1P0?ooo`4000000@3oool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040oooo000?0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000H@3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0G`3oool200000040oooo
000?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
003oool0oooo0600oooo0@0000010?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`000000oooo0?ooo`1P0?ooo`4000000@3oool000h0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1P0?ooo`4000000@3oool001/0oooo0P00001Q
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1O
0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0H03oool100000040oooo000K0?ooo`03
0000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo0600oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1P0?ooo`400000
0@3oool001/0oooo0P00001Q0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l03@00001Q0?ooo`8000000@3o
ool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0
oooo06`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0K03oool100000040oooo000K0?ooo`030000003oool0oooo0600
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1/0?ooo`4000000@3oool001/0oooo
0P00001Q0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0J`3oool200000040oooo
000K0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`1/0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo06`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1P0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0K03oool100000040oooo000K0?ooo`03
0000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1/0?ooo`40
00000@3oool001/0oooo0P00001Q0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00d00000K@3oool200000040oooo000K0?ooo`030000003o
ool0oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0N03oool100000040oooo00000`3oool0000000000003
000000030?ooo`0000000000008000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0600oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<000000?ooo`3oool0N03oool100000040oooo00030?ooo`050000003oool0oooo
0?ooo`0000002`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0600oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
00000?ooo`3oool0N03oool100000040oooo00030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`800000H@3oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1g
0?ooo`8000000@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`8000001@3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo07P0oooo0@0000010?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0N03oool10000
0040oooo00020?ooo`800000103oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0600
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0N03oool100000040oooo000K0?ooo`800000H@3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`1g0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?oo
o`1h0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1h
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1h0?oo
o`4000000@3oool001/0oooo0P00001Q0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo07L0oooo0P0000010?ooo`00
6`3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00030000003oool0oooo07P0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o00030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o00030000003oool0oooo07P0oooo0@0000010?ooo`006`3oool200000640
oooo3@00000;003o00h00000N@3oool200000040oooo000K0?ooo`030000003oool0oooo06`0oooo
00<00000003o0000o`002@00o`000`000000oooo0?ooo`250?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo08D0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l000T00?l000<00000
0?ooo`3oool0Q@3oool100000040oooo000K0?ooo`800000K@3oool00`0000000?l0003o0009003o
00030000003oool0oooo08@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`03
00000000o`000?l000T00?l000<000000?ooo`3oool0Q@3oool100000040oooo000=0?ooo`D00000
0P3oool2000000D0oooo00<000000?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000
003oool0oooo08D0oooo0@0000010?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l000T00?l0
00<000000?ooo`3oool0Q@3oool100000040oooo000?0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool2000006d0oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`240?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<00000
0?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo08D0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo08D0oooo0@0000010?oo
o`003P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo06`0oooo00<00000003o0000
o`002@00o`000`000000oooo0?ooo`250?ooo`4000000@3oool001/0oooo0P00001]0?ooo`030000
0000o`000?l000T00?l000<000000?ooo`3oool0Q03oool200000040oooo000K0?ooo`030000003o
ool0oooo06`0oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`250?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0
oooo08D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l0
00T00?l000<000000?ooo`3oool0Q@3oool100000040oooo000K0?ooo`030000003oool0oooo06`0
oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`250?ooo`4000000@3oool001/0oooo
0P00001]0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0Q03oool200000040oooo
000K0?ooo`030000003oool0oooo06`0oooo00<00000003o0000o`002@00o`000`000000oooo0?oo
o`250?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0K03oool00`0000000?l0003o0009
003o00030000003oool0oooo08D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1/0?oo
o`0300000000o`000?l000T00?l000<000000?ooo`3oool0Q@3oool100000040oooo000K0?ooo`80
0000K@3oool00`0000000?l0003o0009003o00030000003oool0oooo08@0oooo0P0000010?ooo`00
6`3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0
Q@3oool100000040oooo000K0?ooo`030000003oool0oooo06`0oooo00<00000003o0000o`002@00
o`000`000000oooo0?ooo`250?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0K03oool0
0`0000000?l0003o0009003o00030000003oool0oooo08D0oooo0@0000010?ooo`006`3oool20000
06d0oooo00<00000003o0000o`002@00o`000`000000oooo0?ooo`240?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo08D0
oooo0@0000010?ooo`0000<0oooo0000000000000`0000030?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l000T00?l0
00<000000?ooo`3oool0Q@3oool100000040oooo00030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo
00<00000003o0000o`002@00o`000`000000oooo0?ooo`250?ooo`4000000@3oool000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00
001]0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0Q03oool200000040oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<00000
0?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo08D0oooo0@000001
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00<00000003o0000o`002@00o`00
0`000000oooo0?ooo`250?ooo`4000000@3oool00080oooo0P0000030?ooo`@000002@3oool30000
00@0oooo00<000000?ooo`3oool0K03oool00`0000000?l0003o0009003o00030000003oool0oooo
08D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`0300000000o`000?l000T0
0?l000<000000?ooo`3oool0Q@3oool100000040oooo000K0?ooo`800000K@3oool=000008H0oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool1
00000040oooo000K0?ooool000001@0000010?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {550.25, 408.938}} -> {-297.51, \
58.1382, 1.61944, 0.117914}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot43\  = \ 
        Histogram[beats4[\([3]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0218001 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12372 -6 -4.5 ]
[-0.0125 .12372 0 4.5 ]
[-0.0125 .23272 -12 -4.5 ]
[-0.0125 .23272 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .45072 -12 -4.5 ]
[-0.0125 .45072 0 4.5 ]
[-0.0125 .55972 -12 -4.5 ]
[-0.0125 .55972 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12372 m
.00625 .12372 L
s
[(5)] -0.0125 .12372 1 0 Mshowa
0 .23272 m
.00625 .23272 L
s
[(10)] -0.0125 .23272 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(15)] -0.0125 .34172 1 0 Mshowa
0 .45072 m
.00625 .45072 L
s
[(20)] -0.0125 .45072 1 0 Mshowa
0 .55972 m
.00625 .55972 L
s
[(25)] -0.0125 .55972 1 0 Mshowa
.125 Mabswid
0 .03652 m
.00375 .03652 L
s
0 .05832 m
.00375 .05832 L
s
0 .08012 m
.00375 .08012 L
s
0 .10192 m
.00375 .10192 L
s
0 .14552 m
.00375 .14552 L
s
0 .16732 m
.00375 .16732 L
s
0 .18912 m
.00375 .18912 L
s
0 .21092 m
.00375 .21092 L
s
0 .25452 m
.00375 .25452 L
s
0 .27632 m
.00375 .27632 L
s
0 .29812 m
.00375 .29812 L
s
0 .31992 m
.00375 .31992 L
s
0 .36352 m
.00375 .36352 L
s
0 .38532 m
.00375 .38532 L
s
0 .40712 m
.00375 .40712 L
s
0 .42892 m
.00375 .42892 L
s
0 .47252 m
.00375 .47252 L
s
0 .49432 m
.00375 .49432 L
s
0 .51612 m
.00375 .51612 L
s
0 .53792 m
.00375 .53792 L
s
0 .58152 m
.00375 .58152 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12372 m
1 .12372 L
s
.99375 .23272 m
1 .23272 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .45072 m
1 .45072 L
s
.99375 .55972 m
1 .55972 L
s
.125 Mabswid
.99625 .03652 m
1 .03652 L
s
.99625 .05832 m
1 .05832 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .10192 m
1 .10192 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .18912 m
1 .18912 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29812 m
1 .29812 L
s
.99625 .31992 m
1 .31992 L
s
.99625 .36352 m
1 .36352 L
s
.99625 .38532 m
1 .38532 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42892 m
1 .42892 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .49432 m
1 .49432 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .58152 m
1 .58152 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .03652 L
.09524 .03652 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03652 L
.09524 .03652 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .05832 L
.14286 .05832 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05832 L
.14286 .05832 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .10192 L
.19048 .10192 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10192 L
.19048 .10192 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .10192 L
.2381 .10192 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10192 L
.2381 .10192 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .10192 L
.33333 .10192 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .10192 L
.33333 .10192 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .05832 L
.38095 .05832 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .05832 L
.38095 .05832 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .14552 L
.42857 .14552 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .14552 L
.42857 .14552 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .27632 L
.47619 .27632 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .27632 L
.47619 .27632 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .27632 L
.57143 .27632 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .27632 L
.57143 .27632 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .18912 L
.61905 .18912 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .18912 L
.61905 .18912 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .23272 L
.66667 .23272 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .23272 L
.66667 .23272 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0040oooo000:0?oo
o`8000001@3oool00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo03d0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00X0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000000/0oooo3P00000;0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0?03oool2000000<0oooo000A0?ooo`030000003oool0
oooo01L0oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003oool0
oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`0:0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0
oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo01L0oooo00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o
0000o`090000o`030000003oool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
000H0?ooo`d0000030000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l>000000`0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000oooo0?oo
o`0l0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`09
0000o`030000003oool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool08`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?oo
o`3oool02P3oool00`000000003o0000o`090000o`030000003oool0oooo03d0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
0000003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
8`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0
2P3oool00`000000003o0000o`090000o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000T0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0:0?ooo`d00000?P3oool2
000000<0oooo000A0?ooo`030000003oool0oooo02<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`0:0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo00X0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool02P3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000002@0oooo6`00000<0000o`d00000303oool00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1E0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo01H0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
5P3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03d0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003oool0
oooo03d0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000<0?ooo`030000003oool0oooo
0080oooo0`00000m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1D0?ooo`<000000`3oool000X0oooo0P0000050?ooo`030000003oool0oooo03d0
oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000:0?ooo`<00000103oool00`000000oooo0?oo
o`0m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool05P3oool00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03d0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`0F0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000003o0000o`0:0000
o`030000003oool0oooo01H0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003h0oooo3P00000H0?ooo`h000002`000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3oool00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0E@3oool2000000<0
oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0L03oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool200000740oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o3@00000<0000o`030000003oool0oooo05D0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0700oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00T0
oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o
0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001a0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`09
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`800000
1@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo0`00001`0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo3P00001F0?ooo`<00000
0`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0L03oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0700oooo00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo0700oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0L03oool00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000L@3oool00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1^0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0L03oool00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0700oooo00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1`
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0L03oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000L@3oool=000000`0003o3P00001`0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool0
0`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000
003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00001m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000O@3oool00`000000003o0000o`0:0000o`030000003o
ool0oooo07/0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0
003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo
0P0000050?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000007`0oooo00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`1j0?ooo`<000000`3oool000D0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0
oooo07`0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool3000000@0
oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o
0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001m0?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000O@3oool00`00
0000003o0000o`0:0000o`030000003oool0oooo07/0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1l0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000007d0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000
003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03o
ool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0
oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`00
0000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?oo
o`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?oo
o`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool3000007`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1j0?oo
o`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000
003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001m0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0N`3oool2000000<0oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000O@3oool0
0`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool2000007d0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool0
0`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<00000
0?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool3000007`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1j0?oo
o`<000000`3oool000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3o
ool0O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0040oooo00040?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0
O03oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0O03oool00`000000003o0000o`0:0000o`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool0
0`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001m0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0N`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07`0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000O@3oool>000007d0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {-280.554, \
0.150597, 1.57972, 0.172533}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{plot4, \ plot41, \ plot42, \ plot43}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0105108 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11982 -12 -4.5 ]
[-0.0125 .11982 0 4.5 ]
[-0.0125 .22493 -12 -4.5 ]
[-0.0125 .22493 0 4.5 ]
[-0.0125 .33004 -12 -4.5 ]
[-0.0125 .33004 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .54025 -12 -4.5 ]
[-0.0125 .54025 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11982 m
.00625 .11982 L
s
[(10)] -0.0125 .11982 1 0 Mshowa
0 .22493 m
.00625 .22493 L
s
[(20)] -0.0125 .22493 1 0 Mshowa
0 .33004 m
.00625 .33004 L
s
[(30)] -0.0125 .33004 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(40)] -0.0125 .43515 1 0 Mshowa
0 .54025 m
.00625 .54025 L
s
[(50)] -0.0125 .54025 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .0988 m
.00375 .0988 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .18289 m
.00375 .18289 L
s
0 .20391 m
.00375 .20391 L
s
0 .24595 m
.00375 .24595 L
s
0 .26697 m
.00375 .26697 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .35106 m
.00375 .35106 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .51923 m
.00375 .51923 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11982 m
1 .11982 L
s
.99375 .22493 m
1 .22493 L
s
.99375 .33004 m
1 .33004 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .54025 m
1 .54025 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03574 L
.09524 .03574 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03574 L
.09524 .03574 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04625 L
.14286 .04625 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04625 L
.14286 .04625 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .10931 L
.19048 .10931 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10931 L
.19048 .10931 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .11982 L
.2381 .11982 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .11982 L
.2381 .11982 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .20391 L
.28571 .20391 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .20391 L
.28571 .20391 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .06727 L
.33333 .06727 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .06727 L
.33333 .06727 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .14084 L
.38095 .14084 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .14084 L
.38095 .14084 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .288 L
.42857 .288 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .288 L
.42857 .288 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .47719 L
.47619 .47719 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .47719 L
.47619 .47719 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .47719 L
.57143 .47719 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .47719 L
.57143 .47719 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .24595 L
.66667 .24595 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24595 L
.66667 .24595 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .11982 L
.71429 .11982 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11982 L
.71429 .11982 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .06727 L
.80952 .06727 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06727 L
.80952 .06727 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02523 L
.85714 .02523 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02523 L
.85714 .02523 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02523 L
.90476 .02523 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02523 L
.90476 .02523 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04415 L
.14286 .04415 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04415 L
.14286 .04415 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .10301 L
.19048 .10301 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10301 L
.19048 .10301 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .07358 L
.2381 .07358 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07358 L
.2381 .07358 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .22073 L
.28571 .22073 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .22073 L
.28571 .22073 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .01472 L
.33333 .01472 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .1913 L
.42857 .1913 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .1913 L
.42857 .1913 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .42674 L
.47619 .42674 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .42674 L
.47619 .42674 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .45617 L
.52381 .45617 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .16187 L
.80952 .16187 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .16187 L
.80952 .16187 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .14552 L
.2381 .14552 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .14552 L
.2381 .14552 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .04742 L
.33333 .04742 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04742 L
.33333 .04742 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14552 L
.71429 .14552 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04742 L
.90476 .04742 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0218001 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12372 -6 -4.5 ]
[-0.0125 .12372 0 4.5 ]
[-0.0125 .23272 -12 -4.5 ]
[-0.0125 .23272 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .45072 -12 -4.5 ]
[-0.0125 .45072 0 4.5 ]
[-0.0125 .55972 -12 -4.5 ]
[-0.0125 .55972 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12372 m
.00625 .12372 L
s
[(5)] -0.0125 .12372 1 0 Mshowa
0 .23272 m
.00625 .23272 L
s
[(10)] -0.0125 .23272 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(15)] -0.0125 .34172 1 0 Mshowa
0 .45072 m
.00625 .45072 L
s
[(20)] -0.0125 .45072 1 0 Mshowa
0 .55972 m
.00625 .55972 L
s
[(25)] -0.0125 .55972 1 0 Mshowa
.125 Mabswid
0 .03652 m
.00375 .03652 L
s
0 .05832 m
.00375 .05832 L
s
0 .08012 m
.00375 .08012 L
s
0 .10192 m
.00375 .10192 L
s
0 .14552 m
.00375 .14552 L
s
0 .16732 m
.00375 .16732 L
s
0 .18912 m
.00375 .18912 L
s
0 .21092 m
.00375 .21092 L
s
0 .25452 m
.00375 .25452 L
s
0 .27632 m
.00375 .27632 L
s
0 .29812 m
.00375 .29812 L
s
0 .31992 m
.00375 .31992 L
s
0 .36352 m
.00375 .36352 L
s
0 .38532 m
.00375 .38532 L
s
0 .40712 m
.00375 .40712 L
s
0 .42892 m
.00375 .42892 L
s
0 .47252 m
.00375 .47252 L
s
0 .49432 m
.00375 .49432 L
s
0 .51612 m
.00375 .51612 L
s
0 .53792 m
.00375 .53792 L
s
0 .58152 m
.00375 .58152 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12372 m
1 .12372 L
s
.99375 .23272 m
1 .23272 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .45072 m
1 .45072 L
s
.99375 .55972 m
1 .55972 L
s
.125 Mabswid
.99625 .03652 m
1 .03652 L
s
.99625 .05832 m
1 .05832 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .10192 m
1 .10192 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .18912 m
1 .18912 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29812 m
1 .29812 L
s
.99625 .31992 m
1 .31992 L
s
.99625 .36352 m
1 .36352 L
s
.99625 .38532 m
1 .38532 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42892 m
1 .42892 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .49432 m
1 .49432 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .58152 m
1 .58152 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .03652 L
.09524 .03652 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03652 L
.09524 .03652 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .05832 L
.14286 .05832 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05832 L
.14286 .05832 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .10192 L
.19048 .10192 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10192 L
.19048 .10192 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .10192 L
.2381 .10192 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10192 L
.2381 .10192 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .10192 L
.33333 .10192 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .10192 L
.33333 .10192 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .05832 L
.38095 .05832 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .05832 L
.38095 .05832 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .14552 L
.42857 .14552 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .14552 L
.42857 .14552 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .27632 L
.47619 .27632 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .27632 L
.47619 .27632 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .27632 L
.57143 .27632 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .27632 L
.57143 .27632 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .18912 L
.61905 .18912 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .18912 L
.61905 .18912 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .23272 L
.66667 .23272 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .23272 L
.66667 .23272 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00>`3oool500000080oooo
0P0000040?ooo`800000503oool2000001L0oooo1@0000020?ooo`800000103oool200000100oooo
100000030?ooo`800000103oool2000003X0oooo1@0000020?ooo`800000103oool2000001@0oooo
0P00000E0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool2000000@0oooo
0P00003O0?ooo`D000000P3oool2000000@0oooo0P00000E0?ooo`8000005P3oool500000080oooo
0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`8000005`3oool003d0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000>00oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000001H0oooo000m0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool00000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000005P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00003P0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000F0?ooo`00=@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000H0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0<@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0eP3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0503oool003d0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000004@0oooo1@0000020?ooo`800000103oool200000140oooo
0P00000D0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2000000@0oooo
0P00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F
0?ooo`00?03oool2000000@0oooo0P0000040?ooo`800000503oool2000001P0oooo0P0000040?oo
o`800000103oool200000140oooo0P0000040?ooo`800000103oool2000003/0oooo0P0000040?oo
o`800000103oool2000001@0oooo0P00000F0?ooo`800000103oool2000000@0oooo0P00000@0?oo
o`800000103oool2000000@0oooo0P0000170?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
5@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000i0?ooo`800000103oool2000000@0oooo0P00000E0?ooo`8000005`3o
ool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`8000005`3o
ool00?l0ooooSP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
^@3oool00?l0ooooQP3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0]`3oool00?l0ooooSP3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000^@3oool00?l0ooooS@3oool2000000@0oooo0P0000040?oo
o`8000004@3oool2000001D0oooo0P0000040?ooo`800000103oool2000000h0oooo0P0000040?oo
o`800000103oool200000;X0oooo000K0?ooo`800000103ooon4000001/0oooo0P0000040?oooh00
0000_`3oool2000000@0ooooQ000000G0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0_03oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo000J0?ooo`040000003oool0oooo000000<0ooooQ000000J
0?ooo`040000003oool0oooo000000<0ooooP@00002m0?ooo`040000003oool0oooo000000<0oooo
Q@00000F0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl>000000/0oooo00<000000?ooo`3oool0603oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo02H0oooo0P0000030?ooogT00000603oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0E0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`006`3o
ool2000000@0oooo00<000000?ooo`3oool00`3oool7000000D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo00<000000?ooo`3oool06@3o
ool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo00l0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`0000020?ooogT00000
6@3oool2000000@0oooo0P0000040?ooo`P000001@000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000
003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool02@3o
ool7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01l0oooo0P00000:0?ooo`L000001@3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000L000004@3o
ool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
5@3oool00240oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o
ool0oooo01D0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`0000020?ooo`800000
103oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0
203oool2000001l0oooo00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`008@3o
ool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0V0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`0300000000
o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01d0oooo0P00000;0?ooo`L000001@000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l7000000D0003o00<000000000o`000?l01000
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0
oooo00l0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl7
000001P0oooo00<000000?ooo`3oool07`3oool200000100oooo00<000000?l0003o00000`3o0007
000000D0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0
oooo01D0oooo00<000000?ooo`3oool0:`3oool2000000@0oooo1P0000050?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00L000001@00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool02@3oool6
000000X0oooo0P00000O0?ooo`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo
00l0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003oool0oooo
00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo
01`0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool03`3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo02/0oooo0P00000?0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<000000?ooo`3oool06@3oool2000001l0oooo0P00000A0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l010000?l00`000000oooo0?ooo`030?ooo`L000007P3oool00`000000
oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`L000007P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000030?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0>0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`030000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool00240oooo00<0
00000?ooo`3oool03`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo0P00
000@0?ooo`L000001@3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo1000
00030?ooo`800000103oool2000000<0oooo0P00000?0?ooo`L000001@00o`000`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<000000?ooo`3oool06@3oool2000001l0oooo0P00
000A0?ooo`d000001P000?l7000000D0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0E0?ooo`00503oool500000080oooo0P0000040?ooo`030000003oool0oooo00l0oooo20000005
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0D0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<0
00000?ooo`3oool0703oool00`000000003o0000o`040000o`030000003oool0oooo00T0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool06`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000001D0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0
6@3oool2000001P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0L0?ooo`03
000000000?l0003o00@0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01D0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000001P0oooo1`00000507moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl8000002<0oooo0P00000Q0?ooo`030000003oool0oooo01/0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo0P0000030?oo
o`030000003oool0oooo01@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?oo
o`040000003oool0oooo0?ooo`8000007@3oool00`000000003o0000o`040000o`030000003oool0
oooo00T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool07`3oool2000001`0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0P3oool2000001D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<000000?ooo`3oool06@3oool2000001T0oooo0P0000040?ooo`030000
003oool0oooo01`0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool001H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01X0oooo0P00000:0?ooo`<000000P3oool00`000000oooo0?ooo`0D0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01`0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`090?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool001D0oooo0P0000040?ooo`800000
103oool00`000000oooo0?ooo`0L0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
0`3oool8000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool2000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02/0oooo0P00000E0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
003oool0oooo01T0oooo0P00000I0?ooo`<000000`3oool2000001d0oooo2000000;0?ooo`L00000
1P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
5@3oool00240oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0H0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0503oool00`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`008@3o
ool00`000000oooo0?ooo`0L0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool0oooo
0P00000L0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool8000000D0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o0007000000D0o`0000<000000?ooo`3oool00`3oool7000001L0oooo
00<000000?ooo`3oool0:`3oool2000001D0oooo1`000004003o00030000003oool0oooo00<0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`0<000001/0oooo0P00000O0?ooo`030000003oool0oooo03D0oooo
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000003oool0oooo02P0oooo
00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0703oool00`000000Ogmo07mo
O`0307moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0I0?ooo`800000103oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool02P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo0240oooo00<0
00000?ooo`3oool09P3oool2000000<0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01d0oooo0P00000f0?ooo`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l010000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo000Q
0?ooo`030000003oool0oooo01`0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0:
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0:
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0U
0?ooo`040000003oool0oooo00000080oooo0P00000K0?ooo`0300000000o`000?l000800?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo0P00
000O0?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l010000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`030000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool00240oooo00<00000
0?ooo`3oool0703oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00X0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0I0?ooo`<000000`3oool2000001`0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0:0?ooo`L000001@3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`L000008`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo008000006`3oool6
000000D0oooo1`000004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0T0?ooo`8000007`3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01D0oooo000Q0?ooo`030000003oool0oooo01`0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0403oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool20000
00<0oooo00<000000?ooo`3oool0:`3oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01d0oooo0P00000f0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`L000001P000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01D0oooo000Q0?ooo`030000003oool0oooo01`0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0403oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`020?ooo`800000;03oool00`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0T0?ooo`8000007`3oool00`000000
oooo0?ooo`0e0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo01`0oooo
1`00000<0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0K0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0403oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool300000080oooo
00<000000?ooo`3oool0:`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0=@3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`00503oool4000000<0oooo0P00
00040?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0O0?ooo`800000703oool700000180oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02/0oooo0P00000/0?ooo`0300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo0P00
000O0?ooo`800000=P3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`00503oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0[0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo02D0oooo00<000000?ooo`3oool0403oool500000080oooo0P00
00040?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l010000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`040000o`030000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool001D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02l0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0:03oool200000240oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool0:`3oool2000002`0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0903oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000=`3oool00`000000003o0000o`040000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0
003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02/0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000003H0oooo00<000000000o`000?l01000
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3o
ool8000002X0oooo00<000000?ooo`3oool05@3oool001@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`L00000:`3oool00`000000oooo0?ooo`0O0?ooo`800000
=@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000<0oooo0P00000/0?ooo`030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`07000002H0oooo0P00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003L0oooo00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0E0?ooo`005@3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0[0?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo0?ooo`800000=P3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo000Q
0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000/0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`8000004`3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l010000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`00
0000oooo0?ooo`0[0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=@3oool00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo02l0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02l0
oooo00<000000?ooo`3oool07`3oool2000003D0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`020?ooo`800000;03oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool0:P3oool2000001l0oooo0P00000f0?ooo`P000001@000?l70000
03L0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0;`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0B0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool06@3oool4000000T0
oooo0`0000020?ooo`030000003oool0oooo02/0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o00030000003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0_0?ooo`L000001@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000=P3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:`3oool2000002`0oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o00030000003oool0oooo02X0oooo0P00000O0?ooo`030000003oool0oooo
03`0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01D0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo0?ooo`800000=@3oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo02d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01d0oooo0P00000m0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02/0oooo0P00000/0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`8000007`3o
ool00`000000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0E0?ooo`005@3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
=P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0[0?ooo`0300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
?03oool00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
5@3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0O0?ooo`D0
00000P3oool2000000<0oooo0P00000/0?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`000000oooo0?ooo`0Z0?ooo`8000007`3oool2000003d0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000F0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003L0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`8000008@3oool2000003D0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0240oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000002d0oooo00<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o00030000003oool0oooo02/0oooo00<000000?ooo`3oool0403o
ool500000080oooo0P0000040?ooo`030000003oool0oooo03`0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000G0?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`3oool0oooo0000000g0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0240oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000;03oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0:P3oool2000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000?P3oool0
0`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool0
01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02d0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000;@3oool00`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0P00000m0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`005@3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo1`00000a0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0=03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000/0?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?oo
o`800000503oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0l0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?oo
o`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool07`3oool2000003D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0200oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0[0?ooo`03
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03`0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02/0oooo0P00000/0?ooo`030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l01P00000/0?ooo`8000004`3oool2000000@0oooo0`0000030?ooo`800000
?@3oool00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
5@3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03`0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02/0oooo0P00000/0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0;`3oool2000001l0oooo00<000000?ooo`3oool0?03oool0
0`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool0
0240oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01l0oooo0P00000e0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000L00000;`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02/0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01d0oooo0P00000m0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03D0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03<0
oooo00<000000?ooo`3oool04`3oool5000000030?ooo`0000000000008000000`3oool2000000@0
oooo0P0000030?ooo`800000;03oool00`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`0700000340oooo0P00000O0?ooo`030000003oool0oooo03`0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0
oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02/0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03`0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0O0?ooo`800000=@3oool7000000D0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000;03oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0e0?ooo`8000007`3oool2000003d0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000F0?ooo`<000000P3oool2000000@0oooo
00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool0:`3oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?03oool00`000000003o
0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool001L0oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000003L0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0B0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3o
ool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000/0?ooo`0300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
03D0oooo0P00000O0?ooo`800000?@3oool00`000000003o0000o`030000o`030000003oool0oooo
03/0oooo00<000000?ooo`3oool05@3oool001@0oooo1@0000001@3oool000000?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`8000005P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000l0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo01@0oooo0P0000040?ooo`8000002P3oool300000080oooo00<000000?ooo`3oool0:`3o
ool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0100oooo100000030?ooo`800000103o
ool00`000000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0E0?ooo`00503oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0=@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000003/0
oooo1`0000050?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool0:`3oool2000002`0
oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0=@3oool200000180oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo03`0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000E0?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`800000103oool00`00
0000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2
000003d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01D0oooo000F0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool0=@3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo02/0oooo0P00000/0?ooo`H000001@00o`070000
03L0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000003h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0C0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0@03oool0
0`000000o`000?l000030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0`0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool07`3oool200000440oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01l0oooo1@0000020?ooo`8000000`3o
ool200000340oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0k0?ooo`8000004`3o
ool2000000@0oooo0P0000040?ooo`800000?@3oool00`000000003o0000o`030000o`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0=@3oool7
000000H0Ogmo1`00000g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@03oool0
0`000000o`000?l000030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool08@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<P3oool00`0000000?l0
003o0003003o00030000003oool0oooo03`0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0200000340oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`0k0?ooo`8000007`3oool00`000000oooo0?ooo`0l0?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool0
0`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool2
000000<0oooo00<000000?ooo`3oool0<03oool00`0000000?l0003o0003003o00030000003oool0
oooo03`0oooo00<000000?ooo`3oool07@3oool2000003d0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo
03/0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01l0oooo0P0000110?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20000
0340oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0k0?ooo`8000007`3oool00`00
0000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0200
oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0`0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03`0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0
oooo000Q0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@03oool00`000000o`00
0?l000030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool0:`3oool200000340oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0k0?ooo`8000007`3oool2000003d0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo
000E0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo07mo
O`0407moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool07`3oool200000440oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0<03oool00`0000000?l0003o0003003o00030000003oool0oooo03`0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`00503oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo
07moO`0407moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0[0?ooo`800000<@3oool00`0000000?l0003o0003003o00030000003oool0oooo03/0oooo
0P00000O0?ooo`030000003oool0oooo03`0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000G0?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo0000000m0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0>P3oool200000240oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l00003
0000003oool0oooo03<0oooo00<000000?ooo`3oool04`3oool5000000<0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo0300oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01d0oooo0P00000m0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`00
5@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0k0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo00000080oooo0P00000a0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0>`3oool200000180oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0l0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?oo
o`005@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0>`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03/0oooo00<000000?oo
o`3oool07`3oool200000440oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00800000<@3oool00`0000000?l0003o0003003o00030000003oool0oooo
03/0oooo0P00000B0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0E0?ooo`005@3oool3000000<0oooo0P0000040?ooo`030000003oool0oooo
03/0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo0P0000030?ooo`030000003oool0oooo0300oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool2000003d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03/0oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0180oooo100000030?oo
o`800000103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000a0?ooo`L00000?@3oool2
000001@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0?03oool0
0`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool0
0240oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo
03/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0
oooo03<0oooo00<000000?ooo`3oool0503oool2000000<0oooo100000090?ooo`<000000P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0P00000m0?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`008@3oool0
0`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool200000440oooo1`00000e0?ooo`030000003oool0oooo02/0ooooN@00000C0?ooo`800000103o
ool3000000<0oooo00<000000?ooo`3oool0?03oool00`000000003o0000o`030000o`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3oool0>`3oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool0503oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo03`0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo01D0oooo000Q0?ooo`030000003oool0oooo03/0oooo2000000m0?ooo`030000003o
ool0oooo0180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oooh00
0000a@3oool2000003d0oooo1`00000m0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`800000
103oool200000?l0ooooBP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool05@3oool00240ooooQ000003o0?ooofL0ooooQ000000G0?ooo`00o`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {261.688, 184.75}} -> {-0.331812, \
1.43522, 0.00627702, 0.00627702}, {{42.25, 160.813}, {259.813, 186.563}} -> \
{-414.523, 156.966, 3.20758, 0.726593}, {{172.688, 291.25}, {259.813, \
186.563}} -> {-968.333, 57.9382, 3.31334, 0.268054}, {{303.063, 421.625}, \
{259.813, 186.563}} -> {-1622.29, 54.5816, 3.51774, 0.256132}, {{433.5, \
552.063}, {259.813, 186.563}} -> {-1983.23, 75.6802, 3.20758, 0.350323}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({DispersionReport[diffs4]}\  // \ Transpose\)\  // \ 
      TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 4159.739902492323`\)},
          {\(StandardDeviation \[Rule] 64.49604563453734`\)},
          {\(SampleRange \[Rule] 452.`\)},
          {\(MeanDeviation \[Rule] 47.91493595584464`\)},
          {\(MedianDeviation \[Rule] 34.`\)},
          {\(QuartileDeviation \[Rule] 34.5`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats4\  = \ 
        Map[DispersionReport, beats4]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats4]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 3700.0868075385492`\), \(Variance \[Rule] 
              3636.952979249953`\), \(Variance \[Rule] 4989.445650104701`\)},
          {\(StandardDeviation \[Rule] 
              60.82833885236838`\), \(StandardDeviation \[Rule] 
              60.30715529064485`\), \(StandardDeviation \[Rule] 
              70.63600816937988`\)},
          {\(SampleRange \[Rule] 283.`\), \(SampleRange \[Rule] 
              333.`\), \(SampleRange \[Rule] 409.`\)},
          {\(MeanDeviation \[Rule] 
              46.09293995664057`\), \(MeanDeviation \[Rule] 
              45.99585257799977`\), \(MeanDeviation \[Rule] 
              52.69186539730413`\)},
          {\(MedianDeviation \[Rule] 34.`\), \(MedianDeviation \[Rule] 
              37.`\), \(MedianDeviation \[Rule] 31.`\)},
          {\(QuartileDeviation \[Rule] 31.875`\), \(QuartileDeviation \[Rule] 
              36.875`\), \(QuartileDeviation \[Rule] 33.`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, and \
the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(info4\  = \ 
      Transpose[{Range[3], \ 
            N[Map[Mean, \ 
                Abs[beats4]]], \[IndentingNewLine]Map[\((StandardDeviation\  \
/. \ #)\) &, \ stats4]}]\ \  // \ TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "47.754453765670654`", "60.82833885236838`"},
          {"2", "46.01263078518237`", "60.30715529064485`"},
          {"3", "49.977723316680795`", "70.63600816937988`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Accuracy summary for all beats of the four performances of two mazurkas:\
\>", "Subsection"],

Cell[BoxData[{
    \(\(alldiffs\  = \ 
        Flatten[{diffs1, \ diffs2, \ diffs3, \ 
            diffs4}];\)\), "\[IndentingNewLine]", 
    \(\(allbeats\  = \ Transpose[Partition[alldiffs, \ 3]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(allplot\  = \ 
        Histogram[alldiffs, \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00289953 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15969 -12 -4.5 ]
[-0.0125 .15969 0 4.5 ]
[-0.0125 .30467 -18 -4.5 ]
[-0.0125 .30467 0 4.5 ]
[-0.0125 .44964 -18 -4.5 ]
[-0.0125 .44964 0 4.5 ]
[-0.0125 .59462 -18 -4.5 ]
[-0.0125 .59462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15969 m
.00625 .15969 L
s
[(50)] -0.0125 .15969 1 0 Mshowa
0 .30467 m
.00625 .30467 L
s
[(100)] -0.0125 .30467 1 0 Mshowa
0 .44964 m
.00625 .44964 L
s
[(150)] -0.0125 .44964 1 0 Mshowa
0 .59462 m
.00625 .59462 L
s
[(200)] -0.0125 .59462 1 0 Mshowa
.125 Mabswid
0 .04371 m
.00375 .04371 L
s
0 .07271 m
.00375 .07271 L
s
0 .1017 m
.00375 .1017 L
s
0 .1307 m
.00375 .1307 L
s
0 .18869 m
.00375 .18869 L
s
0 .21768 m
.00375 .21768 L
s
0 .24668 m
.00375 .24668 L
s
0 .27567 m
.00375 .27567 L
s
0 .33366 m
.00375 .33366 L
s
0 .36266 m
.00375 .36266 L
s
0 .39165 m
.00375 .39165 L
s
0 .42065 m
.00375 .42065 L
s
0 .47864 m
.00375 .47864 L
s
0 .50763 m
.00375 .50763 L
s
0 .53663 m
.00375 .53663 L
s
0 .56563 m
.00375 .56563 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15969 m
1 .15969 L
s
.99375 .30467 m
1 .30467 L
s
.99375 .44964 m
1 .44964 L
s
.99375 .59462 m
1 .59462 L
s
.125 Mabswid
.99625 .04371 m
1 .04371 L
s
.99625 .07271 m
1 .07271 L
s
.99625 .1017 m
1 .1017 L
s
.99625 .1307 m
1 .1307 L
s
.99625 .18869 m
1 .18869 L
s
.99625 .21768 m
1 .21768 L
s
.99625 .24668 m
1 .24668 L
s
.99625 .27567 m
1 .27567 L
s
.99625 .33366 m
1 .33366 L
s
.99625 .36266 m
1 .36266 L
s
.99625 .39165 m
1 .39165 L
s
.99625 .42065 m
1 .42065 L
s
.99625 .47864 m
1 .47864 L
s
.99625 .50763 m
1 .50763 L
s
.99625 .53663 m
1 .53663 L
s
.99625 .56563 m
1 .56563 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02921 L
.04762 .02921 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02921 L
.04762 .02921 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03791 L
.09524 .03791 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03791 L
.09524 .03791 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04661 L
.14286 .04661 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04661 L
.14286 .04661 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06981 L
.19048 .06981 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06981 L
.19048 .06981 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1046 L
.2381 .1046 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1046 L
.2381 .1046 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .122 L
.28571 .122 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .122 L
.28571 .122 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .1133 L
.33333 .1133 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .1133 L
.33333 .1133 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .20608 L
.38095 .20608 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .20608 L
.38095 .20608 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .59752 L
.42857 .59752 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .59752 L
.42857 .59752 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .53083 L
.47619 .53083 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .53083 L
.47619 .53083 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .50474 L
.57143 .50474 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .50474 L
.57143 .50474 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .38295 L
.61905 .38295 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .38295 L
.61905 .38295 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .25538 L
.66667 .25538 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25538 L
.66667 .25538 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .14519 L
.71429 .14519 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14519 L
.71429 .14519 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .07561 L
.7619 .07561 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07561 L
.7619 .07561 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .04371 L
.80952 .04371 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04371 L
.80952 .04371 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03211 L
.85714 .03211 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03211 L
.85714 .03211 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .03211 L
.90476 .03211 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03211 L
.90476 .03211 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02051 L
.95238 .02051 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02051 L
.95238 .02051 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .02341 L
1 .02341 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02341 L
1 .02341 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C`3oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000L0oooo001A0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`00D@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool004T0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo
001A0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`00D03oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000L0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?ooool00000
2`0000010?ooo`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool100000040oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000=0?ooo`040000003oool0oooo
000000@0ooooo`00000;00000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo0@000001
0?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo6P000001
0?ooo`003P3oool2000000D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0F0?oo
o`4000000@3oool001D0oooo3@00000<07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`0F0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
2@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moOaX00000603oool100000040oooo000E0?ooo`030000003o
ool0oooo00T0oooo3P00000<07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`0_0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool05P3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`0_0?ooo`4000000@3oool001D0oooo0P00000G0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl>00000300oooo0P0000010?ooo`005@3oool00`000000
oooo0?ooo`0F0?ooo`h000002`1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0l0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0?03oool100000040oooo000E0?ooo`030000003oool0oooo02<0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`0l0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool08`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03`0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0?03oool100000040oooo000E0?ooo`800000903oool=000000`0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo03/0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl=000003h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0B03oool100000040oooo000E0?ooo`030000003oool0oooo02l0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0;`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0B03oool100000040oooo000E0?ooo`030000003oool0oooo02l0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0oooo0@000001
0?ooo`005@3oool200000300oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo04L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`h0
0000301oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
?03oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`0l0?ooo`030000001oOgl0Ogmo00X0Ogmo3@00000<07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0B03oool100000040oooo000E0?ooo`030000003oool0
oooo03`0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0?03oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
04P0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0l0?ooo`h000002`3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0B03oool100000040
oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo04P0oooo0@0000010?ooo`005@3oool2000005H0oooo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04L0oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`180?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0E@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0B03oool100000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo04P0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo3P00001:0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo05D0oooo0@0000010?ooo`00203oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo05D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool0
00L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo05D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3o
ool000X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000EP3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05@0oooo0P0000010?ooo`00203oool2
000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1E0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool100000040oooo00080?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1E0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool100000040oooo00080?ooo`<000000`3oool2
000000D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo05D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0E@3oool100000040oooo000E0?ooo`030000003oool0oooo05D0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo05D0oooo
0@0000010?ooo`005@3oool2000005H0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`1D0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo05D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool100000040oooo000E0?ooo`03
0000003oool0oooo05D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo05D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`h00000301o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0E@3oool10000
0040oooo000E0?ooo`800000H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1D0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`1E0?ooo`4000000@3oool001D0oooo0P00001S0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo05@0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
05D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl>000005L0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool100000040oooo000E
0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?oo
o`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?oo
o`4000000@3oool001D0oooo0P00001S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`1Q0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
HP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool10000
0040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`0000<0oooo000000000000
0`0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool100000040oooo
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool100000040oooo00030?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo0P00001S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1Q0?ooo`8000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1R
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1R
0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1R0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?ooo`4000000@3o
ool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0HP3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool1
00000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool100000040oooo
000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3oool2000006<0oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0640oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0HP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0HP3oool1
00000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@0000010?ooo`005@3oool2000006<0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0640
oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0HP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0680oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`1R0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0HP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl=000006@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo000E0?ooo`800000H`3oool0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo06d0oooo0P0000010?ooo`005@3oool00`00
0000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool10000
0040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`1^0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo06h0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo000E
0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1^
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo06h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo000E0?ooo`800000
H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06d0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3o
ool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1^0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040
oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`1^0?ooo`4000000@3oool000030?ooo`000000000000<000000P3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`1^0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1R0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040oooo00030?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000
H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06d0oooo0P0000010?ooo`000`3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1^0?ooo`400000
0@3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo06h0oooo0@0000010?ooo`000P3oool2000000@0oooo0`0000030?ooo`8000001@3o
ool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3o
ool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`1^0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0KP3oool100000040
oooo000E0?ooo`800000H`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06d0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0KP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000oooo0?ooo`1^0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0HP3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0KP3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1^0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo06h0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`h00000L03oool100000040oooo000E0?ooo`800000H`3oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`1j0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`1k0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`1k0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`1k0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1k
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1k0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07moO`d0
0000301oOgl00`000000oooo0?ooo`1k0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
HP3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`1k0?ooo`4000000@3oool001D0oooo0P00001S0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo07X0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0
oooo07/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo
07/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0oooo0@000001
0?ooo`005@3oool2000006<0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?oo
o`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0NP3oool200000040oooo000E0?ooo`03
0000003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo000E0?ooo`030000
003oool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo000E0?ooo`030000003oool0
oooo0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo000E0?ooo`030000003oool0oooo
0680oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo00000`3oool0000000000002000000<0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1R0?ooo`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07/0
oooo0@0000010?ooo`0000<0oooo0000003oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0HP3oool00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`1k0?oo
o`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo0P00001S0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0:07moO`030000003oool0oooo07X0oooo0P000001
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0680oooo3P00000;0?ooo`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool0N`3oool100000040oooo00001@3oool000000?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo07/0oooo3P00001m0?ooo`4000000@3oool00080oooo0P0000040?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`005@3ooooo0000
00/000000@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {313.5, 172.188}} -> {-285.949, \
258.494, 1.58326, 1.3001}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(allplot1\  = \ 
        Histogram[allbeats[\([1]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00934292 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10814 -12 -4.5 ]
[-0.0125 .10814 0 4.5 ]
[-0.0125 .20157 -12 -4.5 ]
[-0.0125 .20157 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .38843 -12 -4.5 ]
[-0.0125 .38843 0 4.5 ]
[-0.0125 .48186 -12 -4.5 ]
[-0.0125 .48186 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10814 m
.00625 .10814 L
s
[(10)] -0.0125 .10814 1 0 Mshowa
0 .20157 m
.00625 .20157 L
s
[(20)] -0.0125 .20157 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(30)] -0.0125 .295 1 0 Mshowa
0 .38843 m
.00625 .38843 L
s
[(40)] -0.0125 .38843 1 0 Mshowa
0 .48186 m
.00625 .48186 L
s
[(50)] -0.0125 .48186 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(60)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .0334 m
.00375 .0334 L
s
0 .05209 m
.00375 .05209 L
s
0 .07077 m
.00375 .07077 L
s
0 .08946 m
.00375 .08946 L
s
0 .12683 m
.00375 .12683 L
s
0 .14552 m
.00375 .14552 L
s
0 .1642 m
.00375 .1642 L
s
0 .18289 m
.00375 .18289 L
s
0 .22026 m
.00375 .22026 L
s
0 .23895 m
.00375 .23895 L
s
0 .25763 m
.00375 .25763 L
s
0 .27632 m
.00375 .27632 L
s
0 .31369 m
.00375 .31369 L
s
0 .33237 m
.00375 .33237 L
s
0 .35106 m
.00375 .35106 L
s
0 .36975 m
.00375 .36975 L
s
0 .40712 m
.00375 .40712 L
s
0 .4258 m
.00375 .4258 L
s
0 .44449 m
.00375 .44449 L
s
0 .46318 m
.00375 .46318 L
s
0 .50055 m
.00375 .50055 L
s
0 .51923 m
.00375 .51923 L
s
0 .53792 m
.00375 .53792 L
s
0 .5566 m
.00375 .5566 L
s
0 .59398 m
.00375 .59398 L
s
0 .61266 m
.00375 .61266 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10814 m
1 .10814 L
s
.99375 .20157 m
1 .20157 L
s
.99375 .295 m
1 .295 L
s
.99375 .38843 m
1 .38843 L
s
.99375 .48186 m
1 .48186 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .0334 m
1 .0334 L
s
.99625 .05209 m
1 .05209 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .08946 m
1 .08946 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .1642 m
1 .1642 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .22026 m
1 .22026 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .25763 m
1 .25763 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .31369 m
1 .31369 L
s
.99625 .33237 m
1 .33237 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .36975 m
1 .36975 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4258 m
1 .4258 L
s
.99625 .44449 m
1 .44449 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .50055 m
1 .50055 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .5566 m
1 .5566 L
s
.99625 .59398 m
1 .59398 L
s
.99625 .61266 m
1 .61266 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .0334 L
.04762 .0334 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0334 L
.04762 .0334 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .02406 L
.09524 .02406 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02406 L
.09524 .02406 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04274 L
.19048 .04274 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04274 L
.19048 .04274 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .10814 L
.2381 .10814 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10814 L
.2381 .10814 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .1642 L
.28571 .1642 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .1642 L
.28571 .1642 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .11749 L
.33333 .11749 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11749 L
.33333 .11749 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .52858 L
.42857 .52858 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .52858 L
.42857 .52858 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .45383 L
.47619 .45383 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45383 L
.47619 .45383 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .59398 L
.57143 .59398 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .59398 L
.57143 .59398 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .47252 L
.61905 .47252 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .47252 L
.61905 .47252 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .30435 L
.66667 .30435 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30435 L
.66667 .30435 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .06143 L
.7619 .06143 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .06143 L
.7619 .06143 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .05209 L
.85714 .05209 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05209 L
.85714 .05209 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04274 L
.90476 .04274 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04274 L
.90476 .04274 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .0334 L
.95238 .0334 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0334 L
.95238 .0334 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0334 L
1 .0334 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0334 L
1 .0334 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000o`000?l0000:0?l000h000002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`01
0?ooo`002P3oool2000000D0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool00@3oool00140oooo3P00000<0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o000K000000<0oooo000A0?ooo`030000003oool0oooo01L0oooo00<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003oool0oooo01L0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool05`3oool00`000000o`000?l000090?l000h00000303o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000d000006@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`030000003o0000o`0000T0
o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool08`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000001P0oooo
00<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
3P00000T0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool05`3oool00`000000o`000?l0
00090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01L0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o000=000000`0o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0G0?ooo`030000003o0000o`0000T0o`0000<000000?oo
o`3oool02P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool02@3oool00`000000o`000?l0000:0?l000030000003oool0oooo0300oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool05`3oool00`000000o`000?l000090?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000603oool=000000`0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`0_0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0<03o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3o
ool00`000000o`000?l0000:0?l000030000003oool0oooo0300oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0<03oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool02@3oool>00000380oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0<03oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0`0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`800000<@3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B03oool2000000<0oooo
000A0?ooo`030000003oool0oooo0300oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0<03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?oo
o`030000003oool0oooo0300oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool300000300oooo3P00000<0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04L0oooo0`0000030?oo
o`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0m0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`030000003o0000o`0000X0o`003@00000<0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03d0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03d0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000?P3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo04P0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0m0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0m0?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0m0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000003h0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`180?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000o`000?l0000:
0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0?@3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0?@3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
?@3oool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00000n0?ooo`h000002`3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0B03oool2000000<0oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001G0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`180?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo00030?ooo`@0
00000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo0`00001F0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`170?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool>000000`0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000h00000B`3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05D0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001T0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool3000006<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0E03oool3000000<0oooo00060?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1S
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000h00000F03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l000090?l000030000003oool0oooo0680oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o
ool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000I03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`010?ooo`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<00000
0?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000001@3o
ool000000?ooo`3oool0000000@0oooo0`00001S0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000oooo0?ooo`1Q0?ooo`<000000`3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool000@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool000D0oooo0P000003
0?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l0
00030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1R0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l000090?l000030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000I03oool00`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0HP3oool2000000<0oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`003@00000<0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`1R0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`00
0?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo0004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:
0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000d00000I@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000H0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000H`3oool00`000000o`000?l0
000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo06d0oooo0`0000030?ooo`00103oool2000000<0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0
000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool000@0oooo0`000003
0?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000006@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000
003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000o`000?l0000:0?l000030000003oool0
oooo00T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo00T0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001T0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0KP3oool2000000<0
oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo3P00000;0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07`0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001m0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1^0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0O03oool00`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1l0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo07`0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo06l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0O03oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000007d0oooo00<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo06h0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1l0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06l0oooo00<0
00000?ooo`3oool00@3oool000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1l
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1l0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo0003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool3000007`0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06d0oooo
0`0000030?ooo`000`3oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1l0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1l0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo
00040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0O03oool00`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1l0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000O@3oool00`000000o`000?l0000:0?l000h00000L03oool2000000<0oooo000A0?ooo`03
0000003oool0oooo07`0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07`0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo07`0oooo3P00001n0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000000/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`8000000`3oool00140ooooo`00000=000000<0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {484.563, 343.25}} -> {-280.554, \
166.194, 1.57972, 0.402576}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(allplot2\  = \ 
        Histogram[allbeats[\([2]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00853049 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10002 -12 -4.5 ]
[-0.0125 .10002 0 4.5 ]
[-0.0125 .18532 -12 -4.5 ]
[-0.0125 .18532 0 4.5 ]
[-0.0125 .27063 -12 -4.5 ]
[-0.0125 .27063 0 4.5 ]
[-0.0125 .35593 -12 -4.5 ]
[-0.0125 .35593 0 4.5 ]
[-0.0125 .44124 -12 -4.5 ]
[-0.0125 .44124 0 4.5 ]
[-0.0125 .52654 -12 -4.5 ]
[-0.0125 .52654 0 4.5 ]
[-0.0125 .61185 -12 -4.5 ]
[-0.0125 .61185 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10002 m
.00625 .10002 L
s
[(10)] -0.0125 .10002 1 0 Mshowa
0 .18532 m
.00625 .18532 L
s
[(20)] -0.0125 .18532 1 0 Mshowa
0 .27063 m
.00625 .27063 L
s
[(30)] -0.0125 .27063 1 0 Mshowa
0 .35593 m
.00625 .35593 L
s
[(40)] -0.0125 .35593 1 0 Mshowa
0 .44124 m
.00625 .44124 L
s
[(50)] -0.0125 .44124 1 0 Mshowa
0 .52654 m
.00625 .52654 L
s
[(60)] -0.0125 .52654 1 0 Mshowa
0 .61185 m
.00625 .61185 L
s
[(70)] -0.0125 .61185 1 0 Mshowa
.125 Mabswid
0 .03178 m
.00375 .03178 L
s
0 .04884 m
.00375 .04884 L
s
0 .0659 m
.00375 .0659 L
s
0 .08296 m
.00375 .08296 L
s
0 .11708 m
.00375 .11708 L
s
0 .13414 m
.00375 .13414 L
s
0 .1512 m
.00375 .1512 L
s
0 .16826 m
.00375 .16826 L
s
0 .20239 m
.00375 .20239 L
s
0 .21945 m
.00375 .21945 L
s
0 .23651 m
.00375 .23651 L
s
0 .25357 m
.00375 .25357 L
s
0 .28769 m
.00375 .28769 L
s
0 .30475 m
.00375 .30475 L
s
0 .32181 m
.00375 .32181 L
s
0 .33887 m
.00375 .33887 L
s
0 .373 m
.00375 .373 L
s
0 .39006 m
.00375 .39006 L
s
0 .40712 m
.00375 .40712 L
s
0 .42418 m
.00375 .42418 L
s
0 .4583 m
.00375 .4583 L
s
0 .47536 m
.00375 .47536 L
s
0 .49242 m
.00375 .49242 L
s
0 .50948 m
.00375 .50948 L
s
0 .54361 m
.00375 .54361 L
s
0 .56067 m
.00375 .56067 L
s
0 .57773 m
.00375 .57773 L
s
0 .59479 m
.00375 .59479 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10002 m
1 .10002 L
s
.99375 .18532 m
1 .18532 L
s
.99375 .27063 m
1 .27063 L
s
.99375 .35593 m
1 .35593 L
s
.99375 .44124 m
1 .44124 L
s
.99375 .52654 m
1 .52654 L
s
.99375 .61185 m
1 .61185 L
s
.125 Mabswid
.99625 .03178 m
1 .03178 L
s
.99625 .04884 m
1 .04884 L
s
.99625 .0659 m
1 .0659 L
s
.99625 .08296 m
1 .08296 L
s
.99625 .11708 m
1 .11708 L
s
.99625 .13414 m
1 .13414 L
s
.99625 .1512 m
1 .1512 L
s
.99625 .16826 m
1 .16826 L
s
.99625 .20239 m
1 .20239 L
s
.99625 .21945 m
1 .21945 L
s
.99625 .23651 m
1 .23651 L
s
.99625 .25357 m
1 .25357 L
s
.99625 .28769 m
1 .28769 L
s
.99625 .30475 m
1 .30475 L
s
.99625 .32181 m
1 .32181 L
s
.99625 .33887 m
1 .33887 L
s
.99625 .373 m
1 .373 L
s
.99625 .39006 m
1 .39006 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42418 m
1 .42418 L
s
.99625 .4583 m
1 .4583 L
s
.99625 .47536 m
1 .47536 L
s
.99625 .49242 m
1 .49242 L
s
.99625 .50948 m
1 .50948 L
s
.99625 .54361 m
1 .54361 L
s
.99625 .56067 m
1 .56067 L
s
.99625 .57773 m
1 .57773 L
s
.99625 .59479 m
1 .59479 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02325 L
.04762 .02325 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02325 L
.04762 .02325 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04884 L
.09524 .04884 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04884 L
.09524 .04884 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .03178 L
.14286 .03178 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .03178 L
.14286 .03178 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .04884 L
.19048 .04884 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04884 L
.19048 .04884 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .07443 L
.2381 .07443 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07443 L
.2381 .07443 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .10002 L
.28571 .10002 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10002 L
.28571 .10002 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .59479 L
.42857 .59479 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .59479 L
.42857 .59479 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .57773 L
.52381 .57773 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .57773 L
.52381 .57773 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .5692 L
.57143 .5692 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .5692 L
.57143 .5692 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .35593 L
.61905 .35593 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35593 L
.61905 .35593 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .27063 L
.66667 .27063 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .27063 L
.66667 .27063 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .13414 L
.71429 .13414 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13414 L
.71429 .13414 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .10002 L
.7619 .10002 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .10002 L
.7619 .10002 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .02325 L
.85714 .02325 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02325 L
.85714 .02325 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .03178 L
.90476 .03178 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03178 L
.90476 .03178 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C@3oool500000080oooo0P0000040?ooo`800000<`3oool2000003H0oooo1@0000020?oo
o`800000103oool2000002l0oooo100000030?ooo`800000103oool2000000`0oooo001?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000;0?ooo`00C`3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0_0?ooo`040000003oool0oooo000003L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002`3oool004L0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
001?0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02l0oooo00@000000?ooo`3oool00000=`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000;0?oo
o`00CP3oool2000000@0oooo0P0000040?ooo`800000<`3oool2000003L0oooo0P0000040?ooo`80
0000103oool200000300oooo0P0000040?ooo`800000103oool2000000`0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000D0?ooool00000
1`0000060?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`00303oool2000000H0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`030000003oool0oooo00@0oooo000;0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`8000001@3oool0
00/0oooo00@000000?ooo`3oool000001@3ooooo000000L000001P3oool000/0oooo00@000000?oo
o`3oool000001@3oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo00X0oooo00<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0103oool000/0oooo00@000000?ooo`3oool000001@3oool=000000`00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo00X0oooo3@00000<
003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool000`0oooo0P0000060?oo
o`030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<000000?ooo`3oool05P3oool00`0000000?l0003o000:003o
00030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool001@0oooo0P00000:0?ooo`03
00000000o`000?l000X00?l03@00000<003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo01H0oooo3P00000F0?ooo`80
00001P3oool001@0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o00030000
003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`002P00
o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`090?ooo`0300000000o`00
0?l000X00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0
oooo03/0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool02@3oool00`00
00000?l0003o000:003o00030000003oool0oooo00T0oooo00<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo000D0?ooo`8000002P3oool>000000/0
oooo3P00000;003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`0j0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo02l0oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0_
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool001@0oooo0P00000`0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo03X0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0_0?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
0000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0
;`3oool=000000/00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03/0oooo00<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o00030000003oool0oooo03/0oooo00<000000?ooo`3oool0103o
ool001@0oooo00<000000?ooo`3oool0>`3oool00`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`00503oool20000
03`0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo
03X0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0k0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0
oooo00050?ooo`D000000P3oool2000000H0oooo00<000000?ooo`3oool0>`3oool00`0000000?l0
003o0009003o00h000002`00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`001`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`030000
0000o`000?l000T00?l000<000000?ooo`3oool02P3oool00`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00@0oooo00070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`800000?03oool=000000`0oooo00<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00d00000?03oool2000000H0oooo00070?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00030000003oool0oooo04L0oooo00<000000?ooo`3oool0
103oool000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0E03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`040?ooo`001P3oool2000000@0oooo0P00
00060?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo04L0oooo00<000000?ooo`3oool0103oool001@0oooo0P00001E
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`16
0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`040?oo
o`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000
003oool0oooo05@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
003oool0oooo04L0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03o
ool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`040?ooo`00503oool2000005D0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`0>
000004P0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0E03oool00`000000oooo0?ooo`040?ooo`00503oool00`000000
oooo0?ooo`1D0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`040?ooo`00503oool2000005D0oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1C0?ooo`8000001P3oool001@0oooo00<00000
0?ooo`3oool0E03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3o
ool0E03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0103oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
003oool0oooo05@0oooo00<000000?ooo`3oool0103oool001@0oooo0P00001E0?ooo`0300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<000000?ooo`3oool0D`3oool2000000H0oooo000D0?ooo`030000003oool0
oooo05@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo00@0oooo00050?ooo`@000000`3oool2000000H0oooo00<000000?ooo`3oool0E03oool00`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
05@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool20000
05D0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1C0?ooo`8000001P3oool000L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0E03oool00`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?oo
o`3oool0103oool000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo00@0oooo00060?ooo`800000103oool2000000H0oooo00<000000?oo
o`3oool0E03oool=000000`00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3o
ool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000
H@3oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`1C0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0H03o
ool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0
oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0E03oool00`000000oooo0?ooo`040?ooo`00503oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool001@0
oooo0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo05<0oooo0P0000060?ooo`00503oool00`000000oooo
0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool001@0oooo00<0
00000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00@0oooo000D
0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0E03oool00`000000oooo0?ooo`04
0?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?oo
o`3oool0103oool001@0oooo0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05<0oooo0P0000060?ooo`00
503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3oool0
103oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`040?ooo`00503oool200000640oooo00<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0D`3oool20000
00H0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo05@0oooo
00<000000?ooo`3oool0103oool000H0oooo0P0000040?ooo`8000001P3oool00`000000oooo0?oo
o`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o00030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool000D0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0600oooo
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`040?ooo`001`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool200000640oooo00<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00d00000E@3oool2000000H0oooo00080?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1P0?ooo`030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo00@0oooo00050?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00@0oooo00060?ooo`800000
103oool2000000H0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0H03oool00`000000oooo0?ooo`040?ooo`00503o
ool200000640oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003o
ool0oooo05l0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o00030000003oool0oooo0600oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0H03oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo
0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0G`3oool2000000H0oooo000D
0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o00030000003oool0oooo0600oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?oo
o`3oool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0G`3oool2000000H0oooo000D0?ooo`030000003o
ool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003o
ool0oooo0600oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0H03oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o00030000003oool0oooo0600oooo00<000000?ooo`3oool0103oool001@0oooo
0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`1O0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`040?ooo`001`3oool300000080oooo0P0000060?ooo`030000003oool0oooo0600oooo00<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0600oooo00<00000
0?ooo`3oool0103oool000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o00030000003oool0oooo0600oooo00<000000?ooo`3oool0103oool000D0oooo1@0000001@3o
ool000000?ooo`3oool0000000D0oooo0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l03P00001Q
0?ooo`8000001P3oool000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`001`3oool2000000<0oooo0P000006
0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo06`0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00
503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00503oool0
0`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`040?ooo`00503oool200000640oooo00<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`1/0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0H03oool00`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool001@0oooo
00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo06d0oooo
00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o00030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool001@0oooo0P00001Q
0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K03oool2000000H0oooo000D0?oo
o`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000
003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000H@3oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o00030000003oool0oooo06`0oooo0P0000060?ooo`00503oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool2000000@0oooo0P0000060?ooo`030000003oool0oooo0600
oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0
oooo00050?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`040?ooo`00203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K03oool20000
00H0oooo00060?ooo`8000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool3000000<0oooo0P0000060?ooo`030000003oool0oooo0600
oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0
oooo000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o00030000003oool0oooo06`0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1P
0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`04
0?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`03
00000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00
503oool200000640oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1/0?ooo`800000
1P3oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0H03oool0
0`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o00030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool0
01@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo
06d0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0H03oool00`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool001@0oooo
0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K03oool2000000H0oooo
000D0?ooo`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo0600oooo00<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000
003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo000D0?oo
o`030000003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
0000003oool0oooo06`0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00503o
ool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`040?ooo`001@3oool3000000@0oooo0P0000060?ooo`030000003oool0
oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo00@0oooo00050?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`040?ooo`001@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo0P00001Q0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
K03oool2000000H0oooo00050?ooo`<000000`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`040?ooo`001P3oool3000000<0oooo0P0000060?ooo`030000003o
ool0oooo0600oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`800000H@3oool00`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0
oooo06`0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000
oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?oo
o`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`040?ooo`00503oool200000640oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1/
0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
00030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3o
ool0H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`0=000006l0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0
H03oool00`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000H@3o
ool00`0000000?l0003o000:003o000300000000o`000?l000T00?l03P00001j0?ooo`8000001P3o
ool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`040?ooo`00503oool00`00
0000oooo0?ooo`1P0?ooo`0300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo0600
oooo00<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo08H0
oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0H03oool00`0000000?l0
003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`040?ooo`00503oool200000640oooo3P00000;003o00030000003oool0oooo08D0oooo0P00
00060?ooo`00503oool00`000000oooo0?ooo`1]0?ooo`0300000000o`000?l000T00?l000<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000oooo0?ooo`020?oo
o`8000001P3oool00`000000oooo0?ooo`1]0?ooo`d00000R03oool00`000000oooo0?ooo`040?oo
o`001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0103oool000L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00<0oooo0P00000l0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00P0oooo0P0000060?ooo`00203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0103oool000D0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000050?ooool000001`0000060?ooo`001@3oool4000000<0oooo0P00003o0?oo
oa<0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {-285.596, \
0.447478, 1.60739, 0.448638}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(allplot3\  = \ 
        Histogram[allbeats[\([3]\)], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {\(-200\), \ 200}, \ 
          HistogramCategories \[Rule] 20, \ 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0075462 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(20)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(40)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(60)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .05245 m
.00375 .05245 L
s
0 .09018 m
.00375 .09018 L
s
0 .12791 m
.00375 .12791 L
s
0 .20337 m
.00375 .20337 L
s
0 .2411 m
.00375 .2411 L
s
0 .27883 m
.00375 .27883 L
s
0 .35429 m
.00375 .35429 L
s
0 .39203 m
.00375 .39203 L
s
0 .42976 m
.00375 .42976 L
s
0 .50522 m
.00375 .50522 L
s
0 .54295 m
.00375 .54295 L
s
0 .58068 m
.00375 .58068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .05245 m
1 .05245 L
s
.99625 .09018 m
1 .09018 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .20337 m
1 .20337 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .27883 m
1 .27883 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39203 m
1 .39203 L
s
.99625 .42976 m
1 .42976 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .54295 m
1 .54295 L
s
.99625 .58068 m
1 .58068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02981 L
.04762 .02981 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02981 L
.04762 .02981 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .03735 L
.09524 .03735 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03735 L
.09524 .03735 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .03735 L
.14286 .03735 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .03735 L
.14286 .03735 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .10527 L
.19048 .10527 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10527 L
.19048 .10527 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .12036 L
.2381 .12036 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12036 L
.2381 .12036 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .09772 L
.28571 .09772 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .09772 L
.28571 .09772 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .12036 L
.33333 .12036 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12036 L
.33333 .12036 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .19582 L
.38095 .19582 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19582 L
.38095 .19582 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .48258 L
.47619 .48258 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .48258 L
.47619 .48258 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .57313 L
.52381 .57313 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .57313 L
.52381 .57313 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .33166 L
.57143 .33166 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .33166 L
.57143 .33166 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .30147 L
.61905 .30147 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30147 L
.61905 .30147 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .18073 L
.66667 .18073 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .18073 L
.66667 .18073 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .09018 L
.71429 .09018 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .09018 L
.71429 .09018 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .05999 L
.7619 .05999 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05999 L
.7619 .05999 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .03735 L
.80952 .03735 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .03735 L
.80952 .03735 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .02226 L
.85714 .02226 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02226 L
.85714 .02226 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .02226 L
.90476 .02226 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02226 L
.90476 .02226 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .02226 L
1 .02226 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02226 L
1 .02226 L
1 .01472 L
.95238 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00C03oool500000080oooo0P0000040?ooo`800000=03oool2000003L0oooo1@0000020?oo
o`800000103oool200000300oooo100000030?ooo`800000103oool2000000X0oooo001>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0`0?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool004H0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool00000>03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?oo
o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`80
0000103oool200000340oooo0P0000040?ooo`800000103oool2000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000A0?ooool00000
3@0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0
oooo0040oooo00090?ooo`040000003oool0oooo000000@0ooooo`00000=000000<0oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`0:
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool00@3oool000T0oooo00@000000?oo
o`3oool00000103oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o6P00000<
0?ooo`h000000`3oool000X0oooo0P0000050?ooo`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`h0
000030000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo00X0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00X0oooo6P00000<0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`h00000<P3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000002@0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000oooo0?ooo`0l0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l=000003l0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<000000000o`00
0?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`030000
003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08`3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo02<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool08`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`190?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000903oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
3P00001:0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool08`3oool00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l>000000/0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02<0oooo00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`030000003oool0oooo00X0oooo00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool08`3oool>000000`0003o00<000000?ooo`3o
ool02P3oool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0`0?ooo`030000
00000?l0003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0`0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02P3o
ool00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0`0?ooo`03000000000?l0
003o00X0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0`0?ooo`h00000303oool=000000`0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
00<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000EP3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo05@0oooo0`0000030?ooo`001@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`h00000F03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`h0000030000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo0680oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo
06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`030000003oool0oooo0680oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000006@0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo0680oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`0:0000o`d00000I@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`001@3oool30000
0080oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00060?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00X0003o00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`000`3oool500000005
0?ooo`000000oooo0?ooo`000000103oool3000006<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1]0?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`010?ooo`001@3oool20000
00<0oooo0P0000050?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o3P00001a0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000006@0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0N`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
I03oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1k0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0040oooo00030?ooo`<00000103oool2000000D0oooo00<000000?oo
o`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1S
0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`<00000H`3oool00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1j0?ooo`<000000`3oool000<0oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo0004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1S0?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool000@0oooo0`000003
0?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000
o`d0000030000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?ooo`03
000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
2@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003o
ool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o
00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07/0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000
o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?oo
o`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`00
0?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3o
ool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0
oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000o`000?l02P000?l00`00
0000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0
003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001T0?ooo`03000000000?l0003o00X0003o
00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07/0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:
0000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0oooo00<000000000
o`000?l02P000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo00T0oooo00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06<0oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`090?ooo`0300000000
0?l0003o00X0003o00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool02@3oool0
0`000000003o0000o`0:0000o`030000003oool0oooo07`0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0H`3oool00`000000003o0000o`0:0000o`030000003oool0oooo
00T0oooo3P00001n0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06<0
oooo00<000000000o`000?l02P000?l00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000I03oool00`000000003o0000o`0:0000o`030000003oool0oooo09@0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S
0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`03
000000000?l0003o00X0003o00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1S0?ooo`03000000000?l0003o00X0003o00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`h00000U`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool00140ooooo`00000=000000<0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {-280.554, \
107.013, 1.57972, 0.498428}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{allplot, \ allplot1, \ allplot2, \ 
            allplot3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00289953 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15969 -12 -4.5 ]
[-0.0125 .15969 0 4.5 ]
[-0.0125 .30467 -18 -4.5 ]
[-0.0125 .30467 0 4.5 ]
[-0.0125 .44964 -18 -4.5 ]
[-0.0125 .44964 0 4.5 ]
[-0.0125 .59462 -18 -4.5 ]
[-0.0125 .59462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15969 m
.00625 .15969 L
s
[(50)] -0.0125 .15969 1 0 Mshowa
0 .30467 m
.00625 .30467 L
s
[(100)] -0.0125 .30467 1 0 Mshowa
0 .44964 m
.00625 .44964 L
s
[(150)] -0.0125 .44964 1 0 Mshowa
0 .59462 m
.00625 .59462 L
s
[(200)] -0.0125 .59462 1 0 Mshowa
.125 Mabswid
0 .04371 m
.00375 .04371 L
s
0 .07271 m
.00375 .07271 L
s
0 .1017 m
.00375 .1017 L
s
0 .1307 m
.00375 .1307 L
s
0 .18869 m
.00375 .18869 L
s
0 .21768 m
.00375 .21768 L
s
0 .24668 m
.00375 .24668 L
s
0 .27567 m
.00375 .27567 L
s
0 .33366 m
.00375 .33366 L
s
0 .36266 m
.00375 .36266 L
s
0 .39165 m
.00375 .39165 L
s
0 .42065 m
.00375 .42065 L
s
0 .47864 m
.00375 .47864 L
s
0 .50763 m
.00375 .50763 L
s
0 .53663 m
.00375 .53663 L
s
0 .56563 m
.00375 .56563 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15969 m
1 .15969 L
s
.99375 .30467 m
1 .30467 L
s
.99375 .44964 m
1 .44964 L
s
.99375 .59462 m
1 .59462 L
s
.125 Mabswid
.99625 .04371 m
1 .04371 L
s
.99625 .07271 m
1 .07271 L
s
.99625 .1017 m
1 .1017 L
s
.99625 .1307 m
1 .1307 L
s
.99625 .18869 m
1 .18869 L
s
.99625 .21768 m
1 .21768 L
s
.99625 .24668 m
1 .24668 L
s
.99625 .27567 m
1 .27567 L
s
.99625 .33366 m
1 .33366 L
s
.99625 .36266 m
1 .36266 L
s
.99625 .39165 m
1 .39165 L
s
.99625 .42065 m
1 .42065 L
s
.99625 .47864 m
1 .47864 L
s
.99625 .50763 m
1 .50763 L
s
.99625 .53663 m
1 .53663 L
s
.99625 .56563 m
1 .56563 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02921 L
.04762 .02921 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02921 L
.04762 .02921 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03791 L
.09524 .03791 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03791 L
.09524 .03791 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04661 L
.14286 .04661 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04661 L
.14286 .04661 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06981 L
.19048 .06981 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06981 L
.19048 .06981 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1046 L
.2381 .1046 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1046 L
.2381 .1046 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .122 L
.28571 .122 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .122 L
.28571 .122 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .1133 L
.33333 .1133 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .1133 L
.33333 .1133 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .20608 L
.38095 .20608 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .20608 L
.38095 .20608 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .59752 L
.42857 .59752 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .59752 L
.42857 .59752 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .53083 L
.47619 .53083 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .53083 L
.47619 .53083 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .50474 L
.57143 .50474 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .50474 L
.57143 .50474 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .38295 L
.61905 .38295 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .38295 L
.61905 .38295 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .25538 L
.66667 .25538 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25538 L
.66667 .25538 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .14519 L
.71429 .14519 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14519 L
.71429 .14519 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .07561 L
.7619 .07561 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07561 L
.7619 .07561 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .04371 L
.80952 .04371 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04371 L
.80952 .04371 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .03211 L
.85714 .03211 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .03211 L
.85714 .03211 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .03211 L
.90476 .03211 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03211 L
.90476 .03211 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02051 L
.95238 .02051 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02051 L
.95238 .02051 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .02341 L
1 .02341 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02341 L
1 .02341 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00934292 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10814 -12 -4.5 ]
[-0.0125 .10814 0 4.5 ]
[-0.0125 .20157 -12 -4.5 ]
[-0.0125 .20157 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .38843 -12 -4.5 ]
[-0.0125 .38843 0 4.5 ]
[-0.0125 .48186 -12 -4.5 ]
[-0.0125 .48186 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10814 m
.00625 .10814 L
s
[(10)] -0.0125 .10814 1 0 Mshowa
0 .20157 m
.00625 .20157 L
s
[(20)] -0.0125 .20157 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(30)] -0.0125 .295 1 0 Mshowa
0 .38843 m
.00625 .38843 L
s
[(40)] -0.0125 .38843 1 0 Mshowa
0 .48186 m
.00625 .48186 L
s
[(50)] -0.0125 .48186 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(60)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .0334 m
.00375 .0334 L
s
0 .05209 m
.00375 .05209 L
s
0 .07077 m
.00375 .07077 L
s
0 .08946 m
.00375 .08946 L
s
0 .12683 m
.00375 .12683 L
s
0 .14552 m
.00375 .14552 L
s
0 .1642 m
.00375 .1642 L
s
0 .18289 m
.00375 .18289 L
s
0 .22026 m
.00375 .22026 L
s
0 .23895 m
.00375 .23895 L
s
0 .25763 m
.00375 .25763 L
s
0 .27632 m
.00375 .27632 L
s
0 .31369 m
.00375 .31369 L
s
0 .33237 m
.00375 .33237 L
s
0 .35106 m
.00375 .35106 L
s
0 .36975 m
.00375 .36975 L
s
0 .40712 m
.00375 .40712 L
s
0 .4258 m
.00375 .4258 L
s
0 .44449 m
.00375 .44449 L
s
0 .46318 m
.00375 .46318 L
s
0 .50055 m
.00375 .50055 L
s
0 .51923 m
.00375 .51923 L
s
0 .53792 m
.00375 .53792 L
s
0 .5566 m
.00375 .5566 L
s
0 .59398 m
.00375 .59398 L
s
0 .61266 m
.00375 .61266 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10814 m
1 .10814 L
s
.99375 .20157 m
1 .20157 L
s
.99375 .295 m
1 .295 L
s
.99375 .38843 m
1 .38843 L
s
.99375 .48186 m
1 .48186 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .0334 m
1 .0334 L
s
.99625 .05209 m
1 .05209 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .08946 m
1 .08946 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .1642 m
1 .1642 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .22026 m
1 .22026 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .25763 m
1 .25763 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .31369 m
1 .31369 L
s
.99625 .33237 m
1 .33237 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .36975 m
1 .36975 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4258 m
1 .4258 L
s
.99625 .44449 m
1 .44449 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .50055 m
1 .50055 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .5566 m
1 .5566 L
s
.99625 .59398 m
1 .59398 L
s
.99625 .61266 m
1 .61266 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .0334 L
.04762 .0334 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0334 L
.04762 .0334 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .02406 L
.09524 .02406 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02406 L
.09524 .02406 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04274 L
.19048 .04274 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04274 L
.19048 .04274 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .10814 L
.2381 .10814 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10814 L
.2381 .10814 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .1642 L
.28571 .1642 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .1642 L
.28571 .1642 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .11749 L
.33333 .11749 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11749 L
.33333 .11749 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .52858 L
.42857 .52858 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .52858 L
.42857 .52858 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .45383 L
.47619 .45383 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45383 L
.47619 .45383 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .59398 L
.57143 .59398 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .59398 L
.57143 .59398 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .47252 L
.61905 .47252 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .47252 L
.61905 .47252 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .30435 L
.66667 .30435 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30435 L
.66667 .30435 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .06143 L
.7619 .06143 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .06143 L
.7619 .06143 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .05209 L
.85714 .05209 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05209 L
.85714 .05209 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04274 L
.90476 .04274 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04274 L
.90476 .04274 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .0334 L
.95238 .0334 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0334 L
.95238 .0334 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0334 L
1 .0334 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0334 L
1 .0334 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00853049 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10002 -12 -4.5 ]
[-0.0125 .10002 0 4.5 ]
[-0.0125 .18532 -12 -4.5 ]
[-0.0125 .18532 0 4.5 ]
[-0.0125 .27063 -12 -4.5 ]
[-0.0125 .27063 0 4.5 ]
[-0.0125 .35593 -12 -4.5 ]
[-0.0125 .35593 0 4.5 ]
[-0.0125 .44124 -12 -4.5 ]
[-0.0125 .44124 0 4.5 ]
[-0.0125 .52654 -12 -4.5 ]
[-0.0125 .52654 0 4.5 ]
[-0.0125 .61185 -12 -4.5 ]
[-0.0125 .61185 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10002 m
.00625 .10002 L
s
[(10)] -0.0125 .10002 1 0 Mshowa
0 .18532 m
.00625 .18532 L
s
[(20)] -0.0125 .18532 1 0 Mshowa
0 .27063 m
.00625 .27063 L
s
[(30)] -0.0125 .27063 1 0 Mshowa
0 .35593 m
.00625 .35593 L
s
[(40)] -0.0125 .35593 1 0 Mshowa
0 .44124 m
.00625 .44124 L
s
[(50)] -0.0125 .44124 1 0 Mshowa
0 .52654 m
.00625 .52654 L
s
[(60)] -0.0125 .52654 1 0 Mshowa
0 .61185 m
.00625 .61185 L
s
[(70)] -0.0125 .61185 1 0 Mshowa
.125 Mabswid
0 .03178 m
.00375 .03178 L
s
0 .04884 m
.00375 .04884 L
s
0 .0659 m
.00375 .0659 L
s
0 .08296 m
.00375 .08296 L
s
0 .11708 m
.00375 .11708 L
s
0 .13414 m
.00375 .13414 L
s
0 .1512 m
.00375 .1512 L
s
0 .16826 m
.00375 .16826 L
s
0 .20239 m
.00375 .20239 L
s
0 .21945 m
.00375 .21945 L
s
0 .23651 m
.00375 .23651 L
s
0 .25357 m
.00375 .25357 L
s
0 .28769 m
.00375 .28769 L
s
0 .30475 m
.00375 .30475 L
s
0 .32181 m
.00375 .32181 L
s
0 .33887 m
.00375 .33887 L
s
0 .373 m
.00375 .373 L
s
0 .39006 m
.00375 .39006 L
s
0 .40712 m
.00375 .40712 L
s
0 .42418 m
.00375 .42418 L
s
0 .4583 m
.00375 .4583 L
s
0 .47536 m
.00375 .47536 L
s
0 .49242 m
.00375 .49242 L
s
0 .50948 m
.00375 .50948 L
s
0 .54361 m
.00375 .54361 L
s
0 .56067 m
.00375 .56067 L
s
0 .57773 m
.00375 .57773 L
s
0 .59479 m
.00375 .59479 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10002 m
1 .10002 L
s
.99375 .18532 m
1 .18532 L
s
.99375 .27063 m
1 .27063 L
s
.99375 .35593 m
1 .35593 L
s
.99375 .44124 m
1 .44124 L
s
.99375 .52654 m
1 .52654 L
s
.99375 .61185 m
1 .61185 L
s
.125 Mabswid
.99625 .03178 m
1 .03178 L
s
.99625 .04884 m
1 .04884 L
s
.99625 .0659 m
1 .0659 L
s
.99625 .08296 m
1 .08296 L
s
.99625 .11708 m
1 .11708 L
s
.99625 .13414 m
1 .13414 L
s
.99625 .1512 m
1 .1512 L
s
.99625 .16826 m
1 .16826 L
s
.99625 .20239 m
1 .20239 L
s
.99625 .21945 m
1 .21945 L
s
.99625 .23651 m
1 .23651 L
s
.99625 .25357 m
1 .25357 L
s
.99625 .28769 m
1 .28769 L
s
.99625 .30475 m
1 .30475 L
s
.99625 .32181 m
1 .32181 L
s
.99625 .33887 m
1 .33887 L
s
.99625 .373 m
1 .373 L
s
.99625 .39006 m
1 .39006 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42418 m
1 .42418 L
s
.99625 .4583 m
1 .4583 L
s
.99625 .47536 m
1 .47536 L
s
.99625 .49242 m
1 .49242 L
s
.99625 .50948 m
1 .50948 L
s
.99625 .54361 m
1 .54361 L
s
.99625 .56067 m
1 .56067 L
s
.99625 .57773 m
1 .57773 L
s
.99625 .59479 m
1 .59479 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02325 L
.04762 .02325 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02325 L
.04762 .02325 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04884 L
.09524 .04884 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04884 L
.09524 .04884 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .03178 L
.14286 .03178 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .03178 L
.14286 .03178 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .04884 L
.19048 .04884 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04884 L
.19048 .04884 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .07443 L
.2381 .07443 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07443 L
.2381 .07443 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .10002 L
.28571 .10002 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10002 L
.28571 .10002 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .59479 L
.42857 .59479 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .59479 L
.42857 .59479 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .57773 L
.52381 .57773 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .57773 L
.52381 .57773 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .5692 L
.57143 .5692 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .5692 L
.57143 .5692 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .35593 L
.61905 .35593 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35593 L
.61905 .35593 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .27063 L
.66667 .27063 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .27063 L
.66667 .27063 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .13414 L
.71429 .13414 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13414 L
.71429 .13414 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .10002 L
.7619 .10002 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .10002 L
.7619 .10002 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .02325 L
.85714 .02325 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02325 L
.85714 .02325 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .03178 L
.90476 .03178 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03178 L
.90476 .03178 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0075462 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(20)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(40)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(60)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .05245 m
.00375 .05245 L
s
0 .09018 m
.00375 .09018 L
s
0 .12791 m
.00375 .12791 L
s
0 .20337 m
.00375 .20337 L
s
0 .2411 m
.00375 .2411 L
s
0 .27883 m
.00375 .27883 L
s
0 .35429 m
.00375 .35429 L
s
0 .39203 m
.00375 .39203 L
s
0 .42976 m
.00375 .42976 L
s
0 .50522 m
.00375 .50522 L
s
0 .54295 m
.00375 .54295 L
s
0 .58068 m
.00375 .58068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .05245 m
1 .05245 L
s
.99625 .09018 m
1 .09018 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .20337 m
1 .20337 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .27883 m
1 .27883 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39203 m
1 .39203 L
s
.99625 .42976 m
1 .42976 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .54295 m
1 .54295 L
s
.99625 .58068 m
1 .58068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02981 L
.04762 .02981 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02981 L
.04762 .02981 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .03735 L
.09524 .03735 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03735 L
.09524 .03735 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .03735 L
.14286 .03735 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .03735 L
.14286 .03735 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .10527 L
.19048 .10527 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .10527 L
.19048 .10527 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .12036 L
.2381 .12036 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12036 L
.2381 .12036 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .09772 L
.28571 .09772 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .09772 L
.28571 .09772 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .12036 L
.33333 .12036 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12036 L
.33333 .12036 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .19582 L
.38095 .19582 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19582 L
.38095 .19582 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .48258 L
.47619 .48258 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .48258 L
.47619 .48258 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .57313 L
.52381 .57313 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .57313 L
.52381 .57313 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .33166 L
.57143 .33166 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .33166 L
.57143 .33166 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .30147 L
.61905 .30147 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30147 L
.61905 .30147 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .18073 L
.66667 .18073 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .18073 L
.66667 .18073 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .09018 L
.71429 .09018 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .09018 L
.71429 .09018 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .05999 L
.7619 .05999 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05999 L
.7619 .05999 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .03735 L
.80952 .03735 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .03735 L
.80952 .03735 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .02226 L
.85714 .02226 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02226 L
.85714 .02226 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .02226 L
.90476 .02226 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02226 L
.90476 .02226 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .02226 L
1 .02226 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02226 L
1 .02226 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00gP3oool500000080oooo
0P0000040?ooo`8000005@3oool2000001H0oooo1@0000020?ooo`800000103oool200000100oooo
100000030?ooo`800000103oool2000003/0oooo1@0000020?ooo`800000103oool2000001<0oooo
0P00000E0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool2000000@0oooo
0P00000l0?ooo`D000000P3oool2000000@0oooo0P00000E0?ooo`8000005P3oool500000080oooo
0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`8000005`3oool003l0oooo1@00
00020?ooo`800000103oool2000001<0oooo0P00000E0?ooo`D000000P3oool2000000@0oooo0P00
000?0?ooo`@000000`3oool2000000@0oooo0P00000k0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000m0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000F0?ooo`00@@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?03oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?oo
o`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000005P3oool00440oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000380oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00l0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03<0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo000i
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0h0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000m0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000F0?ooo`00@@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>@3oool2000000@0
oooo0P0000040?ooo`8000005@3oool2000001L0oooo0P0000040?ooo`800000103oool200000140
oooo0P0000040?ooo`800000103oool2000003`0oooo0P0000040?ooo`800000103oool2000001<0
oooo0P00000F0?ooo`800000103oool2000000@0oooo0P00000@0?ooo`800000103oool2000000@0
oooo0P00000m0?ooo`800000103oool2000000@0oooo0P00000E0?ooo`8000005`3oool2000000@0
oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`8000005`3oool00400oooo
0P0000040?ooo`800000103oool2000001<0oooo0P00000F0?ooo`800000103oool2000000@0oooo
0P00000@0?ooo`800000103oool2000000@0oooo0P00003o0?ooool0oooo0`3oool00?l0ooooo`3o
oonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00;h0oooo0P0000040?ooohD0
0000703oool2000000<0ooooO`00000L0?ooo`800000103ooon4000001L0oooo000Q0?ooo`800000
0`3ooomo000001P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`00803oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0ooooQ@00
000K0?ooo`040000003oool0oooo00000080ooooO`00000K0?ooo`040000003oool0oooo000000<0
ooooQ000000G0?ooo`00803oool010000000oooo0?ooo`0000020?ooogl00000603oool010000000
oooo0?ooo`0000030?ooo`030000003o0000o`0000<0o`00200000050?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo
01T0oooo00@000000?ooo`3oool000000P3oool7000000D00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1`000005003o00030000003oool0
oooo00T0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l>000000D0oooo1`00000G0?ooo`00803oool0
10000000oooo0?ooo`0000020?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool7000001P0oooo00@000000?ooo`3oool000000`3oool7000000H0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000h000006`3oool010000000oooo0?ooo`0000020?ooo`80
0000103oool00`0000000?l0003o0003003o00L000001@00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`L0
00002P3oool2000001/0oooo00@000000?ooo`3oool000000`3oool7000000H0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`00803oool010000000oooo0?ooo`0000020?oo
o`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl=000000/0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?oo
o`3oool02P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool2000000@0oooo00<000000?oo
o`3oool00`3oool>000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o1`00000H0?ooo`030000003oool0oooo01D0oooo000Q0?ooo`80
00000`3oool2000000@0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000G0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000o`000?l000030?l000L0
00001@3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000L00000303oool00`000000oooo0?ooo`0O0?ooo`80
0000103oool7000000D0oooo1`000005003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0J0?ooo`8000008P3oool00`000000oooo0?ooo`0@0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`00
9P3oool00`000000oooo0?ooo`090?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01d0oooo0P00000;0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000L000004@3oool200000240oooo00<000000?ooo`3oool0
5@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0200oooo0P00000A0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`009P3o
ool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
0007000000H0o`0000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`8000005P3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0J0?ooo`8000008P3oool00`000000oooo0?ooo`0@0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`L000007P3o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`8000002`3oool7
000000D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0
oooo00<0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0E0?ooo`8000008@3oool0
0`000000oooo0?ooo`0E0?ooo`L000001@00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo01/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0
oooo0280oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000@0?ooo`L000001@1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`L000007@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01H0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo
00<0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01<0oooo1@0000020?ooo`8000000`3oool2000001`0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo01X0oooo0P00000R0?ooo`030000003oool0oooo
0100oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000
oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05P3oool00`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool8000001P0
oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000007@3oool00`0000000?l0003o0003003o00L000001@00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0E
0?ooo`009P3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo1@0000020?oo
o`800000103oool2000001L0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003oool0oooo0280oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`02000001`0oooo1`0000050?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`07000001`0oooo0P00000R0?ooo`8000004@3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o1`00000T0?ooo`030000003oool0oooo01D0oooo000V0?oo
o`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002T0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0@0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l8000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01D0oooo000V0?ooo`8000005P3oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`3oool2000001L0oooo1`0000060?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo0280oooo0P00000G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Y0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0403oool7000000D0003o00<000000?ooo`3oool0103o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0
Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000001h0oooo00<000000?l0003o0000103o0007000000D0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000
0`3oool2000002P0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo0200oooo0P00000R0?ooo`030000003oool0oooo01H0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003o
ool0oooo01/0oooo1`0000050?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000o`000?l000040?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0W0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool7000000H0oooo1`0000050000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000X0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0140oooo0P0000040?ooo`800000103oool2000001d0oooo00<000000?l0003o0000
103o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0R0?ooo`8000008@3oool2000002P0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`0700000280oooo0P00000R0?ooo`800000:P3oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
003oool0oooo02P0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool09`3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?l0003o0000103o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09`3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0E0?ooo`006`3oool2000000@0oooo0P0000030?ooo`030000003oool0
oooo02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000002<0oooo00<000000?ooo`3oool07@3oool2
000001d0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`030?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`8000008@3oool2
000002P0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0V0?ooo`8000008P3oool0
0`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0E0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
0000o`0000@0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01<0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`007@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00800000:03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02H0oooo0P00000O0?ooo`030000003oool0oooo01`0oooo00<0
00000?l0003o0000103o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo1000
00030?ooo`8000000`3oool2000002P0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0V0?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000003oool0oooo02P0oooo
00<000000?ooo`3oool05@3oool001/0oooo0P0000030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool09`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool07@3oool2000001d0oooo200000050?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`8000005@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000Z0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`800000:03oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02H0oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000002/0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01D0oooo000K0?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool09`3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3o
ool2000002X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
ool0oooo0280oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`00000Y0?ooo`L000001@00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`P00000:P3oool0
0`000000oooo0?ooo`0E0?ooo`009P3oool2000002P0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0100oooo100000030?ooo`800000103oool00`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0V0?ooo`8000005P3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0W0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0]0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Y0?ooo`L000001@00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3o
ool002H0oooo00<000000?ooo`3oool09`3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000Z0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`8000008@3o
ool2000002h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool09P3oool200000280oooo0P00000`0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
:`3oool7000000D0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000L00000
9@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
5@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`80
0000<03oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000oooo0?ooo`0X0?ooo`8000008@3oool00`000000oooo0?ooo`0]0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0_0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01l0oooo0P00000^0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo02H0oooo0P00000R0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
5@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003oool0oooo02P0oooo0P00000Q0?ooo`030000003o
ool0oooo02d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0
oooo02T0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P0000030?ooo`800000;P3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0V0?ooo`8000008P3oool200000300oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool0
02H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo1`00000Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3o
ool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`800000<03oool0
0`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000oooo0?ooo`0X0?ooo`8000005`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P00000^0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`07000002P0oooo0P00000R0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3o
ool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000;`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01d0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003oool0oooo02P0oooo0P00000E0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000002h0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo0P00000R0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool001@0oooo1@0000020?ooo`800000
103oool2000000<0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0]0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0200oooo0P00000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo000F0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01l0oooo0P00000^0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0/0?ooo`8000008P3oool00`000000oooo0?ooo`0_0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01D0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00800000;P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;03oool2000001@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo0?ooo`800000<03oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0X0?oo
o`8000008@3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000_0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000340
oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000P00000:`3oool00`000000
oooo0?ooo`0O0?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0;03oool2000001L0oooo0`0000020?ooo`800000103oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o1`00000a0?ooo`030000003oool0oooo01D0
oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P00000`0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`8000008@3oool00`000000oooo
0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool01@000000
oooo0?ooo`3oool000000340oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo01D0oooo000E0?ooo`800000103oool2000000@0oooo0P0000030?ooo`03
0000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo0300oooo00<000000?ooo`3oool07`3oool2000002h0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo0P00000E0?ooo`D0
000000D0oooo0000003oool0oooo000000030?ooo`800000<03oool00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0E0?ooo`<0
00000P3oool2000000<0oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0E
0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo0P00000`0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?oo
o`800000603oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002l0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l7000003L0oooo00<000000?ooo`3oool05@3oool002H0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0300oooo00<0
00000?ooo`3oool04`3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool2000002h0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`07000002h0oooo0P00000G0?ooo`8000000`3oool2000000@0oooo
00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo
000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool200000300oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo0P00
000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000
003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0E0?ooo`009P3oool2000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380
oooo0P00000R0?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0
oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo01D0oooo0P0000030?ooo`8000000`3oool00`000000oooo
0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00
000_0?ooo`030000003oool0oooo0180oooo0`0000020?ooo`800000103oool200000300oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo0P00
000Q0?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo0P00
000R0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0E0?ooo`009P3oool2000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`3oool000000340oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo0300oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0]0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`009P3o
ool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0@0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`800000
<03oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
;`3oool200000240oooo0P00000^0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
<P3oool200000280oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0P0?ooo`800000<03oool00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?ooo`3o
ool0503oool2000000@0oooo0P0000030?ooo`800000;P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo0380oooo0P00000R0?ooo`030000003oool0oooo02l0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0E0?ooo`009P3oool2000002h0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0180oooo0P0000030?ooo`800000
103oool200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo02l0oooo0P00000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo0300oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
0380oooo0P00000R0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0E0?ooo`00503oool500000080oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0M0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0;`3oool2000001H0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
03<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo
03/0oooo00<000000?ooo`3oool05@3oool001H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000;`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
0P00000R0?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo
000F0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`02000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0b0?ooo`800000
7`3oool200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo02l0oooo0P00000F0?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool0
;@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo03<0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
5@3oool001H0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo0300oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0C0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000P00000
1@3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0O0?ooo`800000;P3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo0380oooo0P00000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?oo
o`3oool05@3oool001D0oooo0P0000040?ooo`<000000`3oool2000000<0oooo0P00000^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`80
0000103oool2000000@0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0103oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0_0?ooo`8000008@3oool00`000000oooo0?ooo`0]0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0C0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000300oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`001`00000b0?ooo`030000003oool0oooo01l0oooo0P00
000^0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool2000001D0oooo0`00
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000003o
0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030000003oool0oooo02d0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool200000300oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0e0?ooo`8000008@3oool00`000000oooo0?ooo`0]0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0_0?oo
o`03000000000?l0003o00<0003o200000050000o`030000003oool0oooo03/0oooo00<000000?oo
o`3oool05@3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000003D0oooo00<000000?ooo`3o
ool04@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0_0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0C0?oo
o`<00000103oool2000000<0oooo0P00000^0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0<P3oool2000001H0oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`0_0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo0P00000^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l0
00030000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo03H0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo03<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000
o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo00<00000
0?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo0`000003
0?ooo`800000103oool200000300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`04
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0e
0?ooo`8000005@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
0P00000^0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool200000280oooo
0P00000`0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o
0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03H0oooo00<0
00000?ooo`3oool04`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0E0?ooo`009P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00
000507moO`030000003oool0oooo03T0oooo00<000000?ooo`3oool07@3oool200000300oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`8000005P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo0P00000^0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0<P3oool200000280oooo00<000000?ooo`3oool0;`3oool00`000000003o
0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000V0?ooo`800000;P3oool00`000000Ogmo07mo
O`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool7000000H0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0503oool3000000<0oooo0P0000030?ooo`030000003oool0oooo02d0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0;`3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000V
0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03`0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo03H0oooo00<000000?ooo`3oool07`3oool2000002h0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`8000008P3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`03
0000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?oo
o`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo0P00000m0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?oo
o`8000008@3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00L00000=@3oool00`000000oooo0?ooo`0P0?oo
o`800000<03oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000V0?ooo`80
0000;P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0?03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0O0?ooo`800000;P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l01`00000j0?ooo`8000008P3oool00`000000oooo0?ooo`0_0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool05@3oool002H0oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo0P00000m0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`800000
8@3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
;`3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000D0?ooo`@000000`3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0@0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool0?03o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo03l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103o
ool00`000000003o0000o`030000o`030000003oool0oooo03/0oooo00<000000?ooo`3oool05@3o
ool001@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo03`0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo03H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`8000000`3oool2000002h0oooo1`000005003o00030000003oool0oooo03h0oooo0P00000R0?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?oo
o`L00000?@3oool00`000000oooo0?ooo`0E0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000002h0oooo1`000005
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>03oool200000180oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000?@3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool2000001L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003D0oooo1`0000110?oo
o`030000003oool0oooo0200oooo0P00000`0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0E0?ooo`005P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000k0?ooo`L00000>`3o
ool00`000000oooo0?ooo`0@0?ooo`<000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo03`0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo03H0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool200000280oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool001@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00
000m0?ooo`030000003o0000o`0000<0o`001`00000g0?ooo`800000603oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo07l000008P3oool00`000000oooo0?ooo`0_0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0?ooo`005@3o
ool2000000@0oooo0P0000040?ooo`8000000`3ooomo000001<0oooo0`0000030?ooo`800000103o
ool00`000000oooo0?ooo`0l0?ooo`L00000?P3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000X`3oool00`000000oooo0?ooo`0_0?ooo`L0
0000BP3oool00`000000oooo0?ooo`0E0?ooo`00a03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool4000000<0oooo0P00002T0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`00a03o
oon500000<80ooooQ000000G0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00001
\
\>"],
  ImageRangeCache->{{{26.375, 568}, {432.75, 355.813}} -> {-0.331812, \
2.77743, 0.00627702, 0.00627702}, {{42.25, 160.813}, {430.875, 357.625}} -> \
{-442.02, 1178.14, 3.34359, 2.74559}, {{172.688, 291.25}, {430.875, 357.625}} -> \
{-937.508, 351.374, 3.20758, 0.817419}, {{303.063, 421.625}, {430.875, \
357.625}} -> {-1529.16, 403.184, 3.35923, 0.937597}, {{433.5, 552.063}, \
{430.875, 357.625}} -> {-1983.23, 435.035, 3.20758, 1.01204}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Transpose[{DispersionReport[alldiffs]}]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 4043.722014772778`\)},
          {\(StandardDeviation \[Rule] 63.590266666941865`\)},
          {\(SampleRange \[Rule] 554.0888381242464`\)},
          {\(MeanDeviation \[Rule] 46.2686895362081`\)},
          {\(MedianDeviation \[Rule] 33.06310975380224`\)},
          {\(QuartileDeviation \[Rule] 33.018690691679005`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(allstats\  = \ 
        Map[DispersionReport, allbeats]\ \  // \ 
          N\ ;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[allstats]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 4724.75811895994`\), \(Variance \[Rule] 
              3200.935899131003`\), \(Variance \[Rule] 
              4105.0129844705725`\)},
          {\(StandardDeviation \[Rule] 
              68.736875976145`\), \(StandardDeviation \[Rule] 
              56.57681414794406`\), \(StandardDeviation \[Rule] 
              64.07037524839832`\)},
          {\(SampleRange \[Rule] 504.`\), \(SampleRange \[Rule] 
              404.`\), \(SampleRange \[Rule] 554.0888381242464`\)},
          {\(MeanDeviation \[Rule] 
              50.05735868717792`\), \(MeanDeviation \[Rule] 
              41.925403899878766`\), \(MeanDeviation \[Rule] 
              45.7076426327994`\)},
          {\(MedianDeviation \[Rule] 40.`\), \(MedianDeviation \[Rule] 
              33.39716987118472`\), \(MedianDeviation \[Rule] 29.`\)},
          {\(QuartileDeviation \[Rule] 
              37.54441906212323`\), \(QuartileDeviation \[Rule] 
              32.518690691679005`\), \(QuartileDeviation \[Rule] 
              30.83406011738248`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, the \
absolute average deviation, and the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(allinfo\  = \ 
      Transpose[{Range[3], \ N[Map[Mean, \ allbeats]], \ 
            N[Map[Mean, \ 
                Abs[allbeats]]], \[IndentingNewLine]Map[\((StandardDeviation\ \
 /. \ #)\) &, \ allstats]}]\ \  // \ TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "6.655712050078253`", "50.861459288664`", 
            "68.736875976145`"},
          {"2", "1.8082942097026669`", "42.0290899791017`", 
            "56.57681414794406`"},
          {"3", \(-8.46400625978087`\), "45.91551934085868`", 
            "64.07037524839832`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tapping accuracy for individual trials", "Section"],

Cell[TextData[{
  "Examine the accuracy of beat tapping for Charles Rosen's 1989 peformance \
of Mazurka Op. 7, No. 3.  Raw data is from ",
  StyleBox["http://mazurka.org.uk/info/revcond/pid52932-05/pid52932-05-abs.\
ma",
    FontFamily->"Courier New"]
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\<D:\mazurkas\>"];\)\), "\[IndentingNewLine]", 
    \(<< \ pid52932-05-abs.ma\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[pid52932x05abs]\)], "Input"],

Cell[BoxData[
    \(20\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3; Rosen 1989", "Subsection"],

Cell["\<\
Calculate the differences between the average tap times and the corrected \
data, removing the extremities:\
\>", "Text"],

Cell[BoxData[{
    \(\(rdifs\  = \ 
        Map[\((Drop[#, \ \(-3\)]\  - \ 
                Drop[pid52932x05corrected, \ \(-2\)])\) &, \ 
          pid52932x05abs];\)\), "\[IndentingNewLine]", 
    \(\(rdifs\  = \ Map[Drop[#, \ 3] &, \ rdifs];\)\  (*\ 
      drop\ the\ first\ measure\ of\ the\ piece\ *) \), \
"\[IndentingNewLine]", 
    \(\(rdifs\  = \ Map[N[#\  - \ Mean[#]] &, \ rdifs];\)\  (*\ 
      estimate\ correction\ for\ alignment\ error\ *) \), \
"\[IndentingNewLine]", 
    \(\(rbeats\  = \ 
        Map[Transpose[Partition[#, \ 3]] &, \ rdifs];\)\)}], "Input"],

Cell["\<\
First display a histogram of all metrical beat displacements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plots\  = \ 
      Map[Histogram[#, \ Frame \[Rule] True, \ 
            HistogramRange \[Rule] {\(-200\), \ 200}, \ 
            HistogramCategories \[Rule] 20, \ 
            DisplayFunction \[Rule] Identity, \ 
            BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}] &, \ rdifs]; 
    Show[GraphicsArray[Partition[plots, \ 4]], \ 
      DisplayFunction \[Rule] $DisplayFunction];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0184794 0.238095 [
[ 0 0 0 0 ]
[ 1 .77614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .77614 L
0 .77614 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0184794 0.245293 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0115413 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13013 -12 -4.5 ]
[-0.0125 .13013 0 4.5 ]
[-0.0125 .24554 -12 -4.5 ]
[-0.0125 .24554 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .47637 -12 -4.5 ]
[-0.0125 .47637 0 4.5 ]
[-0.0125 .59178 -12 -4.5 ]
[-0.0125 .59178 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13013 m
.00625 .13013 L
s
[(10)] -0.0125 .13013 1 0 Mshowa
0 .24554 m
.00625 .24554 L
s
[(20)] -0.0125 .24554 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(30)] -0.0125 .36095 1 0 Mshowa
0 .47637 m
.00625 .47637 L
s
[(40)] -0.0125 .47637 1 0 Mshowa
0 .59178 m
.00625 .59178 L
s
[(50)] -0.0125 .59178 1 0 Mshowa
.125 Mabswid
0 .0378 m
.00375 .0378 L
s
0 .06088 m
.00375 .06088 L
s
0 .08396 m
.00375 .08396 L
s
0 .10705 m
.00375 .10705 L
s
0 .15321 m
.00375 .15321 L
s
0 .17629 m
.00375 .17629 L
s
0 .19938 m
.00375 .19938 L
s
0 .22246 m
.00375 .22246 L
s
0 .26862 m
.00375 .26862 L
s
0 .29171 m
.00375 .29171 L
s
0 .31479 m
.00375 .31479 L
s
0 .33787 m
.00375 .33787 L
s
0 .38404 m
.00375 .38404 L
s
0 .40712 m
.00375 .40712 L
s
0 .4302 m
.00375 .4302 L
s
0 .45328 m
.00375 .45328 L
s
0 .49945 m
.00375 .49945 L
s
0 .52253 m
.00375 .52253 L
s
0 .54561 m
.00375 .54561 L
s
0 .5687 m
.00375 .5687 L
s
0 .61486 m
.00375 .61486 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13013 m
1 .13013 L
s
.99375 .24554 m
1 .24554 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .47637 m
1 .47637 L
s
.99375 .59178 m
1 .59178 L
s
.125 Mabswid
.99625 .0378 m
1 .0378 L
s
.99625 .06088 m
1 .06088 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .10705 m
1 .10705 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17629 m
1 .17629 L
s
.99625 .19938 m
1 .19938 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .26862 m
1 .26862 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .31479 m
1 .31479 L
s
.99625 .33787 m
1 .33787 L
s
.99625 .38404 m
1 .38404 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .45328 m
1 .45328 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .52253 m
1 .52253 L
s
.99625 .54561 m
1 .54561 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .61486 m
1 .61486 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .0378 L
.14286 .0378 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0378 L
.14286 .0378 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06088 L
.19048 .06088 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06088 L
.19048 .06088 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .10705 L
.2381 .10705 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10705 L
.2381 .10705 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .15321 L
.28571 .15321 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .15321 L
.28571 .15321 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .37249 L
.42857 .37249 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .37249 L
.42857 .37249 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .39558 L
.47619 .39558 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .39558 L
.47619 .39558 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .47637 L
.57143 .47637 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .47637 L
.57143 .47637 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .41866 L
.61905 .41866 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41866 L
.61905 .41866 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .33787 L
.66667 .33787 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .33787 L
.66667 .33787 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .18783 L
.71429 .18783 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .18783 L
.71429 .18783 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .04934 L
.7619 .04934 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04934 L
.7619 .04934 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0378 L
.80952 .0378 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0378 L
.80952 .0378 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0184794 0.488926 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0120123 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13484 -12 -4.5 ]
[-0.0125 .13484 0 4.5 ]
[-0.0125 .25496 -12 -4.5 ]
[-0.0125 .25496 0 4.5 ]
[-0.0125 .37508 -12 -4.5 ]
[-0.0125 .37508 0 4.5 ]
[-0.0125 .49521 -12 -4.5 ]
[-0.0125 .49521 0 4.5 ]
[-0.0125 .61533 -12 -4.5 ]
[-0.0125 .61533 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13484 m
.00625 .13484 L
s
[(10)] -0.0125 .13484 1 0 Mshowa
0 .25496 m
.00625 .25496 L
s
[(20)] -0.0125 .25496 1 0 Mshowa
0 .37508 m
.00625 .37508 L
s
[(30)] -0.0125 .37508 1 0 Mshowa
0 .49521 m
.00625 .49521 L
s
[(40)] -0.0125 .49521 1 0 Mshowa
0 .61533 m
.00625 .61533 L
s
[(50)] -0.0125 .61533 1 0 Mshowa
.125 Mabswid
0 .03874 m
.00375 .03874 L
s
0 .06276 m
.00375 .06276 L
s
0 .08679 m
.00375 .08679 L
s
0 .11081 m
.00375 .11081 L
s
0 .15886 m
.00375 .15886 L
s
0 .18289 m
.00375 .18289 L
s
0 .20691 m
.00375 .20691 L
s
0 .23094 m
.00375 .23094 L
s
0 .27899 m
.00375 .27899 L
s
0 .30301 m
.00375 .30301 L
s
0 .32704 m
.00375 .32704 L
s
0 .35106 m
.00375 .35106 L
s
0 .39911 m
.00375 .39911 L
s
0 .42313 m
.00375 .42313 L
s
0 .44716 m
.00375 .44716 L
s
0 .47118 m
.00375 .47118 L
s
0 .51923 m
.00375 .51923 L
s
0 .54326 m
.00375 .54326 L
s
0 .56728 m
.00375 .56728 L
s
0 .59131 m
.00375 .59131 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13484 m
1 .13484 L
s
.99375 .25496 m
1 .25496 L
s
.99375 .37508 m
1 .37508 L
s
.99375 .49521 m
1 .49521 L
s
.99375 .61533 m
1 .61533 L
s
.125 Mabswid
.99625 .03874 m
1 .03874 L
s
.99625 .06276 m
1 .06276 L
s
.99625 .08679 m
1 .08679 L
s
.99625 .11081 m
1 .11081 L
s
.99625 .15886 m
1 .15886 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .20691 m
1 .20691 L
s
.99625 .23094 m
1 .23094 L
s
.99625 .27899 m
1 .27899 L
s
.99625 .30301 m
1 .30301 L
s
.99625 .32704 m
1 .32704 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .39911 m
1 .39911 L
s
.99625 .42313 m
1 .42313 L
s
.99625 .44716 m
1 .44716 L
s
.99625 .47118 m
1 .47118 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54326 m
1 .54326 L
s
.99625 .56728 m
1 .56728 L
s
.99625 .59131 m
1 .59131 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02673 L
.04762 .02673 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02673 L
.04762 .02673 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02673 L
.09524 .02673 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02673 L
.09524 .02673 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .06276 L
.14286 .06276 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .06276 L
.14286 .06276 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .08679 L
.19048 .08679 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08679 L
.19048 .08679 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .12283 L
.28571 .12283 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12283 L
.28571 .12283 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .15886 L
.33333 .15886 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .15886 L
.33333 .15886 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .30301 L
.38095 .30301 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .30301 L
.38095 .30301 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .37508 L
.42857 .37508 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .37508 L
.42857 .37508 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .36307 L
.47619 .36307 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .36307 L
.47619 .36307 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .53124 L
.52381 .53124 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .53124 L
.52381 .53124 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .31502 L
.66667 .31502 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .31502 L
.66667 .31502 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .08679 L
.71429 .08679 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .08679 L
.71429 .08679 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .13484 L
.7619 .13484 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13484 L
.7619 .13484 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .05075 L
.80952 .05075 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05075 L
.80952 .05075 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .07478 L
.85714 .07478 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .07478 L
.85714 .07478 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0184794 0.732558 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0125235 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03976 L
.04762 .03976 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06481 L
.09524 .06481 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06481 L
.09524 .06481 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .10238 L
.14286 .10238 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .10238 L
.14286 .10238 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .1149 L
.19048 .1149 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .1149 L
.19048 .1149 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .12743 L
.2381 .12743 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12743 L
.2381 .12743 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .13995 L
.28571 .13995 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .13995 L
.28571 .13995 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .17752 L
.33333 .17752 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17752 L
.33333 .17752 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27771 L
.38095 .27771 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .34033 L
.42857 .34033 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .34033 L
.42857 .34033 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .49061 L
.52381 .49061 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .49061 L
.52381 .49061 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .57827 L
.57143 .57827 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .57827 L
.57143 .57827 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .3278 L
.61905 .3278 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3278 L
.61905 .3278 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .30276 L
.66667 .30276 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30276 L
.66667 .30276 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .15247 L
.71429 .15247 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .15247 L
.71429 .15247 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .1149 L
.7619 .1149 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .1149 L
.7619 .1149 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .08986 L
.80952 .08986 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08986 L
.80952 .08986 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .06481 L
.85714 .06481 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .06481 L
.85714 .06481 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02724 L
.95238 .02724 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .02724 L
1 .02724 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02724 L
1 .02724 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0184794 0.97619 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0103264 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11798 -12 -4.5 ]
[-0.0125 .11798 0 4.5 ]
[-0.0125 .22124 -12 -4.5 ]
[-0.0125 .22124 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .42777 -12 -4.5 ]
[-0.0125 .42777 0 4.5 ]
[-0.0125 .53103 -12 -4.5 ]
[-0.0125 .53103 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11798 m
.00625 .11798 L
s
[(10)] -0.0125 .11798 1 0 Mshowa
0 .22124 m
.00625 .22124 L
s
[(20)] -0.0125 .22124 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(30)] -0.0125 .32451 1 0 Mshowa
0 .42777 m
.00625 .42777 L
s
[(40)] -0.0125 .42777 1 0 Mshowa
0 .53103 m
.00625 .53103 L
s
[(50)] -0.0125 .53103 1 0 Mshowa
.125 Mabswid
0 .03537 m
.00375 .03537 L
s
0 .05602 m
.00375 .05602 L
s
0 .07667 m
.00375 .07667 L
s
0 .09733 m
.00375 .09733 L
s
0 .13863 m
.00375 .13863 L
s
0 .15928 m
.00375 .15928 L
s
0 .17994 m
.00375 .17994 L
s
0 .20059 m
.00375 .20059 L
s
0 .2419 m
.00375 .2419 L
s
0 .26255 m
.00375 .26255 L
s
0 .2832 m
.00375 .2832 L
s
0 .30385 m
.00375 .30385 L
s
0 .34516 m
.00375 .34516 L
s
0 .36581 m
.00375 .36581 L
s
0 .38646 m
.00375 .38646 L
s
0 .40712 m
.00375 .40712 L
s
0 .44842 m
.00375 .44842 L
s
0 .46908 m
.00375 .46908 L
s
0 .48973 m
.00375 .48973 L
s
0 .51038 m
.00375 .51038 L
s
0 .55169 m
.00375 .55169 L
s
0 .57234 m
.00375 .57234 L
s
0 .59299 m
.00375 .59299 L
s
0 .61365 m
.00375 .61365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11798 m
1 .11798 L
s
.99375 .22124 m
1 .22124 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .42777 m
1 .42777 L
s
.99375 .53103 m
1 .53103 L
s
.125 Mabswid
.99625 .03537 m
1 .03537 L
s
.99625 .05602 m
1 .05602 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .09733 m
1 .09733 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15928 m
1 .15928 L
s
.99625 .17994 m
1 .17994 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .2419 m
1 .2419 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .2832 m
1 .2832 L
s
.99625 .30385 m
1 .30385 L
s
.99625 .34516 m
1 .34516 L
s
.99625 .36581 m
1 .36581 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46908 m
1 .46908 L
s
.99625 .48973 m
1 .48973 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .55169 m
1 .55169 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .59299 m
1 .59299 L
s
.99625 .61365 m
1 .61365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .03537 L
.04762 .03537 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03537 L
.04762 .03537 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .02504 L
.14286 .02504 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .02504 L
.14286 .02504 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .03537 L
.19048 .03537 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .03537 L
.19048 .03537 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .11798 L
.2381 .11798 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .11798 L
.2381 .11798 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .15928 L
.28571 .15928 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .15928 L
.28571 .15928 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .14896 L
.33333 .14896 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .14896 L
.33333 .14896 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .17994 L
.38095 .17994 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17994 L
.38095 .17994 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .29353 L
.42857 .29353 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29353 L
.42857 .29353 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .48973 L
.47619 .48973 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .48973 L
.47619 .48973 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .42777 L
.57143 .42777 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .42777 L
.57143 .42777 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .31418 L
.61905 .31418 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .31418 L
.61905 .31418 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .11798 L
.66667 .11798 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .11798 L
.66667 .11798 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .17994 L
.71429 .17994 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17994 L
.71429 .17994 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .087 L
.7619 .087 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .087 L
.7619 .087 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .087 L
.80952 .087 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .087 L
.80952 .087 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02504 L
.90476 .02504 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02504 L
.90476 .02504 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.169052 0.245293 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0130801 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .04088 L
.09524 .04088 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04088 L
.09524 .04088 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04088 L
.14286 .04088 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04088 L
.14286 .04088 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .1586 L
.19048 .1586 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .1586 L
.19048 .1586 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .18476 L
.2381 .18476 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18476 L
.2381 .18476 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .56408 L
.47619 .56408 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .56408 L
.47619 .56408 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .26324 L
.71429 .26324 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .26324 L
.71429 .26324 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .0278 L
1 .0278 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0278 L
1 .0278 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.169052 0.488926 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0130801 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .04088 L
.04762 .04088 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04088 L
.04762 .04088 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .04088 L
.14286 .04088 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04088 L
.14286 .04088 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1586 L
.2381 .1586 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1586 L
.2381 .1586 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .1586 L
.33333 .1586 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .1586 L
.33333 .1586 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .32864 L
.38095 .32864 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .32864 L
.38095 .32864 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .3548 L
.42857 .3548 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .3548 L
.42857 .3548 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .59024 L
.47619 .59024 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .59024 L
.47619 .59024 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .57716 L
.57143 .57716 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .57716 L
.57143 .57716 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .43328 L
.61905 .43328 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .43328 L
.61905 .43328 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .30248 L
.66667 .30248 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30248 L
.66667 .30248 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .06704 L
.7619 .06704 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .06704 L
.7619 .06704 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .10628 L
.80952 .10628 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .10628 L
.80952 .10628 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.169052 0.732558 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0154896 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -6 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -12 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -12 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -12 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -12 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(10)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(15)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(20)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(25)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(30)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(35)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0302 L
.04762 .0302 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06118 L
.09524 .06118 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06118 L
.09524 .06118 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .07667 L
.14286 .07667 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07667 L
.14286 .07667 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .1851 L
.19048 .1851 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .1851 L
.19048 .1851 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .15412 L
.2381 .15412 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15412 L
.2381 .15412 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .21608 L
.28571 .21608 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .21608 L
.28571 .21608 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .26255 L
.33333 .26255 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .26255 L
.33333 .26255 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .35549 L
.38095 .35549 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .35549 L
.38095 .35549 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .46391 L
.42857 .46391 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .46391 L
.42857 .46391 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .4794 L
.47619 .4794 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4794 L
.47619 .4794 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .51038 L
.61905 .51038 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .51038 L
.61905 .51038 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .40195 L
.66667 .40195 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .40195 L
.66667 .40195 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .1851 L
.71429 .1851 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1851 L
.71429 .1851 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .16961 L
.7619 .16961 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .16961 L
.7619 .16961 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .10765 L
.80952 .10765 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .10765 L
.80952 .10765 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .06118 L
.85714 .06118 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .06118 L
.85714 .06118 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .06118 L
.90476 .06118 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .06118 L
.90476 .06118 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .0302 L
.95238 .0302 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0302 L
.95238 .0302 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .0302 L
1 .0302 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0302 L
1 .0302 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.169052 0.97619 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0115413 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13013 -12 -4.5 ]
[-0.0125 .13013 0 4.5 ]
[-0.0125 .24554 -12 -4.5 ]
[-0.0125 .24554 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .47637 -12 -4.5 ]
[-0.0125 .47637 0 4.5 ]
[-0.0125 .59178 -12 -4.5 ]
[-0.0125 .59178 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13013 m
.00625 .13013 L
s
[(10)] -0.0125 .13013 1 0 Mshowa
0 .24554 m
.00625 .24554 L
s
[(20)] -0.0125 .24554 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(30)] -0.0125 .36095 1 0 Mshowa
0 .47637 m
.00625 .47637 L
s
[(40)] -0.0125 .47637 1 0 Mshowa
0 .59178 m
.00625 .59178 L
s
[(50)] -0.0125 .59178 1 0 Mshowa
.125 Mabswid
0 .0378 m
.00375 .0378 L
s
0 .06088 m
.00375 .06088 L
s
0 .08396 m
.00375 .08396 L
s
0 .10705 m
.00375 .10705 L
s
0 .15321 m
.00375 .15321 L
s
0 .17629 m
.00375 .17629 L
s
0 .19938 m
.00375 .19938 L
s
0 .22246 m
.00375 .22246 L
s
0 .26862 m
.00375 .26862 L
s
0 .29171 m
.00375 .29171 L
s
0 .31479 m
.00375 .31479 L
s
0 .33787 m
.00375 .33787 L
s
0 .38404 m
.00375 .38404 L
s
0 .40712 m
.00375 .40712 L
s
0 .4302 m
.00375 .4302 L
s
0 .45328 m
.00375 .45328 L
s
0 .49945 m
.00375 .49945 L
s
0 .52253 m
.00375 .52253 L
s
0 .54561 m
.00375 .54561 L
s
0 .5687 m
.00375 .5687 L
s
0 .61486 m
.00375 .61486 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13013 m
1 .13013 L
s
.99375 .24554 m
1 .24554 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .47637 m
1 .47637 L
s
.99375 .59178 m
1 .59178 L
s
.125 Mabswid
.99625 .0378 m
1 .0378 L
s
.99625 .06088 m
1 .06088 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .10705 m
1 .10705 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17629 m
1 .17629 L
s
.99625 .19938 m
1 .19938 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .26862 m
1 .26862 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .31479 m
1 .31479 L
s
.99625 .33787 m
1 .33787 L
s
.99625 .38404 m
1 .38404 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .45328 m
1 .45328 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .52253 m
1 .52253 L
s
.99625 .54561 m
1 .54561 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .61486 m
1 .61486 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0378 L
.04762 .0378 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0378 L
.04762 .0378 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06088 L
.09524 .06088 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06088 L
.09524 .06088 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .0378 L
.14286 .0378 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0378 L
.14286 .0378 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .07242 L
.19048 .07242 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07242 L
.19048 .07242 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .11859 L
.28571 .11859 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .11859 L
.28571 .11859 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .234 L
.38095 .234 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .234 L
.38095 .234 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .41866 L
.42857 .41866 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .41866 L
.42857 .41866 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .38404 L
.47619 .38404 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .38404 L
.47619 .38404 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .48791 L
.57143 .48791 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .48791 L
.57143 .48791 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .33787 L
.61905 .33787 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .33787 L
.61905 .33787 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .234 L
.66667 .234 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .234 L
.66667 .234 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .17629 L
.71429 .17629 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17629 L
.71429 .17629 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .0955 L
.7619 .0955 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0955 L
.7619 .0955 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0955 L
.80952 .0955 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0955 L
.80952 .0955 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02626 L
.85714 .02626 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02626 L
.85714 .02626 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02626 L
.90476 .02626 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02626 L
.90476 .02626 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02626 L
.95238 .02626 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02626 L
.95238 .02626 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.319626 0.245293 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0136885 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1516 -12 -4.5 ]
[-0.0125 .1516 0 4.5 ]
[-0.0125 .28848 -12 -4.5 ]
[-0.0125 .28848 0 4.5 ]
[-0.0125 .42537 -12 -4.5 ]
[-0.0125 .42537 0 4.5 ]
[-0.0125 .56225 -12 -4.5 ]
[-0.0125 .56225 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1516 m
.00625 .1516 L
s
[(10)] -0.0125 .1516 1 0 Mshowa
0 .28848 m
.00625 .28848 L
s
[(20)] -0.0125 .28848 1 0 Mshowa
0 .42537 m
.00625 .42537 L
s
[(30)] -0.0125 .42537 1 0 Mshowa
0 .56225 m
.00625 .56225 L
s
[(40)] -0.0125 .56225 1 0 Mshowa
.125 Mabswid
0 .04209 m
.00375 .04209 L
s
0 .06947 m
.00375 .06947 L
s
0 .09685 m
.00375 .09685 L
s
0 .12422 m
.00375 .12422 L
s
0 .17898 m
.00375 .17898 L
s
0 .20635 m
.00375 .20635 L
s
0 .23373 m
.00375 .23373 L
s
0 .26111 m
.00375 .26111 L
s
0 .31586 m
.00375 .31586 L
s
0 .34324 m
.00375 .34324 L
s
0 .37062 m
.00375 .37062 L
s
0 .39799 m
.00375 .39799 L
s
0 .45275 m
.00375 .45275 L
s
0 .48012 m
.00375 .48012 L
s
0 .5075 m
.00375 .5075 L
s
0 .53488 m
.00375 .53488 L
s
0 .58963 m
.00375 .58963 L
s
0 .61701 m
.00375 .61701 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1516 m
1 .1516 L
s
.99375 .28848 m
1 .28848 L
s
.99375 .42537 m
1 .42537 L
s
.99375 .56225 m
1 .56225 L
s
.125 Mabswid
.99625 .04209 m
1 .04209 L
s
.99625 .06947 m
1 .06947 L
s
.99625 .09685 m
1 .09685 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23373 m
1 .23373 L
s
.99625 .26111 m
1 .26111 L
s
.99625 .31586 m
1 .31586 L
s
.99625 .34324 m
1 .34324 L
s
.99625 .37062 m
1 .37062 L
s
.99625 .39799 m
1 .39799 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .48012 m
1 .48012 L
s
.99625 .5075 m
1 .5075 L
s
.99625 .53488 m
1 .53488 L
s
.99625 .58963 m
1 .58963 L
s
.99625 .61701 m
1 .61701 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0284 L
.04762 .0284 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0284 L
.04762 .0284 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06947 L
.09524 .06947 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06947 L
.09524 .06947 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .11053 L
.14286 .11053 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11053 L
.14286 .11053 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .13791 L
.19048 .13791 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .13791 L
.19048 .13791 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .09685 L
.2381 .09685 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .09685 L
.2381 .09685 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .23373 L
.28571 .23373 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .23373 L
.28571 .23373 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .22004 L
.33333 .22004 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22004 L
.33333 .22004 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .22004 L
.38095 .22004 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .22004 L
.38095 .22004 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .3843 L
.42857 .3843 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .3843 L
.42857 .3843 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .49381 L
.47619 .49381 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .49381 L
.47619 .49381 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .43906 L
.57143 .43906 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .43906 L
.57143 .43906 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .52119 L
.61905 .52119 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .52119 L
.61905 .52119 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .34324 L
.66667 .34324 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .34324 L
.66667 .34324 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .26111 L
.71429 .26111 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .26111 L
.71429 .26111 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .11053 L
.7619 .11053 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .11053 L
.7619 .11053 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .08316 L
.80952 .08316 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08316 L
.80952 .08316 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .06947 L
.85714 .06947 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .06947 L
.85714 .06947 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .0284 L
.95238 .0284 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0284 L
.95238 .0284 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.319626 0.488926 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0103264 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11798 -12 -4.5 ]
[-0.0125 .11798 0 4.5 ]
[-0.0125 .22124 -12 -4.5 ]
[-0.0125 .22124 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .42777 -12 -4.5 ]
[-0.0125 .42777 0 4.5 ]
[-0.0125 .53103 -12 -4.5 ]
[-0.0125 .53103 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11798 m
.00625 .11798 L
s
[(10)] -0.0125 .11798 1 0 Mshowa
0 .22124 m
.00625 .22124 L
s
[(20)] -0.0125 .22124 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(30)] -0.0125 .32451 1 0 Mshowa
0 .42777 m
.00625 .42777 L
s
[(40)] -0.0125 .42777 1 0 Mshowa
0 .53103 m
.00625 .53103 L
s
[(50)] -0.0125 .53103 1 0 Mshowa
.125 Mabswid
0 .03537 m
.00375 .03537 L
s
0 .05602 m
.00375 .05602 L
s
0 .07667 m
.00375 .07667 L
s
0 .09733 m
.00375 .09733 L
s
0 .13863 m
.00375 .13863 L
s
0 .15928 m
.00375 .15928 L
s
0 .17994 m
.00375 .17994 L
s
0 .20059 m
.00375 .20059 L
s
0 .2419 m
.00375 .2419 L
s
0 .26255 m
.00375 .26255 L
s
0 .2832 m
.00375 .2832 L
s
0 .30385 m
.00375 .30385 L
s
0 .34516 m
.00375 .34516 L
s
0 .36581 m
.00375 .36581 L
s
0 .38646 m
.00375 .38646 L
s
0 .40712 m
.00375 .40712 L
s
0 .44842 m
.00375 .44842 L
s
0 .46908 m
.00375 .46908 L
s
0 .48973 m
.00375 .48973 L
s
0 .51038 m
.00375 .51038 L
s
0 .55169 m
.00375 .55169 L
s
0 .57234 m
.00375 .57234 L
s
0 .59299 m
.00375 .59299 L
s
0 .61365 m
.00375 .61365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11798 m
1 .11798 L
s
.99375 .22124 m
1 .22124 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .42777 m
1 .42777 L
s
.99375 .53103 m
1 .53103 L
s
.125 Mabswid
.99625 .03537 m
1 .03537 L
s
.99625 .05602 m
1 .05602 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .09733 m
1 .09733 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15928 m
1 .15928 L
s
.99625 .17994 m
1 .17994 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .2419 m
1 .2419 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .2832 m
1 .2832 L
s
.99625 .30385 m
1 .30385 L
s
.99625 .34516 m
1 .34516 L
s
.99625 .36581 m
1 .36581 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46908 m
1 .46908 L
s
.99625 .48973 m
1 .48973 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .55169 m
1 .55169 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .59299 m
1 .59299 L
s
.99625 .61365 m
1 .61365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02504 L
.04762 .02504 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02504 L
.04762 .02504 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .02504 L
.09524 .02504 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .02504 L
.09524 .02504 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .09733 L
.14286 .09733 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .09733 L
.14286 .09733 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .087 L
.19048 .087 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .087 L
.19048 .087 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .11798 L
.2381 .11798 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .11798 L
.2381 .11798 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .20059 L
.33333 .20059 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .20059 L
.33333 .20059 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .16961 L
.38095 .16961 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16961 L
.38095 .16961 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .35549 L
.47619 .35549 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .35549 L
.47619 .35549 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .42777 L
.57143 .42777 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .42777 L
.57143 .42777 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .29353 L
.61905 .29353 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .29353 L
.61905 .29353 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .23157 L
.66667 .23157 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .23157 L
.66667 .23157 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .12831 L
.71429 .12831 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .12831 L
.71429 .12831 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .087 L
.7619 .087 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .087 L
.7619 .087 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .03537 L
.95238 .03537 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .03537 L
.95238 .03537 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .03537 L
1 .03537 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .03537 L
1 .03537 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.319626 0.732558 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0122626 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13734 -12 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13734 m
.00625 .13734 L
s
[(10)] -0.0125 .13734 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(20)] -0.0125 .25997 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(30)] -0.0125 .38259 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(40)] -0.0125 .50522 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .11282 m
.00375 .11282 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .21092 m
.00375 .21092 L
s
0 .23544 m
.00375 .23544 L
s
0 .28449 m
.00375 .28449 L
s
0 .30902 m
.00375 .30902 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .40712 m
.00375 .40712 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13734 m
1 .13734 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .50522 m
1 .50522 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .06377 L
.19048 .06377 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .06377 L
.19048 .06377 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .17413 L
.28571 .17413 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17413 L
.28571 .17413 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .22318 L
.33333 .22318 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22318 L
.33333 .22318 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .2477 L
.38095 .2477 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .2477 L
.38095 .2477 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .32128 L
.42857 .32128 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32128 L
.42857 .32128 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .57879 L
.47619 .57879 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .57879 L
.47619 .57879 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .51748 L
.57143 .51748 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .51748 L
.57143 .51748 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .18639 L
.66667 .18639 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .18639 L
.66667 .18639 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .18639 L
.71429 .18639 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .18639 L
.71429 .18639 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .11282 L
.7619 .11282 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .11282 L
.7619 .11282 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .02698 L
.80952 .02698 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .02698 L
.80952 .02698 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .07603 L
.85714 .07603 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .07603 L
.85714 .07603 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .03924 L
.90476 .03924 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .03924 L
.90476 .03924 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02698 L
.95238 .02698 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02698 L
.95238 .02698 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .02698 L
1 .02698 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02698 L
1 .02698 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.319626 0.97619 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0130801 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06704 L
.09524 .06704 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06704 L
.09524 .06704 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .47252 L
.42857 .47252 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .53792 L
.47619 .53792 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .53792 L
.47619 .53792 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .52484 L
.52381 .52484 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52484 L
.52381 .52484 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .36788 L
.61905 .36788 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .36788 L
.61905 .36788 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .38096 L
.66667 .38096 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .38096 L
.66667 .38096 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .1586 L
.71429 .1586 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1586 L
.71429 .1586 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .06704 L
.80952 .06704 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06704 L
.80952 .06704 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .0278 L
.85714 .0278 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0278 L
.85714 .0278 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.470199 0.245293 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0133774 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -12 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(10)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(20)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(30)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(40)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .0816 L
.09524 .0816 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0816 L
.09524 .0816 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .0816 L
.14286 .0816 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0816 L
.14286 .0816 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .17524 L
.19048 .17524 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .17524 L
.19048 .17524 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .10836 L
.2381 .10836 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10836 L
.2381 .10836 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .22875 L
.33333 .22875 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22875 L
.33333 .22875 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .30902 L
.38095 .30902 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .30902 L
.38095 .30902 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .32239 L
.42857 .32239 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32239 L
.42857 .32239 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .48292 L
.47619 .48292 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .48292 L
.47619 .48292 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .4963 L
.52381 .4963 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4963 L
.52381 .4963 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .38928 L
.61905 .38928 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .38928 L
.61905 .38928 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .34915 L
.66667 .34915 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .34915 L
.66667 .34915 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .25551 L
.71429 .25551 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .25551 L
.71429 .25551 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .09498 L
.7619 .09498 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .09498 L
.7619 .09498 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .10836 L
.80952 .10836 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .10836 L
.80952 .10836 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .05485 L
.85714 .05485 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05485 L
.85714 .05485 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02809 L
.95238 .02809 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02809 L
.95238 .02809 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .02809 L
1 .02809 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .02809 L
1 .02809 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.470199 0.488926 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.00997634 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11448 -12 -4.5 ]
[-0.0125 .11448 0 4.5 ]
[-0.0125 .21424 -12 -4.5 ]
[-0.0125 .21424 0 4.5 ]
[-0.0125 .31401 -12 -4.5 ]
[-0.0125 .31401 0 4.5 ]
[-0.0125 .41377 -12 -4.5 ]
[-0.0125 .41377 0 4.5 ]
[-0.0125 .51353 -12 -4.5 ]
[-0.0125 .51353 0 4.5 ]
[-0.0125 .6133 -12 -4.5 ]
[-0.0125 .6133 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11448 m
.00625 .11448 L
s
[(10)] -0.0125 .11448 1 0 Mshowa
0 .21424 m
.00625 .21424 L
s
[(20)] -0.0125 .21424 1 0 Mshowa
0 .31401 m
.00625 .31401 L
s
[(30)] -0.0125 .31401 1 0 Mshowa
0 .41377 m
.00625 .41377 L
s
[(40)] -0.0125 .41377 1 0 Mshowa
0 .51353 m
.00625 .51353 L
s
[(50)] -0.0125 .51353 1 0 Mshowa
0 .6133 m
.00625 .6133 L
s
[(60)] -0.0125 .6133 1 0 Mshowa
.125 Mabswid
0 .03467 m
.00375 .03467 L
s
0 .05462 m
.00375 .05462 L
s
0 .07457 m
.00375 .07457 L
s
0 .09453 m
.00375 .09453 L
s
0 .13443 m
.00375 .13443 L
s
0 .15438 m
.00375 .15438 L
s
0 .17434 m
.00375 .17434 L
s
0 .19429 m
.00375 .19429 L
s
0 .23419 m
.00375 .23419 L
s
0 .25415 m
.00375 .25415 L
s
0 .2741 m
.00375 .2741 L
s
0 .29405 m
.00375 .29405 L
s
0 .33396 m
.00375 .33396 L
s
0 .35391 m
.00375 .35391 L
s
0 .37386 m
.00375 .37386 L
s
0 .39382 m
.00375 .39382 L
s
0 .43372 m
.00375 .43372 L
s
0 .45367 m
.00375 .45367 L
s
0 .47363 m
.00375 .47363 L
s
0 .49358 m
.00375 .49358 L
s
0 .53348 m
.00375 .53348 L
s
0 .55344 m
.00375 .55344 L
s
0 .57339 m
.00375 .57339 L
s
0 .59334 m
.00375 .59334 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11448 m
1 .11448 L
s
.99375 .21424 m
1 .21424 L
s
.99375 .31401 m
1 .31401 L
s
.99375 .41377 m
1 .41377 L
s
.99375 .51353 m
1 .51353 L
s
.99375 .6133 m
1 .6133 L
s
.125 Mabswid
.99625 .03467 m
1 .03467 L
s
.99625 .05462 m
1 .05462 L
s
.99625 .07457 m
1 .07457 L
s
.99625 .09453 m
1 .09453 L
s
.99625 .13443 m
1 .13443 L
s
.99625 .15438 m
1 .15438 L
s
.99625 .17434 m
1 .17434 L
s
.99625 .19429 m
1 .19429 L
s
.99625 .23419 m
1 .23419 L
s
.99625 .25415 m
1 .25415 L
s
.99625 .2741 m
1 .2741 L
s
.99625 .29405 m
1 .29405 L
s
.99625 .33396 m
1 .33396 L
s
.99625 .35391 m
1 .35391 L
s
.99625 .37386 m
1 .37386 L
s
.99625 .39382 m
1 .39382 L
s
.99625 .43372 m
1 .43372 L
s
.99625 .45367 m
1 .45367 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .49358 m
1 .49358 L
s
.99625 .53348 m
1 .53348 L
s
.99625 .55344 m
1 .55344 L
s
.99625 .57339 m
1 .57339 L
s
.99625 .59334 m
1 .59334 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02469 L
.04762 .02469 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02469 L
.04762 .02469 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .05462 L
.09524 .05462 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05462 L
.09524 .05462 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .07457 L
.14286 .07457 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07457 L
.14286 .07457 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .12445 L
.19048 .12445 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12445 L
.19048 .12445 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .05462 L
.2381 .05462 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .05462 L
.2381 .05462 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .15438 L
.28571 .15438 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .15438 L
.28571 .15438 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .16436 L
.33333 .16436 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16436 L
.33333 .16436 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .17434 L
.38095 .17434 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17434 L
.38095 .17434 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .2741 L
.42857 .2741 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .2741 L
.42857 .2741 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .36389 L
.47619 .36389 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .36389 L
.47619 .36389 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .32398 L
.57143 .32398 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .32398 L
.57143 .32398 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .28408 L
.61905 .28408 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .28408 L
.61905 .28408 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .21424 L
.66667 .21424 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .21424 L
.66667 .21424 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .15438 L
.71429 .15438 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .15438 L
.71429 .15438 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .17434 L
.7619 .17434 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .17434 L
.7619 .17434 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .0646 L
.80952 .0646 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0646 L
.80952 .0646 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .04464 L
.90476 .04464 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04464 L
.90476 .04464 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.470199 0.732558 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0136885 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1516 -12 -4.5 ]
[-0.0125 .1516 0 4.5 ]
[-0.0125 .28848 -12 -4.5 ]
[-0.0125 .28848 0 4.5 ]
[-0.0125 .42537 -12 -4.5 ]
[-0.0125 .42537 0 4.5 ]
[-0.0125 .56225 -12 -4.5 ]
[-0.0125 .56225 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1516 m
.00625 .1516 L
s
[(10)] -0.0125 .1516 1 0 Mshowa
0 .28848 m
.00625 .28848 L
s
[(20)] -0.0125 .28848 1 0 Mshowa
0 .42537 m
.00625 .42537 L
s
[(30)] -0.0125 .42537 1 0 Mshowa
0 .56225 m
.00625 .56225 L
s
[(40)] -0.0125 .56225 1 0 Mshowa
.125 Mabswid
0 .04209 m
.00375 .04209 L
s
0 .06947 m
.00375 .06947 L
s
0 .09685 m
.00375 .09685 L
s
0 .12422 m
.00375 .12422 L
s
0 .17898 m
.00375 .17898 L
s
0 .20635 m
.00375 .20635 L
s
0 .23373 m
.00375 .23373 L
s
0 .26111 m
.00375 .26111 L
s
0 .31586 m
.00375 .31586 L
s
0 .34324 m
.00375 .34324 L
s
0 .37062 m
.00375 .37062 L
s
0 .39799 m
.00375 .39799 L
s
0 .45275 m
.00375 .45275 L
s
0 .48012 m
.00375 .48012 L
s
0 .5075 m
.00375 .5075 L
s
0 .53488 m
.00375 .53488 L
s
0 .58963 m
.00375 .58963 L
s
0 .61701 m
.00375 .61701 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1516 m
1 .1516 L
s
.99375 .28848 m
1 .28848 L
s
.99375 .42537 m
1 .42537 L
s
.99375 .56225 m
1 .56225 L
s
.125 Mabswid
.99625 .04209 m
1 .04209 L
s
.99625 .06947 m
1 .06947 L
s
.99625 .09685 m
1 .09685 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23373 m
1 .23373 L
s
.99625 .26111 m
1 .26111 L
s
.99625 .31586 m
1 .31586 L
s
.99625 .34324 m
1 .34324 L
s
.99625 .37062 m
1 .37062 L
s
.99625 .39799 m
1 .39799 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .48012 m
1 .48012 L
s
.99625 .5075 m
1 .5075 L
s
.99625 .53488 m
1 .53488 L
s
.99625 .58963 m
1 .58963 L
s
.99625 .61701 m
1 .61701 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .05578 L
.04762 .05578 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05578 L
.04762 .05578 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .05578 L
.09524 .05578 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05578 L
.09524 .05578 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .06947 L
.14286 .06947 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .06947 L
.14286 .06947 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .1516 L
.19048 .1516 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .1516 L
.19048 .1516 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .12422 L
.2381 .12422 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12422 L
.2381 .12422 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .06947 L
.28571 .06947 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .06947 L
.28571 .06947 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .26111 L
.33333 .26111 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .26111 L
.33333 .26111 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .23373 L
.38095 .23373 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .23373 L
.38095 .23373 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .56225 L
.42857 .56225 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .56225 L
.42857 .56225 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .58963 L
.47619 .58963 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .58963 L
.47619 .58963 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .57594 L
.57143 .57594 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .57594 L
.57143 .57594 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .26111 L
.61905 .26111 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .26111 L
.61905 .26111 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .32955 L
.66667 .32955 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .32955 L
.66667 .32955 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .1516 L
.71429 .1516 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1516 L
.71429 .1516 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .16529 L
.7619 .16529 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .16529 L
.7619 .16529 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .11053 L
.80952 .11053 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .11053 L
.80952 .11053 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .08316 L
.85714 .08316 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .08316 L
.85714 .08316 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .04209 L
.90476 .04209 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04209 L
.90476 .04209 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.470199 0.97619 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0122626 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13734 -12 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13734 m
.00625 .13734 L
s
[(10)] -0.0125 .13734 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(20)] -0.0125 .25997 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(30)] -0.0125 .38259 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(40)] -0.0125 .50522 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .11282 m
.00375 .11282 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .21092 m
.00375 .21092 L
s
0 .23544 m
.00375 .23544 L
s
0 .28449 m
.00375 .28449 L
s
0 .30902 m
.00375 .30902 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .40712 m
.00375 .40712 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13734 m
1 .13734 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .50522 m
1 .50522 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .07603 L
.19048 .07603 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07603 L
.19048 .07603 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .1496 L
.2381 .1496 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .1496 L
.2381 .1496 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .17413 L
.28571 .17413 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17413 L
.28571 .17413 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11282 L
.33333 .11282 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .25997 L
.38095 .25997 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .25997 L
.38095 .25997 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .38259 L
.42857 .38259 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .38259 L
.42857 .38259 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .49296 L
.52381 .49296 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .49296 L
.52381 .49296 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .48069 L
.61905 .48069 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .48069 L
.61905 .48069 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .22318 L
.66667 .22318 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .22318 L
.66667 .22318 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11282 L
.71429 .11282 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .10055 L
.7619 .10055 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .10055 L
.7619 .10055 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .10055 L
.80952 .10055 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .10055 L
.80952 .10055 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02698 L
.85714 .02698 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02698 L
.85714 .02698 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .0515 L
.95238 .0515 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0515 L
.95238 .0515 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.620772 0.245293 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0122626 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13734 -12 -4.5 ]
[-0.0125 .13734 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13734 m
.00625 .13734 L
s
[(10)] -0.0125 .13734 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(20)] -0.0125 .25997 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(30)] -0.0125 .38259 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(40)] -0.0125 .50522 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .11282 m
.00375 .11282 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .21092 m
.00375 .21092 L
s
0 .23544 m
.00375 .23544 L
s
0 .28449 m
.00375 .28449 L
s
0 .30902 m
.00375 .30902 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .40712 m
.00375 .40712 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13734 m
1 .13734 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .50522 m
1 .50522 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02698 L
.04762 .02698 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .03924 L
.09524 .03924 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .13734 L
.2381 .13734 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13734 L
.2381 .13734 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .18639 L
.33333 .18639 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .18639 L
.33333 .18639 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .22318 L
.38095 .22318 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .22318 L
.38095 .22318 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .32128 L
.42857 .32128 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32128 L
.42857 .32128 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .43164 L
.57143 .43164 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .43164 L
.57143 .43164 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .35807 L
.66667 .35807 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .35807 L
.66667 .35807 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .19865 L
.71429 .19865 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .19865 L
.71429 .19865 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .07603 L
.7619 .07603 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07603 L
.7619 .07603 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .12508 L
.80952 .12508 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .12508 L
.80952 .12508 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02698 L
.85714 .02698 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02698 L
.85714 .02698 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .02698 L
.90476 .02698 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02698 L
.90476 .02698 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .02698 L
.95238 .02698 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02698 L
.95238 .02698 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .03924 L
1 .03924 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .03924 L
1 .03924 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.620772 0.488926 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0115413 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13013 -12 -4.5 ]
[-0.0125 .13013 0 4.5 ]
[-0.0125 .24554 -12 -4.5 ]
[-0.0125 .24554 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .47637 -12 -4.5 ]
[-0.0125 .47637 0 4.5 ]
[-0.0125 .59178 -12 -4.5 ]
[-0.0125 .59178 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13013 m
.00625 .13013 L
s
[(10)] -0.0125 .13013 1 0 Mshowa
0 .24554 m
.00625 .24554 L
s
[(20)] -0.0125 .24554 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(30)] -0.0125 .36095 1 0 Mshowa
0 .47637 m
.00625 .47637 L
s
[(40)] -0.0125 .47637 1 0 Mshowa
0 .59178 m
.00625 .59178 L
s
[(50)] -0.0125 .59178 1 0 Mshowa
.125 Mabswid
0 .0378 m
.00375 .0378 L
s
0 .06088 m
.00375 .06088 L
s
0 .08396 m
.00375 .08396 L
s
0 .10705 m
.00375 .10705 L
s
0 .15321 m
.00375 .15321 L
s
0 .17629 m
.00375 .17629 L
s
0 .19938 m
.00375 .19938 L
s
0 .22246 m
.00375 .22246 L
s
0 .26862 m
.00375 .26862 L
s
0 .29171 m
.00375 .29171 L
s
0 .31479 m
.00375 .31479 L
s
0 .33787 m
.00375 .33787 L
s
0 .38404 m
.00375 .38404 L
s
0 .40712 m
.00375 .40712 L
s
0 .4302 m
.00375 .4302 L
s
0 .45328 m
.00375 .45328 L
s
0 .49945 m
.00375 .49945 L
s
0 .52253 m
.00375 .52253 L
s
0 .54561 m
.00375 .54561 L
s
0 .5687 m
.00375 .5687 L
s
0 .61486 m
.00375 .61486 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13013 m
1 .13013 L
s
.99375 .24554 m
1 .24554 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .47637 m
1 .47637 L
s
.99375 .59178 m
1 .59178 L
s
.125 Mabswid
.99625 .0378 m
1 .0378 L
s
.99625 .06088 m
1 .06088 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .10705 m
1 .10705 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17629 m
1 .17629 L
s
.99625 .19938 m
1 .19938 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .26862 m
1 .26862 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .31479 m
1 .31479 L
s
.99625 .33787 m
1 .33787 L
s
.99625 .38404 m
1 .38404 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .45328 m
1 .45328 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .52253 m
1 .52253 L
s
.99625 .54561 m
1 .54561 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .61486 m
1 .61486 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02626 L
.04762 .02626 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02626 L
.04762 .02626 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .06088 L
.09524 .06088 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .06088 L
.09524 .06088 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .06088 L
.14286 .06088 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .06088 L
.14286 .06088 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .11859 L
.19048 .11859 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .11859 L
.19048 .11859 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .17629 L
.2381 .17629 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17629 L
.2381 .17629 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .17629 L
.28571 .17629 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17629 L
.28571 .17629 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .16475 L
.33333 .16475 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16475 L
.33333 .16475 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .28016 L
.38095 .28016 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .28016 L
.38095 .28016 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .22246 L
.42857 .22246 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .22246 L
.42857 .22246 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .37249 L
.47619 .37249 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .37249 L
.47619 .37249 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .4302 L
.52381 .4302 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4302 L
.52381 .4302 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .37249 L
.61905 .37249 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37249 L
.61905 .37249 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .22246 L
.66667 .22246 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .22246 L
.66667 .22246 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .17629 L
.71429 .17629 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17629 L
.71429 .17629 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .10705 L
.7619 .10705 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .10705 L
.7619 .10705 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .13013 L
.80952 .13013 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13013 L
.80952 .13013 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .02626 L
.85714 .02626 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02626 L
.85714 .02626 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .0378 L
1 .0378 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0378 L
1 .0378 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.620772 0.732558 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0130801 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0278 L
.04762 .0278 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .1586 L
.14286 .1586 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .1586 L
.14286 .1586 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .1586 L
.19048 .1586 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .1586 L
.19048 .1586 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .10628 L
.28571 .10628 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10628 L
.28571 .10628 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .10628 L
.33333 .10628 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .10628 L
.33333 .10628 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19784 L
.38095 .19784 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .45944 L
.47619 .45944 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45944 L
.47619 .45944 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .47252 L
.52381 .47252 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .4202 L
.61905 .4202 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .4202 L
.61905 .4202 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .34172 L
.66667 .34172 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .34172 L
.66667 .34172 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .32864 L
.71429 .32864 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .32864 L
.71429 .32864 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .11936 L
.7619 .11936 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .11936 L
.7619 .11936 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .04088 L
.85714 .04088 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04088 L
.85714 .04088 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.620772 0.97619 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0130801 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04762 .01472 m
.04762 .04088 L
.09524 .04088 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04088 L
.09524 .04088 L
.09524 .01472 L
.04762 .01472 L
s
.5 .5 .5 r
.09524 .01472 m
.09524 .13244 L
.14286 .13244 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .13244 L
.14286 .13244 L
.14286 .01472 L
.09524 .01472 L
s
.5 .5 .5 r
.14286 .01472 m
.14286 .14552 L
.19048 .14552 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .14552 L
.19048 .14552 L
.19048 .01472 L
.14286 .01472 L
s
.5 .5 .5 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
.5 .5 .5 r
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
.2381 .01472 L
s
.5 .5 .5 r
.28571 .01472 m
.28571 .18476 L
.33333 .18476 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .18476 L
.33333 .18476 L
.33333 .01472 L
.28571 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .23708 L
.38095 .23708 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .23708 L
.38095 .23708 L
.38095 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38095 .01472 m
.38095 .3548 L
.42857 .3548 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .3548 L
.42857 .3548 L
.42857 .01472 L
.38095 .01472 L
s
.5 .5 .5 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
.5 .5 .5 r
.47619 .01472 m
.47619 .57716 L
.52381 .57716 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .57716 L
.52381 .57716 L
.52381 .01472 L
.47619 .01472 L
s
.5 .5 .5 r
.52381 .01472 m
.52381 .59024 L
.57143 .59024 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .59024 L
.57143 .59024 L
.57143 .01472 L
.52381 .01472 L
s
.5 .5 .5 r
.57143 .01472 m
.57143 .3548 L
.61905 .3548 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3548 L
.61905 .3548 L
.61905 .01472 L
.57143 .01472 L
s
.5 .5 .5 r
.61905 .01472 m
.61905 .23708 L
.66667 .23708 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .23708 L
.66667 .23708 L
.66667 .01472 L
.61905 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .19784 L
.71429 .19784 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .19784 L
.71429 .19784 L
.71429 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
.71429 .01472 L
s
.5 .5 .5 r
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
.7619 .01472 L
s
.5 .5 .5 r
.80952 .01472 m
.80952 .04088 L
.85714 .04088 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04088 L
.85714 .04088 L
.85714 .01472 L
.80952 .01472 L
s
.5 .5 .5 r
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0278 L
.90476 .0278 L
.90476 .01472 L
.85714 .01472 L
s
.5 .5 .5 r
.90476 .01472 m
.90476 .0278 L
.95238 .0278 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0278 L
.95238 .0278 L
.95238 .01472 L
.90476 .01472 L
s
.5 .5 .5 r
.95238 .01472 m
.95238 .04088 L
1 .04088 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04088 L
1 .04088 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.25, 511.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C0001ob000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo000g0?ooo`D000000P3oool2000000@0oooo
0P00000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3oool4000000<0oooo
0P0000040?ooo`800000>`3oool500000080oooo0P0000040?ooo`8000004P3oool2000001@0oooo
1@0000020?ooo`800000103oool2000000h0oooo100000030?ooo`800000103oool2000003/0oooo
1@0000020?ooo`800000103oool2000001@0oooo0P00000F0?ooo`D000000P3oool2000000@0oooo
0P00000?0?ooo`@000000`3oool2000000@0oooo0P00000i0?ooo`D000000P3oool2000000@0oooo
0P00000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`800000403oool4000000<0oooo
0P0000040?ooo`8000004`3oool003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo000i0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo
00@000000?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
5`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000B0?ooo`00<@3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<P3oool4000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool01000
0000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0<P3oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403o
ool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<03oool4000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool003T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003`0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000180oooo000h0?ooo`800000103oool2000000@0
oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0
oooo0P0000040?ooo`800000?03oool2000000@0oooo0P0000040?ooo`8000004P3oool2000001D0
oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`800000103oool2000003`0
oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000G0?ooo`800000103oool2000000@0
oooo0P00000@0?ooo`800000103oool2000000@0oooo0P00000j0?ooo`800000103oool2000000@0
oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0
oooo0P0000040?ooo`8000004`3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o
0?ooool0ooooU@3oool001T0oooo0P00002P0?ooo`800000V`3oool2000009l0oooo0P00002H0?oo
o`00603oool010000000oooo0?ooo`0000020?oooh000000703oool010000000oooo0?ooo`000003
0?ooog/000006`3oool010000000oooo0?ooo`0000030?oooh4000006@3oool010000000oooo0?oo
o`0000020?oooh8000004`3oool001P0oooo00@000000?ooo`3oool000000P3ooon0000001`0oooo
00@000000?ooo`3oool000000`3ooomk000001/0oooo00@000000?ooo`3oool000000`3ooon10000
01T0oooo00@000000?ooo`3oool000000P3ooon2000001<0oooo000H0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0
oooo000000<0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`040000003o
ool0oooo000000<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`00
603oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool06P3oool010000000oooo0?ooo`0000030?ooo``000001@1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`d000006@3oool010000000oooo0?ooo`0000020?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl8000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`L00000303oool00`000000oooo0?ooo`0A0?ooo`006@3oool2000000<0oooo0P000004
0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000oooo0?ooo`0>
0?ooo`8000007@3oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo00h0oooo0P00000L0?ooo`800000103oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01P0oooo0P0000030?ooo`L000001@1oOgl00`000000oooo0?ooo`04
0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00l0oooo0P00000C
0?ooo`007P3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0203oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0803oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo00X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl700000180oooo00<000000?oo
o`3oool04@3oool001h0oooo00<000000?ooo`3oool00`3oool7000000D0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`0000050?ooo`L0
00004@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`H000001@1oOgl00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0:0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`00
7P3oool200000100oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
803oool2000002<0oooo00<000000?ooo`3oool0203oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
0P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00h0oooo0P00000R0?ooo`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool2000000@0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
5@3oool2000001<0oooo000N0?ooo`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00P3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`030?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo1`00000A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000N0?ooo`030000003oool0
oooo01D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00P3oool700000140oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3oool2
000000@0oooo1`00000<0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3oool2
000001<0oooo000N0?ooo`8000005P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0803oool2000002<0oooo00<000000?ooo`3oool03P3oool70000
00D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo1`00000507moO`030000003oool0oooo01T0oooo0P00000R0?ooo`030000003oool0oooo
00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01H0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0140oooo000N0?ooo`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000
Ogmo07moO`0307moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000001L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl=000001P0oooo00<000000?ooo`3oool04@3oool001h0oooo
00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0oooo
00<000000?ooo`3oool07@3oool2000001L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo0240oooo0P00000C0?ooo`007P3oool2000001H0oooo1`00
000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0200oooo0P00000S0?ooo`030000003oool0oooo01@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool06@3oool200000280oooo00<000000?ooo`3oool02@3oool7000000D0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo00<0
00000?ooo`3oool05P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`004P3oool500000080oooo0P000003
0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01@0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0D
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0?
0?ooo`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`L000007@3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`00000M0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000001H0oooo00<0000007moO`1oOgl00`1oOgl6000000D0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000G0?ooo`L000001@1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000oooo0?ooo`0Q0?ooo`8000004`3o
ool001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000703o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo0200oooo0P00000H0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001H0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`030?ooo`L000006`3oool2000001D0oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`0E0?ooo`L000001P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000001h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0140oooo000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000M0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001H0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000007@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000M0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool2000001<0oooo000D0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000001H0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`020?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo0?ooo`800000703oool8000000D0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo01`0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo000C0?ooo`800000103oool2
000000<0oooo0P00000L0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0803oool2000001L0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00P3oool7
000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool2000001L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000903oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo1`00000S0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
703oool00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo0280oooo00<000000?ooo`3oool04@3oool001h0oooo00<000000?ooo`3oool08@3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0503o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo00P0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000903oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`80
00007@3oool7000000D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo0240oooo0P00000C0?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0203oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo0280oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo000N0?ooo`8000008P3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0P0?ooo`8000008`3o
ool00`000000oooo0?ooo`0D0?ooo`L000002P3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02D0oooo0P00000R0?ooo`030000003oool0oooo0280oooo1`00000507moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0140oooo000N0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`L000008`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo02D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo02L0oooo00<000000?ooo`3oool07@3oool2000002T0oooo1`00000507moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool7000002<0oooo0P00000C0?ooo`007P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09@3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001h0
oooo0P00000R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0V0?ooo`8000008`3oool00`000000oooo0?ooo`0U0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool09@3oool200000280oooo00<000000?ooo`3oool0:03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool2000002l0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0
oooo0P00000C0?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`d000001@1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool4000000<0oooo
0P0000030?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001h0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool09@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo
000N0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0V0?ooo`8000008`3oool00`000000oooo0?oo
o`0U0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool200000280oooo00<0
00000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0]0?ooo`8000004`3oool00180oooo100000030?ooo`8000000`3oool00`000000oooo0?oo
o`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool4000000<0oooo0P00
00040?ooo`030000003oool0oooo02D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000<03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`00
4P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02D0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo0P00000^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02H0oooo0P00
000G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0U0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool200000280oooo
00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`800000;`3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool2000001<0oooo
000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000_0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0C0?ooo`@000000`3oool2000000@0oooo00<00000
0?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000B0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:03oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool20000
02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02d0oooo0P00000C0?ooo`004`3oool2000000@0oooo0P0000030?ooo`800000;P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0V0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02D0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0U0?ooo`8000005P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P00000Y0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02h0oooo00<000000?ooo`3oool04@3oool001h0oooo00<000000?ooo`3oool0;@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`L000001@1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool0
01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool09@3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02D0oooo0P00000E0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo0P00000C0?ooo`007P3oool2
000002h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool09P3oool2000002<0oooo00<000000?ooo`3oool0:`3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0^0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0140oooo000N0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`L00000:03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0140oooo000N0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0V0?ooo`8000008`3oool00`000000
oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0[0?ooo`8000008P3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl8000002T0oooo00<000000?ooo`3oool04P3oool2000000@0
oooo0P0000030?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0
oooo0P00000C0?ooo`007P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`L00000<03oool00`00
0000oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`02000003D0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<`3oool20000
01<0oooo000N0?ooo`800000;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo1`00000X0?ooo`8000008`3oool00`000000oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0[0?ooo`8000008P3oool00`000000
oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000`0?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000f0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04@3oool001<0oooo0P0000040?ooo`8000000`3oool00`00
0000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0[0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool70000
00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02/0oooo00<0000007mo
O`1oOgl00`1oOgl7000000D0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?oo
o`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0c0?ooo`8000004`3oool001@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00800000;P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0;03oool2000001P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000;@3oool7000000D0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0:`3oool200000280oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0140oooo000E0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000000i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool00180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo02d0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo
0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo03<0oooo0P00000C0?ooo`004`3oool2000000@0oooo0P00
00030?ooo`800000=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02`0oooo0P00
000G0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0[0?ooo`8000005P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?ooo`0c
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo03L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2000003D0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0<`3oool2000001<0oooo000N0?ooo`030000003oool0oooo03<0oooo1`00
000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo0?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140
oooo000N0?ooo`800000>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0/0?ooo`8000008`3oool00`000000oooo
0?ooo`0g0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02/0oooo0P00000H0?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool001h0oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M
0?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0c0?ooo`8000004`3oool001h0oooo00<000000?oo
o`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo2000000_0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo1`00000^0?ooo`030000003oool0oooo01@0oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04`3oool300000080oooo0P0000030?ooo`030000003oool0oooo03@0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007P3oool2000003X0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo0P00000S0?ooo`03
0000003oool0oooo03L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000003oool0oooo0340oooo0P00000R0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000=P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000N0?oo
o`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0g0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00000e
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl8000003D0oooo0P00000C
0?ooo`007P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0=`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03@0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0140oooo000N
0?ooo`800000>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0<`3oool2000002<0oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0<@3oool200000280oooo00<00000
0?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`800000=@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool2000001<0oooo000D
0?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0F
0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A
0?ooo`005@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000>@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool04@3oool00180oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00000j0?ooo`03
0000001oOgl0Ogmo00<0Ogmo1`00000e0?ooo`8000005P3oool5000000050?ooo`000000oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`0g0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0a0?ooo`8000008P3oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2000003D0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo0P00000C0?oo
o`004P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0=`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03@0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo
00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo03L0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo0380oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0140oooo000D0?ooo`8000000`3oool2000000<0oooo
0P00000j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>@3oool2000001P0oooo
0P0000030?ooo`800000103oool00`000000oooo0?ooo`0g0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0a0?ooo`8000008P3oool00`000000oooo
0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000003oool0oooo03@0oooo
00<000000?ooo`3oool07@3oool2000003D0oooo1`00000507moO`030000003oool0oooo03X0oooo
0P00000C0?ooo`007P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03L0oooo1`00
000407moO`030000003oool0oooo0380oooo00<000000?ooo`3oool05@3oool300000080oooo0P00
00040?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0140oooo000N0?ooo`030000003oool0oooo03T0oooo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0?@3oool00`000000Ogmo07moO`0207moO`030000003oool0oooo0380oooo00<00000
0?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000
=P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P00000k0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool2000001<0oooo000N0?ooo`800000>P3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03T0oooo0P00000S0?ooo`030000003o
ool0oooo03d0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0a0?ooo`8000005@3o
ool5000000050?ooo`000000oooo0?ooo`0000000`3oool2000003D0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0
>P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
4@3oool001h0oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`030000001o
Ogl0Ogmo0080Ogmo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3oool001h0oooo00<000000?oo
o`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00800000>`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo0P00000C0?ooo`007P3oool2
000003X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`8000008`3oool0
0`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0<@3oool2
000001L0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04P3oool2000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo03d0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0140oooo000N0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0?@3oool0
0`000000Ogmo07moO`0207moO`030000003oool0oooo0380oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool3
000000<0oooo0P0000030?ooo`800000>`3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo03X0oooo0P00000C0?ooo`007P3oool2000003X0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0i0?ooo`8000008`3oool00`000000oooo0?ooo`0m0?ooo`030000001oOgl0Ogmo
0080Ogmo00<000000?ooo`3oool0<@3oool200000280oooo00<000000?ooo`3oool0=03oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3oool001<0
oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool0?@3oool6000003@0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000
Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2000003/0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`8000004`3oool00180oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00<0oooo1`00000f0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<000000?ooo`3oool04@3o
ool001D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02000003X0oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`8000006@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo0?ooog/000008P3oool00`000000oooo0?ooo`0d0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0140oooo000C0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo03T0oooo1`00000l0?ooo`030000003oool0oooo01D0oooo0P0000030?ooo`04
0000003oool0oooo00000:00oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0400oooo00<000000?ooo`3oool07@3oool2000003/0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`8000004`3oool001<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo0P00000G0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000X03oool00`000000oooo0?ooo`0d0?ooo`L00000@P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03X0oooo1`00000m0?ooo`030000003oool0oooo0140oooo000C0?oo
o`<000000`3oool2000000<0ooooP000000G0?ooo`<000000`3oool200000:40oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo0P00000M0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0080oooo0P00000C0?ooo`00o`3ooomO0?oooh4000007`3ooon2000001<0
oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?oo
ool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3o
ool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo000g0?ooo`D000000P3oool2000000@0
oooo0P00000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`800000403oool4000000<0
oooo0P0000040?ooo`800000>03oool500000080oooo0P0000040?ooo`800000503oool2000001D0
oooo1@0000020?ooo`800000103oool200000100oooo100000030?ooo`800000103oool2000003P0
oooo1@0000020?ooo`800000103oool2000001@0oooo0P00000F0?ooo`D000000P3oool2000000@0
oooo0P00000?0?ooo`@000000`3oool2000000@0oooo0P00000i0?ooo`D000000P3oool2000000@0
oooo0P00000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3oool4000000<0
oooo0P0000040?ooo`800000503oool003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000F0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001<0oooo000i0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000i0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
00005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000C0?ooo`00<@3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<03oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool003T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403o
ool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000001<0oooo000h0?ooo`800000103oool20000
00@0oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`8000004@3oool20000
00@0oooo0P0000040?ooo`800000>@3oool2000000@0oooo0P0000040?ooo`800000503oool20000
01H0oooo0P0000040?ooo`800000103oool200000140oooo0P0000040?ooo`800000103oool20000
03T0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000G0?ooo`800000103oool20000
00@0oooo0P00000@0?ooo`800000103oool2000000@0oooo0P00000j0?ooo`800000103oool20000
00@0oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`800000403oool20000
00@0oooo0P0000040?ooo`800000503oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00603oool2000000<0ooooPP00000I0?oo
o`800000103ooon1000001T0oooo0P0000040?oooh4000006P3oool2000000@0ooooP000000D0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo06H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo
000G0?ooo`040000003oool0oooo00000080ooooPP00000H0?ooo`040000003oool0oooo000000<0
ooooP@00000H0?ooo`040000003oool0oooo000000<0ooooP@00000I0?ooo`040000003oool0oooo
000000<0ooooP000000D0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`L000001@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`030?ooo`P000001@3oool7000001P0oooo00@000000?ooo`3oool000000`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOglC000000D0oooo00<000000?ooo`3oool04P3oool001L0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool010000000oooo0?ooo`0000030?ooo`L000001@1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo3@00000I0?ooo`040000003oool0oooo000000<0oooo1`00
000507moO`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01@0oooo0P00
000D0?ooo`00603oool2000000<0oooo0P0000040?ooo`h000001@1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo01D0oooo0P00000I0?ooo`800000103oool7000000D0oooo1`000005
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0603oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?oo
o`3oool0403oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo01D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00<0oooo1`0000050?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0D0?ooo`800000503oool001d0oooo0P00000A0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`800000
7`3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`L000001P1oOgl00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`d000002`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?ooo`3oool0403o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0?0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo000M0?ooo`030000003oool0oooo0100oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0
oooo00T0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0D0?ooo`800000503oool001d0oooo00<000000?ooo`3oool0403oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`00
0000Ogmo07moO`0407moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0B0?ooo`007@3oool200000140oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl70000
01L0oooo0P00000O0?ooo`030000003oool0oooo00l0oooo1`00000507moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo
01D0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`3oool200000100oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl=000001L0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?oo
o`3oool0403oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`P000005`3oool00`000000oooo0?ooo`0G0?oo
o`800000103oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0803oool2000001@0oooo000M0?ooo`030000003oool0oooo0100oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool05@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`L000005`3oool00`000000oooo0?ooo`0A0?ooo`D0
00000P3oool2000000@0oooo00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`00
7@3oool200000140oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`800000
7`3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo0`0000030?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000005`3oool00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?oo
o`004@3oool500000080oooo0P0000030?ooo`030000003oool0oooo0100oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool03`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000F
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0P
0?ooo`800000503oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000180oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo1`00000N0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000005`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P00000A0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo0P00000D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001L0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo
0P00000O0?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000005`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000004P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000005`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`D000000P3oool2000000@0oooo
00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0307moO`L000001P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo01D0oooo1`0000050?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0200oooo
0P00000D0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00004P3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000005`3oool7000000D0Ogmo1`00000507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000140oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0180oooo000B0?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool05P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool06`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
oooo0P00000@0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`L000007@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`007@3oool2000001L0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo0240oooo0P00000O0?ooo`030000003oool0oooo01/0oooo
1`0000050?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000004@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
00<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo2000000R0?ooo`800000503oool001d0oooo00<000000?ooo`3oool05P3oool7000000D0
Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo0000000A0?ooo`L000001@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl7000002<0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0oooo
01`0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool09`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`007@3oool2000001d0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`L000001@1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0Q0?ooo`8000007`3oool00`000000oooo0?ooo`0W0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool09`3oool2000001@0oooo000M0?ooo`030000003oool0oooo01`0oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo
000M0?ooo`030000003oool0oooo01`0oooo1`00000;0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl7000002@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0K0?ooo`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo000M
0?ooo`800000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo0P00000O
0?ooo`030000003oool0oooo02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0240oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo0P00000D
0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo1@0000020?oo
o`800000103oool00`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo100000030?oo
o`800000103oool00`000000oooo0?ooo`0W0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`L00000:P3oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000903oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0180oooo000M
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`8000008`3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool2000002h0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo0P00000D0?ooo`007@3o
ool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`8000007`3o
ool00`000000oooo0?ooo`0W0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003o
ool0oooo0280oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0180oooo000A0?ooo`@00000
0`3oool2000000<0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo0280oooo00<000000?ooo`3oool0403oool4000000<0oooo0P0000040?ooo`030000
003oool0oooo02L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0280oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`004@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000002@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool09`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo02P0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`800000503oool00180oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000;`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W
0?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool09`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo0P00
000O0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000:@3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool00140oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000:P3oool00`000000oooo0?ooo`0@
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0W0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool2000001@0oooo
000B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool001d0oooo0P00000_
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]
0?ooo`8000007`3oool00`000000oooo0?ooo`0W0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000:P3oool00`000000oooo0?ooo`0@
0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0]
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0oooo02h0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`800000503oool001d0oooo00<000000?oo
o`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool2000002T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B
0?ooo`007@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02d0oooo0P00000O0?ooo`030000003oool0oooo02L0oooo1`00000607mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002X0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000;`3oool2000001@0oooo000M
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0]
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0
oooo00<000000?ooo`3oool04P3oool001d0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000007`3oool00`000000oooo
0?ooo`0]0?ooo`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:03oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000^0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0<`3oool2000001@0oooo000M0?ooo`030000003oool0oooo02h0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`0^0?oo
o`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04P3oool001d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`03
07moO`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo0P00000D
0?ooo`007@3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?oo
o`8000007`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`@000000`3oool2000000@0oooo00<000000?oo
o`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0;@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04P3oool00180oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0d0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool00140oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03@0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03@0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000002l0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`P00000:@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02d0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`80
0000503oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
0000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl7000002l0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000003H0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]
0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0^
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool001@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000=P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0oooo1`0000050?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0180oooo000A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo
00<000000?ooo`3oool04@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo02h0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`800000503oool00180oooo0P00
00040?ooo`8000000`3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool2000001<0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000<03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0oooo03@0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo000M0?oo
o`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?oo
o`800000503oool001d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`<0
00000P3oool2000000@0oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`00
7@3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool2000001l0oooo00<000000?ooo`3oool0
=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`800000
103oool00`000000oooo0?ooo`0^0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool00000
03/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?ooo`3oool0=03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo1@0000001@3oool000000?ooo`3o
ool0000000<0oooo0P00000j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0c0?ooo`800000503oool001d0oooo00<000000?ooo`3oool0=03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo0?ooo`800000=@3oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0>@3oool00`000000Ogmo07moO`0307moO`L00000=P3oool00`000000oooo0?ooo`0B0?oo
o`007@3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl8000000D0Ogmo00<000000?ooo`3o
ool0<`3oool2000001l0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000003`0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`007@3oool0
0`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`800000
103oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
>@3oool2000001@0oooo000M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0>P3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>@3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool04P3o
ool001d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo0P00000O0?ooo`030000003oool0
oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000<03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0oooo
03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0>@3oool2000001@0oooo000C0?ooo`<000000P3oool2000000<0
oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180
oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0
oooo00<000000?ooo`3oool04P3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04`3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0180oooo000A0?ooo`D0000000D0oooo0000003oool0oooo0000
00020?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`8000004P3oool5000000050?ooo`00
0000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo
0P00000C0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0i0?ooo`800000503oool00140oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`040?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo000B0?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool00`000000oooo000000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool20000
03/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`004`3oool2000000<0
oooo0P0000030?ooo`800000=@3oool7000000H0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0c0?ooo`800000503oool2000000<0oooo0P0000040?ooo`030000003oool0oooo03@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0?oo
o`800000103oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0>@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03T0oooo0P00000D0?oo
o`007@3oool00`000000oooo0?ooo`110?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L0
0000=P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool3000000<0oooo00<000000?ooo`3o
ool0>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`110?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3o
ool2000003X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0i0?ooo`800000503o
ool001d0oooo0P0000120?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool2
000001l0oooo00<000000?ooo`3oool0=03oool7000000D0Ogmo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool2
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`L00000?03o
ool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`L00000=P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo1`00000l0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0>P3oool=000003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3o
ool001d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0180oooo0`0000030?ooo`800000103ooon0000001@0oooo000M0?oooh8000007`3ooon10000
01l0ooooP@00002d0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3o
oonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00=`3oool50000
0080oooo0P0000040?ooo`8000004`3oool2000001H0oooo1@0000020?ooo`800000103oool20000
0100oooo100000030?ooo`800000103oool2000003P0oooo1@0000020?ooo`800000103oool20000
01@0oooo0P00000E0?ooo`D000000P3oool2000000@0oooo0P00000@0?ooo`@000000`3oool20000
00@0oooo0P00000h0?ooo`D000000P3oool2000000@0oooo0P00000D0?ooo`8000005P3oool50000
0080oooo0P0000040?ooo`8000003`3oool4000000<0oooo0P0000040?ooo`800000>@3oool50000
0080oooo0P0000040?ooo`8000004`3oool2000001H0oooo1@0000020?ooo`800000103oool20000
0100oooo100000030?ooo`800000103oool2000001<0oooo000i0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000B0?ooo`00>@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
>@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`04
0000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000004P3oool00340oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02l0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02l0oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0300
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0100oooo000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000i
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`00>03oool2
000000@0oooo0P0000040?ooo`8000004`3oool2000001L0oooo0P0000040?ooo`800000103oool2
00000140oooo0P0000040?ooo`800000103oool2000003T0oooo0P0000040?ooo`800000103oool2
000001@0oooo0P00000F0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000103oool2
000000@0oooo0P00000i0?ooo`800000103oool2000000@0oooo0P00000D0?ooo`8000005`3oool2
000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo0P0000040?ooo`800000>P3oool2
000000@0oooo0P0000040?ooo`8000004`3oool2000001L0oooo0P0000040?ooo`800000103oool2
00000140oooo0P0000040?ooo`800000103oool2000001<0oooo003o0?ooool0ooooU@3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool001P0oooo0P000003
0?oooh8000006@3oool2000000@0ooooP@00000I0?ooo`800000103ooon1000001X0oooo0P000003
0?oooh8000004`3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080
ooooPP00000H0?ooo`040000003oool0oooo000000<0ooooP@00000H0?ooo`040000003oool0oooo
000000<0ooooP@00000I0?ooo`040000003oool0oooo00000080ooooPP00000C0?ooo`005`3oool0
10000000oooo0?ooo`0000020?ooo`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00@0oooo1`0000050?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
0`3oool=000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`L0
00001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`03
0000001oOgl0Ogmo00<0Ogmo3@00000I0?ooo`040000003oool0oooo00000080oooo1`00000507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`d00000303oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`d00000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`800000103oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool2000001T0oooo0P00
00040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`L000002`3oool00`000000oooo0?oo
o`0H0?ooo`8000000`3oool2000000@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0E0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo1`00000A0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool00`3oool=000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`03
07moO`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool03`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04@3oool001d0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo1`00000507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0M0?ooo`800000103oool7000000H0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl7000001L0oooo0P00000C0?ooo`007@3oool2000000@0oooo1`00000607moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl700000140oooo0P00000O0?ooo`030000
003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0140oooo000M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`L00000603oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`P000005`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool700000140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0140oooo000M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo1`00000N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0A0?ooo`007@3oool2000000X0oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
01/0oooo0P00000O0?ooo`030000003oool0oooo00T0oooo1`0000050?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01d0oooo0P00000:0?ooo`h000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool06`3oool2000001<0oooo000M0?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0403oool500000080oooo0P0000040?ooo`030000003oool0oooo01D0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01`0
oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool02@3oool8000000D0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L000007P3oool00`000000oooo
0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
01L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl7000001d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool001d0
oooo00<000000?ooo`3oool0403oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000005`3oool7
000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool200000180oooo1@0000020?ooo`800000103oool0
0`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo0P00000G0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo01/0oooo0P00000C0?ooo`007@3oool200000140oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool20000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000007@3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl7000002@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000G0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo1@0000020?ooo`80
00000`3oool00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool04@3oool00140oooo1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`L00000
1@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000M0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool0oooo0P00000F0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001P0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000007P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
0280oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
01/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000G0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000001d0oooo0P00000C0?ooo`004`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000M0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool2000001l0oooo00<000000?ooo`3oool0
6`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000N0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool05@3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo1`00000T0?ooo`030000003oool0oooo0140oooo000C0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000N0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01D0oooo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool2
000000@0oooo0P0000030?ooo`030000003oool0oooo01H0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`L000001@1oOgl70000
00H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`P000001@1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0M0?ooo`8000005`3ooolC000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool20000
01<0oooo000M0?ooo`8000007@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240
oooo0P00000O0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0L0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
3P00000S0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool001d0oooo00<0
00000?ooo`3oool0703oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool07@3oool2000002T0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`8000004`3oool001d0oooo0P00000M
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool200000180oooo10000003
0?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`L000001@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?oo
o`3oool0703oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0;@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0307mo
O`d000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool09`3oool2000001l0oooo00<000000?ooo`3oool08P3oool7000000D0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000;`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo0P00
000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02L0oooo0P00000C0?ooo`007@3oool2000001d0oooo1`00000;
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool200000180oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000:P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`@000000`3oool2000000@0oooo00<0
00000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000M
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0X0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001<0oooo000M
0?ooo`800000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl7000002<0oooo0P00000O0?ooo`030000003oool0oooo02d0oooo20000005
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo1000
00030?ooo`8000000`3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo0000000`0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`004@3oool4000000<0oooo
0P0000030?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000_0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02L0oooo0P00000C0?ooo`004@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02h0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02h0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo
000B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool2000002l0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool09`3oool2000001l0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl700000300oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0140oooo000A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001<0oooo000B
0?ooo`800000103oool2000000<0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo0P00000B
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo02h0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool2000001l0
oooo00<000000?ooo`3oool0;P3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo
00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`000000=P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?oo
o`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001<0oooo000M0?ooo`03
0000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0d
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A
0?ooo`007@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`L00000:@3oool2000001<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`L00000<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool7000000D0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P00000_0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02L0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`007@3o
ool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02d0oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl7000000D0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`007@3oool0
0`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
0`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0;P3oool7000000D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000e0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`030?ooo`L00000:@3oool2000001<0oooo000M0?ooo`030000
003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo
02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0140oooo000M0?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0
oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103o
ool2000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
<`3oool2000001<0oooo000A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0B0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3o
ool0>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo0P00000E
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000l0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo000D0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000=P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0403oool5000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000e0?ooo`8000007`3oool00`000000oooo0?oo
o`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P00
00030?ooo`800000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03<0oooo0P00
000C0?ooo`004@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
1`00000507moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`004P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo03@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0;@3oool2000001@0oooo0P0000030?ooo`800000103oool00`000000
oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo
00<000000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0c0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02h0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M
0?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo0P00000O
0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<`3oool2000001<0oooo000M0?ooo`03
0000003oool0oooo03@0oooo1`00000607moO`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0>P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool04P3oool300000080oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000k0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0
oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo0100oooo1@0000001@3oool000000?ooo`3oool00000
00<0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0
oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000003H0oooo00<000000?ooo`3oool07@3oool2
000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0<`3oool2000001<0oooo000M0?ooo`030000003oool0oooo
03X0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`L00000<03oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo0`0000020?ooo`800000
0`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000607moO`030000
003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000k0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0>@3oool2000001D0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0i0?ooo`800000503oool2000000<0oooo0P0000040?ooo`030000003oool0oooo03@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003H0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`00
0000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0A0?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`D0000000D0oooo
0000003oool0oooo000000020?ooo`800000=@3oool7000000D0oooo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0c0?ooo`8000004`3oool001<0oooo0`0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0@03oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool04@3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?oo
o`<000000`3oool2000000@0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0400oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo000A0?ooo`D0000000D0oooo0000003oool0oooo00000002
0?ooo`800000>`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03T0oooo0P00000O
0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0C
0?ooo`8000000`3oool2000000<0oooo0P0000110?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0<`3oool2000001<0oooo000A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool7000000D0Ogmo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000C
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`04
07moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`04
07moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000k0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>@3oool2000001l0oooo00<000000?oo
o`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`800000@@3oool00`000000Ogmo07moO`0407mo
O`030000003oool0oooo03<0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`P0
0000?03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo1`00000l0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool7000003`0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`100?ooo`P00000=P3oool00`000000oooo0?ooo`0A0?ooo`00
7@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool001d0ooooPP00000O0?oooh4000007`3ooon1000001l0ooooPP00000C0?ooo`00o`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00=`3oool500000080oooo0P0000040?ooo`8000004`3o
ool2000001H0oooo1@0000020?ooo`800000103oool200000100oooo100000030?ooo`800000103o
ool2000003X0oooo1@0000020?ooo`800000103oool200000180oooo0P00000D0?ooo`D000000P3o
ool2000000@0oooo0P00000>0?ooo`@000000`3oool2000000@0oooo0P00000k0?ooo`D000000P3o
ool2000000@0oooo0P00000D0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3o
ool4000000<0oooo0P0000040?ooo`800000>@3oool500000080oooo0P0000040?ooo`8000004`3o
ool2000001H0oooo1@0000020?ooo`800000103oool200000100oooo100000030?ooo`800000103o
ool2000001<0oooo000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`00>@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?oo
o`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`040000003o
ool0oooo000001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000?03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000004P3oool00340oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
5`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0340oooo100000040?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3o
ool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0380oooo100000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0300oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo000i0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000k0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000l0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
00005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000B0?ooo`00>03oool2000000@0oooo0P0000040?ooo`800000
4`3oool2000001L0oooo0P0000040?ooo`800000103oool200000140oooo0P0000040?ooo`800000
103oool2000003/0oooo0P0000040?ooo`800000103oool200000180oooo0P00000E0?ooo`800000
103oool2000000@0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000l0?ooo`800000
103oool2000000@0oooo0P00000D0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`800000
403oool2000000@0oooo0P0000040?ooo`800000>P3oool2000000@0oooo0P0000040?ooo`800000
4`3oool2000001L0oooo0P0000040?ooo`800000103oool200000140oooo0P0000040?ooo`800000
103oool2000001<0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool001P0oooo0P0000030?oooh800000703oool2000000<0oooo
O000000L0?ooo`800000103ooon1000001X0oooo0P0000030?oooh8000004`3oool001L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`800000103oool20000
01P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo000G0?ooo`040000003oool0oooo00000080ooooPP00000K0?ooo`040000003oool0
oooo00000080ooooO000000K0?ooo`040000003oool0oooo000000<0ooooP@00000I0?ooo`040000
003oool0oooo00000080ooooPP00000C0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00@0oooo3@00000K0?ooo`040000003oool0oooo00000080oooo1`00000507mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00
00020?ooo`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl7000000D0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo
0P0000040?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo00P0oooo0P00000K0?ooo`040000003oool0oooo000000<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`800000103oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool2000001`0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
oooo0?ooo`030?ooo`L000002`3oool00`000000oooo0?ooo`0J0?ooo`800000103oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000000/0
oooo00<000000?ooo`3oool0603oool2000000<0oooo0P0000040?ooo`L000001P1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool00`000000
Ogmo07moO`0407moO`030000003oool0oooo0080oooo0P00000C0?ooo`007@3oool00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01l0oooo0P0000040?ooo`L000001@1oOgl00`000000Ogmo
07moO`0307moO`L00000101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<000000?ooo`3oool0503oool200000280oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool8000000D0oooo
00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`L000004P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`d000001@1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo00<0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1P00000G
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool2000000X0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool05@3oool2000001<0oooo000M0?ooo`800000103oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo01D0oooo0P00000Q0?ooo`8000002P3oool7000000D0Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool06@3oool200000280oooo00<000000?ooo`3oool02@3oool7000000D0Ogmo00<0000007mo
O`1oOgl00`1oOgl8000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3o
ool00`3oool>000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0?0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`040?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`03
0000001oOgl0Ogmo00@0Ogmo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool001d0oooo00<000000?ooo`3oool0403oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`800000
403oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01T0oooo0P00000R0?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo00@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L00000
4@3oool00`000000oooo0?ooo`0M0?ooo`8000002P3oool00`000000Ogmo07moO`0407moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`800000
4`3oool001d0oooo0P00000A0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000oooo0?ooo`0E0?ooo`8000005@3o
ool500000080oooo0P0000030?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000140oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl=000001P0oooo00<000000?ooo`3oool04@3oool001d0oooo00<0
00000?ooo`3oool0403oool00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`030?ooo`L00000603oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0200000100oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0I0?ooo`8000008P3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
1`00000G0?ooo`030000003oool0oooo01d0oooo0P00000:0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`L000008`3oool2000001<0oooo000M0?ooo`030000003oool0oooo0100oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000A0?ooo`L000001@3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0407moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0140oooo000M0?ooo`8000004@3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`800000
5`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000L0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0I0?ooo`80
00008P3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00<0Ogmo1`0000060?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`D0
00000P3oool2000000<0oooo00<000000?ooo`3oool02@3oool8000000D0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000A0?ooo`D00000
0P3oool2000000<0oooo00<000000?ooo`3oool0403oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01<0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0?0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000603oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02P0oooo00<000000?ooo`3oool04@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000180oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P00000G0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001<0
oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000140
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool08@3oool200000240oooo0P00000L0?ooo`H000001@1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`L000001@1oOgl00`000000oooo0?ooo`0I0?ooo`8000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000@0?ooo`L00000303oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo1`00000507moO`030000003oool0
oooo01/0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000603oool7000000D0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool001<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000180oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo1`00000507moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000903oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
7P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000B0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool00`3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool2000002L0
oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`030?ooo`L000006`3oool2000001L0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000903oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool00`3oool7000001d0oooo00<000000?ooo`3oool04P3oool2
000000@0oooo0P0000030?ooo`8000007@3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`8000004`3oool0
0180oooo0P0000040?ooo`8000000`3oool200000140oooo1`00000;0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
0240oooo0P00000Q0?ooo`030000003oool0oooo02`0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0D0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool08P3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo1`0000050?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0/0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool001d0oooo
00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo
100000030?ooo`8000000`3oool2000002d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool200000280oooo
00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`800000:@3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02L0oooo0P00000C0?ooo`007@3oool00`000000oooo0?oo
o`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08P3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0140oooo000M0?ooo`8000008`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0Q0?ooo`8000005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
0P00000]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl7000002L0oooo
0P00000R0?ooo`030000003oool0oooo0280oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<0
00000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0280oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool07@3oool2000002T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`80
00004`3oool001d0oooo00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`800000;@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0:`3oool200000280oooo00<000000?ooo`3oool08P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0140oooo000M0?ooo`8000008`3oool7000000D0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`8000005P3oool2000000@0oooo0P0000030?ooo`03
0000003oool0oooo02`0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl7000002X0oooo00<000000?ooo`3o
ool04@3oool001d0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02`0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`030000
001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo0P00000Y0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02d0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0X0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo0P00000]0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0[0?ooo`8000008P3oool00`000000oooo0?ooo`0R0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0140oooo100000030?ooo`8000000`3oool00`000000oooo0?ooo`0X0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0:03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02`0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002T0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7
000002<0oooo0P00000Q0?ooo`800000;@3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:`3oool2
00000280oooo00<000000?ooo`3oool08P3oool7000000D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7
000000H0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool2000002T0oooo1`00000507moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool2000001<0oooo000A0?ooo`@000000`3oool2
000000<0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000`0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo
000A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0380oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo1`00000^0?ooo`030000003oool0oooo01<0oooo
100000030?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000Y0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool09`3oool2000001H0oooo0P0000040?ooo`8000000`3oool20000
03<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
0080Ogmo00<000000?ooo`3oool0<@3oool2000001D0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00000_0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3oool0
01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002X0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00140
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000<`3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`0a0?ooo`8000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000`0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool00`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000
103oool2000000<0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000003@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`H00000=03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000M
0?ooo`800000:@3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02L0oooo0P00000E0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0b0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo
0P0000040?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo02L0oooo
00<000000?ooo`3oool07@3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02d0oooo0P00000C0?ooo`007@3oool00`000000oooo0?oo
o`0^0?ooo`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0503oool2000000@0oooo0P0000030?ooo`800000<`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=P3oool200000280oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0d
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`P00000:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool04@3oool001d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`8000008@3oool2000003<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03H0oooo0P00000R0?oo
o`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01d0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3oool001d0oooo00<000000?ooo`3o
ool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0380oooo1`00000507moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0^0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0
=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`L00000:P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo03P0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0140oooo000M0?ooo`800000=@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02d0oooo0P00000Q0?ooo`800000>@3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03H0oooo0P00000R0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P00000_0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3o
ool001d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0180oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0oooo0`0000020?ooo`8000000`3oool20000
03T0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0f0?ooo`8000008P3oool00`00
0000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0
oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
0000;`3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool2000001<0oooo000M0?ooo`800000
=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl7000002l0oooo0P00000E0?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`80
0000>@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03H0oooo0P00000R0?ooo`03
0000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000f
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A
0?ooo`004P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo03@0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02h0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140
oooo000A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00000e0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool2000001<0oooo000C0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`02000003D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool2
000001L0oooo0P0000030?ooo`8000000`3oool2000003T0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0f0?ooo`8000005P3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02h0oooo00<000000?ooo`3oool04@3oool001@0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000A0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03@0oooo00<000000?ooo`3oool07`3oool2000003T0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0f0?ooo`8000005`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000=@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02d0oooo0P00000C0?ooo`004P3oool2000000@0oooo0P000003
0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo03P0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`3oool000000300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000e0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03<0oooo0P00000Q0?ooo`030000003oool0oooo03P0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool04@3oool001d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01l0oooo0P00000i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
=P3oool2000001H0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3o
ool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3o
ool001d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo0P00000Q0?ooo`800000>@3oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03H0oooo0P00000R0?ooo`030000003oool0
oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo02h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0=03oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`00
0000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001d0
oooo00<000000?ooo`3oool0=03oool7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03P0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2
000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo1`00000_0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0>P3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P00000i
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=P3oool200000280oooo00<00000
0?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04`3oool300000080oooo0P0000030?ooo`030000003oool0oooo03@0oooo3@000006
07moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000k0?oo
o`P000001@1oOgl00`000000oooo0?ooo`0c0?ooo`8000005P3oool2000000<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0h0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02h0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000120?ooo`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?oo
o`110?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool2000003T0oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0f0?ooo`8000008P3oool00`000000oooo
0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0A0?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`800000@@3oool00`000000
Ogmo07moO`0407moO`030000003oool0oooo03<0oooo0P00000C0?ooo`007@3oool00`000000oooo
0?ooo`110?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0D0?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool0>03oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`007@3oool200000480oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0c0?ooo`8000008@3oool2000003T0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0f0?ooo`8000008P3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`110?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04`3oool2000000<0
oooo0P0000030?ooo`800000@@3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03<0
oooo0P00000C0?ooo`004`3oool300000080oooo0P0000030?ooo`030000003oool0oooo0440oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0>03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo
000D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@`3oool00`000000
Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07`3oool2000003T0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0f0?ooo`8000005`3oool300000080
oooo0P0000040?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000
Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool00140oooo
1@0000001@3oool000000?ooo`3oool000000080oooo0P0000120?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0<`3oool200000240oooo00<000000?ooo`3oool0>03oool00`000000
Ogmo07moO`0307moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool200000440oooo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0c0?ooo`8000004`3oool00140oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0440oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01l0oooo0P00
000i0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=P3oool2000001D0oooo1@00
00001@3oool000000?ooo`3oool0000000<0oooo0P00000_0?ooo`L000001@1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`<00000103oool2000000<0oooo
00<000000?ooo`3oool0>03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03L0oooo
00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`0407moO`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001<0oooo0P0000030?ooo`8000000`3oool200000480
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`8000005@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool7
000003T0oooo00<000000?ooo`3oool0503oool00`000000oooo000000020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo1`00000f0?ooo`030000003oool0oooo01d0oooo0P0000110?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0<`3oool2000001<0oooo000M0?ooo`030000003oool0
oooo0440oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooog`00000
5`3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`<000000`3o
ool010000000oooo0?ooo`00002P0?ooo`030000003oool0oooo03@0oooo1`00000507moO`030000
003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3o
ool200000480oooo1`00000e0?ooo`8000005P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000:00oooo00<000000?ooo`3oool0>P3oool7000003`0oooo00<000000?ooo`3oool0
7@3oool200000440oooo2000000e0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0D0?ooo`<000000`3oool200000:40oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool04@3o
ool001d0ooooPP00002o0?oooh4000007`3ooon2000001<0oooo003o0?ooool0ooooU@3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo000g0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005P3oool5
00000080oooo0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`800000>@3oool5
00000080oooo0P0000040?ooo`8000004`3oool2000001D0oooo1@0000020?ooo`800000103oool2
000000l0oooo100000030?ooo`800000103oool2000003T0oooo1@0000020?ooo`800000103oool2
000001@0oooo0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool2
000000@0oooo0P00000i0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005P3oool5
00000080oooo0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`8000004`3oool0
03T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000180oooo000i0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?oo
o`00<@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0<03oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000F0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0<03oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0<03oool4000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0403oool003T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000180oooo000h0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3o
ool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000>P3o
ool2000000@0oooo0P0000040?ooo`8000004`3oool2000001H0oooo0P0000040?ooo`800000103o
ool200000100oooo0P0000040?ooo`800000103oool2000003X0oooo0P0000040?ooo`800000103o
ool2000001@0oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000@0?ooo`800000103o
ool2000000@0oooo0P00000j0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3o
ool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`8000004`3o
ool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0oooo
o`3ooonE0?ooo`00603oool2000000<0ooooPP00000J0?ooo`8000000`3ooon0000001X0oooo0P00
00040?oooh4000006P3oool2000000<0ooooPP00000C0?ooo`005`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?oooh8000006@3oool01000
0000oooo0?ooo`0000020?oooh0000006@3oool010000000oooo0?ooo`0000030?oooh800000603o
ool010000000oooo0?ooo`0000020?oooh8000004`3oool001L0oooo00@000000?ooo`3oool00000
0P3oool7000000D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo5000000507moO`030000003oool0oooo01L0oooo00@000000?ooo`3oool0
00000P3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo1`0000050?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo1`00000507mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`h000001@1oOgl00`000000oooo0?ooo`0A
0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0@0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00X0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo
0P0000040?ooo`L000001P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0403oool7000001X0oooo0P0000030?ooo`800000103oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1oOgl7000001X0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000000D0oooo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo
0P0000030?ooo`030000001oOgl0Ogmo00<0Ogmo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl7000000`0oooo1`00000C0?ooo`007@3oool00`000000oooo0?oo
o`090?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool7000000D0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07@3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo1`00000;0?ooo`L000001@3oool00`000000oooo0?ooo`0M
0?ooo`L000001@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000H
0?ooo`030000003oool0oooo0140oooo000M0?ooo`8000002P3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?oo
o`8000007`3oool2000000@0oooo3@00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01`0oooo00<000000?oo
o`3oool04@3oool001d0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`80
00002P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool06`3oool2000001<0oooo000M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl7000000D0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0140oooo000M0?ooo`8000002P3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`8000007`3o
ool200000100oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0140oooo000M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`030?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo01/0oooo00<000000?ooo`3oool07@3oool2000000X0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo01/0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo
01H0oooo00<000000?ooo`3oool07@3oool200000100oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000003oool0oooo
01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000000X0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool05@3oool2000001<0oooo1@0000020?ooo`8000000`3oool00`000000
oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl>000000D0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140
oooo000M0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000A0?oo
o`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl7000001d0oooo00<000000?ooo`3oool07@3oool2000000X0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo01/0oooo0P00000C0?oo
o`004@3oool500000080oooo0P0000030?ooo`030000003oool0oooo00T0oooo3P00000507moO`L0
00001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool00`3oool7000001P0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P00000G0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`L000005P3oool200000200oooo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000603oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000H0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo
1@0000020?ooo`800000103oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00X0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo
00<000000?ooo`3oool04@3oool500000080oooo0P0000030?ooo`030000003oool0oooo00T0oooo
2000000507moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000001h0oooo
00<000000?ooo`3oool04@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo008000005`3oool7000000D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool2000001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001P0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000004P3oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000T0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?ooo`3oool04P3oool20000
00@0oooo0P0000030?ooo`8000005`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000000X0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0200000140oooo1`0000050?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool2000001<0oooo000C0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002`3oool=
000000D0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo
00<000000?ooo`3oool04@3oool00180oooo0P0000040?ooo`8000000`3oool2000002<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08@3oool2000001l0oooo00<000000?ooo`3oool05P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000002@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0280oooo00<000000?oo
o`3oool07@3oool2000001L0oooo3@0000050?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000S0?oo
o`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0E0?oo
o`L00000303oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00000S0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0240oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0R0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo0280oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000S0?ooo`L00000
1@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo0P00000O0?ooo`030000
003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0280oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0X0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo1`00000T0?ooo`030000003oool0oooo01d0oooo0P00000Y0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02P0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3o
ool2000002T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000002<0oooo0P00000C0?ooo`007@3oool0
0`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0A0?ooo`007@3oool2000002T0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0W0?ooo`8000007`3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
02P0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0:03oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool2000002T0
oooo00<0000007moO`1oOgl00`1oOgl7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000Y0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo
0?ooo`0X0?ooo`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo
00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo
00<000000?ooo`3oool07@3oool2000002T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0W0?ooo`8000004`3oool001d0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02L0oooo0P00
000C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02P0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
1`00000Z0?ooo`030000003oool0oooo0140oooo000A0?ooo`@000000`3oool2000000<0oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000:@3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0/0?ooo`800000803oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo
00<000000?ooo`3oool04@3oool00140oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Z0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?oo
o`800000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;@3oool2000001<0oooo000B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000@0oooo00<0
00000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<0
00000?ooo`3oool04@3oool4000000<0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool04@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000300oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`800000
103oool2000000<0oooo0P00000Y0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
0`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`004@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool7000000D0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000;`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3oool00180oooo0P00
00040?ooo`8000000`3oool2000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09`3oool2000001l0oooo00<0
00000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000`0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000`
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo02h0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`800000=@3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0240oooo00<000000?ooo`3oool04@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000@0oooo
00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0240oooo
00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02h0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo
00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0^0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0M0?ooo`800000;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;@3oool2000001<0oooo000M0?ooo`800000;`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W
0?ooo`8000007`3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo02h0oooo1`00000507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo1`00000S0?ooo`03
0000003oool0oooo01d0oooo0P00000_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0]0?ooo`8000004`3oool001d0oooo0P00000e0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0W0?ooo`800000
7`3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`007@3o
ool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`L000001@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0180oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0d0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02h0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`P00000:@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0=03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003D0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool7000002T0oooo0P00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`02000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0/0?ooo`800000
803oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0M0?ooo`800000;`3oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`L00000;`3oool2000001<0oooo000B0?ooo`800000103o
ool2000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000f0?ooo`L0
00001@1oOgl00`000000Ogmo07moO`0307moO`L00000;`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo000A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0>P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000003D0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0<`3oool2000001@0oooo0P0000040?ooo`8000000`3oool2000003/0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`800000=@3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`0c0?ooo`8000004`3oool001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0140oooo000A0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0
oooo00<000000?ooo`3oool07@3oool2000003/0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103o
ool2000000<0oooo0P00000e0?ooo`L000001P1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03<0oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool04`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000e0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000003D0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0<`3oool2000001<0oooo000M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000f0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000>`3o
ool7000000D0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L0
0000<03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04@3oool001d0oooo0P00000k0?ooo`030000001oOgl0Ogmo00@0Ogmo1`00000e0?oo
o`8000007`3oool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo0P0000040?oo
o`8000000`3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`80
0000=@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0c0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0
>P3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
7@3oool200000440oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo0`0000020?ooo`8000000`3o
ool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003/0oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0i0?ooo`8000005P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000480oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0=03oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P00000e0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo03<0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`D0000000D0
oooo0000003oool0oooo000000020?ooo`800000@@3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo0380oooo0P00000P0?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`0307moO`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0j0?ooo`L0
00001@1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0=03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000
>`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03T0oooo0P00000D0?ooo`030000
003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`100?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0400oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03<0oooo0P00000C0?ooo`00
4`3oool300000080oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`800000
0`3oool200000440oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0@03oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000l0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0@03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool04@3oool00140oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00000k0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>@3oool2000001l0oooo00<000000?ooo`3o
ool0@03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0A0?ooo`004@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407mo
O`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool200000440oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0@03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool2000003D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<`3oool2000001<0oooo000B0?ooo`03
0000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0j0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0400oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo01<0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`100?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?oo
o`<000000P3oool2000000<0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo000C0?ooo`8000000`3oool2000000<0oooo0P00000k0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>@3oool2000001l0oooo00<000000?ooo`3o
ool0@03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000@P3oool0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003H0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`800000@@3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3o
ool5000000050?ooo`000000oooo0?ooo`0000000`3oool200000440oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo1@0000001@3oool00000
0?ooo`3oool000000080oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03<0oooo0P00000C0?ooo`00
7@3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0400oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003/0oooo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0i0?ooo`8000007`3oool00`000000oooo0?ooo`10
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0oooo00<0
00000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool07@3oool200000440oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`800000103oool00`000000oooo0?oo
o`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0C0?ooo`8000000`3oool2000000<0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03<0oooo0P00
000C0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<00000
0?ooo`3oool0@03oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003/0oooo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0i0?ooo`8000004`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0@03oool00`000000Ogmo07mo
O`0307moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`100?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03@0oooo00<0000007moO`1oOgl00`1oOgl7000000H0Ogmo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0j
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0D
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P0000110?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0<P3oool200000200oooo00<000000?ooo`3oool0@03o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001d0oooo00<000000?ooo`3oool0>P3oool00`000000Ogmo07moO`0407moO`030000003oool0
oooo03X0oooo00<000000?ooo`3oool04P3oool2000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`100?ooo`L00000=@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0400oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo01d0oooo0P00000e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool8000003D0oooo0P00000C0?ooo`007@3oool2000003/0oooo2000000k0?ooo`800000503oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0@03o
ool7000003H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`L00000@`3o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo0180oooo0`0000030?ooo`8000000`3ooon000000200oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool04@3oool0
01d0ooooPP00002o0?oooh4000007`3ooon2000001<0oooo003o0?ooool0ooooU@3oool00?l0oooo
o`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?oo
o`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
0000\
\>"],
  ImageRangeCache->{{{26.375, 552.75}, {447.875, 39.5625}} -> {-0.311763, \
0.238223, 0.00638692, 0.00638692}, {{39, 155.563}, {438.125, 366.125}} -> \
{-411.033, 16.9874, 3.31765, 0.684426}, {{167.188, 283.688}, {438.125, \
366.125}} -> {-979.135, 17.0457, 3.44695, 0.683217}, {{295.375, 411.875}, \
{438.125, 366.125}} -> {-1452.73, 15.3961, 3.26945, 0.621583}, {{423.5, \
540.063}, {438.125, 366.125}} -> {-1976.48, 18.6718, 3.26945, 0.753835}, \
{{39, 155.563}, {358.938, 286.875}} -> {-404.712, -44.1274, 3.2663, 0.59456}, \
{{167.188, 283.688}, {358.938, 286.875}} -> {-927.958, -44.1274, 3.2663, \
0.59456}, {{295.375, 411.875}, {358.938, 286.875}} -> {-1451.33, -37.2631, \
3.2663, 0.502072}, {{423.5, 540.063}, {358.938, 286.875}} -> {-2003.54, \
-50.7107, 3.31427, 0.683728}, {{39, 155.563}, {279.688, 207.688}} -> {-405.1, \
-98.5399, 3.26945, 0.568682}, {{167.188, 283.688}, {279.688, 207.688}} -> \
{-928.85, -130.623, 3.26945, 0.753835}, {{295.375, 411.875}, {279.688, \
207.688}} -> {-1452.73, -109.998, 3.26945, 0.634808}, {{423.5, 540.063}, \
{279.688, 207.688}} -> {-1976.48, -103.123, 3.26945, 0.595133}, {{39, \
155.563}, {200.5, 128.5}} -> {-405.1, -158.431, 3.26945, 0.581907}, \
{{167.188, 283.688}, {200.5, 128.5}} -> {-975.977, -223.113, 3.4358, \
0.819987}, {{295.375, 411.875}, {200.5, 128.5}} -> {-1452.73, -154.83, \
3.26945, 0.568682}, {{423.5, 540.063}, {200.5, 128.5}} -> {-1976.48, \
-172.834, 3.26945, 0.634808}, {{39, 155.563}, {121.25, 49.25}} -> {-405.1, \
-235.72, 3.26945, 0.634808}, {{167.188, 283.688}, {121.25, 49.25}} -> \
{-942.505, -254.109, 3.31765, 0.684426}, {{295.375, 411.875}, {121.25, \
49.25}} -> {-1452.73, -220.988, 3.26945, 0.595133}, {{423.5, 540.063}, \
{121.25, 49.25}} -> {-1976.48, -220.988, 3.26945, 0.595133}}]
}, Open  ]],

Cell["\<\
Now display separate histograms for individual metrical position in the \
meter, doing one beat at a time.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plots1\  = \ 
        Map[Histogram[#[\([1]\)], \ Frame \[Rule] True, \ 
              HistogramRange \[Rule] {\(-200\), \ 200}, \ 
              HistogramCategories \[Rule] 20, \ 
              DisplayFunction \[Rule] Identity, \ 
              BarStyle \[Rule] {RGBColor[1, 0, 0]}] &, \ 
          rbeats];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[plots1, \ 4]], \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0184794 0.238095 [
[ 0 0 0 0 ]
[ 1 .77614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .77614 L
0 .77614 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0184794 0.245293 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .08829 L
.19048 .08829 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08829 L
.19048 .08829 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .01472 L
.2381 .01472 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .30902 L
.33333 .30902 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .30902 L
.33333 .30902 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .41938 L
.42857 .41938 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .41938 L
.42857 .41938 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .41938 L
.47619 .41938 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .41938 L
.47619 .41938 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .52974 L
.66667 .52974 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .52974 L
.66667 .52974 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .16187 L
.71429 .16187 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .16187 L
.71429 .16187 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .08829 L
.85714 .08829 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .08829 L
.85714 .08829 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0184794 0.488926 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04274 L
.04762 .04274 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04274 L
.04762 .04274 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04274 L
.14286 .04274 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04274 L
.14286 .04274 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .12683 L
.19048 .12683 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12683 L
.19048 .12683 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .07077 L
.2381 .07077 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07077 L
.2381 .07077 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .04274 L
.28571 .04274 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .04274 L
.28571 .04274 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .07077 L
.33333 .07077 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .07077 L
.33333 .07077 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .295 L
.38095 .295 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .295 L
.38095 .295 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .18289 L
.47619 .18289 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .18289 L
.47619 .18289 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .295 L
.52381 .295 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .295 L
.52381 .295 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .21092 L
.7619 .21092 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .21092 L
.7619 .21092 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0184794 0.732558 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .08012 L
.09524 .08012 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08012 L
.09524 .08012 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17822 L
.33333 .17822 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17822 L
.33333 .17822 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .27632 L
.42857 .27632 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .27632 L
.42857 .27632 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .34172 L
.52381 .34172 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .34172 L
.52381 .34172 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .17822 L
.71429 .17822 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17822 L
.71429 .17822 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .17822 L
.7619 .17822 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .17822 L
.7619 .17822 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .11282 L
.80952 .11282 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .11282 L
.80952 .11282 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .11282 L
.85714 .11282 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .11282 L
.85714 .11282 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0184794 0.97619 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .08012 L
.09524 .08012 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08012 L
.09524 .08012 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .08012 L
.33333 .08012 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .08012 L
.33333 .08012 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .27632 L
.38095 .27632 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27632 L
.38095 .27632 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .53792 L
.52381 .53792 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .53792 L
.52381 .53792 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .14552 L
.66667 .14552 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .14552 L
.66667 .14552 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08012 L
.7619 .08012 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .08012 L
.85714 .08012 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .08012 L
.85714 .08012 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.169052 0.245293 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .21092 L
.2381 .21092 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .21092 L
.2381 .21092 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .0932 L
.38095 .0932 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .0932 L
.38095 .0932 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .44636 L
.42857 .44636 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .44636 L
.42857 .44636 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .56408 L
.47619 .56408 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .56408 L
.47619 .56408 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .52484 L
.57143 .52484 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .52484 L
.57143 .52484 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .40712 L
.66667 .40712 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .40712 L
.66667 .40712 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .21092 L
.71429 .21092 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .21092 L
.7619 .21092 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .21092 L
.7619 .21092 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .05396 L
1 .05396 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .05396 L
1 .05396 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.169052 0.488926 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .25016 L
.38095 .25016 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .25016 L
.38095 .25016 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .40712 L
.42857 .40712 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .40712 L
.42857 .40712 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .44636 L
.47619 .44636 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .44636 L
.47619 .44636 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .44636 L
.61905 .44636 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .44636 L
.61905 .44636 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .2894 L
.71429 .2894 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .2894 L
.71429 .2894 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .17168 L
.80952 .17168 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .17168 L
.80952 .17168 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.169052 0.732558 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .4856 L
.38095 .4856 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .4856 L
.38095 .4856 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .17168 L
.47619 .17168 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .17168 L
.47619 .17168 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .56408 L
.57143 .56408 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .56408 L
.57143 .56408 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .52484 L
.61905 .52484 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .52484 L
.61905 .52484 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .17168 L
.7619 .17168 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .17168 L
.7619 .17168 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .17168 L
.80952 .17168 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .17168 L
.80952 .17168 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .13244 L
.85714 .13244 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .13244 L
.85714 .13244 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05396 L
.95238 .05396 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.169052 0.97619 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04934 L
.14286 .04934 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04934 L
.14286 .04934 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04934 L
.19048 .04934 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04934 L
.19048 .04934 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .29171 L
.38095 .29171 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .29171 L
.38095 .29171 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .39558 L
.42857 .39558 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .39558 L
.42857 .39558 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .29171 L
.47619 .29171 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .29171 L
.47619 .29171 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .36095 L
.61905 .36095 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .36095 L
.61905 .36095 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .25708 L
.66667 .25708 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25708 L
.66667 .25708 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .18783 L
.71429 .18783 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .18783 L
.71429 .18783 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .11859 L
.7619 .11859 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .11859 L
.7619 .11859 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08396 L
.80952 .08396 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08396 L
.80952 .08396 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04934 L
.90476 .04934 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04934 L
.90476 .04934 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.319626 0.245293 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .05396 L
.19048 .05396 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .05396 L
.19048 .05396 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .2894 L
.28571 .2894 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .2894 L
.28571 .2894 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .44636 L
.42857 .44636 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .44636 L
.42857 .44636 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .36788 L
.47619 .36788 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .36788 L
.47619 .36788 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .40712 L
.52381 .40712 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .40712 L
.52381 .40712 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .32864 L
.57143 .32864 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .32864 L
.57143 .32864 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .4856 L
.66667 .4856 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .4856 L
.66667 .4856 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .2894 L
.71429 .2894 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .2894 L
.71429 .2894 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .05396 L
.7619 .05396 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05396 L
.7619 .05396 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .17168 L
.85714 .17168 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .17168 L
.85714 .17168 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.319626 0.488926 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .07077 L
.2381 .07077 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07077 L
.2381 .07077 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .12683 L
.28571 .12683 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12683 L
.28571 .12683 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .12683 L
.38095 .12683 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12683 L
.38095 .12683 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .18289 L
.42857 .18289 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .18289 L
.42857 .18289 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .295 L
.47619 .295 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .295 L
.47619 .295 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .4912 L
.57143 .4912 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .4912 L
.57143 .4912 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .26697 L
.61905 .26697 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .26697 L
.61905 .26697 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .18289 L
.66667 .18289 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .18289 L
.66667 .18289 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .15486 L
.71429 .15486 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .15486 L
.71429 .15486 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .07077 L
.95238 .07077 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .07077 L
.95238 .07077 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .07077 L
1 .07077 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .07077 L
1 .07077 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.319626 0.732558 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04742 L
.19048 .04742 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04742 L
.19048 .04742 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .11282 L
.2381 .11282 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .11282 L
.2381 .11282 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17822 L
.28571 .17822 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17822 L
.33333 .17822 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17822 L
.33333 .17822 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .27632 L
.38095 .27632 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27632 L
.38095 .27632 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .21092 L
.42857 .21092 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .21092 L
.42857 .21092 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .50522 L
.47619 .50522 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .50522 L
.47619 .50522 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .37442 L
.61905 .37442 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .17822 L
.66667 .17822 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .17822 L
.66667 .17822 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .17822 L
.71429 .17822 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17822 L
.71429 .17822 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .11282 L
.7619 .11282 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .11282 L
.7619 .11282 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .11282 L
.85714 .11282 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .11282 L
.85714 .11282 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .04742 L
1 .04742 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04742 L
1 .04742 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.319626 0.97619 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .12508 L
.2381 .12508 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12508 L
.2381 .12508 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .38259 L
.42857 .38259 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .38259 L
.42857 .38259 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .38259 L
.66667 .38259 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .38259 L
.66667 .38259 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .23544 L
.7619 .23544 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .23544 L
.7619 .23544 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0515 L
.85714 .0515 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0515 L
.85714 .0515 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.470199 0.245293 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0452772 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10527 -6 -4.5 ]
[-0.0125 .10527 0 4.5 ]
[-0.0125 .19582 -6 -4.5 ]
[-0.0125 .19582 0 4.5 ]
[-0.0125 .28638 -6 -4.5 ]
[-0.0125 .28638 0 4.5 ]
[-0.0125 .37693 -6 -4.5 ]
[-0.0125 .37693 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .55804 -12 -4.5 ]
[-0.0125 .55804 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10527 m
.00625 .10527 L
s
[(2)] -0.0125 .10527 1 0 Mshowa
0 .19582 m
.00625 .19582 L
s
[(4)] -0.0125 .19582 1 0 Mshowa
0 .28638 m
.00625 .28638 L
s
[(6)] -0.0125 .28638 1 0 Mshowa
0 .37693 m
.00625 .37693 L
s
[(8)] -0.0125 .37693 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(10)] -0.0125 .46749 1 0 Mshowa
0 .55804 m
.00625 .55804 L
s
[(12)] -0.0125 .55804 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .12791 m
.00375 .12791 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .21846 m
.00375 .21846 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .58068 m
.00375 .58068 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10527 m
1 .10527 L
s
.99375 .19582 m
1 .19582 L
s
.99375 .28638 m
1 .28638 L
s
.99375 .37693 m
1 .37693 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .55804 m
1 .55804 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .58068 m
1 .58068 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .10527 L
.09524 .10527 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .10527 L
.09524 .10527 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .2411 L
.19048 .2411 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .2411 L
.19048 .2411 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .05999 L
.2381 .05999 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .05999 L
.2381 .05999 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .19582 L
.28571 .19582 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .19582 L
.28571 .19582 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .19582 L
.33333 .19582 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19582 L
.33333 .19582 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .33166 L
.38095 .33166 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .33166 L
.38095 .33166 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .42221 L
.42857 .42221 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .42221 L
.42857 .42221 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .42221 L
.47619 .42221 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .42221 L
.47619 .42221 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .55804 L
.52381 .55804 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .55804 L
.52381 .55804 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .46749 L
.61905 .46749 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .46749 L
.61905 .46749 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .51276 L
.66667 .51276 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .51276 L
.66667 .51276 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .2411 L
.71429 .2411 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .2411 L
.71429 .2411 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .10527 L
.7619 .10527 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .10527 L
.7619 .10527 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .2411 L
.80952 .2411 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .2411 L
.80952 .2411 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .10527 L
.85714 .10527 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .10527 L
.85714 .10527 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .05999 L
.95238 .05999 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05999 L
.95238 .05999 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.470199 0.488926 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04742 L
.04762 .04742 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .08012 L
.14286 .08012 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08012 L
.14286 .08012 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08012 L
.19048 .08012 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .04742 L
.2381 .04742 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .04742 L
.2381 .04742 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .11282 L
.28571 .11282 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .11282 L
.28571 .11282 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .27632 L
.33333 .27632 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .27632 L
.33333 .27632 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17822 L
.38095 .17822 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .37442 L
.47619 .37442 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .37442 L
.47619 .37442 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .21092 L
.66667 .21092 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .24362 L
.71429 .24362 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .24362 L
.71429 .24362 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .17822 L
.7619 .17822 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .17822 L
.7619 .17822 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08012 L
.80952 .08012 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .08012 L
.90476 .08012 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .08012 L
.90476 .08012 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.470199 0.732558 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0932 L
.09524 .0932 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0932 L
.19048 .0932 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05396 L
.28571 .05396 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .25016 L
.33333 .25016 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .25016 L
.33333 .25016 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .52484 L
.47619 .52484 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .52484 L
.47619 .52484 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .32864 L
.61905 .32864 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .32864 L
.61905 .32864 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .2894 L
.7619 .2894 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .2894 L
.7619 .2894 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .13244 L
.85714 .13244 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .13244 L
.85714 .13244 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.470199 0.97619 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0255915 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14267 -6 -4.5 ]
[-0.0125 .14267 0 4.5 ]
[-0.0125 .27063 -12 -4.5 ]
[-0.0125 .27063 0 4.5 ]
[-0.0125 .39859 -12 -4.5 ]
[-0.0125 .39859 0 4.5 ]
[-0.0125 .52654 -12 -4.5 ]
[-0.0125 .52654 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14267 m
.00625 .14267 L
s
[(5)] -0.0125 .14267 1 0 Mshowa
0 .27063 m
.00625 .27063 L
s
[(10)] -0.0125 .27063 1 0 Mshowa
0 .39859 m
.00625 .39859 L
s
[(15)] -0.0125 .39859 1 0 Mshowa
0 .52654 m
.00625 .52654 L
s
[(20)] -0.0125 .52654 1 0 Mshowa
.125 Mabswid
0 .04031 m
.00375 .04031 L
s
0 .0659 m
.00375 .0659 L
s
0 .09149 m
.00375 .09149 L
s
0 .11708 m
.00375 .11708 L
s
0 .16826 m
.00375 .16826 L
s
0 .19386 m
.00375 .19386 L
s
0 .21945 m
.00375 .21945 L
s
0 .24504 m
.00375 .24504 L
s
0 .29622 m
.00375 .29622 L
s
0 .32181 m
.00375 .32181 L
s
0 .3474 m
.00375 .3474 L
s
0 .373 m
.00375 .373 L
s
0 .42418 m
.00375 .42418 L
s
0 .44977 m
.00375 .44977 L
s
0 .47536 m
.00375 .47536 L
s
0 .50095 m
.00375 .50095 L
s
0 .55214 m
.00375 .55214 L
s
0 .57773 m
.00375 .57773 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14267 m
1 .14267 L
s
.99375 .27063 m
1 .27063 L
s
.99375 .39859 m
1 .39859 L
s
.99375 .52654 m
1 .52654 L
s
.125 Mabswid
.99625 .04031 m
1 .04031 L
s
.99625 .0659 m
1 .0659 L
s
.99625 .09149 m
1 .09149 L
s
.99625 .11708 m
1 .11708 L
s
.99625 .16826 m
1 .16826 L
s
.99625 .19386 m
1 .19386 L
s
.99625 .21945 m
1 .21945 L
s
.99625 .24504 m
1 .24504 L
s
.99625 .29622 m
1 .29622 L
s
.99625 .32181 m
1 .32181 L
s
.99625 .3474 m
1 .3474 L
s
.99625 .373 m
1 .373 L
s
.99625 .42418 m
1 .42418 L
s
.99625 .44977 m
1 .44977 L
s
.99625 .47536 m
1 .47536 L
s
.99625 .50095 m
1 .50095 L
s
.99625 .55214 m
1 .55214 L
s
.99625 .57773 m
1 .57773 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .0659 L
.14286 .0659 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0659 L
.14286 .0659 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04031 L
.19048 .04031 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04031 L
.19048 .04031 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .0659 L
.2381 .0659 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0659 L
.2381 .0659 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .11708 L
.28571 .11708 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .11708 L
.28571 .11708 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19386 L
.38095 .19386 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .24504 L
.42857 .24504 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .24504 L
.42857 .24504 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .373 L
.47619 .373 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .373 L
.47619 .373 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .24504 L
.52381 .24504 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .24504 L
.52381 .24504 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .21945 L
.61905 .21945 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .21945 L
.61905 .21945 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .09149 L
.66667 .09149 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .09149 L
.66667 .09149 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .16826 L
.71429 .16826 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .16826 L
.71429 .16826 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .14267 L
.7619 .14267 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14267 L
.7619 .14267 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .14267 L
.80952 .14267 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .14267 L
.80952 .14267 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04031 L
.85714 .04031 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04031 L
.85714 .04031 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04031 L
.95238 .04031 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04031 L
.95238 .04031 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.620772 0.245293 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0490503 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -6 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(2)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(4)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(6)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(8)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(10)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(12)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .13734 m
.00375 .13734 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .23544 m
.00375 .23544 L
s
0 .25997 m
.00375 .25997 L
s
0 .28449 m
.00375 .28449 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .38259 m
.00375 .38259 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03924 m
1 .03924 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .13734 m
1 .13734 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18639 m
1 .18639 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25997 m
1 .25997 L
s
.99625 .28449 m
1 .28449 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .38259 m
1 .38259 L
s
.99625 .43164 m
1 .43164 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .48069 m
1 .48069 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57879 m
1 .57879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .06377 L
.04762 .06377 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .06377 L
.04762 .06377 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11282 L
.14286 .11282 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .25997 L
.19048 .25997 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .25997 L
.19048 .25997 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .21092 L
.2381 .21092 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .21092 L
.2381 .21092 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .25997 L
.28571 .25997 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .25997 L
.28571 .25997 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .21092 L
.33333 .21092 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .35807 L
.42857 .35807 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .35807 L
.42857 .35807 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .50522 L
.47619 .50522 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .50522 L
.47619 .50522 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .55427 L
.52381 .55427 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .55427 L
.52381 .55427 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .50522 L
.61905 .50522 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .50522 L
.61905 .50522 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .50522 L
.66667 .50522 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .50522 L
.66667 .50522 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .35807 L
.71429 .35807 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .35807 L
.71429 .35807 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .25997 L
.7619 .25997 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .25997 L
.7619 .25997 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .21092 L
.80952 .21092 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .21092 L
.80952 .21092 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .06377 L
.90476 .06377 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .06377 L
.90476 .06377 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .11282 L
1 .11282 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .11282 L
1 .11282 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.620772 0.488926 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04274 L
.09524 .04274 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04274 L
.09524 .04274 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .0988 L
.19048 .0988 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0988 L
.19048 .0988 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .15486 L
.2381 .15486 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15486 L
.2381 .15486 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .18289 L
.28571 .18289 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .18289 L
.28571 .18289 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .15486 L
.33333 .15486 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .15486 L
.33333 .15486 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .18289 L
.38095 .18289 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .18289 L
.38095 .18289 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .0988 L
.42857 .0988 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .0988 L
.42857 .0988 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .23895 L
.47619 .23895 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .23895 L
.47619 .23895 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .26697 L
.52381 .26697 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .26697 L
.52381 .26697 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .32303 L
.61905 .32303 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .32303 L
.61905 .32303 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .26697 L
.66667 .26697 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .26697 L
.66667 .26697 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .18289 L
.71429 .18289 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .18289 L
.71429 .18289 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .15486 L
.7619 .15486 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .15486 L
.7619 .15486 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .07077 L
.80952 .07077 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07077 L
.80952 .07077 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .07077 L
.95238 .07077 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .07077 L
.95238 .07077 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.620772 0.732558 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04934 L
.09524 .04934 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .22246 L
.14286 .22246 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .22246 L
.14286 .22246 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .08396 L
.19048 .08396 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08396 L
.19048 .08396 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .15321 L
.28571 .15321 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .15321 L
.28571 .15321 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .04934 L
.33333 .04934 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04934 L
.33333 .04934 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .18783 L
.38095 .18783 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .18783 L
.38095 .18783 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .18783 L
.42857 .18783 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .18783 L
.42857 .18783 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .39558 L
.47619 .39558 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .39558 L
.47619 .39558 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .36095 L
.52381 .36095 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .36095 L
.52381 .36095 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .39558 L
.61905 .39558 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .39558 L
.61905 .39558 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .25708 L
.66667 .25708 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .25708 L
.66667 .25708 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .32633 L
.71429 .32633 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .32633 L
.71429 .32633 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .18783 L
.7619 .18783 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .18783 L
.7619 .18783 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04934 L
.85714 .04934 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .04934 L
.90476 .04934 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04934 L
.90476 .04934 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.620772 0.97619 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0327002 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -18 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -6 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -18 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -24 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -24 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(2.5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(5)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(7.5)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(10)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(12.5)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(15)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(17.5)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .08012 L
.04762 .08012 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .08012 L
.04762 .08012 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04742 L
.09524 .04742 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04742 L
.14286 .04742 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .04742 L
.19048 .04742 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04742 L
.19048 .04742 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .08012 L
.2381 .08012 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .14552 L
.28571 .14552 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .27632 L
.33333 .27632 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .27632 L
.33333 .27632 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .14552 L
.38095 .14552 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .14552 L
.38095 .14552 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .34172 L
.42857 .34172 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .24362 L
.47619 .24362 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .24362 L
.47619 .24362 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .40712 L
.52381 .40712 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .40712 L
.52381 .40712 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .34172 L
.61905 .34172 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .34172 L
.61905 .34172 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .24362 L
.66667 .24362 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .24362 L
.71429 .24362 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .24362 L
.71429 .24362 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14552 L
.7619 .14552 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .04742 L
.80952 .04742 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04742 L
.80952 .04742 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .08012 L
.85714 .08012 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .08012 L
.85714 .08012 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04742 L
.95238 .04742 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .04742 L
1 .04742 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04742 L
1 .04742 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.875, 512.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C000202000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003G0?ooo`D000000P3oool2000000@0oooo
0P00000D0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3oool4000000<0oooo
0P0000040?ooo`800000o`3ooomE0?ooo`00f@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000o`3ooomD0?ooo`00f@3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000o`3ooomD0?ooo`00d@3oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00@03oool50000
0080oooo0P0000040?ooo`800000403oool2000001<0oooo1@0000020?ooo`800000103oool20000
00d0oooo100000030?ooo`800000103oool2000003X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000440oooo1@0000020?ooo`800000103oool200000100oooo
0P00000C0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2000000@0oooo
0P0000110?ooo`D000000P3oool2000000@0oooo0P00000A0?ooo`8000004`3oool500000080oooo
0P0000040?ooo`8000003@3oool4000000<0oooo0P0000040?ooo`8000004P3oool00480oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003P0oooo0P0000040?ooo`80
0000103oool2000001@0oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000@0?ooo`80
0000103oool2000000@0oooo0P0000140?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000A0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000h`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004@3oool003X0oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0=T0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo03P0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00l0oooo00120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00003S0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000A
0?ooo`00@@3oool2000000@0oooo0P0000040?ooo`800000403oool2000001@0oooo0P0000040?oo
o`800000103oool2000000h0oooo0P0000040?ooo`800000103oool200000><0oooo0P0000040?oo
o`800000103oool200000100oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>0?oo
o`800000103oool2000000@0oooo0P0000120?ooo`800000103oool2000000@0oooo0P00000A0?oo
o`800000503oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo0P0000040?oo
o`8000004P3oool00;P0oooo0P0000040?oooh400000o`3ooomE0?ooo`00]`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooD`3oool00;L0oooo00@000000?ooo`3oool0
00000`3ooon200000?l0ooooE03oool002<0oooo0P00002B0?ooo`040000003oool0oooo000000<0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`800000103ooomf000002D0
oooo0P0000030?ooogH000004`3oool00280oooo00@000000?ooo`3oool000000`3ooomf000001P0
oooo00@000000?ooo`3oool000000`3oool00`000000o`000?l000030?l000030000003oool0oooo
00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00280oooo00@000000?ooo`3oool000000`3o
oomf000001T0oooo0P0000040?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3o
ool010000000oooo0?ooo`0000030?ooogH00000903oool010000000oooo0?ooo`0000020?ooogH0
00004`3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`080?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?ooo`L0
00001@3oool7000000D0o`0000<000000?l0003o00000`3o0007000000H0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`003@00000A0?ooo`03
0000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3oool00`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool0203oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A
0?ooo`008P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01/0oooo00<00000
0?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00d0oooo0P00
000T0?ooo`040000003oool0oooo00000080oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo00P0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool002<0oooo0P00
00040?ooo`030000003oool0oooo00P0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0=0?ooo`8000007`3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0S0?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02<0oooo0P0000030?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo00P0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l00003
0?l000L000001@3oool8000000D0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`02
0?ooo`030000003o0000o`0000<0o`001P0000050?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0=0?ooo`800000:P3oool7000000@0o`0000<00000
0?ooo`3oool0203oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`080?oo
o`H000001@3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool03@3oool2000001l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l0
00030000003oool0oooo0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`020?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003oool0oooo00h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?oo
o`030000003o0000o`000080o`0000<000000?ooo`3oool0203oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?oo
o`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00h0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0403oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool00P3oool00`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool03@3oool2000002X0oooo0P0000040?ooo`030000003o0000o`000080o`0000<000000?ooo`3o
ool0203oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo00d0oooo0P00000O0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
0`3oool00`000000o`000?l000020?l000030000003oool0oooo00P0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4@3oool002T0oooo00<000000?ooo`3oool03@3oool00`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o
ool0oooo0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o0007000000D0o`0000<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo1`0000040?ooo`d00000103o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0=0?ooo`800000603o
ool4000000<0oooo0P0000040?ooo`8000000`3oool2000000@0oooo1P00000:0?ooo`L000001@3o
0006000000D0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o000A00000100oooo00<000000?ooo`3oool04@3o
ool001H0oooo100000030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool03@3oool7
000000D0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo``000003`3oool2
000001l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003oool0
oooo0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`030?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0I0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`005P3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
6@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
403oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0=0?ooo`8000006@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
00006P3oool00`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo01d0oooo0P00000C0?ooo`00
5`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003oool0oooo01h0oooo0P00000O0?ooo`030000003oool0oooo00l0
oooo1`00000B0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000030?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o000<000000l0oooo0P00000J0?ooo`030000003oool0oooo00P0
oooo0P0000030?ooo`8000006P3oool00`000000o`000?l000030?l000030000003oool0oooo0080
oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo01h0
oooo00<000000?ooo`3oool04@3oool001P0oooo00<000000?ooo`3oool0203oool2000000@0oooo
00<000000?ooo`3oool06@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01l0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01/0oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`005P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool60000
00D0o`001P0000050?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003oool0oooo01h0oooo0P00000I0?ooo`800000103oool00`00
0000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool00`3oool00`00
0000o`000?l000030?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool20000
00X0oooo0`0000030?ooo`030000003oool0oooo01T0oooo00<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003oool0oooo01P0oooo0P00000I0?ooo`8000002P3oool30000
0080oooo0P00000J0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0A0?ooo`005`3oool2000000X0oooo0`0000030?ooo`030000003oool0oooo01h0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo
00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01T0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0140oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool07P3oool2000001/0
oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01/0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0H0?ooo`800000:P3oool2000001X0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000H000001@3o00000`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000030?l00003
0000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l00003
0000003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0
7P3oool00`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0
8`3oool2000000@0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0603oool2000002D0oooo0P0000030?ooo`800000
6P3oool00`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4@3oool002T0oooo00<000000?ooo`3oool07P3oool00`000000o`000?l000030?l000030000003o
ool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`001P00000P0?ooo`8000006@3oool3000000<0oooo00<000000?ooo`3oool0:03o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0N0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`001`0000050?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02D0oooo00D000000?ooo`3oool0
oooo0000000K0?ooo``00000103o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o000<000001X0oooo0P00000W0?ooo`030000003oool0oooo0080
00006P3oool7000000@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l00003
0000003oool0oooo01d0oooo0P00000C0?ooo`008`3oool2000000@0oooo00<000000?ooo`3oool0
7P3oool00`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
8`3oool2000001l0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo02@0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0P0000030?ooo`030000
003oool0oooo02@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000
003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool00280oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0N0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0T0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
8`3oool2000002D0oooo00<000000?ooo`3oool00P3oool2000002D0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4@3oool002D0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`8000007`3oool00`000000oooo
0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000P000001@3oool7000001d0oooo00<000000?ooo`3oool08`3oool3000000<0oooo
00<000000?ooo`3oool0903oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool300000080oooo00<000000?ooo`3oool0903oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool2000000@0oooo00<000000?ooo`3oool07P3oool00`000000o`000?l0
00030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02@0oooo1P0000050?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`800000:P3oool2000002D0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00P3oool700000200oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`8000007`3oool00`000000oooo0?ooo`0X
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0T
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool002<0oooo0`0000030?oo
o`030000003oool0oooo01h0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`020?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02<0oooo0P00000Z0?ooo`8000009@3oool00`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo0P00000O0?ooo`03
0000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`00
:@3oool00`000000oooo0?ooo`0N0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000L000009@3oool2000001X0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000030?ooo`8000009@3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo0P00000O0?ooo`030000003o
ool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`00
:@3oool00`000000oooo0?ooo`0N0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003oool0oooo02T0oooo0P00000J0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P00000U0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02P0oooo0P00000C0?ooo`00
:@3oool00`000000oooo0?ooo`0N0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1`3oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo02@0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo0?ooo`020?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool07P3oool00`000000o`000?l000030?l000030000003o
ool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool08`3oool200000180oooo1@0000020?ooo`800000103o
ool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool05P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:@3oool7000000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool2000001P0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`020?ooo`8000009@3oool7000000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000:P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01H0oooo10000009
0?ooo`<000000`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0:@3oool2000001P0oooo100000090?ooo`<000000P3oool2000002/0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<00000
0?ooo`3oool04@3oool001P0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0
00000200oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0
oooo02<0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000002X0oooo1`0000050?l000030000003oool0oooo00<0oooo1`0000050?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`006@3o
ool00`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`0N0?ooo`030000003o
0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000<03oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000L00000:`3oool2000002X0oooo0P00000[0?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0140oooo000F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0N0?ooo`L00000103oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`80
0000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000`
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02X0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001H0oooo100000090?oo
o`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02h0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01`0oooo1@0000020?oo
o`800000103oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000N0?oo
o`D000000P3oool2000000<0oooo0P00000[0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool08`3oool2000001l0oooo00<000000?ooo`3o
ool0;P3oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000;03oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`00:@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000340oooo00<000000?l0003o00000P3o0007000000@0o`0000<000000?ooo`3o
ool0;`3oool200000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00800000:`3oool6000000D0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool2000001<0oooo000Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool08`3oool2000001l0oooo00<000000?ooo`3o
ool0;P3oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00002
0?l000030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000<@3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3o
ool7000000/0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02h0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`030000003o0000o`000080o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000P0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000300oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000L0?ooo`D0
00000P3oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`80
00007`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003oool0oooo0300oooo00<000000?ooo`3o
ool07@3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000N0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000Z0?oo
o`800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o0007000002/0oooo00<000000?ooo`3oool04@3oool001h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0S
0?ooo`8000007`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000N0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00
000Z0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000N
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo0300oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo
00<000000?ooo`3oool04@3oool001d0oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`0Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003oool0oooo02<0oooo0P00000O0?ooo`030000003oool0oooo0400oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0403oool5000000030?ooo`0000000000008000000`3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo02l0oooo1P0000050?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool0;`3oool200000180oooo1@0000000`3oool0000000000002000000<0oooo0P00
00040?ooo`8000000`3oool200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000L00000<@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`10
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000
003oool0oooo0300oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0140oooo000Y0?ooo`030000003oool0oooo02T0oooo300000050?l000030000003o0000o`0000<0
o`001P0000050?l000030000003oool0oooo02<0oooo0P00000O0?ooo`030000003oool0oooo0400
oooo00<000000?l0003o00000`3o000700000300oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000l0?oo
o`030000003o0000o`000080o`0000<000000?ooo`3oool0;`3oool2000001@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000<03oool00`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0=03oool20000
01<0oooo000Y0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`800000103oool00`000000
oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0
oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003oool0oooo0300
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool002T0oooo
00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003oool0oooo02<0oooo
0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0480oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`000080o`0000<00000
0?ooo`3oool0;`3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool200000300oooo00<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3o
ool002T0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003oool0
oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000@P3oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04@3oool2000000@0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?oo
o`0j0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0A0?ooo`800000103oool2000000X0oooo0`0000020?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo03D0oooo00<0
00000?ooo`3oool04@3oool00100oooo1@0000000`3oool0000000000002000000<0oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool08`3oool2000001@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<00000
0?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`000080o`0000<00000
0?ooo`3oool0;`3oool2000002X0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo000B0?oo
o`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo0080oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003o
ool0oooo0300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
1@000000oooo0?ooo`3oool0000003H0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0S0?ooo`8000004`3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo0400oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00
000Z0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0080oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0703oool500000080oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0_0?ooo`8000007P3oool500000080oooo0P000003
0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03@0oooo00<000000?l0003o00000`3o0007000000@0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0S0?ooo`8000007`3oool00`000000oooo0?ooo`100?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<000000?l0003o0000
0P3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000340oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00140
oooo0P0000040?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3oool0=03oool00`000000
o`000?l000030?l000030000003oool0oooo00P0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000
o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000o`000?l000020?l0
00030000003oool0oooo02l0oooo0P00000P0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000oooo0?ooo`0d0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0=03oool00`000000
o`000?l000030?l000030000003oool0oooo00P0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0S0?ooo`8000007`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000P3o00000`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo
0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0203oool00`000000o`00
0?l000030?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0j0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0;`3oool200000200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000<03oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0203oool00`000000o`000?l000030?l000030000003oool0oooo02@0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000103oool3000000<0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003oool0oooo0300oooo00<0
00000?ooo`3oool07@3oool2000000@0oooo0`0000020?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo03D0oooo00<0
00000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l00003
0?l000030000003oool0oooo00P0oooo1`00000U0?ooo`8000007`3oool00`000000oooo0?ooo`10
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0_
0?ooo`800000:P3oool200000300oooo00<000000?l0003o00000`3o0006000003L0oooo00<00000
0?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l0
00030000003oool0oooo03D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`100?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo03X0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l0
00030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool001`0oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=03oool2000001l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l00003
0000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0j0?ooo`03
0000003o0000o`000080o`0000<000000?ooo`3oool0;`3oool2000002X0oooo0P00000`0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`00
7P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l0
00030000003oool0oooo0300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?oo
o`007P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000=P3oool00`00
0000o`000?l000030?l000030000003oool0oooo03@0oooo0P00000O0?ooo`030000003oool0oooo
0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0100oooo1@0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0j0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0;`3oool20000
0180oooo1@0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`8000000`3oool20000
0300oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0140oooo000N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03@0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`00
0080o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0140oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool20000
0180oooo100000030?ooo`800000103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0_0?ooo`800000503oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000`0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0>@3oool2000001<0oooo000M0?ooo`800000103oool30000
00<0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003oool0oooo
03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0
oooo03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000P3o0000
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`00
0000oooo0?ooo`0d0?ooo`L00000=P3oool2000001<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0j0?ooo`H00000<@3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool200000300oooo1`00000l0?ooo`030000
003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000480oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo0P0000030?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04@3oool2000000<0oooo100000090?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00
:@3ooomf00000180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02T0ooooMP00000Z0?ooogH000004`3oool00;80oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`3o0?oooe<0oooo002n0?ooo`030000003oool0oooo0400oooo
1`00000f0?ooo`030000003oool0oooo0?l0ooooD`3oool00;h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oomC0?ooo`00_P3ooon100000?l0ooooE@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0
oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?oo
ool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3o
ool003L0oooo1@0000020?ooo`800000103oool2000001<0oooo0P00000F0?ooo`D000000P3oool2
000000@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo0P00000h0?ooo`D000000P3oool2
000000@0oooo0P00000D0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3oool4
000000<0oooo0P0000040?ooo`800000>@3oool500000080oooo0P0000040?ooo`8000004`3oool2
000001H0oooo1@0000020?ooo`800000103oool200000100oooo100000030?ooo`800000103oool2
00000;<0oooo000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00002b0?ooo`00>@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>@3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000/P3oool00340oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02l0oooo100000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0300oooo100000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03h0oooo1@000002
0?ooo`800000103oool200000140oooo0P00000C0?ooo`D000000P3oool2000000@0oooo0P00000=
0?ooo`@000000`3oool2000000@0oooo0P00000B0?ooo`00>@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000>@3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000004@3oool003P0oooo0P0000040?ooo`800000103oool2000001<0oooo0P00000G0?oo
o`800000103oool2000000@0oooo0P00000A0?ooo`800000103oool2000000@0oooo0P00000i0?oo
o`800000103oool2000000@0oooo0P00000D0?ooo`8000005`3oool2000000@0oooo0P0000040?oo
o`800000403oool2000000@0oooo0P0000040?ooo`800000>P3oool2000000@0oooo0P0000040?oo
o`8000004`3oool2000001L0oooo0P0000040?ooo`800000103oool200000140oooo0P0000040?oo
o`800000103oool2000004<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000140oooo003o0?ooool0oooo7@3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03`3oool00?l0ooooo`3ooolU0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000A0?ooo`00o`3ooooo0?ooob@0
oooo0P0000040?ooo`800000103oool200000140oooo0P00000D0?ooo`800000103oool2000000@0
oooo0P00000>0?ooo`800000103oool2000000@0oooo0P00000B0?ooo`00603oool2000000<0oooo
PP00000I0?ooo`800000103ooon1000001X0oooo0P0000030?oooh800000/`3oool001L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0;40oooo000G0?ooo`040000003oool0oooo00000080ooooPP00000H0?ooo`040000003oool0oooo
000000<0ooooPP00000H0?ooo`040000003oool0oooo00000080ooooPP00002c0?ooo`005`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2a0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0@0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S
0?ooo`8000000`3ooomf000001<0oooo000H0?ooo`8000000`3oool2000000@0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool05`3oool2000000@0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?oo
o`8000000`3oool2000000X0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool2000002@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0403oool00`000000o`000?l000030?l0
00030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?oo
o`040000003oool0oooo00000080ooooMP00000C0?ooo`007@3oool2000000@0oooo1`0000060?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0@0?oo
o`L000007`3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo0P00000:0?oo
o`P000001@3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`003P0000040?oo
o`800000903oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000M0?oo
o`030000003oool0oooo0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3oool2000000@0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000M0?oo
o`030000003oool0oooo0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02<0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000G0?ooo`@0
00000P3oool200000140oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo01D0oooo0P00000H0?ooo`@000000`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01L0oooo100000020?ooo`8000004@3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`80
0000:P3oool2000000@0oooo4@0000050?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l001800000103oool00`000000oooo0?ooo`0A0?ooo`00
5`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003o
ool0oooo0080oooo0P00000A0?ooo`L000001@3o0007000000D0o`001`0000050?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`8000006@3o
ool00`000000oooo0?ooo`030?ooo`800000403oool7000000D0o`001`0000060?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o0007000000D0o`0000<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P00000A0?ooo`d000001@3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0?0?ooo`800000:P3oool2000001@0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000I0?ooo`050000003oool0
oooo0?ooo`000000603oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo00D0
00000?ooo`3oool0oooo0000000N0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool05P3oool00`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01D0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`03
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?oo
o`@000000`3oool2000000@0oooo0P0000030?ooo`800000503oool00`000000o`000?l000030?l0
00L00000103o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o0007000001D0oooo00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`80
00005`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01D0oooo0P00000I0?ooo`80
0000103oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool2000001d0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0?0?ooo`800000603oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool04`3oool00`000000o`000?l000030?l0
00030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo01H0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool05@3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01D0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P00000D0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003oool0oooo01P0oooo0P00000C0?ooo`007@3oool2000001L0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
1`00000G0?ooo`8000007`3oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`8000007@3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000000D0o`00
00<000000?l0003o00000`3o000700000140oooo0P00000J0?ooo`030000003oool0oooo00P0oooo
0P0000030?ooo`030000003oool0oooo01<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01`0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00P3oool2000001@0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000H000006`3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?oo
o`0F0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0E0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01`0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0G0?ooo`8000002P3oool300000080oooo00<000000?ooo`3oool04`3oool00`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0A0?ooo`006@3oool3000000030?ooo`000000000001L0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool2
000001X0oooo0`0000020?ooo`030000003oool0oooo01D0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo0`0000000`3oool000000000000M
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo01D0oooo0P00000Z0?ooo`800000503oool00`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A
0?ooo`006P3oool010000000oooo0?ooo`00000H0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0000001L0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool00000
7P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
4`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0A0?ooo`005`3oool5000000030?ooo`000000000001L0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`L000001@3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool2000001P0oooo1@00
00020?ooo`8000005P3oool7000000D0oooo00<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool7000001L0oooo00<0
00000?ooo`3oool05`3oool5000000030?ooo`000000000001d0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
0007000000H0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00`3oool=000001L0oooo0P00000Z0?ooo`800000503o
ool7000000D0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`005`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01H0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo0240oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo000000020?ooo`030000
003oool0oooo01H0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003oool0oooo0240oooo00<000000?ooo`3oool0603oool00`000000oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0S0?ooo`800000
0`3oool200000200oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`006@3o
ool200000080oooo0P00000G0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool03`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3o
ool2000001X0oooo0P0000030?ooo`030000003oool0oooo0240oooo00<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0I0?ooo`8000000P3oool2000001d0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3o
ool2000002@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool05P3o
ool00`000000o`000?l000030?l000030000003oool0oooo00l0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003oool0oooo0240oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0200000200oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000L000007`3oool2000001<0oooo000M0?ooo`8000005`3oool700000140oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`003@00000M
0?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`P000001@3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool2000001d0oooo3@000005
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000002T0oooo0P00000U
0?ooo`8000000`3oool00`000000oooo0?ooo`0O0?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000M0?oo
o`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`800000803oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02<0oooo0`0000020?ooo`030000003oool0oooo01l0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo02@0oooo00<000000?ooo`3o
ool04@3oool001L0oooo0`0000030?ooo`800000;`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`800000
603oool3000000@0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`<00000
0`3oool2000002T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool2000002X0oooo0P00000P0?ooo`H00000
1@3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0T0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`800000;`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?oo
o`800000603oool010000000oooo0?ooo`0000030?ooo`800000:@3oool7000000D0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo0P00
000Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02d0oooo0P00000Z0?ooo`8000009@3oool00`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001L0oooo0`000003
0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F
0?ooo`<00000103oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`<000000`3oool00`000000oooo0?ooo`0X
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0T
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A
0?ooo`00603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo0240oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`8000000`3oool2000002D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`001P00000V0?ooo`030000003oool0oooo0140oooo000H0?ooo`<0
00000P3oool2000002l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool2000001T0oooo0`0000030?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01P0oooo0`0000020?ooo`800000:@3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`80
00006P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0903oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000M0?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000002D0
oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0:03oool2000001<0oooo000M0?ooo`030000003oool0oooo02h0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0903oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000;`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0W0?ooo`8000007`3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000L000008`3oool00`000000oooo0?oo
o`0M0?ooo`800000:@3oool00`000000o`000?l000030?l000L000001@3oool00`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0]0?ooo`800000603oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo
0P00000U0?ooo`L00000103o0007000000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001d0oooo00<0
00000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`@000002@3oool300000080oooo00<0
00000?ooo`3oool0:P3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002l0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool09`3oool2000001l0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01d0oooo0P00000Y0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`800000:P3oool2000002/0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<00000
0?ooo`3oool04@3oool001P0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0^0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003oool0oooo02L0oooo00<000000?ooo`3oool0603oool2000000<0oooo00<000000?oo
o`3oool0:03oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<000000?l0
003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<000000?oo
o`3oool04@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:03oool00`000000o`000?l0
00030?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0X0?ooo`800000:`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`00
00020?ooo`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`800000603oool010000000oooo0?oo
o`0000030?ooo`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
2000000Y0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool2000002T0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02d0
oooo0P00000Z0?ooo`030000003oool0oooo02X0oooo00<000000?l0003o00000P3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001P0oooo
0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo
0P0000030?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool0703oool500000080oooo
0P0000030?ooo`800000:`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?oo
o`0000020?ooo`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`800000603oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool010000000
oooo0?ooo`0000020?ooo`800000:@3oool00`000000o`000?l000030?l000030000003oool0oooo
00T0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;@3oool200000200oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000002`0oooo00<000000?l0003o00000P3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001P0oooo0P000003
0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0G
0?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo0P000003
0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`09
0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P00000[0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`001`00
000Z0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`09
0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000;03oool00`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02L0oooo0P00000O0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3o
ool2000002T0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02d0oooo0P00000P0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`02000002/0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0140oooo000M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3o
ool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`8000000`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002l0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool2
000001l0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`800000:@3oool0
0`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool2
000002X0oooo0P00000[0?ooo`H000001@3oool00`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004@3oool50000
0080oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0@0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3oool0:03oool00`00
0000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo03D0oooo00<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000300oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:P3oool00`000000o`000?l000030?l0
00030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0X0?oo
o`800000=P3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P00000_0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`003@00000Y0?oo
o`800000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00
000_0?ooo`L000001@3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000:@3oool00`000000o`00
0?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool2000002X0oooo
00<000000?ooo`3oool0=@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000<03oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000Z0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
2@3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo1@0000000`3oool00000
00000002000000<0oooo0P0000040?ooo`8000000`3oool2000003H0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000
;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo03<0oooo0P00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00800000:@3oool00`000000o`000?l00003
0?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;@3oool2000001@0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
=@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool2000000@0oooo0P0000030?ooo`030000003o
ool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`800000103o
ool2000000<0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o
ool0oooo00T0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000003H0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo0P00
000C0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool0=@3oool00`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool2000002l0oooo1`0000050?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0c0?ooo`8000007`3oool00`000000oooo0?ooo`0d0?oo
o`L000001@3o00000`000000o`000?l000030?l000L00000<03oool00`000000oooo0?ooo`0M0?oo
o`800000:@3oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;@3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool2000003H0oooo00<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool0
01d0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
02P0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02h0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P00000:0?ooo`<000000P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000=@3oool00`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0c0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0
oooo0P00000Y0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0]0?ooo`800000:P3oool2000003H0oooo00<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool00140oooo
1@0000000`3oool000000000000200000080oooo00<000000?ooo`3oool0=03oool00`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0oooo
00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`D0000000<0oooo000000000000
0P0000020?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0e0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0>P3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0X0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo02P0oooo0P00000f0?ooo`030000003o0000o`000080o`001`00000a0?oo
o`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool2000003D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool2000001@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`800000>`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000002T0oooo1`00000;0?ooo`03
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo02d0oooo0P00000Z0?ooo`030000003oool0oooo03D0oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo0000000l0?ooo`030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?oo
o`3oool0703oool500000080oooo0P0000030?ooo`800000=P3oool00`000000o`000?l000020?l0
00030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool001<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00800000=@3oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?oo
o`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000l0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00800000>`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`800000803oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000=`3oool00`000000o`000?l000020?l0
00030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00180oooo0P0000040?ooo`80
00000`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3o
ool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3o
ool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P00000f0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0=03oool2000001<0
oooo000M0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0j0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0e0?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003D0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000L00000=@3oool2000001l0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000>`3oool00`000000o`000?l0
00040?l000030000003o0000o`0000<0o`001`00000_0?ooo`800000803oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P00000f0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0d
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool2000000@0oooo0`000002
0?ooo`030000003oool0oooo03D0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000=@3oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?ooo`3oool0>@3oool2000001l0oooo00<000000?oo
o`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000>`3oool00`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool2000002X0oooo0P00000f0?oo
o`030000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?oo
o`004@3oool5000000<0oooo0`0000000`3oool000000?ooo`0e0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0100
oooo1@0000030?ooo`<000000P3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140
oooo1@0000030?ooo`<0000000<0oooo0000003oool0>`3oool00`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo03D0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
0000=P3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000l0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000l0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02P0oooo0P00000f0?ooo`030000003o0000
o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01000
0000oooo0?ooo`3oool5000000030?ooo`000000000003D0oooo1`0000060?l000030000003oool0
oooo03T0oooo0P00000D0?ooo`040000003oool0oooo0?ooo`D000000P3oool2000003/0oooo1`00
00050?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04`3oool010000000oooo0?oo
o`3oool5000000030?ooo`000000000003/0oooo00<000000?l0003o0000103o0007000003D0oooo
0P00000Z0?ooo`030000003oool0oooo03D0oooo00<000000?l0003o00000P3o00000`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000l0?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000480oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000003`0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo02P0oooo0P00000f0?ooo`H00000=`3oool00`000000oooo0?ooo`0A0?ooo`004`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo0P00000k0?ooo`030000003o
0000o`0000@0o`0000<000000?ooo`3oool0>@3oool2000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000020?ooo`800000>`3oool00`000000o`000?l000040?l000030000003o
ool0oooo03T0oooo0P00000Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`004P3oool2000000D0oooo0P0000020?ooo`030000003oool0
oooo03X0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0140oooo0P0000050?ooo`8000000`3oool00`000000oooo0?ooo`100?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`8000001@3oool2
00000080oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000040?l000030000003oool0
oooo03X0oooo00<000000?ooo`3oool0:03ooomf000001<0oooo000M0?ooo`030000003oool0oooo
03X0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`00
00@0o`0000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2a0?ooo`007@3oool2000003/0
oooo2000000k0?ooo`8000007`3oool00`000000oooo0?ooo`100?ooo`L00000=P3oool00`000000
oooo0?ooo`0M0?ooo`800000>`3oool8000003/0oooo0P00002c0?ooo`007@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/@3oool001d0ooooPP00
000O0?oooh4000007`3ooon200000;<0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?oo
o`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
000g0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005P3oool500000080oooo0P00
00040?ooo`800000403oool4000000<0oooo0P0000040?ooo`800000>03oool500000080oooo0P00
00040?ooo`800000503oool2000001H0oooo1@0000020?ooo`800000103oool2000000l0oooo1000
00030?ooo`800000103oool200000?l0ooooE@3oool003T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000?l0ooooE03oool003T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000?l0ooooE03oool00340oooo100000040?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02l0oooo100000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03l0oooo1@0000020?ooo`800000103oool2
00000100oooo0P00000C0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2
000000@0oooo0P00002c0?ooo`00>@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000>@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000@`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
@03oool500000080oooo0P0000040?ooo`8000004@3oool2000001<0oooo1@0000020?ooo`800000
103oool2000000d0oooo100000030?ooo`800000103oool200000180oooo000h0?ooo`800000103o
ool2000000@0oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`8000004@3o
ool2000000@0oooo0P0000040?ooo`800000>@3oool2000000@0oooo0P0000040?ooo`800000503o
ool2000001L0oooo0P0000040?ooo`800000103oool200000100oooo0P0000040?ooo`800000103o
ool2000004@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000480
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000140oooo003o0?oo
og`0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0400oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000140
oooo003o0?oooh@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003X0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00l0oooo003o0?oooh<0oooo0P0000040?ooo`800000103oool200000100oooo0P00
000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`800000103oool2000000@0oooo0P00
00130?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000A0?oo
o`00603oool2000000<0ooooPP00000I0?ooo`800000103ooon100000><0oooo0P0000040?ooo`80
0000103oool200000140oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`80
0000103oool2000000@0oooo0P00000B0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
oe<0oooo000G0?ooo`040000003oool0oooo00000080ooooPP00000H0?ooo`040000003oool0oooo
000000<0ooooP@00003o0?oooeD0oooo000G0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool02@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02<0oooo0P00
003o0?ooobh0oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo0280oooo00@000000?ooo`3oool0
00000`3ooomf000002D0oooo0P0000030?ooogH000004`3oool001P0oooo0P0000030?ooo`800000
103oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0
3P3oool2000001T0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0ooooMP00000T0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`007@3oool00`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`003@0000050?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l0
00030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3ooomf000001<0oooo000M0?oo
o`800000103oool00`000000o`000?l000030?l000h000001@3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00L000001@3o00000`000000o`000?l000040?l000030000003oool0oooo00h0oooo0P00000O0?oo
o`030000003oool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`08
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`02
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool001d0oooo00<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00X0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo00l0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0S0?ooo`800000103oool00`000000oooo0?ooo`08
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`02
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool010000000oooo0?ooo`00
00020?ooo`800000103oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool<000000D0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo0080oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`d000009@3oool2000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`005`3oool400000080oooo0P0000040?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?ooo`3oool03P3oool2000001l0oooo00<000000?oo
o`3oool02@3ooolC000000D0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?oo
o`d00000:`3oool00`000000oooo0?ooo`0C0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo0P0000040?oo
o`H000001@3oool6000000D0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`001P00000@0?ooo`030000003oool0oooo0140oooo000G0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo00X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool03@3oool2000002X0oooo00<000000?ooo`3o
ool04`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04@3oool001P0oooo00<000000?ooo`3oool00P3oool2000000@0oooo1`00000<0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0>0?ooo`800000
7`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0X0?ooo`800000503oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool001T0oooo00D000000?ooo`3oool0oooo
0000000H0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000L000007@3oool00`000000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo01<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`00
0?l000030?l000030000003oool0oooo00d0oooo0P00000Z0?ooo`030000003oool0oooo01<0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo
000G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05P3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo01<0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000
o`000?l000030?l000030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool4000000<0
oooo0P0000040?ooo`8000000`3oool2000001@0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`001`00000E0?ooo`030000003oool0oooo0140
oooo000H0?ooo`8000000`3oool2000001L0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003oool0oooo00h0oooo0P00000O0?ooo`030000003oool0oooo01/0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00P3oool00`000000o`000?l000030?l000030000003oool0oooo00d0oooo0P00000H0?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3o
ool05P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0203oool2000000@0oooo00<000000?ooo`3oool04`3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01P0
oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool06`3oool7000000H0o`001`0000050?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo0240oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool7000000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`001`0000040?ooo`L000003`3oool2000001X0
oooo00<000000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool04`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo000M0?ooo`8000005`3oool7000000D0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool7000000H0o`0000<000000?ooo`3oool03P3oool2000001T0oooo
0P0000040?ooo`030000003oool0oooo0240oooo00<000000?l0003o0000103o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0G0?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3oool06@3oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo01`0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000@0o`00
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool08@3oool00`000000o`000?l000040?l000030000003oool0oooo00<0
oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01h0
oooo0P00000I0?ooo`8000002P3oool300000080oooo0P00000D0?ooo`L000001@3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`001`0000040?l000030000003oool0oooo01T0
oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000M0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003oool0oooo00h0oooo
0P00000K0?ooo`040000003oool0oooo0?ooo`8000008P3oool00`000000o`000?l000040?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`001`00000S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool06@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo000I0?ooo`<00000
00<0oooo0000003oool07@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00T0oooo
00<000000?l0003o0000103o00000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo
0P0000040?ooo`030000003oool0oooo0240oooo00<000000?l0003o0000103o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003oool0oooo02L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0I0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool07P3oool2000002X0oooo
0P00000J0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0140oooo000J0?ooo`040000003oool0oooo000001h0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000@0o`00
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08@3oool00`000000o`000?l000040?l000030000003oool0oooo00<0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0S0?ooo`800000103oool00`000000oooo
0?ooo`0I0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000020?l000030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool001L0oooo1@00
00000`3oool000000000000M0?ooo`030000003o0000o`0000<0o`001`0000050?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool02@3oool800000100oooo0P00000I0?ooo`<000000`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0
7P3oool2000002X0oooo0P00000J0?ooo`L00000103o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
703oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo0280oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Q0?ooo`P000001@3oool7000000D0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`002000000Y0?ooo`030000
003oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000000K0?ooo``00000103o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`003000000P0?ooo`800000:P3oool00`000000
oooo0?ooo`0O0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0A0?ooo`00603oool00`000000oooo000000020?ooo`8000007@3oool00`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo0240oooo0P00000O0?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo
0P0000040?ooo`030000003oool0oooo02@0oooo00<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0S0?ooo`8000000`3oool200000200oooo00<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0140oooo000I0?ooo`8000000P3oool00`000000oooo0?oo
o`0L0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0T0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003oool0oooo02T0oooo0P00000T0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool07`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo01T0oooo
00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0703oool00`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0d0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0S0?ooo`<000000`3oool00`000000oooo0?ooo`0T0?ooo`030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0200000200oooo300000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o
0000o`000080o`0000<000000?ooo`3oool0603oool2000001<0oooo000M0?ooo`8000007@3oool0
0`000000o`000?l000030?l000030000003oool0oooo00<0oooo1`0000050?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo0240oooo0P00000O0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0903oool0
0`000000o`000?l000020?l000L00000103o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`8000009@3oool2
000000<0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000
o`000080o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo0280oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo00<000000?l0003o00000P3o00000`00
0000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo0P00000[0?ooo`030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo
00<0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0140oooo000M0?ooo`8000007@3oool00`000000o`000?l000030?l000030000003oool0oooo00T0
oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`8000007`3oool00`000000
oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo00<000000?l0003o00000P3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool2000002D0
oooo0`0000020?ooo`030000003oool0oooo02X0oooo00<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000020?l000030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool001L0oooo
0`0000030?ooo`030000003oool0oooo01`0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0903oool00`000000o`00
0?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02@0oooo
00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0:@3oool2000002X0oooo0P00000[0?ooo`030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo
1P00000K0?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo
0P00000M0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo0240oooo0P00000O0?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02@0
oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0
oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`005`3oool3000000<0oooo
00<000000?ooo`3oool0703oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
00009P3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0Y0?ooo`800000:P3oool2000002/0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo0?ooo`020?ooo`800000
7@3oool00`000000o`000?l000030?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0Q0?ooo`8000007`3oool00`000000oooo0?ooo`0d0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000L00000
<03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000
003oool0oooo02@0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02X0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`00603o
ool300000080oooo00<000000?ooo`3oool0703oool00`000000o`000?l000030?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0100oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo03@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0903oool6000000D0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0Y0?ooo`8000006P3oool00`000000oooo0?ooo`020?ooo`800000
103oool2000000<0oooo0P00000[0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0703oool00`000000o`000?l000030?l000030000003o
ool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000=P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0oooo100000090?ooo`<0
00000`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool001d0oooo0P00000M0?ooo`L000002`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000002<0oooo0P00000D0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000003D0oooo1`000005
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y
0?ooo`8000006P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00800000:`3oool0
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000oooo0?ooo`0S0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0;P3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0:P3o
ool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000;`3oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0W0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000l0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo0P00000H0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool2000002/0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo00<000000?ooo`3oool0
;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`800000
103oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo02X0oooo00<000000?ooo`3oool0
5P3oool4000000T0oooo0`0000020?ooo`030000003oool0oooo02X0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo03@0oooo00<000000?ooo`3oool0703oool500000080oooo0P0000040?ooo`030000
003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`800000
:P3oool2000002/0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`005`3o
ool010000000oooo0?ooo`0000020?ooo`800000;`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o0007000000D0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0W0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000<@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool001P0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool2000002X0oooo0P00000[
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`001`0000040?l000030000003oool0oooo02@0oooo00<00000
0?ooo`3oool04@3oool001L0oooo00@000000?ooo`3oool000000P3oool2000002l0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool09`3oool2000001l0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`800000:P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000020?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001P0oooo0P00
00030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0
oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080
o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo
0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000L00000:`3oool2000001h0oooo1@0000020?ooo`8000000`3oool2000002/0oooo
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002l0oooo00<0
00000?l0003o00000`3o0007000000H0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool2000001l0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000/0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003oool0oooo02@0oooo00<000000?ooo`3o
ool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?ooo`3oool0;`3oool200000200oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00800000:`3oool6000000D0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo1P00000U0?ooo`80
00004`3oool001d0oooo0P00000_0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo02L0oooo0P00000O0?ooo`030000
003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo0300oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000<@3oool00`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0140oooo000A0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3oool0;P3oool00`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0@0?ooo`D0000000<0oooo0000000000000P0000030?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0
o`001P00000a0?ooo`800000803oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000300oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`800000
0`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000
;`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo200000050?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`800000
7`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool2000002X0
oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000300oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo1@0000020?oo
o`800000103oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0_0?oo
o`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`02000002l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0@0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?oo
o`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000l0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`800000
:P3oool200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004P3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool2000003/0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool2000000@0oooo
0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo
000M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0@0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo0P00
000Z0?ooo`800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000M
0?ooo`800000;`3oool700000180oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02L0oooo0P00000D0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`D0000000<0oooo0000000000000P000003
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo04L0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?oo
o`3oool04@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo03X0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`800000503oool01@000000oooo0?ooo`3oool0
000000/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool04@3oool001d0oooo0P0000180?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`8000007`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool0
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0200000300oooo00<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool2000001<0oooo000A0?oo
o`D0000000<0oooo0000000000000P0000020?ooo`030000003oool0oooo04L0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0oooo1@0000020?oo
o`800000103oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`800000503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0A`3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03X0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo0000000a0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool200000300oooo
1`0000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00
00180?ooo`030000003o0000o`0000<0o`001`00000Y0?ooo`8000007`3oool00`000000oooo0?oo
o`0j0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool000000340oooo1P0000050?l000030000003oool0oooo03@0oooo0P00000C0?ooo`800000
103oool2000000X0oooo0`0000020?ooo`030000003oool0oooo03D0oooo00<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool001<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000004T0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l000L00000=P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02P0oooo
0P00000f0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`02000004P0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`0]0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0=03oool2000002X0oooo00<000000?ooo`3oool0=@3oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0A0?ooo`004P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo04L0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003oool0oooo03X0oooo00<0
00000?ooo`3oool07@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02P0oooo0P00
000f0?ooo`H000001@3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000M
0?ooo`030000003oool0oooo04L0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00003
0?l000030000003oool0oooo03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool2000002X0oooo00<00000
0?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<00000
0?ooo`3oool04@3oool001d0oooo0P0000180?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;@3oool2000001l0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000030?l0
00030000003oool0oooo03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool2000001h0oooo1@0000020?oo
o`8000000`3oool2000003/0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo04L0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0>P3oool00`000000o`000?l000030?l000030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000l0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`170?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03X0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0100oooo1@0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool20000
0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000003/0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0^0?ooo`8000004`3oool00140oooo1@0000030?ooo`<0
000000<0oooo000000000000B03oool00`000000o`000?l000030?l000030000003oool0oooo02d0
oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool00`00
0000o`000?l000030?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000004T0oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo100000030?ooo`800000103oool00`00
0000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01@00
0000oooo0?ooo`3oool0000003H0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d
0?ooo`800000803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000k
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A
0?ooo`004`3oool010000000oooo0?ooo`3oool5000000030?ooo`000000000004P0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`8000004P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l0
00030?l000030000003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo0P00
00040?ooo`<000000P3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000B@3oool00`000000o`000?l000030?l000030000
003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo0P00000k0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool70000
03H0oooo0P00000Z0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`170?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo0P0000030?ooo`@000002@3oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0:03oool2000003/0oooo1`00000a0?ooo`030000003oool0
oooo0140oooo000B0?ooo`8000001@3oool200000080oooo0P0000180?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0;@3oool200000180oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02T0ooooMP00000Z0?ooogH000004`3o
ool001d0oooo00<000000?ooo`3oool0A`3oool00`000000o`000?l000030?l000030000003oool0
oooo02h0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo03X0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0?l0ooooD`3oool001d0oooo0P0000180?ooo`L00000;`3oool2000001l0oooo00<000000?oo
o`3oool0>P3oool7000003`0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`007@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00
7@3ooon2000001l0ooooP@00003o0?oooeD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0
oooo000g0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005P3oool500000080oooo
0P0000040?ooo`800000403oool4000000<0oooo0P0000040?ooo`800000f@3oool500000080oooo
0P0000040?ooo`8000004`3oool2000001H0oooo1@0000020?ooo`800000103oool200000100oooo
100000030?ooo`800000103oool2000003P0oooo1@0000020?ooo`800000103oool2000001@0oooo
0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool2000000@0oooo
0P00000C0?ooo`00>@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000fP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool003T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000=X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000180oooo000a0?ooo`@00000103oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`04
0000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0n0?ooo`D000000P3oool2000000@0
oooo0P00000A0?ooo`8000004`3oool500000080oooo0P0000040?ooo`8000003@3oool4000000<0
oooo0P0000040?ooo`800000<P3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0;`3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0403oool003T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000480oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000180oooo000h0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3o
ool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000@`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000>03oool2000000@0
oooo0P0000040?ooo`8000004`3oool2000001L0oooo0P0000040?ooo`800000103oool200000140
oooo0P0000040?ooo`800000103oool2000003T0oooo0P0000040?ooo`800000103oool2000001@0
oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000@0?ooo`800000103oool2000000@0
oooo0P00000C0?ooo`00fP3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00hP3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000o`3ooomC0?ooo`00h@3oool2000000@0oooo0P000004
0?ooo`8000004@3oool2000001@0oooo0P0000040?ooo`800000103oool2000000h0oooo0P000004
0?ooo`800000103oool200000?l0ooooE03oool00?l0ooooo`3ooonE0?ooo`00603oool2000000<0
ooooPP00002j0?ooo`8000000`3ooon2000001T0oooo0P0000040?oooh4000004`3oool001L0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;L0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo0P00000B0?ooo`005`3oool010000000oooo0?ooo`0000020?oooh8000009@3oool2
00000980oooo00@000000?ooo`3oool000000P3ooon2000001P0oooo00@000000?ooo`3oool00000
0`3ooon1000001<0oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8P3oool010000000oooo0?ooo`0000020?ooogH000006@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02@3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo0P000004
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool2000002@0oooo00@00000
0?ooo`3oool000000P3ooomf000001T0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?ooo`3oool0203oool2000001P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool001P0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3oool00`000000
o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000
o`000?l000030?l000030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool2000000<0
oooo00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0
oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0
oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00000`3o0007000000D0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`001`0000050?ooo`L000001@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000
o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000103oool00`000000o`00
0?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o00000`3o0007000000D0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?ooo`3oool00`3oool7000000@0oooo0P00000U0?ooo`8000000`3oool00`000000o`00
0?l000030?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`00
0?l000030?l000030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool2000000@0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o0007000000D0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000P000002P3oool2000001l0oooo00<000000?ooo`3oool02@3oool00`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0:03oool7000000@0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000L000001@3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00P3oool00`000000o`000?l000030?l000030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0103oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool02@3oool7000000D0oooo1`0000050?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000M
0?ooo`030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`04
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00004
0?l000030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`08
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003oool0oooo0080oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0103oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`8000007`3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool001d0oooo0P0000040?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l0
00030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0>0?oo
o`800000:P3oool2000000T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool00P3oool00`000000o`000?l000030?l0
00030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool400000080oooo00<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`005`3oool400000080oooo00<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00P0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00P3oool00`000000o`000?l000030?l000030000003oool0oooo00P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`040?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0100oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`00200000050?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000000H0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01D0oooo00<000000?ooo`3o
ool04@3oool001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01H0oooo100000030?ooo`800000103oool2000000<0oooo0P0000090?ooo``00000
1@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`001`0000040?ooo`L00000
2P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`L00000
1P3oool=000000D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool03`3oool2000001l0oooo00<000000?ooo`3oool0
6`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`L000001P3oool00`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o0007000000D0o`002000000@0?ooo`800000603o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
6@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000903oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l000030?l000030000003oool0oooo00@0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000I0?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P00000J0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`0H0?ooo`8000006@3oool010000000oooo0?ooo`0000020?ooo`8000008`3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0?0?ooo`8000007`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0103oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
01D0oooo00<000000?ooo`3oool04@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool20000
00<0oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`L000001P3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
01D0oooo00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`8000004@3oool00`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool2000001P0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`8000006P3oool70000
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0280oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`00
0000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0
oooo0P00000:0?ooo`<000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`8000008`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`001`0000050?l000d000004@3oool2000001P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02P0oooo0P00000P0?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280
oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0
oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0
oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o0000103o000=000001L0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000A0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`80
0000:P3oool00`000000oooo0?ooo`0O0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0M0?ooo`8000008`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo01/0oooo0P00000I0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo0100oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003oool0oooo01H0oooo00<000000?ooo`3oool0
:03oool200000200oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01T0oooo0`0000000`3oool000000?ooo`0S0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`00
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?oo
o`0@0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool010000000oooo0?oo
o`00000T0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0G0?ooo`<000000`3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo
2000000S0?ooo`030000003oool0oooo0140oooo000M0?ooo`8000004@3oool00`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05@3oool2000002D0oooo0P00
00030?ooo`800000803oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01T0oooo00<0
00000?ooo`3oool05`3oool5000000030?ooo`000000000002<0oooo00<000000?l0003o00000`3o
0007000000D0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`8000007`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3o
ool001T0oooo0`0000000`3oool000000?ooo`0A0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool08P3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01`0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo
00<000000?ooo`3oool04@3oool001X0oooo00@000000?ooo`3oool000004P3oool00`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00800000803oool00`000000o`000?l000020?l000L00000
103o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o0006000001X0oooo0P00000J0?ooo`030000003oool000000080oooo0P00000S0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool2000001l0oooo00<000000?ooo`3oool0
:03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000G0?ooo`D0000000<0
oooo0000000000004@3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo3@00
00050?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003oool0oooo01D0oooo0P00000U0?ooo`8000000`3oool00`000000oooo0?oo
o`0O0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool200000080oooo00<0
00000?ooo`3oool08P3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01`0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`L000001@3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`800000803oool00`000000o`000?l0
00020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08P3oool00`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l0
00030?l000030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0^0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool0403oool00`000000o`000?l000030?l000030000003oool0oooo00l0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02<0oooo0`000002
0?ooo`800000803oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000H000001@3o00000`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01d0oooo0P00000S0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool06`3oool2000001l0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A
0?ooo`006@3oool200000080oooo0P00000A0?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool03`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo01D0oooo0P00000Z0?oo
o`030000003oool0oooo01l0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`020?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0280oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00L00000<03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool03`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo01H0oooo00<000000?ooo`3oool0:03oool200000200oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`020?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0M0?ooo`8000008`3oool00`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo01/0oooo0P00000O0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000
003oool0oooo0100oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01l0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`<00000
0`3oool00`000000oooo0?ooo`0R0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`8000004@3o
ool700000140oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o0007000000D0oooo1`00000G0?ooo`8000006P3o
ool00`000000oooo0?ooo`020?ooo`800000103oool2000000<0oooo0P00000P0?ooo`030000003o
0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool00P3oool700000200oooo00<000000?ooo`3oool05`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0280oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
;P3oool7000000D0o`001`0000050?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo02T0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`80
00008`3oool7000000D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo01/0oooo0P00000B0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3o
ool0=03oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000
003oool0oooo02P0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0200000200oooo
00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0X0?ooo`8000006@3oool3000000<0oooo
00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`005`3oool3000000<0oooo0P00000Y0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool09`3oool2000001/0oooo00<000000?ooo`3oool01`3oool2000000<0
oooo00<000000?ooo`3oool07`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0
oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`800000;`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool2000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool0
0`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo02P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo0080oooo0P00000P0?ooo`H000001@3oool00`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0H0?ooo`<000000P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000o`000?l000030?l00003
0000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo0P00000Y0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool2000001P0oooo100000090?ooo`<0
00000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000003H0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A
0?ooo`005`3oool3000000<0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool2000002/0oooo00<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<000000?oo
o`3oool07@3oool2000002l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00L000001@3oool7000001d0oooo0P00000C0?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool0=03oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000H0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00
603oool300000080oooo0P00000Y0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
9`3oool2000002X0oooo0P00000[0?ooo`H000001@3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`001`00000[0?ooo`030000003oool0oooo01d0oooo0P00000_0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0]0?ooo`800000
7`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0603oool2000000<0oooo00<000000?ooo`3oool0;P3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`D000000P3oool2
000000<0oooo0P00000`0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool05`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001d0oooo0P00000Y0?ooo`L000001@3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool09`3oool200000200oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000340oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo00000080oooo0P00000_0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`001`00000_0?ooo`8000007`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00800000<03oool00`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`8000006P3oool2000000<0
oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000340oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo00000080oooo0P00000_0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0<`3oool2000001l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000;`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?oo
o`800000803oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000`
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool0603oool2000000<0oooo00<00000
0?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04@3oool001P0oooo0P0000030?ooo`030000003oool0oooo02h0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool0;`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0^0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool200000300oooo1`0000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?oo
o`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03<0oooo0P00000O0?oo
o`030000003oool0oooo03@0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`800000;`3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?oo
o`800000:P3oool2000003H0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03@0oooo1`0000050?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo00<000000?ooo`3o
ool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0=@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`80
0000103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`D0
000000<0oooo0000000000000P0000030?ooo`800000103oool2000000<0oooo0P00000f0?ooo`03
0000003o0000o`000080o`001`00000a0?ooo`030000003oool0oooo0140oooo1@0000020?ooo`80
00000`3oool2000002l0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`80
0000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000012
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A
0?ooo`00603oool2000000<0oooo0P00000_0?ooo`030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02L0oooo0P00000D0?oo
o`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03D0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000300
oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000480oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000003H0
oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0d0?ooo`8000005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000_0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0<`3oool2000001@0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0e0?ooo`030000003o0000o`000080
o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000`0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002l0oooo3@0000060?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02L0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000f0?ooo`030000003o0000
o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000`0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`800000103oool3000000<0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo
00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P00
000:0?ooo`<000000P3oool00`000000oooo0?ooo`0e0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00
000_0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool2000001l0oooo00<0
00000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00004
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool2000003H0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0;P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003/0oooo00<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0W0?ooo`800000:P3oool00`000000oooo0?ooo`0e0?oo
o`030000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?oo
o`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03<0oooo0P00000O0?oo
o`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo000A0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3o
ool0>P3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:03oool2000003H0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00
4`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000?03oool00`00
0000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0e0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`00
0000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000>`3oool00`00
0000o`000?l000040?l000030000003o0000o`0000<0o`001`0000050?l000030000003oool0oooo
02L0oooo0P00000N0?ooo`D000000P3oool2000000<0oooo0P00000f0?ooo`030000003o0000o`00
0080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`D0000000<0oooo0000
000000000P0000020?ooo`800000;`3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo
03<0oooo0P00000O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000l0?ooo`030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000g0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`0^0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000l0?ooo`030000003o0000o`0000@0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P00000f0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0=03oool20000
01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000;`3oool70000
00D0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo
03<0oooo0P00000O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103oool2000000<0
oooo0P00000k0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool200000200
oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0=@3oool00`000000
o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000o`000?l000030?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l0
00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3o
ool0>P3oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000030?l000030000003oool0oooo02P0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000f0?ooo`03
0000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000f0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0
oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`100?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0M0?ooo`800000103oool300000080oooo00<000000?ooo`3oool0=@3oool00`00
0000o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool20000
00@0oooo0P0000030?ooo`800000=@3oool00`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`8000004P3oool40000
00<0oooo0P0000040?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000>`3oool00`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool7000002T0
oooo0P00000Z0?ooo`800000=P3oool00`000000o`000?l000020?l000030000003oool0oooo03D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo03D0oooo00<000000?l0003o00000P3o00000`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo0P00000e0?ooo`L000001P3o00000`000000
o`000?l000030?l000030000003oool0oooo03<0oooo0P00000C0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`0j0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo02P0oooo0P00000f0?ooo`030000003o0000o`000080
o`0000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0
oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000120?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0A0?ooo`004@3oool5000000030?ooo`0000000000008000000P3oool20000
03/0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo
03<0oooo0P00000B0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool20000
00<0oooo0P00000f0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o0000103o00000`00
0000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0@03o
ool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo03X0oooo00<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0e0?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`D000000`3oool3000000030?oo
o`000000000003/0oooo00<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003oool0oooo03<0oooo0P00000C0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000>`3o
ool8000000D0o`0000<000000?ooo`3oool0<`3oool2000001@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00800000=P3oool00`000000o`000?l0
00020?l000030000003oool0oooo03@0oooo0P00000E0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool00000?03oool00`000000o`000?l000040?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo
000C0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000130?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0
=@3oool00`000000o`000?l000020?l000030000003oool0oooo03D0oooo00<000000?ooo`3oool0
4`3oool010000000oooo0?ooo`3oool5000000030?ooo`000000000003/0oooo200000050?l00003
0000003oool0oooo03<0oooo0P00000O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000130?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000f
0?ooo`H00000=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000130?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103o
ool2000000<0oooo0P0000120?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3o
ool2000001<0oooo0P0000030?ooo`@000002@3oool300000080oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo0440oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03o
ool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001d0oooo00<000000?ooo`3oool0@@3oool00`000000o`000?l000030?l000030000003oool0
oooo03@0oooo00<000000?ooo`3oool0:03ooomf000001@0oooo0P0000050?ooo`8000000P3oool2
00000480oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`8000007`3oool0
0`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
0440oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool04@3oool001d0oooo0P0000120?ooo`L00000=@3oool200000;l0
oooo0P0000120?ooo`L00000=@3oool2000001l0oooo00<000000?ooo`3oool0@03oool7000003H0
oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0140oooo000M0?oooh800000_`3ooon2000001l0ooooP@00
000C0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00>03oool500000080oooo0P00
00040?ooo`8000004P3oool2000001D0oooo1@0000020?ooo`800000103oool2000000l0oooo1000
00030?ooo`800000103oool2000003X0oooo1@0000020?ooo`800000103oool2000001@0oooo0P00
000F0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool2000000@0oooo0P00
003o0?oooeD0oooo000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000005P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000k0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oo
oe@0oooo000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000k
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003o0?oooe@0oooo
000b0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0a0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`3O0?ooo`D000000P3oool2000000@0oooo0P00000A0?ooo`8000004`3oool5
00000080oooo0P0000040?ooo`8000003@3oool4000000<0oooo0P0000040?ooo`8000004P3oool0
03X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000440oooo1@000002
0?ooo`800000103oool200000100oooo0P00000C0?ooo`D000000P3oool2000000@0oooo0P00000=
0?ooo`@000000`3oool2000000@0oooo0P0000130?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
0000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000A0?ooo`00>@3oool2000000@0oooo0P0000040?ooo`8000004P3o
ool2000001H0oooo0P0000040?ooo`800000103oool200000100oooo0P0000040?ooo`800000103o
ool2000003/0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000G0?ooo`800000103o
ool2000000@0oooo0P00000@0?ooo`800000103oool2000000@0oooo0P0000140?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000120?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000A0?ooo`00o`3ooon40?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`@00000103oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`00o`3oooml0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`100?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000A0?ooo`00o`3o
oon40?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000110?oo
o`800000103oool2000000@0oooo0P00000A0?ooo`800000503oool2000000@0oooo0P0000040?oo
o`8000003P3oool2000000@0oooo0P0000040?ooo`8000004P3oool00?l0ooooP`3oool2000000@0
oooo0P0000040?ooo`800000403oool2000001@0oooo0P0000040?ooo`800000103oool2000000h0
oooo0P0000040?ooo`800000103oool200000;<0oooo000J0?ooo`8000000`3ooomn000001/0oooo
0P0000040?oooh400000o`3ooomE0?ooo`006@3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`80
0000103oool200000?l0ooooE03oool001T0oooo00@000000?ooo`3oool000000P3ooomn000001X0
oooo00@000000?ooo`3oool000000`3ooon100000?l0ooooE@3oool001T0oooo00@000000?ooo`3o
ool000000P3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08`3oool2000000@0ooooMP00000U0?ooo`8000000`3ooomf000001<0oooo000I0?oo
o`040000003oool0oooo00000080oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0603oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`006P3oool2000000<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool06@3oool2000000@0oooo
00<000000?ooo`3oool00`3oool7000000D0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000L000001@3oool00`000000o`000?l000030?l000030000003oool0oooo00<0oooo
00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooogH00000903oool010000000
oooo0?ooo`0000020?ooogH000004`3oool001l0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool01000
0000oooo0?ooo`0000020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003oool0oooo0140oooo000O0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003oool0oooo
01l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000030?l000030000003oool0oooo
00<0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`020?ooo`800000903oool0
10000000oooo0?ooo`0000020?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003oool0oooo0140oooo000O0?ooo`L000001@3oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`030?ooo`L000001@3oool00`000000o`000?l000030?l000030000003oool0
oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000030?l000030000003oool0
oooo00<0oooo00<000000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool2
000000<0oooo00<000000?l0003o00000`3o000A000000D0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000L00000103o00000`000000oooo0?ooo`030?ooo``000004`3oool0
01l0oooo00<000000?ooo`3oool02@3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0?0?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`001`00000;0?ooo`L000001@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0080oooo1`0000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000L00000103o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`005`0000040?ooo`800000:P3oool00`000000o`000?l000030?l000030000003oool0oooo
00d0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo
00h0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool02@3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool00`000000
o`000?l000030?l000030000003oool0oooo00d0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000
o`000?l000020?l000030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool001l0oooo
0P00000:0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0603oool2000002X0oooo
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0=0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo
00<000000?l0003o00000P3o00000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo
000I0?ooo`@000000P3oool00`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo00l0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0203oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P00
00030?ooo`L000003`3oool7000000D0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?oo
o`030?ooo`H00000403oool00`000000oooo0?ooo`0A0?ooo`006@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool03`3oool00`000000o`000?l00003
0?l000030000003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool7000000D0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`001`000005
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool4000000<0oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003o0000o`000080o`001`000005
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0H
0?ooo`800000603oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool06@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`006P3oool00`000000oooo0?ooo`02
0?ooo`8000002P3oool7000000D0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0?
0?ooo`L000008@3oool00`000000oooo0?ooo`0E0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo01/0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0203oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P00000J0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000oooo0?ooo`0H0?ooo`8000004`3oool001/0oooo00D000000?ooo`3oool0oooo0000
000A0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo01P0oooo0P00000J0?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`030000
003oool0oooo01T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool001T0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
203oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool2000001X0oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo01T0oooo00<000000?ooo`3o
ool04@3oool001X0oooo0P0000030?ooo`800000403oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0503oool200000240oooo00<000000?ooo`3oool0
5@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo01P0oooo0P00000I0?ooo`80
00002P3oool300000080oooo00<000000?ooo`3oool06@3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`00
7`3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo0P0000040?ooo`030000
003oool0oooo01D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`800000
2P3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0X0?ooo`800000
6P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0E0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000
003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0H0?ooo`800000
:P3oool00`000000oooo0?ooo`0I0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo000O0?ooo`800000403o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000L000001@3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0503oool2000001d0oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`L000001@3o0008000000D0o`0000<000000?ooo`3oool00`3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0007000001d0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo
0P00000J0?ooo`L00000103o0007000000@0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000020?l000030000003o0000o`0000<0o`001P00000K0?ooo`030000003oool0oooo0140oooo
000O0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool2000000@0oooo00<0
00000?ooo`3oool06`3oool00`000000o`000?l000030?l000030000003oool0oooo00@0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0oooo0240oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool00`3oool<000000D0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0603oool2000002X0oooo00<0
00000?ooo`3oool07`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo000O
0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`04
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`000000o`000?l00002
0?l000030000003oool0oooo01@0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S
0?ooo`8000000`3oool200000200oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A
0?ooo`007`3oool200000100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo01@0oooo0P00000K0?ooo`<000000`3oool00`000000oooo0?ooo`0K0?oo
o`L000001P3oool7000000D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l0
00L000008`3oool00`000000oooo0?ooo`0S0?ooo`800000103oool00`000000oooo0?ooo`080?oo
o`030000003o0000o`000080o`0000<000000?ooo`3oool0503oool00`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0H0?oo
o`800000903oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`006`3oool3000000030?ooo`000000oooo
0100oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`080?ooo`030000003o0000
o`000080o`0000<000000?ooo`3oool0503oool00`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00P00000P0?ooo`030000003o0000o`000080o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo01d0oooo0P00000C
0?ooo`00703oool010000000oooo0?ooo`00000A0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0=03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000o`000?l000020?l000030000003oool0oooo01@0oooo300000040?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o0007000001X0oooo0P00000U0?ooo`8000000`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool00`3o
ool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool04@3o
ool001T0oooo1@0000000`3oool000000000000@0?ooo`030000003o0000o`0000<0o`001`000005
0?l000L000001@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`001`00000F
0?ooo`8000008@3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o0000103o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo0P000004
0?ooo`030000003oool0oooo00P0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0O
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`800000803oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo000I0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool00`000000o`000?l00003
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`09
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000o`000?l00002
0?l000030000003oool0oooo01l0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`000080o`0000<000000?ooo`3oool07P3oool2000002D0oooo0`000002
0?ooo`030000003oool0oooo01l0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A
0?ooo`006P3oool00`000000oooo000000020?ooo`030000003oool0oooo00l0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?oo
o`3oool02@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000040?l000030000003oool0oooo02L0oooo00<000000?oo
o`3oool08`3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000o`000?l000020?l0
00030000003oool0oooo01l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0X0?oo
o`800000803oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0
003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo000K0?ooo`80
00000P3oool200000100oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool06P3oool200000240oooo00<000000?ooo`3o
ool0=03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo1P00000Q0?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003oool0oooo01h0oooo0P00000Z0?ooo`030000003oool0oooo01l0oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`030000
003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l000030000
003oool0oooo00T0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02P0oooo0P00000P0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0
0`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4@3oool001l0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o
ool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`090?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0=03oool7000000D0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool07P3o
ool2000001X0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000030?ooo`800000803o
ool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o
0007000000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000`00000803o
ool00`000000oooo0?ooo`0A0?ooo`007`3oool200000100oooo1`0000050?ooo`L000002`3oool0
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000L00000703oool200000240oooo00<000000?ooo`3oool0>P3oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000040?l000030000003oool0oooo02L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003oool0oooo01l0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07`3o
ool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o
00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3o
ool001l0oooo00<000000?ooo`3oool0;@3oool00`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`001`0000040?l000030000003oool0oooo01h0oooo0P00000J0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P00000P0?ooo`030000003o0000o`000080o`0000<00000
0?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0:03oool2000001<0oooo000O0?ooo`030000003oool0oooo02d0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0>P3oool7000000D0o`0000<000000?l0003o00000`3o0008000002T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool07`3oool00`000000o`000?l00002
0?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`03
0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001l0oooo0P00000^0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0803oool200000240oooo00<000000?oo
o`3oool0@03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo0000000a0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool0
0`000000o`000?l000020?l000030000003oool0oooo01h0oooo0P00000H0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00P3oool200000200oooo1P0000050?ooo`030000003o
0000o`000080o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0140oooo000I0?ooo`<000000`3oool00`000000oooo0?ooo`0]0?ooo`030000003o0000
o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`D000000P3oool2
000000@0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00L0oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0F0?ooo`@000002@3oool300000080oooo00<000000?ooo`3oool0:P3oool0
0`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0A0?ooo`006@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02d0oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
@P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003oool0oooo01h0oooo0P00000Z0?ooo`80
0000:`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0A0?ooo`006@3oool010000000oooo0?ooo`0000020?ooo`80
0000;P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0200oooo0P00000F0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000480oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02h0oooo00<00000
0?ooo`3oool05P3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<00000
0?l0003o00000P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<00000
0?ooo`3oool04@3oool001T0oooo0`0000030?ooo`030000003oool0oooo02d0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0X0?ooo`800000:`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`006P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02d0oooo00<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000@P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool07P3oool2000002X0oooo00<000000?ooo`3oool0:P3oool00`000000o`00
0?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0A0?ooo`006P3oool300000080oooo0P00000^0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0803oool2000001D0oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`100?ooo`030000003o0000o`0000<0o`001`00000`0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0;`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo00<0oooo00<0
00000?l0003o00000P3o00000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo1@00
00020?ooo`8000000`3oool2000002/0oooo00<000000?l0003o00000P3o00000`000000oooo0?oo
o`030?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool001l0oooo00<00000
0?ooo`3oool0;@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo0240oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<00000
0?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`H00000803oool200000200oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002`0oooo00<000000?l0003o0000
0P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4@3oool001l0oooo00<000000?ooo`3oool0;@3oool00`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`100?ooo`030000003o
0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02l0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000
:`3oool6000000D0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000L00000
:P3oool2000001<0oooo000O0?ooo`800000;P3oool7000000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
000700000280oooo0P00000Q0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0oooo1@0000020?ooo`800000103o
ool00`000000oooo0?ooo`0_0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0:@3o
ool200000200oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003L0
oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02l0
oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0<`3oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000<@3oool00`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003oool0oooo
02X0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P00000f0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000003oool0oooo
03<0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`00
00<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<000000?l0003o00000P3o
0007000000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0Y0?ooo`8000007`3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo03D0oooo00<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3o
ool001l0oooo0P00000d0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0V0?ooo`8000008@3oool00`000000oooo0?ooo`100?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<000000?l0003o0000
0P3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo0P00000f0?ooo`030000
003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0140oooo000J0?ooo`8000000`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003o
ool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`030000003o0000o`000080o`0000<000000?ooo`3o
ool00`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0:@3oool2000002X0oooo00<000000?ooo`3oool0=@3oool00`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00
6@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03<0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02L0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0M0?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool0;`3oool00`000000o`000?l000020?l000030000003oool0oooo00<0oooo00<000000?l0003o
00000P3o00000`000000o`000?l000030?l000030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:03oool2000003H0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001T0oooo00@000000?ooo`3oool0
00000P3oool2000003@0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo02H0oooo0P00000Q0?ooo`030000003oool0oooo0400oooo00<000000?l0003o
00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;`3oool6000000D0oooo00<000000?l0003o00000P3o0007000002/0oooo0P00000B0?ooo`D0
000000<0oooo0000000000000P0000030?ooo`800000103oool2000000<0oooo00<000000?ooo`3o
ool0=@3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0A0?ooo`006P3oool2000000<0oooo00<000000?ooo`3oool0
<`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
>P3oool00`000000o`000?l000020?l000030000003oool0oooo0300oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000000P3oool20000
03H0oooo1P0000050?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001T0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0c0?ooo`030000003o0000o`00
0080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`00
0080o`0000<000000?ooo`3oool0;`3oool2000001@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000>`3oool00`000000o`000?l000030?l0
00030000003oool0oooo02h0oooo0P00000C0?ooo`006P3oool2000000<0oooo0P00000d0?ooo`03
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0V0?ooo`80
00008@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o
00000P3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00
7`3oool00`000000oooo0?ooo`0c0?ooo`030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo1@0000020?ooo`800000
103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0@0?ooo`D0000000<0oooo0000000000000P0000030?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000
003oool0oooo02l0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000k0?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo
0?ooo`0c0?ooo`030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000@P3oool00`000000o`000?l000030?l000030000003oool0oooo
03@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`00
00020?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000003oool0oooo03<0oooo00<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000@P3o
ool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo
0000000l0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0;`3oool2000002X0oooo
0P00000k0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0A0?ooo`007`3oool2000003@0oooo00<000000?l0003o00000P3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo02H0oooo0P00000F0?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`800000103oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`000080o`0000<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03X0oooo00<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000O
0?ooo`030000003oool0oooo03<0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l00003
0?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03X0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0_0?ooo`800000:P3o
ool2000003/0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0140oooo000O0?ooo`030000003oool0oooo03<0oooo00<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool2
000000@0oooo0`0000030?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`8000002P3oool3
000000<0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003oool0
oooo0300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0j0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`007`3oool20000
03@0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02H0oooo0P00000Q0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`00
0000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000N0?ooo`D000000P3oool20000
00<0oooo0P00000k0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0A0?ooo`004`3oool500000080oooo0P0000030?ooo`030000003oool0oooo03<0
oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo02L0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03X0
oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003`0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000e0?ooo`030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
0000o`000080o`0000<000000?ooo`3oool0;`3oool200000200oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`02000003/0oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0^0?ooo`8000004`3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00800000=03oool6000000D0o`0000<000000?l0003o00000`3o000=000002P0oooo0P00
000Q0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l0
00020?l000030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`020?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000>P3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01`0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0j0?ooo`030000
003o0000o`000080o`0000<000000?ooo`3oool0;`3oool200000200oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`800000>`3oool00`000000o`000?l000030?l000030000
003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000003X0oooo00<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000003`0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01d0oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00503oool20000
00@0oooo0P0000030?ooo`800000>@3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0<P3oool200000240oooo00<000000?ooo`3oool0@03oool00`00
0000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000o`000?l00002
0?l000030000003oool0oooo02l0oooo0P00000Z0?ooo`800000>`3oool00`000000o`000?l00003
0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?oo
o`3oool0>03oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l0
00030000003oool0oooo0300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0j0?oo
o`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?oo
o`007`3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0>P3oool00`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000Z0?ooo`80
0000>`3oool00`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<000000?ooo`3o
ool04@3oool001l0oooo0P00000i0?ooo`L000001@3o00000`000000oooo0?ooo`0b0?ooo`800000
8@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0M0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0
>P3oool00`000000o`000?l000020?l000030000003oool0oooo0300oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003o
ool0oooo02l0oooo0P00000B0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`800000103o
ool2000000<0oooo0P00000k0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`030000003o0000
o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l000020?l000030000003oool0
oooo0300oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
0000o`0000<0o`0000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`007`3oool2
000003l0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0b0?ooo`800000503oool4
000000<0oooo0P0000040?ooo`030000003oool0oooo0400oooo00<000000?l0003o00000`3o0000
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool0
0`000000o`000?l000020?l000030000003oool0oooo02l0oooo0P00000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000003/0oooo00<00000
0?l0003o00000`3o00000`000000oooo0?ooo`0^0?ooo`8000004`3oool001<0oooo1@0000000`3o
ool000000000000200000080oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l000030?l0
00030000003oool0oooo03<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l00003
0?l000030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0j
0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<00000
0?ooo`3oool0>P3oool00`000000o`000?l000030?l000030000003oool0oooo02l0oooo00<00000
0?ooo`3oool04@3oool001D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo03h0oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0400oooo00<000000?l0003o00000`3o00000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0>P3oool600000340oooo0P00000D0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
0P00000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool700000100oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo
000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000003l0oooo1`00
000d0?ooo`8000005P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000120?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0140oooo0P0000030?ooo`@000002@3oool300000080
ooooMP00000C0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0@03oool00`000000o`000?l000030?l000030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0:@3ooomf00000;<0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`1n000001D0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`10
0?ooo`L00000=P3oool00`000000oooo0?ooo`3o0?oooe<0oooo000D0?ooo`800000103oool20000
0:80oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3o0?oooe<0oooo002n0?oooh40
0000o`3ooomE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0
oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 553.25}, {448.313, 39.5625}} -> {-0.311283, \
0.237885, 0.00638008, 0.00638008}, {{39, 155.625}, {438.563, 366.438}} -> \
{-466.663, 4.96664, 3.59328, 0.232562}, {{167.313, 283.938}, {438.563, \
366.438}} -> {-927.832, 6.86398, 3.26316, 0.277194}, {{295.625, 412.25}, \
{438.563, 366.438}} -> {-1619.32, 5.70122, 3.59328, 0.261632}, {{423.938, \
540.563}, {438.563, 366.438}} -> {-2195.65, 5.70122, 3.59328, 0.261632}, \
{{39, 155.625}, {359.25, 287.188}} -> {-404.839, -14.7401, 3.2663, 0.198187}, \
{{167.313, 283.938}, {359.25, 287.188}} -> {-928.723, -14.7401, 3.2663, \
0.198187}, {{295.625, 412.25}, {359.25, 287.188}} -> {-1452.61, -14.7401, \
3.2663, 0.198187}, {{423.938, 540.563}, {359.25, 287.188}} -> {-2195.65, \
-19.2106, 3.59328, 0.247096}, {{39, 155.625}, {279.938, 207.875}} -> \
{-404.839, -34.3884, 3.2663, 0.198187}, {{167.313, 283.938}, {279.938, \
207.875}} -> {-928.723, -48.1438, 3.2663, 0.277461}, {{295.625, 412.25}, \
{279.938, 207.875}} -> {-1619.32, -46.1652, 3.59328, 0.261632}, {{423.938, \
540.563}, {279.938, 207.875}} -> {-2195.65, -41.1369, 3.59328, 0.232562}, \
{{39, 155.625}, {200.625, 128.563}} -> {-404.839, -46.8319, 3.2663, \
0.171762}, {{167.313, 283.938}, {200.625, 128.563}} -> {-1042.99, -72.1035, \
3.59328, 0.261632}, {{295.625, 412.25}, {200.625, 128.563}} -> {-1452.61, \
-54.0368, 3.2663, 0.198187}, {{423.938, 540.563}, {200.625, 128.563}} -> \
{-1976.49, -82.8564, 3.2663, 0.303886}, {{39, 155.625}, {121.375, 49.25}} -> \
{-418.116, -60.8629, 3.37412, 0.163783}, {{167.313, 283.938}, {121.375, \
49.25}} -> {-927.832, -103.039, 3.26316, 0.277194}, {{295.625, 412.25}, \
{121.375, 49.25}} -> {-1619.32, -92.6927, 3.59328, 0.247096}, {{423.938, \
540.563}, {121.375, 49.25}} -> {-2195.65, -98.0317, 3.59328, 0.261632}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plots2\  = \ 
        Map[Histogram[#[\([2]\)], \ Frame \[Rule] True, \ 
              HistogramRange \[Rule] {\(-200\), \ 200}, \ 
              HistogramCategories \[Rule] 20, \ 
              DisplayFunction \[Rule] Identity, \ 
              BarStyle \[Rule] {RGBColor[0, 1, 0]}] &, \ 
          rbeats];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[plots2, \ 4]], \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0184794 0.238095 [
[ 0 0 0 0 ]
[ 1 .77614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .77614 L
0 .77614 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0184794 0.245293 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0515 L
.09524 .0515 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0515 L
.14286 .0515 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .0515 L
.2381 .0515 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0515 L
.2381 .0515 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .3458 L
.38095 .3458 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .3458 L
.38095 .3458 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .41938 L
.42857 .41938 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .41938 L
.42857 .41938 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .56653 L
.52381 .56653 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56653 L
.52381 .56653 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16187 L
.66667 .16187 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .27223 L
.71429 .27223 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .27223 L
.71429 .27223 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0184794 0.488926 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .32864 L
.33333 .32864 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .32864 L
.33333 .32864 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .36788 L
.38095 .36788 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .36788 L
.38095 .36788 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .40712 L
.42857 .40712 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .40712 L
.42857 .40712 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56408 L
.52381 .56408 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .44636 L
.61905 .44636 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .44636 L
.61905 .44636 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0932 L
.71429 .0932 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05396 L
.80952 .05396 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0932 L
.85714 .0932 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0184794 0.732558 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04274 L
.09524 .04274 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04274 L
.09524 .04274 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07077 L
.14286 .07077 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .15486 L
.19048 .15486 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .15486 L
.19048 .15486 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .0988 L
.2381 .0988 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0988 L
.2381 .0988 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .04274 L
.28571 .04274 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .04274 L
.28571 .04274 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .15486 L
.33333 .15486 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .15486 L
.33333 .15486 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .18289 L
.38095 .18289 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .18289 L
.38095 .18289 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .21092 L
.42857 .21092 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .21092 L
.42857 .21092 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .43515 L
.52381 .43515 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .43515 L
.52381 .43515 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .40712 L
.57143 .40712 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .18289 L
.61905 .18289 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .18289 L
.61905 .18289 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .26697 L
.66667 .26697 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .26697 L
.66667 .26697 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .07077 L
.7619 .07077 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07077 L
.7619 .07077 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04274 L
.80952 .04274 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .04274 L
1 .04274 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04274 L
1 .04274 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0184794 0.97619 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .04415 L
.04762 .04415 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04415 L
.04762 .04415 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04415 L
.09524 .04415 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04415 L
.09524 .04415 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13244 L
.2381 .13244 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .1913 L
.28571 .1913 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .1913 L
.28571 .1913 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .27959 L
.42857 .27959 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .27959 L
.42857 .27959 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .39731 L
.57143 .39731 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .39731 L
.57143 .39731 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .27959 L
.61905 .27959 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .27959 L
.61905 .27959 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .07358 L
.66667 .07358 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .07358 L
.66667 .07358 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .1913 L
.71429 .1913 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .07358 L
.7619 .07358 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07358 L
.7619 .07358 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .10301 L
.80952 .10301 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .10301 L
.80952 .10301 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .04415 L
.90476 .04415 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04415 L
.90476 .04415 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.169052 0.245293 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .15321 L
.19048 .15321 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .15321 L
.19048 .15321 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .25708 L
.28571 .25708 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .25708 L
.28571 .25708 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .15321 L
.33333 .15321 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .15321 L
.33333 .15321 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .29171 L
.38095 .29171 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .29171 L
.38095 .29171 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .32633 L
.42857 .32633 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32633 L
.42857 .32633 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .32633 L
.52381 .32633 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .32633 L
.52381 .32633 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .25708 L
.61905 .25708 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .25708 L
.61905 .25708 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .29171 L
.71429 .29171 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .29171 L
.71429 .29171 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .15321 L
.7619 .15321 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .15321 L
.7619 .15321 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.169052 0.488926 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .08396 L
.19048 .08396 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08396 L
.19048 .08396 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15321 L
.2381 .15321 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .18783 L
.28571 .18783 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .18783 L
.28571 .18783 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .11859 L
.33333 .11859 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .11859 L
.33333 .11859 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .32633 L
.38095 .32633 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .32633 L
.38095 .32633 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .29171 L
.42857 .29171 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29171 L
.42857 .29171 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .39558 L
.52381 .39558 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .39558 L
.52381 .39558 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .53407 L
.61905 .53407 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .53407 L
.61905 .53407 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .15321 L
.71429 .15321 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .15321 L
.71429 .15321 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.169052 0.732558 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0452772 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10527 -6 -4.5 ]
[-0.0125 .10527 0 4.5 ]
[-0.0125 .19582 -6 -4.5 ]
[-0.0125 .19582 0 4.5 ]
[-0.0125 .28638 -6 -4.5 ]
[-0.0125 .28638 0 4.5 ]
[-0.0125 .37693 -6 -4.5 ]
[-0.0125 .37693 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .55804 -12 -4.5 ]
[-0.0125 .55804 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10527 m
.00625 .10527 L
s
[(2)] -0.0125 .10527 1 0 Mshowa
0 .19582 m
.00625 .19582 L
s
[(4)] -0.0125 .19582 1 0 Mshowa
0 .28638 m
.00625 .28638 L
s
[(6)] -0.0125 .28638 1 0 Mshowa
0 .37693 m
.00625 .37693 L
s
[(8)] -0.0125 .37693 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(10)] -0.0125 .46749 1 0 Mshowa
0 .55804 m
.00625 .55804 L
s
[(12)] -0.0125 .55804 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .12791 m
.00375 .12791 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .21846 m
.00375 .21846 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .58068 m
.00375 .58068 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10527 m
1 .10527 L
s
.99375 .19582 m
1 .19582 L
s
.99375 .28638 m
1 .28638 L
s
.99375 .37693 m
1 .37693 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .55804 m
1 .55804 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .58068 m
1 .58068 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05999 L
.09524 .05999 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05999 L
.09524 .05999 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .05999 L
.14286 .05999 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05999 L
.14286 .05999 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .15055 L
.19048 .15055 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .15055 L
.19048 .15055 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .15055 L
.2381 .15055 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .15055 L
.2381 .15055 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .33166 L
.28571 .33166 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .33166 L
.28571 .33166 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .28638 L
.33333 .28638 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .28638 L
.33333 .28638 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .33166 L
.38095 .33166 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .33166 L
.38095 .33166 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .28638 L
.42857 .28638 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .28638 L
.42857 .28638 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .51276 L
.57143 .51276 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .51276 L
.57143 .51276 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .46749 L
.61905 .46749 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .46749 L
.61905 .46749 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .51276 L
.66667 .51276 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .51276 L
.66667 .51276 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .28638 L
.71429 .28638 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .28638 L
.71429 .28638 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .15055 L
.7619 .15055 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .15055 L
.7619 .15055 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .10527 L
.90476 .10527 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .10527 L
.90476 .10527 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.169052 0.97619 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .2894 L
.33333 .2894 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .2894 L
.33333 .2894 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .21092 L
.38095 .21092 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .56408 L
.57143 .56408 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .56408 L
.57143 .56408 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .36788 L
.61905 .36788 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .36788 L
.61905 .36788 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .2894 L
.66667 .2894 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .17168 L
.71429 .17168 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .17168 L
.71429 .17168 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0932 L
.7619 .0932 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.319626 0.245293 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .16187 L
.14286 .16187 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .16187 L
.14286 .16187 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .0515 L
.2381 .0515 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0515 L
.2381 .0515 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .27223 L
.28571 .27223 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .27223 L
.28571 .27223 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .30902 L
.38095 .30902 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .30902 L
.38095 .30902 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .27223 L
.61905 .27223 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .27223 L
.61905 .27223 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .23544 L
.66667 .23544 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .23544 L
.66667 .23544 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .30902 L
.71429 .30902 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .30902 L
.71429 .30902 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .16187 L
.7619 .16187 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .16187 L
.7619 .16187 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.319626 0.488926 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .05396 L
.14286 .05396 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .13244 L
.19048 .13244 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0932 L
.2381 .0932 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17168 L
.28571 .17168 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .36788 L
.33333 .36788 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .36788 L
.33333 .36788 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .2894 L
.38095 .2894 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .2894 L
.38095 .2894 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .36788 L
.42857 .36788 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .40712 L
.47619 .40712 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .52484 L
.57143 .52484 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .52484 L
.57143 .52484 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .40712 L
.66667 .40712 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .40712 L
.66667 .40712 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13244 L
.7619 .13244 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.319626 0.732558 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04569 L
.09524 .04569 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04569 L
.09524 .04569 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .16961 L
.33333 .16961 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16961 L
.33333 .16961 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .23157 L
.38095 .23157 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .23157 L
.38095 .23157 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .32451 L
.42857 .32451 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32451 L
.42857 .32451 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .44842 L
.52381 .44842 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .44842 L
.52381 .44842 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .44842 L
.57143 .44842 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .44842 L
.57143 .44842 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .35549 L
.61905 .35549 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35549 L
.61905 .35549 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .07667 L
.66667 .07667 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .07667 L
.66667 .07667 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .13863 L
.7619 .13863 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .13863 L
.7619 .13863 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .07667 L
.85714 .07667 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .07667 L
.85714 .07667 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .04569 L
.90476 .04569 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04569 L
.90476 .04569 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.319626 0.97619 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0420431 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -6 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -6 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -6 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(2)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(4)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(6)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(8)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(10)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(12)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(14)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .11982 m
.00375 .11982 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .20391 m
.00375 .20391 L
s
0 .22493 m
.00375 .22493 L
s
0 .24595 m
.00375 .24595 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .33004 m
.00375 .33004 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .54025 m
.00375 .54025 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .11982 m
1 .11982 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .22493 m
1 .22493 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33004 m
1 .33004 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05676 L
.09524 .05676 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05676 L
.09524 .05676 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .14084 L
.14286 .14084 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .14084 L
.14286 .14084 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .0988 L
.19048 .0988 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0988 L
.19048 .0988 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .14084 L
.28571 .14084 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .14084 L
.28571 .14084 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .26697 L
.33333 .26697 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .26697 L
.33333 .26697 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .22493 L
.38095 .22493 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .22493 L
.38095 .22493 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .47719 L
.52381 .47719 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .47719 L
.52381 .47719 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .56128 L
.57143 .56128 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .56128 L
.57143 .56128 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .43515 L
.66667 .43515 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .43515 L
.66667 .43515 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .22493 L
.71429 .22493 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .22493 L
.71429 .22493 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .05676 L
.80952 .05676 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05676 L
.80952 .05676 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .05676 L
.90476 .05676 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .05676 L
.90476 .05676 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.470199 0.245293 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .10765 L
.14286 .10765 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .10765 L
.14286 .10765 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .07667 L
.2381 .07667 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .07667 L
.2381 .07667 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .13863 L
.28571 .13863 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .13863 L
.28571 .13863 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .10765 L
.33333 .10765 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .10765 L
.33333 .10765 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .38646 L
.38095 .38646 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .38646 L
.38095 .38646 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .29353 L
.42857 .29353 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29353 L
.42857 .29353 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .44842 L
.47619 .44842 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .44842 L
.47619 .44842 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .26255 L
.52381 .26255 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .32451 L
.61905 .32451 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .32451 L
.61905 .32451 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .13863 L
.66667 .13863 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13863 L
.66667 .13863 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .23157 L
.71429 .23157 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .23157 L
.71429 .23157 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .04569 L
.7619 .04569 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04569 L
.7619 .04569 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04569 L
.85714 .04569 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .04569 L
1 .04569 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04569 L
1 .04569 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.470199 0.488926 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0267547 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -6 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(5)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(10)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(15)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(20)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04147 L
.09524 .04147 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04147 L
.09524 .04147 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .09498 L
.14286 .09498 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .09498 L
.14286 .09498 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .04147 L
.19048 .04147 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04147 L
.19048 .04147 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .06822 L
.2381 .06822 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .06822 L
.2381 .06822 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .17524 L
.28571 .17524 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .17524 L
.28571 .17524 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .14849 L
.33333 .14849 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .14849 L
.33333 .14849 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .12173 L
.38095 .12173 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12173 L
.38095 .12173 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .30902 L
.47619 .30902 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .25551 L
.57143 .25551 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .25551 L
.57143 .25551 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .28226 L
.61905 .28226 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .28226 L
.61905 .28226 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .17524 L
.66667 .17524 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .17524 L
.66667 .17524 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .14849 L
.7619 .14849 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14849 L
.7619 .14849 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .04147 L
.80952 .04147 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04147 L
.80952 .04147 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .04147 L
.90476 .04147 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.470199 0.732558 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .0515 L
.19048 .0515 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .0515 L
.28571 .0515 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0515 L
.28571 .0515 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .30902 L
.33333 .30902 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .30902 L
.33333 .30902 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .23544 L
.38095 .23544 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .23544 L
.38095 .23544 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .41938 L
.57143 .41938 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41938 L
.57143 .41938 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .19865 L
.61905 .19865 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .19865 L
.61905 .19865 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .16187 L
.71429 .16187 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .16187 L
.71429 .16187 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .16187 L
.7619 .16187 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .16187 L
.7619 .16187 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .0515 L
.85714 .0515 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0515 L
.85714 .0515 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.470199 0.97619 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .12508 L
.14286 .12508 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .08829 L
.19048 .08829 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .08829 L
.19048 .08829 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .12508 L
.33333 .12508 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12508 L
.33333 .12508 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .49296 L
.42857 .49296 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .49296 L
.42857 .49296 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .56653 L
.47619 .56653 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .56653 L
.47619 .56653 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .41938 L
.52381 .41938 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .41938 L
.52381 .41938 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .45617 L
.57143 .45617 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .45617 L
.57143 .45617 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .60332 L
.61905 .60332 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .3458 L
.66667 .3458 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .3458 L
.66667 .3458 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.71429 .01472 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0515 L
.7619 .0515 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0515 L
.7619 .0515 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .0515 L
.95238 .0515 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0515 L
.95238 .0515 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.620772 0.245293 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .01472 L
.19048 .01472 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .01472 L
.28571 .01472 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .25016 L
.33333 .25016 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .25016 L
.33333 .25016 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .44636 L
.38095 .44636 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .44636 L
.38095 .44636 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .32864 L
.57143 .32864 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .32864 L
.57143 .32864 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .40712 L
.61905 .40712 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .44636 L
.66667 .44636 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .44636 L
.66667 .44636 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.620772 0.488926 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0420431 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -6 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -6 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -6 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(2)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(4)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(6)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(8)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(10)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(12)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(14)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .11982 m
.00375 .11982 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .20391 m
.00375 .20391 L
s
0 .22493 m
.00375 .22493 L
s
0 .24595 m
.00375 .24595 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .33004 m
.00375 .33004 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .54025 m
.00375 .54025 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .11982 m
1 .11982 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .22493 m
1 .22493 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33004 m
1 .33004 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .05676 L
.04762 .05676 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05676 L
.04762 .05676 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .0988 L
.14286 .0988 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0988 L
.14286 .0988 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .14084 L
.19048 .14084 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .14084 L
.19048 .14084 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .22493 L
.2381 .22493 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .22493 L
.2381 .22493 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .22493 L
.28571 .22493 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .22493 L
.28571 .22493 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .14084 L
.33333 .14084 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .14084 L
.33333 .14084 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .51923 L
.38095 .51923 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .51923 L
.38095 .51923 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .35106 L
.42857 .35106 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .56128 L
.47619 .56128 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .56128 L
.47619 .56128 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .56128 L
.52381 .56128 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56128 L
.52381 .56128 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .35106 L
.61905 .35106 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .0988 L
.66667 .0988 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .0988 L
.66667 .0988 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .22493 L
.71429 .22493 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .22493 L
.71429 .22493 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .05676 L
.7619 .05676 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05676 L
.7619 .05676 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .22493 L
.80952 .22493 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .22493 L
.80952 .22493 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .05676 L
.95238 .05676 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05676 L
.95238 .05676 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .0988 L
1 .0988 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0988 L
1 .0988 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.620772 0.732558 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0420431 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -6 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -6 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -6 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(2)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(4)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(6)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(8)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(10)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(12)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(14)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .11982 m
.00375 .11982 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .20391 m
.00375 .20391 L
s
0 .22493 m
.00375 .22493 L
s
0 .24595 m
.00375 .24595 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .33004 m
.00375 .33004 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .54025 m
.00375 .54025 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .11982 m
1 .11982 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .22493 m
1 .22493 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33004 m
1 .33004 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .14084 L
.09524 .14084 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .14084 L
.09524 .14084 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .14084 L
.14286 .14084 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .14084 L
.14286 .14084 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .18289 L
.19048 .18289 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .18289 L
.19048 .18289 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .0988 L
.2381 .0988 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .0988 L
.2381 .0988 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .05676 L
.28571 .05676 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .05676 L
.28571 .05676 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .35106 L
.38095 .35106 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .35106 L
.38095 .35106 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .47719 L
.42857 .47719 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .47719 L
.42857 .47719 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .43515 L
.47619 .43515 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .43515 L
.47619 .43515 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .35106 L
.52381 .35106 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .35106 L
.52381 .35106 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .35106 L
.66667 .35106 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .35106 L
.66667 .35106 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .3931 L
.71429 .3931 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .3931 L
.71429 .3931 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .14084 L
.7619 .14084 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .14084 L
.7619 .14084 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .05676 L
.80952 .05676 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .05676 L
.80952 .05676 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .05676 L
.85714 .05676 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05676 L
.85714 .05676 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .0988 L
.95238 .0988 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0988 L
.95238 .0988 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.620772 0.97619 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0255915 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14267 -6 -4.5 ]
[-0.0125 .14267 0 4.5 ]
[-0.0125 .27063 -12 -4.5 ]
[-0.0125 .27063 0 4.5 ]
[-0.0125 .39859 -12 -4.5 ]
[-0.0125 .39859 0 4.5 ]
[-0.0125 .52654 -12 -4.5 ]
[-0.0125 .52654 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14267 m
.00625 .14267 L
s
[(5)] -0.0125 .14267 1 0 Mshowa
0 .27063 m
.00625 .27063 L
s
[(10)] -0.0125 .27063 1 0 Mshowa
0 .39859 m
.00625 .39859 L
s
[(15)] -0.0125 .39859 1 0 Mshowa
0 .52654 m
.00625 .52654 L
s
[(20)] -0.0125 .52654 1 0 Mshowa
.125 Mabswid
0 .04031 m
.00375 .04031 L
s
0 .0659 m
.00375 .0659 L
s
0 .09149 m
.00375 .09149 L
s
0 .11708 m
.00375 .11708 L
s
0 .16826 m
.00375 .16826 L
s
0 .19386 m
.00375 .19386 L
s
0 .21945 m
.00375 .21945 L
s
0 .24504 m
.00375 .24504 L
s
0 .29622 m
.00375 .29622 L
s
0 .32181 m
.00375 .32181 L
s
0 .3474 m
.00375 .3474 L
s
0 .373 m
.00375 .373 L
s
0 .42418 m
.00375 .42418 L
s
0 .44977 m
.00375 .44977 L
s
0 .47536 m
.00375 .47536 L
s
0 .50095 m
.00375 .50095 L
s
0 .55214 m
.00375 .55214 L
s
0 .57773 m
.00375 .57773 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14267 m
1 .14267 L
s
.99375 .27063 m
1 .27063 L
s
.99375 .39859 m
1 .39859 L
s
.99375 .52654 m
1 .52654 L
s
.125 Mabswid
.99625 .04031 m
1 .04031 L
s
.99625 .0659 m
1 .0659 L
s
.99625 .09149 m
1 .09149 L
s
.99625 .11708 m
1 .11708 L
s
.99625 .16826 m
1 .16826 L
s
.99625 .19386 m
1 .19386 L
s
.99625 .21945 m
1 .21945 L
s
.99625 .24504 m
1 .24504 L
s
.99625 .29622 m
1 .29622 L
s
.99625 .32181 m
1 .32181 L
s
.99625 .3474 m
1 .3474 L
s
.99625 .373 m
1 .373 L
s
.99625 .42418 m
1 .42418 L
s
.99625 .44977 m
1 .44977 L
s
.99625 .47536 m
1 .47536 L
s
.99625 .50095 m
1 .50095 L
s
.99625 .55214 m
1 .55214 L
s
.99625 .57773 m
1 .57773 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 1 0 r
.04762 .01472 m
.04762 .04031 L
.09524 .04031 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04031 L
.09524 .04031 L
.09524 .01472 L
.04762 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .11708 L
.14286 .11708 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11708 L
.14286 .11708 L
.14286 .01472 L
.09524 .01472 L
s
0 1 0 r
.14286 .01472 m
.14286 .04031 L
.19048 .04031 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .04031 L
.19048 .04031 L
.19048 .01472 L
.14286 .01472 L
s
0 1 0 r
.19048 .01472 m
.19048 .04031 L
.2381 .04031 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .04031 L
.2381 .04031 L
.2381 .01472 L
.19048 .01472 L
s
0 1 0 r
.2381 .01472 m
.2381 .0659 L
.28571 .0659 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0659 L
.28571 .0659 L
.28571 .01472 L
.2381 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .09149 L
.33333 .09149 L
.33333 .01472 L
.28571 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .24504 L
.38095 .24504 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .24504 L
.38095 .24504 L
.38095 .01472 L
.33333 .01472 L
s
0 1 0 r
.38095 .01472 m
.38095 .29622 L
.42857 .29622 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29622 L
.42857 .29622 L
.42857 .01472 L
.38095 .01472 L
s
0 1 0 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 1 0 r
.47619 .01472 m
.47619 .39859 L
.52381 .39859 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .39859 L
.52381 .39859 L
.52381 .01472 L
.47619 .01472 L
s
0 1 0 r
.52381 .01472 m
.52381 .32181 L
.57143 .32181 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .32181 L
.57143 .32181 L
.57143 .01472 L
.52381 .01472 L
s
0 1 0 r
.57143 .01472 m
.57143 .14267 L
.61905 .14267 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .14267 L
.61905 .14267 L
.61905 .01472 L
.57143 .01472 L
s
0 1 0 r
.61905 .01472 m
.61905 .14267 L
.66667 .14267 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .14267 L
.66667 .14267 L
.66667 .01472 L
.61905 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .11708 L
.71429 .11708 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11708 L
.71429 .11708 L
.71429 .01472 L
.66667 .01472 L
s
0 1 0 r
.71429 .01472 m
.71429 .0659 L
.7619 .0659 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0659 L
.7619 .0659 L
.7619 .01472 L
.71429 .01472 L
s
0 1 0 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 1 0 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 1 0 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 1 0 r
.95238 .01472 m
.95238 .04031 L
1 .04031 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .04031 L
1 .04031 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.75, 512.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C000202000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00=L0oooo1@00
00020?ooo`800000103oool2000001@0oooo0P00000F0?ooo`D000000P3oool2000000@0oooo0P00
000?0?ooo`@000000`3oool2000000@0oooo0P00000i0?ooo`D000000P3oool2000000@0oooo0P00
000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`800000403oool4000000<0oooo0P00
00040?ooo`800000>@3oool500000080oooo0P0000040?ooo`8000004`3oool2000001@0oooo1@00
00020?ooo`800000103oool2000000l0oooo100000030?ooo`800000103oool2000001D0oooo003I
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0100oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`00f@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo
000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000503oool00400oooo1@0000020?ooo`800000103oool200000100oooo0P00000C
0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2000000@0oooo0P00000b
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0`0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0`0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0B0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000>@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000503o
ool00480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003P0oooo
0P0000040?ooo`800000103oool2000001@0oooo0P00000G0?ooo`800000103oool2000000@0oooo
0P00000@0?ooo`800000103oool2000000@0oooo0P00000j0?ooo`800000103oool2000000@0oooo
0P00000C0?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo
0P0000040?ooo`800000>P3oool2000000@0oooo0P0000040?ooo`8000004`3oool2000001D0oooo
0P0000040?ooo`800000103oool200000100oooo0P0000040?ooo`800000103oool2000001D0oooo
000j0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`3o0?oooo80oooo00120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00003o0?oooo@0oooo00110?ooo`800000103oool2000000@0oooo0P00000@0?oo
o`800000503oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo0P0000040?oo
o`800000o`3ooooe0?ooo`00^03oool2000000@0ooooP@00000I0?ooo`800000103ooon2000001/0
oooo0P0000030?ooogh000005@3oool00;L0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo002g0?ooo`040000003oool0oooo
000000<0ooooPP00000G0?ooo`040000003oool0oooo000000<0ooooPP00000J0?ooo`040000003o
ool0oooo00000080ooooOP00000E0?ooo`00]`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0:0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0603oool010000000oooo0?ooo`0000020?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool002<0oooo0P0000040?ooogH0
0000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04`3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0:0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool06@3oool2000000<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool010000000oooo0?ooo`00
00030?ooogH000007`3oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`800000103oool7000000D00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o00L000001@00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0=000000`0oooo1`00
000P0?ooo`d000002`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1`00
000:0?ooo`8000005@3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`030?ooo`L000002`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`07000000D00?l000<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0C0?ooo`008P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0603oool2000001l0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0C0?ooo`008`3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M
0?ooo`8000002P3oool7000000H00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00L000007@3oool200000200oooo0P00000F0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00H000001@00o`07000000D00?l000<00000
0?ooo`3oool0503oool2000001D0oooo000Y0?ooo`030000003oool0oooo0080oooo300000050?oo
o`L000001000o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo0P00000H0?oo
o`@000000`3oool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool03`3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo01D0oooo00<000000?oo
o`3oool04`3oool002T0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo0P00000I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o00L00000
1P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00P000001@00o`000`000000oooo0?ooo`030?ooo`L00000
4@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
0P3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003o
ool0oooo01T0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01D0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`040?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`800000403o
ool00`0000000?l0003o0004003o00L000001@3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l01`00000S0?ooo`800000803oool2000001H0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1`00000F0?ooo`8000005@3o
ool001H0oooo100000030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool06@3oool0
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0603oool2
000001P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0E0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o0003003o00030000003o
ool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`0300000000
o`000?l000@00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo0240oooo00<000000?ooo`3oool04`3oool001H0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3o
ool2000000@0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00@0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`0000000?l0003o0004003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0E0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01<0oooo000G0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00
000J0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0H0?ooo`8000007`3oool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0103oool00`0000000?l0003o0003003o00030000003oool0oooo01/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`0300000000o`000?l000@00?l000<0
00000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool00P3oool00`0000000?l0003o0003003o00030000003oool0oooo0240oooo00<0
00000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<00000
0?ooo`3oool06@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo1`000005
0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`04
0?ooo`L000007@3oool00`000000oooo0?ooo`0M0?ooo`800000403oool00`0000000?l0003o0004
003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02L0oooo0P00000P0?ooo`8000005P3oool7000000D00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool0803oool2000001D0oooo000F0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`H000001@00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l01`00000J0?ooo`8000007`3oool00`000000oooo0?ooo`0Q
0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo00l0oooo00<00000
003o0000o`001000o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo0P000003
0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01<0oooo000G0?ooo`8000002P3oool3000000<0oooo00<000000?oo
o`3oool07P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool08@3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool03`3oool00`0000000?l0003o0004003o00030000003oool0oooo00T0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01/0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo000Y
0?ooo`030000003oool0oooo01h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0H
0?ooo`<000000P3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00@00000
0?ooo`3oool0oooo0P00000@0?ooo`P000002`3oool7000000D00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool09`3o
ool2000001d0oooo00<000000?ooo`3oool00P00000L0?ooo`0300000000o`000?l000<00?l03@00
0005003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o
0003003o00030000003oool0oooo0200oooo0P00000E0?ooo`00:@3oool00`000000oooo0?ooo`0N
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o00030000003oool0oooo01h0oooo0P00000K0?ooo`050000003oool0oooo0?ooo`0000008`3o
ool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`8000000`3o
ool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool02@3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3oool04`3o
ool002T0oooo00<000000?ooo`3oool07P3oool00`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01H0oooo1@0000020?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool02@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool0
0`0000000?l0003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool0
02T0oooo00<000000?ooo`3oool07P3oool7000000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o00L000001000o`000`000000oooo0?ooo`0N0?ooo`800000603oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool3
000000<0oooo00<000000?ooo`3oool0:03oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool06@3oool300000080oooo00<000000?ooo`3oool06`3oool0
0`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo
02@0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0002003o00030000003oool0oooo
01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo000000030?ooo`030000003oool0oooo
0240oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
02P0oooo00<000000?ooo`3oool07@3oool2000002T0oooo1`000005003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00L000001@00o`000`00
0000oooo0?ooo`0W0?ooo`800000803oool2000001`0oooo1`00000;0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`L000008P3oool20000
01D0oooo000S0?ooo`800000103oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0N0?ooo`8000006P3oool2000000<0
oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0
oooo00<000000?ooo`3oool04`3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo02`0oooo00<000000?ooo`3oool04`3oool002D0oooo
00@000000?ooo`3oool0oooo0P00000U0?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000
o`000P00o`000`000000oooo0?ooo`0N0?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`03
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01d0oooo0P00000_0?ooo`L000001@00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo02L0oooo0P00000P0?ooo`030000003oool0oooo02d0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<000000?ooo`3o
ool04`3oool002<0oooo0P0000040?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
1000o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0N0?ooo`800000;P3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0:`3oool2000001D0oooo000S0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000800?l000<000000?ooo`3oool07P3oool2000001l0oooo00<000000?ooo`3oool08@3o
ool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool00`3o
ool00`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo000S0?ooo`<000000`3oool0
0`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`00
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo0`0000040?ooo`030000003oool0
oooo0240oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0
oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`00
0000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`00
0000oooo0?ooo`0N0?ooo`800000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0240oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool07@3oool2000003D0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o00030000003oool0oooo02L0oooo0P00000P0?ooo`800000;P3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:`3oool2
000001D0oooo000Y0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0N0?ooo`800000603oool30000
00@0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0004003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo
02P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01<0oooo000Y0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo
00<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo
0`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool2000003D0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<000000?ooo`3oool00`3oool7000002T0oooo0P00000P0?ooo`800000;P3oool7000000D00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00L00000;@3oool2000001D0oooo
000H0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo1P00000P0?ooo`8000007`3oool00`000000oooo0?oo
o`0Q0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`800000103oool00`000000oooo0?oo
o`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0c0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool04`3oool001P0oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02@0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000f0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool500000080
oooo0P0000030?ooo`030000003oool0oooo03<0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`80
00009@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`000000oooo0?ooo`0Y0?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`03
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`800000=@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`000000oooo0?ooo`0c0?ooo`8000005P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000=@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01<0oooo000I0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000003o
ool0oooo02@0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0240oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000f0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0503oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000d0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo0340oooo0P00000E0?ooo`005P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0Y0?oo
o`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000003D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`00
5P3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
003oool0oooo03@0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000=@3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
01<0oooo000Y0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0:@3oool2000001P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01d0oooo0P00000e0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0004003o00030000003oool0oooo03<0oooo0P00000E0?ooo`800000103oool20000
00<0oooo0P00000d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo0340oooo0P00000E0?ooo`00:@3oool00`000000
oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o00030000003oool0oooo02X0oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo20000005003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`07000002X0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0004003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0c0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool04`3oool002T0
oooo00<000000?ooo`3oool0903oool6000000D00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`0Y0?ooo`8000006@3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo02T0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02X0oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02P0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`800000=@3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
oooo0?ooo`0c0?ooo`800000803oool00`000000oooo0?ooo`0c0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380
oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0:@3oool2000001T0oooo
0P0000040?ooo`030000003oool0oooo02P0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0N0?ooo`800000=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0a0?ooo`8000005@3oool001`0oooo1@00
00020?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0<`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo000N
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02X0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`L000001@00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0004003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0c0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool04`3oool001h0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000:P3oool00`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0:@3oool2000001l0
oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`800000=@3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
oooo0?ooo`0c0?ooo`800000803oool00`000000oooo0?ooo`0c0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380
oooo00<000000?ooo`3oool04`3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000:`3oool00`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
02h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo
03@0oooo00<000000?ooo`3oool07P3oool2000003@0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00L00000<`3oool2000001D0oooo000N0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o00030000003oool0oooo02T0oooo0P00000B0?ooo`D000000P3oool2
000000@0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo03<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo03P0oooo00<000000?ooo`3oool04`3oool001d0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000<03oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo03P0oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0:@3oool7
000000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00H00000:`3oool2
000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
<03oool7000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`800000
=@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l02000000e0?ooo`800000
803oool2000003@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo03L0oooo0P00000E0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02l0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000f0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0@0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3o
ool0=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03<0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03P0oooo00<000000?ooo`3o
ool04`3oool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000
503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03/0oooo00<0
00000?ooo`3oool04P3oool500000080oooo0P0000030?ooo`030000003oool0oooo03<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0d
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000e0?ooo`0300000000
o`000?l000<00?l01`00000l0?ooo`8000005P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000=@3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00403oool5000000030?oo
o`0000000000008000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02l0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0;P3oool2000001l0oooo00<000000?ooo`3oool0=03oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P00000d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0g0?ooo`8000005@3oool00180oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0700000300
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000003oool0oooo0440
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000
oooo0?ooo`0c0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool200000300oooo00<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0;P3oool2000001l0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0d0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01d0oooo0P00000e0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
@03oool2000001D0oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0c0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01<0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0^0?ooo`8000004P3oool5000000030?ooo`0000000000008000000`3oool00`000000oooo
0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0N0?ooo`800000=03oool7000000D00?l000<000000?ooo`3oool0=`3oool2000001D0oooo
000A0?ooo`800000103oool2000000X0oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003o
ool0oooo02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`L000001@00
o`000`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3o
ool2000003D0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`100?ooo`800000803o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02h0oooo0P00000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool0
0`0000000?l0003o0003003o00030000003oool0oooo0440oooo00<000000?ooo`3oool07P3oool2
000003X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0g0?ooo`8000005@3oool0
02T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000?03o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o0003003o00030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`8000004`3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo
02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03X0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
03@0oooo00<000000?ooo`3oool07@3oool2000003D0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`100?ooo`800000803oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00703oool500000080
oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool2000001l0
oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo01h0
oooo0P00000j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0=`3oool2000001D0
oooo000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0340oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03X0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
03T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
01<0oooo000N0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000`0?oo
o`0300000000o`000?l000800?l01`000005003o00030000003oool0oooo02h0oooo0P00000O0?oo
o`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0@0?ooo`D0
00000`3oool300000080oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`80
0000=@3oool00`0000000?l0003o0003003o00030000003oool0oooo0400oooo0P00000P0?ooo`03
0000003oool0oooo03T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo0P00000D0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0100
oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`800000>P3oool00`000000
0?l0003o0003003o00030000003oool0oooo03L0oooo0P00000E0?ooo`007@3oool2000000@0oooo
0`0000030?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0B0?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`0j0?ooo`L0
00001@00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03@0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`110?ooo`030000003oool0oooo0180oooo100000030?oo
o`8000000`3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`H0
00001@3oool700000300oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000480oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`800000=@3oool00`0000000?l0003o0003003o00030000003oool0oooo0400oooo0P00
000D0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0@03oool00`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000f0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool20000
03X0oooo1`00000i0?ooo`8000005@3oool002T0ooooMP00000C0?ooo`8000001@3oool2000000<0
oooo00<000000?ooo`3oool0@03oool00`0000000?l0003o0003003o00030000003oool0oooo03@0
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000003oool0
oooo0440oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo
002n0?ooo`030000003oool0oooo0400oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3ooomn000001D0
oooo002n0?ooo`030000003oool0oooo0400oooo1`00000f0?ooo`030000003oool0oooo01d0oooo
0P00000e0?ooo`L00000@P3oool2000001D0oooo0P0000040?ooo`800000UP3oool00;h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`2a0?ooo`00_P3ooon1000001l0ooooPP00002c
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0
oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooomi0?ooo`D000000P3oool2
000000@0oooo0P00000C0?ooo`8000005P3oool500000080oooo0P0000040?ooo`800000403oool4
000000<0oooo0P0000040?ooo`800000>03oool500000080oooo0P0000040?ooo`800000503oool2
000001D0oooo1@0000020?ooo`800000103oool200000100oooo100000030?ooo`800000103oool2
000001<0oooo003o0?ooog/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180
oooo003o0?ooog/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
03T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo003P
0?ooo`D000000P3oool2000000@0oooo0P00000A0?ooo`8000004`3oool500000080oooo0P000004
0?ooo`8000003@3oool4000000<0oooo0P0000040?ooo`800000<P3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool00400
oooo1@0000020?ooo`800000103oool200000100oooo0P00000C0?ooo`D000000P3oool2000000@0
oooo0P00000=0?ooo`@000000`3oool2000000@0oooo0P0000130?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
00005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000005P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000B0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000>03oool2000000@0oooo0P0000040?ooo`8000004`3oool2000001L0oooo0P0000040?oo
o`800000103oool200000140oooo0P0000040?ooo`800000103oool2000003T0oooo0P0000040?oo
o`800000103oool2000001@0oooo0P00000F0?ooo`800000103oool2000000@0oooo0P00000A0?oo
o`800000103oool2000000@0oooo0P00000C0?ooo`00@P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000>P3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00>P3oool4000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0@03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooomC0?ooo`00@P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@@3oool2000000@0
oooo0P0000040?ooo`8000004@3oool2000001@0oooo0P0000040?ooo`800000103oool2000000h0
oooo0P0000040?ooo`800000103oool200000?l0ooooE03oool00440oooo0P0000040?ooo`800000
103oool200000100oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`800000
103oool2000000@0oooo0P00002i0?ooo`800000103ooon2000001T0oooo0P0000040?oooh400000
4`3oool00?l0ooooF03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00o`3ooomH0?ooo`040000
003oool0oooo000000<0ooooPP00000H0?ooo`040000003oool0oooo000000<0ooooP@00000C0?oo
o`00o`3ooomH0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`090?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool0
02<0oooo0P0000040?ooogH000009@3oool2000000<0ooooMP00000H0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`00
0?l000@00?l000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04@3oool00280oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`800000103oool2000000@0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
2@3oool00`0000000?l0003o0004003o00030000003oool0oooo00P0oooo0P00000I0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool010000000oooo0?ooo`0000030?ooogH00000
903oool010000000oooo0?ooo`0000020?ooogH000007`3oool00`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
0000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00280oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0=0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0>0?ooo`0300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000@00?l000<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo3@0000050?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01<0oooo0P00000T0?oo
o`040000003oool0oooo00000080oooo0P00000?0?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo0P000004
0?ooo`d000001P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000@00?l000<00000
0?ooo`3oool0203oool2000001l0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool002<0oooo0P0000040?oo
o`030000003oool0oooo00d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
00030000003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool2000000<0oooo00<000000?oo
o`3oool03P3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000@00?l000<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo00d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`06000001D0oooo0P00000Z0?ooo`80
00003`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o00L000005@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`03
00000000o`000?l000@00?l000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`@0
00000`3oool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00h0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01d0oooo0P00000@0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
2@3oool00`0000000?l0003o0004003o00030000003oool0oooo00P0oooo0P00000H0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool03@3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo0P00000Z0?ooo`8000003`3o
ool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool05P3o
ool4000000<0oooo00<000000?ooo`3oool03`3oool00`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`08000000D00?l000<000000?ooo`3oool0503o
ool2000001<0oooo000Y0?ooo`030000003oool0oooo00d0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool0
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`090?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0103oool0
0`0000000?l0003o0003003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool0
01H0oooo100000030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool03@3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o00030000003oool0oooo01P0oooo0P00000H0?ooo`@000000`3oool20000
00@0oooo0P0000030?ooo`8000003`3oool6000000D00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`060000
01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`800000403oool00`00
00000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo00T0oooo2000000:0?ooo`800000603oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00@0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000F0?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0=0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`0300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`800000103o
ool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`040?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0A0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo0?ooo`8000003P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo0P00
000I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P00000D0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0M0?ooo`800000603o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
5@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
103oool00`0000000?l0003o0003003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4@3oool001P0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool03@3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0C0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01L0oooo0P0000040?ooo`800000403oool00`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo01/0oooo0P00000O0?ooo`030000003oool0oooo01D0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo00@0oooo1`00000G0?ooo`030000003o
ool0oooo0140oooo000F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0=0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0603o
ool2000001P0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`800000
503oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l01P000005003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00l0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`005`3o
ool2000000X0oooo0`0000030?ooo`030000003oool0oooo00d0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`<000000P3o
ool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3o
ool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0
oooo00d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0H0?ooo`800000:P3oool2
000001@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0
oooo01h0oooo00<000000?ooo`3oool07@3oool200000100oooo3P000005003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00L000007@3oool2
000001l0oooo00<000000?ooo`3oool05@3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`00
0000oooo0?ooo`0=0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o00030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0L0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0H0?ooo`<000000P3oool00`000000oooo0?ooo`0E0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0140oooo000Y0?ooo`030000003oool0oooo00d0oooo3@000004003o00L000001000o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o00L000006P3oool2000002X0oooo0P00000D0?ooo`L000001@00o`000`000000
oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l01`00000P0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0703oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0280
oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0000001L0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0280oooo00<000000?oo
o`3oool04@3oool002T0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o0002003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool2000001d0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0Q0?ooo`800000603oool500000080oooo00<000000?ooo`3o
ool05@3oool=000000D00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`07000002<0oooo0P00000C0?ooo`00
8`3oool2000000@0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o0002003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
003oool0oooo01h0oooo0P00000U0?ooo`8000000`3oool2000001X0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0H0?ooo`<000000P3oool00`000000oooo0?ooo`0L0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`00
8P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01T0oooo00<00000003o0000
o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02@0oooo00<000000?oo
o`3oool06@3oool01@000000oooo0?ooo`3oool0000001h0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000U0?ooo`040000003oool0oooo
0?ooo`8000006P3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01h0oooo0P00000W
0?ooo`030000003oool0oooo008000006P3oool7000000@0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`000000oooo0?ooo`0S0?ooo`800000603oool500000080oooo0P00000M0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool08@3oool2000001X0oooo0P0000030?ooo`030000003oool0
oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool04@3oool002<0oooo0P0000040?ooo`030000003oool0oooo
01T0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02<0oooo0P0000030?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0L0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l0
00800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool07P3oool2000002D0oooo00<000000?ooo`3oool00P3oool20000
02D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0L0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0240oooo00<00000003o0000o`000`00o`08000000D00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool002<0
oooo0`0000030?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo0`0000020?ooo`030000003oool0oooo02@0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0
oooo0P0000030?ooo`8000007@3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0240
oooo0P00000O0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`040?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool002T0oooo
00<000000?ooo`3oool06@3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01h0oooo
0P00000Z0?ooo`8000009@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`040?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo
00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0T0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0M0?ooo`8000007@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0240oooo0P00
000H0?ooo`<00000103oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool0103oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0N
0?ooo`800000:P3oool2000002D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`040?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool002T0oooo00<00000
0?ooo`3oool06@3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool0103oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0W0?ooo`8000004`3oool001P0oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo01T0oooo1P000005
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`06000000D00?l000<00000
003o0000o`000P00o`000`000000oooo0?ooo`0N0?ooo`8000006P3oool00`000000oooo0?ooo`02
0?ooo`800000103oool2000000<0oooo0P00000U0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0M0?ooo`8000007@3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo0240oooo0P00000H0?ooo`<00000103oool00`000000oooo0?ooo`0Q
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02@0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01H0oooo0`00
00040?ooo`030000003oool0oooo01`0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0Q0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0103oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool0oooo0P00000U0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`000000oooo0?ooo`0N0?ooo`8000006P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo008000009@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02<0oooo0P00
000H0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0703oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool3000000<0oooo
00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o00030000003oool0oooo00@0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`006@3oool00`000000oooo0?oo
o`070?ooo`800000103oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`0000030?ooo`8000007@3oool00`0000000?l0003o0003003o00L000001@00o`07000000D00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`07000002<0oooo0P00000O0?ooo`030000003oool0oooo0240oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`040?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo
00<000000?ooo`3oool04@3oool001H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02@0oooo1P000005003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0080oooo
3000000P0?ooo`800000603oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080
oooo0P00000U0?ooo`0300000000o`000?l000<00?l01P000005003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00H000009P3oool00`000000
oooo0?ooo`0F0?ooo`<00000103oool00`000000oooo0?ooo`0L0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`L000001P3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l01`00000Z0?ooo`030000003oool0oooo0140
oooo000F0?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool05P3oool4000000T0oooo
0`0000020?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`0000000?l0
003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0;P3oool2000002X0oooo0P00000U0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<0
00000?ooo`3oool05`3oool3000000<0oooo0P00000M0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02L0oooo0P00
000O0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool002T0oooo00<00000
0?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A
0?ooo`00:@3oool00`000000oooo0?ooo`0Y0?ooo`L000001000o`07000000D00?l000<000000?oo
o`3oool0;P3oool2000002X0oooo0P00000U0?ooo`L00000103oool00`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?oo
o`3oool0;`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0;`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<000000?oo
o`3oool07@3oool2000001d0oooo1`0000050?ooo`L000001@3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool09`3oool2000001P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0]0?ooo`8000004`3oool001`0oooo1@0000020?oo
o`800000103oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo0P00000N0?oo
o`D000000P3oool2000000<0oooo0P00000`0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?oo
o`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?oo
o`007P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000<@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0140oooo000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`3oool200000300oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool200000200oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00800000<03oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02P0oooo0P00000O0?ooo`800000=@3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool09`3oool2000001T0oooo0P000004
0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<@3oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000340oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000N0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0;P3oool200000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000<03oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<00000
0?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03@0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l01`00
000`0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo0P000004
0?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo0P00
000e0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0W0?ooo`8000007`3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0_
0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o00030000003oool0oooo02h0oooo0P00000Z0?ooo`800000<03oool00`0000000?l0003o0003
003o00H000001@00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<00000
0?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo02l0oooo00<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02l0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01H0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo1@000002
0?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0_0?oo
o`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
00030000003oool0oooo02h0oooo0P00000Z0?ooo`800000<03oool00`0000000?l0003o0003003o
00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02T0oooo00<000000?ooo`3oool05`3oool2000000@0oooo0P00000e0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?oo
o`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000`0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0A0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<00000
0?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
0000000`0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<`3oool2000001<0oooo
000@0?ooo`D0000000<0oooo0000000000000P0000030?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`8000004P3oool5000000030?ooo`00
00000000008000000`3oool2000000@0oooo0P0000030?ooo`800000<03oool00`0000000?l0003o
0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000<03oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03@0
oooo00<000000?ooo`3oool04@3oool00180oooo00D000000?ooo`3oool0oooo0000000;0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02T0oooo00<000000?ooo`3oool07@3oool2000003D0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo02L0oooo0P00000D0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000300oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool200000300
oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0;P3oool2000001@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00800000<03oool00`0000000?l0003o0003003o0003
0000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo02P0oooo0P00000O0?ooo`030000003oool0oooo03@0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3o
ool04@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02h0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`004P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02l0oooo1P0000050?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0;P3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool200000300oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo0P00000e0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?ooo`80
00007`3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0A0?ooo`004@3oool2000000@0oooo0P00000:0?ooo`<00000
0`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`0000020?ooo`030000
003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0100oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0>P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo0P00000Z0?ooo`800000<03o
ool00`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0
>P3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
0P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`3oool2000003D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l01`000005003o00030000003oool0oooo02L0oooo0P00000B0?oo
o`D0000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo02h0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`80
0000:P3oool200000300oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`L0
00001@00o`000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0^0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00:@3oool0
0`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`3oool2000003D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000
003oool0oooo02L0oooo0P00000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0^0?ooo`L000001@00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0<`3oool2000001<0oooo000L0?ooo`D000000P3o
ool2000000@0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo02h0oooo0P00000N0?ooo`D000000P3oool2000000<0oooo0P00000`0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0003003o00030000003o
ool0oooo02T0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000003`0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0340oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo
02P0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo0000000f0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001h0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000003/0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000803oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00800000<03oool00`0000000?l0003o0003003o00030000003o
ool0oooo00P0oooo1`00000Z0?ooo`8000007`3oool2000003D0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00P000001@3oool7000002T0oooo0P00000C0?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo000N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0
oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0;`3oool0
0`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000N0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0;P3oool200000200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`800000<03oool00`0000000?l0003o0003003o00030000003oool0oooo
03X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0140oooo000M0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0>P3oool00`000000
0?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool2000000@0
oooo0`0000020?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01d0oooo0P00000e0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`8000007`3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool002T0oooo
00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo
0P00000Z0?ooo`800000<03oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo
00<000000?ooo`3oool0403oool5000000030?ooo`0000000000008000000`3oool00`000000oooo
0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=03oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo03X0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0@0?ooo`D000000`3oool300000080oooo00<000000?ooo`3oool0
=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003o
ool0oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000:P3o
ool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool2000003D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo03X0oooo0P00000D0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
0000000f0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<0
00000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0:03oool200000300oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?oo
o`3oool500000080oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l01`00000e0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0>P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000003H0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000Y0?oo
o`030000003oool0oooo03X0oooo1`00000`0?ooo`800000:P3oool200000300oooo1`00000l0?oo
o`030000003oool0oooo0140oooo0P0000040?ooo`800000103oool2000003D0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03X0oooo0P00000D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0d0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0140oooo000Y0?ooogH00000:P3ooomf000001l0oooo00<000000?ooo`3o
ool0=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0A0?ooo`8000001@3oool2000000<0oooo00<000000?ooo`3o
ool0=03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0A0?ooo`00o`3ooomO0?ooo`030000003oool0oooo03@0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03/0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo
003o0?oooel0oooo0P00000e0?ooo`d00000?03oool2000001l0oooo00<000000?ooo`3oool0=03o
ool=000003`0oooo00<000000?ooo`3oool04@3oool00?l0ooooG`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo003o0?oooel0ooooPP00000O0?oooh4000004`3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo003o0?ooool0ooooU@3oool00=L0oooo1@0000020?ooo`800000103oool20000
01@0oooo0P00000F0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@000000`3oool20000
00@0oooo0P00003J0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`800000503oool50000
0080oooo0P0000040?ooo`8000003`3oool4000000<0oooo0P0000040?ooo`8000005@3oool00=T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000=/0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo003I0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00003K0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000D0?ooo`00d@3oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403o
ool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0d@3oool4000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool00400oooo
1@0000020?ooo`800000103oool200000100oooo0P00000C0?ooo`D000000P3oool2000000@0oooo
0P00000=0?ooo`@000000`3oool2000000@0oooo0P00000j0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000100?ooo`D000000P3oool2000000@0oooo0P00000A
0?ooo`8000004`3oool500000080oooo0P0000040?ooo`8000003@3oool4000000<0oooo0P000004
0?ooo`800000>`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000503oool00480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
03P0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000G0?ooo`800000103oool20000
00@0oooo0P00000@0?ooo`800000103oool2000000@0oooo0P0000130?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@0
00000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000i0?ooo`800000103oool2000000@0oooo0P00
000C0?ooo`8000005@3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo0P00
00040?ooo`8000005@3oool00480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000>80oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0;80oooo000j0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`3H0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`2`0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000hP3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000/P3oool00440oooo0P0000040?ooo`800000103oool200000100oooo0P00
000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`800000103oool2000000@0oooo0P00
000I0?ooo`800000a`3oool2000000@0oooo0P0000040?ooo`8000004@3oool2000001@0oooo0P00
00040?ooo`800000103oool2000000h0oooo0P0000040?ooo`800000103oool2000001/0oooo0P00
00030?ooogh000005@3oool00;L0oooo00@000000?ooo`3oool000000`3ooon100000;/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`00]`3oool010000000oooo0?oo
o`0000030?oooh800000^P3oool010000000oooo0?ooo`0000020?ooogh000005@3oool00;L0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0;T0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo
00T0oooo00<000000?ooo`3oool04`3oool002<0oooo0P0000040?ooogH00000603oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool20000
00@0ooooMP00000J0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo000R0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3o
ool2000000<0oooo0P0000040?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3o
ool00`0000000?l0003o0003003o00030000003oool0oooo00P0oooo0P00000E0?ooo`008P3oool0
10000000oooo0?ooo`0000030?ooogH000007`3oool00`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0280oooo00@000000?ooo`3oool000000`3ooomf00000200oooo00<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo000R0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool=000000D00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`0700000140oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`03
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
0000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00280oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01<0oooo0P00000O0?ooo`03
0000003oool0oooo00l0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo01D0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o
00030000003oool0oooo00P0oooo0P00000P0?ooo`800000103oool7000000D00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`07000000D0oooo1`00000:0?ooo`8000005@3oool002<0oooo0P0000040?ooo`03
0000003oool0oooo00P0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<000000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00l0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool7000000X0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o00H0
00002P3oool200000200oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`00
:@3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l03@000004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l01P00000E0?ooo`8000007`3oool00`000000oooo0?ooo`0?0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`800000
2P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
6P3oool2000001D0oooo000Y0?ooo`030000003oool0oooo00P0oooo00<00000003o0000o`000P00
o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo100000030?ooo`030000003o
ool0oooo00l0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003o
ool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0=0?ooo`8000006P3o
ool400000080oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`00:@3oool0
0`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool02@3oool0
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0603oool2
000001P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool04`3oool00`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`00
0000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool02@3oool00`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`00
00000?l0003o0003003o00L000001@00o`000`0000000?l0003o0004003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00L000005`3oool00`00
0000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
01<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l030000005003o00030000003oool0oooo0080oooo1`00000?0?ooo`8000006`3oool00`00
0000oooo0?ooo`020?ooo`8000002P3oool00`0000000?l0003o0003003o00L000001@00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o00L00000703oool2000001D0oooo000Y0?ooo`030000003oool0oooo00P0
oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0H0?ooo`8000006P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`00
00000?l0003o0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01<0oooo000F0?ooo`@000000`3oool2000000@0oooo0P0000040?oo
o`030000003oool0oooo00P0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00P0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0H0?ooo`8000006P3o
ool010000000oooo0?ooo`0000020?ooo`8000002P3oool00`0000000?l0003o0003003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
003oool0oooo0200oooo0P00000E0?ooo`005P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000
003oool0oooo00T0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0
3`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
1000o`000`0000000?l0003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
003oool0oooo00P0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01T0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo000G0?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`0300000000o`000?l000800?l0
00<000000?ooo`3oool02@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0603oool2000001l0oooo00<000000?ooo`3oool03`3oool00`0000000?l0
003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0
003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0603oool200000200
oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo0240
oooo00<000000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool0203oool2000000@0oooo
00<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo00T0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`L000001@3oool00`0000000?l0
003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0>000001d0oooo
00<000000?ooo`3oool05`3oool2000000X0oooo0`0000030?ooo`030000003oool0oooo01<0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0203oool00`0000000?l0003o0003003o00030000003oool0oooo01P0oooo
0P00000P0?ooo`8000002P3oool7000000D0oooo00<00000003o0000o`000`00o`07000000D00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo0200oooo
0P00000E0?ooo`005P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo00T0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo
0P00000O0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0
003o0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo000G0?ooo`8000002P3oool3000000<0oooo00<0
00000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo00T0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`H000001@00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo00P0oooo1`00000J0?ooo`800000803oool00`000000oooo0?oo
o`0E0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo00P0oooo00<00000
003o0000o`000P00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0H0?ooo`8000006P3oool300000080oooo00<00000
0?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0603oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?ooo`<0000000<0oooo0000000000005P3oool0
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0803oool2
000001D0oooo000Y0?ooo`030000003oool0oooo00P0oooo00<00000003o0000o`000P00o`000`00
0000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0000000M
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool08`3oool2000000@0oooo00<00000
0?ooo`3oool0603oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0:@3oool2000001d0oooo00@000000?ooo`3oool000005`3oool00`0000000?l0003o
0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0C0?ooo`00:@3oool00`000000oooo0?ooo`080?ooo`H000002`3oool00`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o00L000006P3oool2000001P0oooo1@0000020?ooo`030000003oool0oooo01/0oooo1`000006
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0603oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0H0?ooo`D0000000<0oooo0000000000005P3oool7000000D0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0803o
ool2000001D0oooo000Y0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo
0000000J0?ooo`d000001000o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0:@3oool2000001X0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool002<0oooo
0P0000040?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo
0?ooo`0N0?ooo`8000006@3oool00`000000oooo000000030?ooo`030000003oool0oooo0240oooo
00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo
00<000000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3oool0903oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool00280oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool00`000000oooo
0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o00030000003oool0oooo02T0oooo0P00000L0?ooo`8000000P3oool200000280oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0803oool2000001D0oooo000U0?ooo`040000003oool0oooo0?ooo`800000
6P3oool00`0000000?l0003o0002003o00L000001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
003oool0oooo01h0oooo0P00000O0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool0
8`3oool3000000<0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01<0oooo000S0?ooo`800000103oool00`000000oooo0?ooo`0I0?ooo`0300000000
o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0240oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0T0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003o
ool0oooo02T0oooo0P00000P0?ooo`8000008P3oool00`0000000?l0003o0003003o00L000001@00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l01`00000R0?ooo`8000005@3o
ool002<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`00
0?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<000000?ooo`3oool07P3oool2000001l0oooo00<000000?ooo`3oool08@3oool0
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool2
00000200oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o00030000003oool0
oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`008`3oool30000
00<0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o0002003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo
01l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00800?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000
oooo0?ooo`0I0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0F0?ooo`<00000103oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02@0
oooo1P000005003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool200000200
oooo0P00000R0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`0V0?ooo`8000005@3oool002T0oooo00<000000?ooo`3oool06@3oool00`0000000?l0
003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l01`000004003o00030000003oool0oooo01h0oooo
0P00000H0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool00`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01P0oooo0`0000030?ooo`030000003oool0oooo
0240oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo
02L0oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool06@3oool00`000000
0?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool2000001X0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo000Y
0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0N
0?ooo`800000603oool3000000@0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`8000008P3oool7000000D0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
00000?ooo`3oool09P3oool2000001D0oooo000Y0?ooo`030000003oool0oooo01T0oooo00<00000
003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02T0oooo0P00
000J0?ooo`<000000`3oool00`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02L0oooo00<0
00000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P000004
0?ooo`030000003oool0oooo01T0oooo1P0000050?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`06000000D0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0N
0?ooo`8000006@3oool3000000<0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F
0?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0080oooo0P00000^0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02H0oooo0P00000E
0?ooo`00603oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0903oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0:@3oool2000001/0oooo0`0000020?ooo`030000003oool0oooo02d0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo0?ooo`8000009@3oool00`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0
oooo01h0oooo0P00000O0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`07
000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Y0?ooo`800000803oool0
0`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool0
01T0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool0903oool00`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`00
00000?l0003o0002003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0N0?ooo`800000;P3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0V0?ooo`8000005@3oool001H0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02@0oooo30000004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`080?ooo`H00000803oool2000001l0oooo00<000000?ooo`3oool08@3oool00`00
00000?l0003o0004003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0L0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:@3oool20000
0200oooo00<000000?ooo`3oool0;@3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01<0oooo000F0?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3oool0;`3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo0240
oooo00<00000003o0000o`001000o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0
oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo0000000[0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo
02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0;P3oool2000001P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000:`3oool7000000@00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
:@3oool2000001/0oooo0P0000030?ooo`800000;P3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0V0?ooo`800000
5@3oool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000
0000o`000?l000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000<@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02X0oooo00<000000?oo
o`3oool0603oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0_0?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02l0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?oo
o`3oool08@3oool00`0000000?l0003o0004003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000340oooo00<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0Y0?ooo`8000006P3oool010000000oooo0?ooo`0000020?ooo`800000;P3oool7000000D00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`000000oooo0?ooo`0V0?ooo`8000005@3oool002T0oooo00<0
00000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000603oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`001000o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo0P0000030?ooo`030000003oool0oooo03<0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02L0oooo
00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo0240oooo00<0
0000003o0000o`001000o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00L00000:`3oool2000001X0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0c0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo
000L0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0^0?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000@00?l000<0
00000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0_0?ooo`8000006`3oool2000000<0oooo0P00
000d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`0V0?ooo`8000005@3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000<@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool08@3oool8000000D0oooo1`000005003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03<0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02L0oooo
00<000000?ooo`3oool04`3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo0?ooo`800000<03oool00`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`8000007`3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02l0
oooo0P00000P0?ooo`800000=03oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<000000?ooo`3oool09P3oool2000001D0oooo000N0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000340oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0_0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0c0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01<0oooo000N0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000340oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool200000180oooo
1@0000020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`00
0000<@3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`000000oooo0?ooo`0_0?ooo`800000803oool00`000000oooo0?ooo`0c0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01<0oooo000M0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
;`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?oo
o`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01h0oooo0P00000d0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0V0?oo
o`8000005@3oool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`80
0000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f
0?ooo`L000001@00o`000`0000000?l0003o0003003o00d00000:P3oool00`000000oooo0?ooo`0B
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0_0?ooo`800000503o
ool500000080oooo0P0000030?ooo`030000003oool0oooo03<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3o
ool002T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
?03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`0000030?ooo`030000
003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000e0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01<0oooo000Y0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool2000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000?03oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0;`3oool2
000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000=03o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00H00000:03oool2000001D0oooo000Y0?ooo`030000003oool0
oooo02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02l0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000e0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?oo
o`0_0?ooo`H000001@00o`000`0000000?l0003o0003003o00030000003oool0oooo02h0oooo0P00
000O0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0_0?ooo`0300000000o`000?l000800?l03000000a0?ooo`8000005P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P00000d0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0:`3oool2000001D0oooo000@0?ooo`D0000000<0oooo0000000000000P00
00030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0703oool500000080oooo0P00
00040?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`0j0?ooo`8000005@3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo03<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo000B
0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000<@3oool00`0000000?l0003o0002003o00030000003oool0oooo03/0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0c0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0C0?ooo`004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00000e0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`8000007`3oool00`00
0000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool000000340oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0j
0?ooo`800000803oool2000003@0oooo00<00000003o0000o`000`00o`07000000D00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0[0?ooo`8000005@3oool00180oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0d0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0oooo00<000000?oo
o`3oool0>P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02`0oooo00<000000?ooo`3oool04`3oool00180oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l01`00000`0?ooo`800000503oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_
0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0>P3oool200000200oooo0P00000d
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:`3oool2000001D0oooo000A0?oo
o`800000103oool2000000X0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?oo
o`3oool07@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<00000003o
0000o`000P00o`000`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0180oooo1@0000000`3o
ool000000000000200000080oooo00<000000?ooo`3oool0<`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02`0oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3o
ool0=03oool00`0000000?l0003o0003003o00030000003oool0oooo03@0oooo0P00000D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o0003
0000003oool0oooo03X0oooo0P00000F0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`0c0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000003@0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0[0?ooo`8000005@3oool0
02T0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000003oool0oooo
03@0oooo0P00000C0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0>P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`00
0000oooo0?ooo`0j0?ooo`8000005P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000000=@3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<00000
0?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o
00030000003oool0oooo03D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0100oooo1@0000030?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?oo
o`3oool0>P3oool2000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000003D0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01<0oooo000L0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0=03oool0
0`0000000?l0003o0003003o00030000003oool0oooo03@0oooo0P00000O0?ooo`030000003oool0
oooo03X0oooo00<00000003o0000o`000`00o`07000003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0C0?ooo`800000103oool2000000<0oooo0P00000d0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0:`3oool2000001D0oooo000N0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
>P3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo0000000a0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0>P3oool200000200
oooo00<000000?ooo`3oool0<`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0
oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool2000003D0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`80
00007`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o0003
0000003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool2000003@0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`030?ooo`L000001@00o`000`000000oooo0?ooo`0[0?ooo`80
00005@3oool001h0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0
=03oool00`0000000?l0003o0003003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0
403oool5000000<0oooo0`0000020?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0>P3oool200000200
oooo00<000000?ooo`3oool0<`3oool00`0000000?l0003o0003003o00030000003oool0oooo00T0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool2000001@0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000003`0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo0P0000030?ooo`@0
00002@3oool3000000<0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o0003
0000003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0c0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o0003
0000003oool0oooo02`0oooo00<000000?ooo`3oool04`3oool001d0oooo0P0000040?ooo`<00000
0`3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000
oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`000`000000
oooo0?ooo`0j0?ooo`800000803oool2000003@0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0:`3oool2000001D0
oooo000Y0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000?03oool00`0000000?l0003o0003003o00030000003oool0oooo
03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l0
00800?l000<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0B0?ooo`D000000`3oool30000
00030?ooo`000000oooo03@0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?oo
o`00:@3oool00`000000oooo0?ooo`0d0?ooo`L00000=P3oool2000001@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo03X0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;`3oool6000003`0oooo0P00000F0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool00000=@3oool00`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo000Y0?ooogH0
00004`3oool2000000D0oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02T0ooooMP00000F0?ooo`04
0000003oool0oooo0?ooo`D0000000<0oooo000000000000=03oool7000000/0oooo1`00000]0?oo
o`8000005@3oool00;h0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o0003
0000003oool0oooo03X0oooo00<000000?ooo`3oool0]@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0OP00000E0?ooo`00_P3oool00`000000oooo0?ooo`0j0?ooo`L0
0000?03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000U@3oool00;h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0;@0oooo0P0000050?ooo`800000U@3oool00;h0ooooP@00003o0?oooeD0oooo003o
0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0oooo
U@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003G0?ooo`D000000P3oool2000000@0oooo0P00
000D0?ooo`8000005P3oool500000080oooo0P0000040?ooo`8000003`3oool4000000<0oooo0P00
00040?ooo`800000o`3ooomE0?ooo`00f@3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000o`3ooomD0?ooo`00f@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000o`3ooomD0?ooo`00d@3oool4000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool01000
0000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00@03oool500000080
oooo0P0000040?ooo`800000403oool2000001<0oooo1@0000020?ooo`800000103oool2000000d0
oooo100000030?ooo`800000103oool2000003X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000400oooo1@0000020?ooo`800000103oool200000140oooo0P00
000C0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2000000@0oooo0P00
00110?ooo`D000000P3oool2000000@0oooo0P00000A0?ooo`8000004`3oool500000080oooo0P00
00040?ooo`800000303oool4000000<0oooo0P0000040?ooo`8000004`3oool00480oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003P0oooo0P0000040?ooo`800000
103oool2000001@0oooo0P00000G0?ooo`800000103oool2000000@0oooo0P00000@0?ooo`800000
103oool2000000@0oooo0P0000130?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000B0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
hP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool003X0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0=P0oooo
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
03P0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0;0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0100oooo00120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00003R0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?oo
o`00@@3oool2000000@0oooo0P0000040?ooo`800000403oool2000001@0oooo0P0000040?ooo`80
0000103oool2000000h0oooo0P0000040?ooo`800000103oool200000>80oooo0P0000040?ooo`80
0000103oool200000140oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`80
0000103oool2000000@0oooo0P0000120?ooo`800000103oool2000000@0oooo0P00000A0?ooo`80
0000503oool2000000@0oooo0P0000040?ooo`8000003@3oool2000000@0oooo0P0000040?ooo`80
00004`3oool00;P0oooo0P0000040?oooh400000o`3ooomE0?ooo`00]`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`800000o`3ooomD0?ooo`00]`3oool010000000oooo0?ooo`0000030?oooh400000
o`3ooomE0?ooo`008`3oool2000000@0ooooMP00000H0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo
0P0000040?ooogH000009@3oool2000000<0ooooMP00000C0?ooo`008P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o00030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0A0?ooo`008P3oool010000000oooo0?ooo`0000030?ooogH000006@3oool2
000000@0oooo00<000000?ooo`3oool00`3oool7000000D00?l01`000005003o000300000000o`00
0?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000@00?l000<00000003o0000o`000`00o`07000000D0oooo1`00000;0?ooo`030000003oool0
oooo0280oooo00@000000?ooo`3oool000000`3ooomf000002@0oooo00@000000?ooo`3oool00000
0P3ooomf000001<0oooo000R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
203oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o00030000003oool0oooo00P0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
1000o`000`0000000?l0003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool0
8P3oool010000000oooo0?ooo`0000030?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool0203oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`080?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0003003o
00030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0R0?oo
o`040000003oool0oooo000000<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`08
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<000000?ooo`3oool0203oool2000002@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo00P0oooo00<0
0000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo000S
0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0203oool00`0000000?l0003o0003003o00030000003oool0oooo01d0oooo00<00000
0?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1`000005
003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0S
0?ooo`800000103oool00`0000000?l0003o0002003o00030000003oool0oooo00P0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo0P000003
0?ooo`030000003oool0oooo00P0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0002
003o00030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?oo
o`3oool0203oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o00L000001000o`07000000X0oooo1`00000O0?oo
o`030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo02T0oooo1P00000:0?ooo`L000001000o`07000000D00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l04@00000:0?oo
o`800000:P3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo1P000005003o
00030000003oool0oooo00P0oooo1P0000050?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo00P0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000800?l000<000000?ooo`3oool04`3oool2000001l0oooo00<000000?ooo`3o
ool02@3oool00`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo00P0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000
003oool0oooo00P0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000800?l000<000000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`0000000?l0003o0002003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0H0?ooo`800000
:P3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o00030000003oool0oooo00P0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000F0?ooo`@000000`3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<00000003o0000o`000P00
o`0=000000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<000000?ooo`3oool00`3oool6000001D0oooo0P00000O0?ooo`030000003o
ool0oooo00T0oooo1`00000;0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3o
ool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203o
ool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0A0?ooo`005P3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003o
ool0oooo00T0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00P0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0003003o00030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04@3oool001L0oooo00<000000?ooo`3oool02`3oool0
10000000oooo0?ooo`3oool2000000T0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`090?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<000000?ooo`3oool07P3oool2000001l0oooo00<0
00000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo01<0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0603oool2000001P0oooo1000
00030?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0203oool00`0000000?l0003o
0003003o00H000001@00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`L000005@3oool00`000000oooo0?oo
o`0A0?ooo`00603oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`08
0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o00030000003oool0oooo01l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000o`07000000D00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo00<0
0000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo
00<000000?ooo`3oool04@3oool001H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo1P00000;0?ooo`0300000000o`000?l000800?l0
1`000004003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool07P3oool2000001l0oooo
00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo
00D000000?ooo`3oool0oooo0000000E0?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01P0oooo0P00000I0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P0000090?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02<0
oooo0P00000C0?ooo`005`3oool2000000X0oooo0`0000030?ooo`030000003oool0oooo01T0oooo
00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo
0P0000040?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0004003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0
003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000800?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo01T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo
0?ooo`080?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<0
00000?ooo`3oool06@3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo01h0oooo0P00
000H0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06`3oool00`0000000?l0
003o0003003o000300000000o`000?l000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0C0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o00030000003oool0oooo01P0oooo0P00000H0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`L00000103oool00`00
00000?l0003o0003003o000300000000o`000?l000800?l01`000005003o000300000000o`000?l0
00800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo
02@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool06@3oool6000000D0
oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l01`000004003o00030000003oool0oooo01h0oooo0P00000K0?ooo`050000003oool0oooo0?oo
o`0000007@3oool00`0000000?l0003o0003003o00P000001@3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0>000001d0oooo00<000000?oo
o`3oool05`3oool2000000X0oooo0`0000030?ooo`030000003oool0oooo01<0oooo00<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`8000002P3oool300000080oooo00<000000?oo
o`3oool04`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool002T0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000800?l000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`80
0000103oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool02P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool04`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0H0?ooo`800000:P3oool00`000000oooo0?ooo`0C0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool2000000@0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000800?l000<000000?ooo`3oool07P3oool2000001T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
2P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
4`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool0
4@3oool00280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0T0?ooo`030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01L0oooo0`0000030?ooo`030000003oool0oooo01/0oooo1`00000<0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`07000002X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l03000000J0?ooo`800000
:P3oool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000<00?l01P0000050?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`009@3o
ool010000000oooo0?ooo`3oool2000002D0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0
003o0002003o00030000003oool0oooo01h0oooo0P00000O0?ooo`030000003oool0oooo02h0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02h0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`0300000000o`000?l000800?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000000@0oooo00<0
00000?ooo`3oool0903oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02h0oooo00<0
00000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3oool04`3oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo02<0oooo0P00000U0?ooo`8000000`3oool00`000000oooo0?oo
o`0C0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000P00o`000`000000oooo0?ooo`0N0?ooo`8000007`3oool00`000000oooo0?ooo`0^
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0C0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04`3oool00`0000000?l0
003o0003003o00030000003oool0oooo00P0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0140oooo000S0?ooo`<000000`3oool00`000000oooo0?oo
o`0T0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`050000003oool0oooo0?ooo`0000005@3oool6000000D0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l01`000005003o00030000
003oool0oooo02<0oooo0P00000W0?ooo`030000003oool0oooo00800000503oool7000000X0oooo
1`000004003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0S0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool07P3oool2000001l0oooo00<0
00000?ooo`3oool0;P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`800000103oool00`000000oooo0?oo
o`0N0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo0P0000030?ooo`030000003oool0oooo02X0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0T
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0N
0?ooo`8000007`3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo00<00000
0?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?oo
o`0300000000o`000?l000800?l000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool3000000<0oooo00<000000?oo
o`3oool07P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool08`3oool2000002D0oooo0`0000020?ooo`030000003oool0oooo02X0oooo00<00000003o
0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo0?ooo`020?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`H0
0000803oool2000001l0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o0003
0000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`03
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
0000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001P0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02@0oooo00<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0N0?ooo`0300000000o`000?l000<00?l01P000005003o0003
00000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0S0?ooo`80
0000:P3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3o
ool04@3oool001P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000002D0
oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<000000?ooo`3oool0:@3oool2000001l0oooo00<000000?ooo`3oool0;P3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001T0oooo
00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool0903oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`07000000D00?l0
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02<0oooo
0P00000Z0?ooo`030000003oool0oooo02X0oooo00<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0A0?ooo`005P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0903oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`07000000D00?l000<00000003o0000o`000P00o`000`000000oooo
0?ooo`0Y0?ooo`8000004P3oool500000080oooo0P0000040?ooo`030000003oool0oooo02h0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:P3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo
000F0?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000<03oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0N0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o000300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0S0?ooo`8000006P3oool00`000000
oooo0?ooo`020?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:P3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo02@0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool0:@3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000<03oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`L00000<03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0N0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool0
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02X0oooo00<00000003o0000o`000P00
o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0T0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0
oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0
oooo02X0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000`0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000
0?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool08`3oool2000001X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000002/0oooo00<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool08`3oool2000001<0oooo000Y0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`00
0P00o`07000000@00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<000000?ooo`3oool0:@3oool2000001@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000<03oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?oo
o`3oool07P3oool00`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo0P0000030?oo
o`030000003oool0oooo02X0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?oo
o`00703oool500000080oooo0P0000040?ooo`030000003oool0oooo02@0oooo00<00000003o0000
o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3o
ool0:@3oool2000001<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`d0
00001@00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo1`0000040?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<000000?ooo`3oool00`3oool7000002D0oooo0P00000H0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000009P3oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o
0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool05P3oool4000000T0oooo0`00
00030?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01H0oooo100000090?ooo`<000000P3oool00`000000oooo0?oo
o`0Z0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000009@3oool00`0000000?l0
003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l01P00000[0?ooo`8000007`3oool00`000000oooo
0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0140oooo000N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<00000003o0000o`000P00o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`0_0?ooo`800000:P3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l00080
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo02@0
oooo00<000000?ooo`3oool04@3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000009P3oool00`0000000?l0003o0002003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0;P3oool2000001l0oooo00<000000?ooo`3oool0>P3oool00`00
00000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<00000003o0000o`000P00o`000`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0A0?ooo`007@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02@0
oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l00080
0?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0_0?ooo`800000:P3oool00`000000
oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`07000002H0
oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0903oool00`0000000?l0
003o0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;P3oool2000001l0oooo
00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02X0oooo
00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0903oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo01`0oooo1@0000020?ooo`800000103oool00`000000oooo0?oo
o`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0;`3oool2000001h0oooo1@00
00020?ooo`8000000`3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo02@0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o00030000003oool0oooo02h0oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<00000
003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000:`3oool00`0000000?l0
003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o00030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000;03oool00`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000800?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?oo
o`00403oool5000000030?ooo`0000000000008000000`3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo02@0oooo1P0000050?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0oooo0P00000O0?ooo`03
0000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02l0oooo0P00000P
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000002/0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo02T0oooo0P00
000C0?ooo`004P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000002/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000002`0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003o
ool0oooo02X0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`800000<03oool00`0000000?l0003o
0002003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`0^0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`000000
oooo0?ooo`0_0?ooo`800000803oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000;03oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<00000003o
0000o`000P00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0@0?ooo`D000000P3oool2000000@0oooo00<000000?oo
o`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?oo
o`3oool07@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo0P0000040?oo
o`8000000`3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000B0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000503oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000l0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000
o`000?l000<00?l01P00000a0?ooo`800000:P3oool00`000000oooo0?ooo`0Z0?ooo`0300000000
o`000?l000800?l000<00000003o0000o`000`00o`06000000D00?l000<00000003o0000o`000P00
o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000A0?ooo`800000103oool2
000000X0oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000P00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
000l0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02X0oooo00<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0002003o00030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool002T0oooo00<00000
0?ooo`3oool0;`3oool00`0000000?l0003o0002003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`000000oooo0?ooo`0^0?ooo`800000503oool00`000000oooo0?ooo`02
0?ooo`800000103oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0=03oool2000002X0oooo00<000000?ooo`3oool0:P3oool00`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003
003o000300000000o`000?l000800?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A
0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000800?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0oooo03D0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo02l0oooo1P0000050?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool0;P3oool2000001<0oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0j0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02X0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
0000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o0003
0000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001`0oooo1@0000020?ooo`800000
103oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
;P3oool2000001l0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000
003oool0oooo03X0oooo00<000000?ooo`3oool0403oool5000000030?ooo`000000000000800000
0`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=03oool200000180oooo1@0000000`3oool0000000000002000000<0oooo0P0000040?ooo`800000
0`3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`020?ooo`L000001000o`000`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0140oooo000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000003`0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o0003
0000003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
00/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003oool0
oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Z0?ooo`0300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l0
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`800000>`3oool00`0000000?l0003o0003003o00030000
003oool0oooo02h0oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000
0?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0d0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P00000[0?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<000000?ooo`3o
ool0:@3oool2000001<0oooo000N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000
003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool2000000<0oooo00<000000?ooo`3oool0:P3oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000
003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`0^0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`800000503oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02X0oooo1P000005003o00030000003oool0oooo00P0oooo00<00000003o0000
o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000
103oool3000000<0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000
003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`800000
103oool2000000X0oooo0`0000030?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`0000020?ooo`030000
003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`080?ooo`030000
0000o`000?l000800?l000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00:@3o
ool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;P3o
ool2000001l0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000003o
ool0oooo03@0oooo0P00000Z0?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003oool0
oooo00P0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0140oooo000Y0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0^0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00L00000=P3oool20000
02X0oooo00<000000?ooo`3oool0;`3oool00`0000000?l0003o0003003o00030000003oool0oooo
00P0oooo00<00000003o0000o`000P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0140oooo000@0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo02l0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo03/0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0203oool00`0000000?l0003o0002003o00030000003oool0oooo02X0
oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool00`000000
0?l0003o0003003o00030000003oool0oooo02h0oooo0P00000O0?ooo`030000003oool0oooo03X0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0
oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0j0?ooo`8000007P3oool500000080
oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`080?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool0oooo0P00000k0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool0;P3oool200000180oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0j0?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo03/0oooo00<00000
0?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
<@3oool00`0000000?l0003o0003003o00030000003oool0oooo00P0oooo00<00000003o0000o`00
0P00o`000`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool0>P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo02l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
>P3oool00`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000
0?l0003o0003003o000300000000o`000?l000800?l000<000000?ooo`3oool0>P3oool200000200
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0200000300oooo1`00000:0?ooo`03
00000000o`000?l000800?l000<000000?ooo`3oool0:@3oool2000001<0oooo000B0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0oooo02h0
oooo0P00000C0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo
02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0oooo
03/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`00
0000oooo0?ooo`100?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0A0?ooo`004@3oool2000000<0oooo100000090?ooo`<000000`3oool00`000000
oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000003`0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000003oool0
oooo03/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@03oool00`0000000?l0003o0002003o00030000003oool0
oooo02X0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0>P3oool00`00
00000?l0003o0003003o00030000003oool0oooo02h0oooo0P00000B0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`800000103o
ool3000000<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o0003003o000300000000
o`000?l000800?l000<000000?ooo`3oool0>P3oool2000001l0oooo0P0000040?ooo`<000000P3o
ool00`000000oooo0?ooo`100?ooo`0300000000o`000?l000800?l000<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0003003o00030000003oool0
oooo03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000P00o`000`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0@03oool00`0000000?l0003o0002003o00030000003oool0
oooo02X0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0>P3oool70000
0300oooo0P00000O0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool<0000
03`0oooo0P00000Z0?ooo`030000003oool0oooo0400oooo1P00000/0?ooo`030000003oool0oooo
0140oooo000Y0?ooogH000007`3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0
ooooMP00000C0?ooo`00_P3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Y0?ooogH00000/`3oool00;h0oooo00<0
00000?ooo`3oool0>P3oool7000003`0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00_P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomC
0?ooo`00_P3ooon100000?l0ooooE@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
03L0oooo1@0000020?ooo`800000103oool2000001@0oooo0P00000E0?ooo`D000000P3oool20000
00@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo0P00000i0?ooo`D000000P3oool20000
00@0oooo0P00000C0?ooo`8000005@3oool500000080oooo0P0000040?ooo`8000003P3oool40000
00<0oooo0P0000040?ooo`800000?03oool500000080oooo0P0000040?ooo`8000004P3oool20000
01D0oooo1@0000020?ooo`800000103oool2000000l0oooo100000030?ooo`800000103oool20000
03X0oooo1@0000020?ooo`800000103oool2000001@0oooo0P00000E0?ooo`D000000P3oool20000
00@0oooo0P00000@0?ooo`@000000`3oool2000000@0oooo0P00000C0?ooo`00>@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@
0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000?@3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000004P3oool003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000F0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
03d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003/0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo000a0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0c0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0a0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`00>@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000?@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000>`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3o
ool003P0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000F0?ooo`800000103oool2
000000@0oooo0P00000A0?ooo`800000103oool2000000@0oooo0P00000j0?ooo`800000103oool2
000000@0oooo0P00000C0?ooo`8000005P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2
000000@0oooo0P0000040?ooo`800000?@3oool2000000@0oooo0P0000040?ooo`8000004P3oool2
000001H0oooo0P0000040?ooo`800000103oool200000100oooo0P0000040?ooo`800000103oool2
000003/0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000F0?ooo`800000103oool2
000000@0oooo0P00000A0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo000H
0?ooo`8000000`3ooon2000001/0oooo0P0000040?ooogd000007P3oool2000000<0ooooOP00000K
0?ooo`800000103ooon1000001<0oooo000G0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo
0?ooo`0000020?oooh8000006P3oool010000000oooo0?ooo`0000030?ooogd000007@3oool01000
0000oooo0?ooo`0000020?ooogh000006P3oool010000000oooo0?ooo`0000030?oooh4000004`3o
ool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`0300000000
o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00@000000?ooo`3oool000000`3oool00`0000000?l0003o0003003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
00030000003oool0oooo01D0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0A0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`800000103oool00`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<000000?ooo`3oool03P3oool2000001X0oooo00@000000?oo
o`3oool000000`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool02@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`800000103oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o
0003003o00030000003oool0oooo0080oooo0P00000J0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`001000o`000`000000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<0
0000003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o00030000003oool0oooo00l0oooo00<0
00000?ooo`3oool06@3oool2000000@0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o
0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo01`0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo1`000005003o00d000001@00o`000`0000000?l0003o
0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0004003o00030000003oool0oooo01D0oooo1`00000C0?ooo`007@3oool00`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`001000o`000`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003
003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0002
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003
003o00030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`09
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000@00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool2000000@0oooo20000005003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`0800000100oooo0P00000Q0?ooo`L000001@3oool00`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00H000001@00o`000`000000oooo0?ooo`090?ooo`L000001@00o`000`000000oooo0?ooo`0Q0?oo
o`800000103oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00L000001@00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0=000000D0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`020?ooo`8000008@3oool00`000000oooo0?ooo`090?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?oo
o`007@3oool00`000000oooo0?ooo`0:0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo01H0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool00P3oool00`0000000?l0003o0003003o00030000003oool0oooo00l0oooo00<00000003o0000
o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool03`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool02@3oool7000000D00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00P0
00007@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000000/0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
0`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0
5@3oool200000240oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0002003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool08@3oool2000000@0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
3`3oool00`0000000?l0003o0003003o00030000003oool0oooo0080oooo0P00000Q0?ooo`030000
003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo0280oooo00<000000?ooo`3oool04@3oool001L0oooo100000020?ooo`030000003o
ool0oooo00X0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`@000000`3o
ool00`000000oooo0?ooo`090?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00P3o
ool00`0000000?l0003o0003003o00030000003oool0oooo00l0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`0K0?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00l0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`005`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool0
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0?0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool03`3oool0
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool03`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0oooo
0080oooo0P00000;0?ooo`L000001@3oool00`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo
01D0oooo0P00000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool60000
00D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l01`000005003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0?0?ooo`L000007P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`070000
00D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0?0?ooo`L00000103oool20000
0240oooo00<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003oool0oooo
00l0oooo1`000006003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0A0?ooo`006@3oool01@000000oooo0?ooo`3oool0000001P0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00D000000?oo
o`3oool0oooo000000050?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool0
0`0000000?l0003o0003003o00030000003oool0oooo01D0oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo0280oooo00<000000?ooo`3oool04@3oool0
01L0oooo00@000000?ooo`3oool000000P3oool2000001L0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0E0?ooo`8000006P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00h0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo01D0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`00603o
ool2000000<0oooo00<000000?ooo`3oool05P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo01H0oooo00<000000?ooo`3oool06@3oool2000000@0oooo00<000000?ooo`3oool03P3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0L0?ooo`8000000`3oool2000000@0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool02@3o
ool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo01X0oooo0P00000Q0?ooo`030000003o
ool0oooo00T0oooo1`00000G0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l01`00000T0?ooo`030000003o
ool0oooo0140oooo000M0?ooo`030000003oool0oooo01H0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool02@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool06@3oool2
000000@0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0004003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo02P0oooo00<000000?ooo`3oool04@3oool001d0oooo0P00000G0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l01`0000050?ooo`L000005`3oool200000240oooo00<000000?ooo`3oool03P3oool70000
00D00?l000<00000003o0000o`000`00o`07000000D00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`020?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0Q0?ooo`800000103oool=000000D00?l000<000000?ooo`3oool02@3oool00`00
00000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`070000
01`0oooo0P00000J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool0
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool0
01d0oooo00<000000?ooo`3oool05P3oool00`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00l0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
0240oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0000002T0oooo00<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00d00000:@3oool2000001<0oooo000M0?oo
o`8000005`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02L0oooo0P00000Q0?oo
o`030000003oool0oooo01@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o
00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`0000000?l0003o0003003o
00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0002003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?oo
o`800000103oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000@00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000I0?ooo`<0
000000<0oooo0000003oool05`3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`800000403oool00`000000
0?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0803oool2000001/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140
oooo000J0?ooo`040000003oool0oooo000001P0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo0`0000020?ooo`030000003oool0oooo01@0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o00030000003oool0oooo0080
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0
oooo0`0000000`3oool000000?ooo`0@0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3o
ool02@3oool00`0000000?l0003o0003003o000300000000o`000?l000800?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo0`0000030?ooo`03
0000003oool0oooo02L0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001L0oooo1@0000000`3oool00000
0000000G0?ooo`L000001@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool09`3oool2000001d0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?ooo`03
00000000o`000?l000<00?l000<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`04
0000003oool0oooo00000140oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0W0?oo
o`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool08P3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`D000000P3oool00`000000oooo0?ooo`0D0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`020?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0503oool2000001d0oooo1@0000000`3o
ool000000000000@0?ooo`L000002`3oool7000000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0P0?ooo`8000008@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l0
00@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0140oooo000H0?ooo`030000003oool000000080oooo0P00000S0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?ooo`8000006P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09`3oool0
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0A0?ooo`006@3oool200000080oooo00<000000?ooo`3oool08P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0503oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`00
00000?l0003o0003003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo000000020?ooo`800000:03oool00`0000000?l0003o0002003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0803oool200000240oooo00<000000?ooo`3oool09`3oool00`00
00000?l0003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0
oooo0P0000030?ooo`030000003oool0oooo01@0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o00030000003oool0oooo0080oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo0P0000020?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0240
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140
oooo000M0?ooo`8000008`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool09`3oool200000240oooo00<000000?ooo`3oool0503oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`030?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00P3oool00`0000000?l0
003o0003003o00030000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09`3oool00`0000000?l0
003o0004003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0503oool=000000D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool7000000@0oooo1`00
000G0?ooo`030000003oool0oooo0240oooo0P00000X0?ooo`0300000000o`000?l000800?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0P0?ooo`8000008@3oool00`000000oooo0?oo
o`0W0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo0280oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000800?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool09`3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`005`3oool3000000<0oooo0P00000S0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?oo
o`8000008@3oool00`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<000000?oo
o`3oool08@3oool2000002P0oooo00<00000003o0000o`000P00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
00030000003oool0oooo0200oooo0P00000Q0?ooo`030000003oool0oooo02L0oooo00<00000003o
0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01P0oooo0`0000040?ooo`030000003oool0oooo02H0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0K0?ooo`<000000`3oool00`000000oooo0?ooo`0W0?oo
o`0300000000o`000?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool09`3oool8000000D00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?oo
o`8000008`3oool7000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool09`3oool2000001X0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<00000
0?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0oooo00<0
0000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0240oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`005`3oool3000000<0oooo00<00000
0?ooo`3oool0:03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0:`3oool2000001d0oooo00@000000?ooo`3oool000000P3oool2000002P0oooo
00<00000003o0000o`000P00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0200oooo
0P00000D0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`<00000103oool00`000000oooo0?oo
o`0V0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool3000000<0oooo00<0
00000?ooo`3oool09`3oool00`0000000?l0003o0002003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000300oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000H0?ooo`<000000P3oool2000002T0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000@00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0W0?ooo`8000006`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02H0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`0000000?l0
003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0300oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`8000004`3oool001d0
oooo00<000000?ooo`3oool0:03oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`001000o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0
oooo00<000000?ooo`3oool06@3oool3000000<0oooo00<000000?ooo`3oool09P3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01`0oooo0`0000020?ooo`800000:03oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0803oool2000001H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<03oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool0
01d0oooo0P00000Y0?ooo`0300000000o`000?l000<00?l01`000006003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool09`3oool200000240oooo00<000000?ooo`3oool09P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09`3oool00`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000300oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo000M0?ooo`030000003oool0oooo02P0oooo00<00000003o0000o`000`00o`00
0`000000oooo0?ooo`030?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo0P00000X0?ooo`0300000000o`00
0?l000800?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0P0?ooo`8000005@3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo02h0oooo1`000005003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0140oooo000M0?ooo`030000003oool0oooo02P0oooo00<00000003o0000o`000`00o`000`00
0000oooo0?ooo`030?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09`3oool00`00
00000?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo0P00000Y0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool09`3oool200000240oooo00<000000?ooo`3oool09P3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09`3oool00`000000
0?l0003o0002003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0
oooo0P0000040?ooo`030000003oool0oooo02H0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0L0?ooo`8000000`3oool2000002P0oooo00<00000003o0000o`000P00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o00030000003oool0oooo0200oooo0P00000Q0?ooo`030000003oool0oooo03@0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00L00000=P3oool00`000000
oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`800000:@3oool00`000000
0?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`000`000000
0?l0003o0003003o00L000001@00o`000`0000000?l0003o0003003o00030000003oool0oooo02L0
oooo0P00000J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000800?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo00<000000?ooo`3oool0:03oool00`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`000`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<00000003o0000o`000`00o`07
000000D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00L00000;@3oool2
000001d0oooo00@000000?ooo`3oool000000P3oool2000002P0oooo1P000005003o000300000000
o`000?l000<00?l01`000005003o000300000000o`000?l000<00?l01`000005003o00030000003o
ool0oooo0200oooo0P00000Q0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3o
ool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`800000103o
ool00`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo0P0000030?ooo`030000003o
ool0oooo02`0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`00603oool2
000000<0oooo0P00000Y0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool09`3oool2
000001X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0V0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo01/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0:03o
ool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000
o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool06@3o
ool2000000@0oooo00<000000?ooo`3oool09P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`8000000`3o
ool2000002d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0P0?ooo`8000008@3o
ool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000:@3oool0
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`00
0`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02L0oooo0P00000Q0?ooo`030000003oool0
oooo02H0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo0380oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03@0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo03X0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0:03oool00`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`000`00
00000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;03oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`00
00000?l0003o0003003o00030000003oool0oooo0240oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo02P0
oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000@0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool09P3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`800000;@3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool700000280
oooo0P00000D0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0A0?ooo`004@3oool500000080oooo0P0000030?ooo`800000:@3oool00`0000000?l0
003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`000`0000000?l0
003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo02L0oooo0P00000Q0?ooo`030000003oool0oooo02H0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000:P3oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000
003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0240oooo0P00000]
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`03
0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0/
0?ooo`8000005P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000=P3o
ool00`0000000?l0003o0003003o00L00000>`3oool2000001<0oooo000C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000002T0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`030?ooo`L000001@00o`000`000000oooo0?ooo`0W0?ooo`800000503o
ool500000080oooo0P0000040?ooo`030000003oool0oooo02H0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool05@3o
ool500000080oooo0P0000030?ooo`030000003oool0oooo02`0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o00030000003oool0oooo02d0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`004`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:P3oool00`0000000?l0
003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`001000o`000`0000000?l0
003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000:03oool00`0000000?l0003o0003003o00030000003oool0oooo
00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00000^0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo000C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Z0?ooo`030000
0000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000
003oool0oooo02P0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000X0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool00`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0a0?ooo`8000006@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P00000]0?ooo`0300000000o`000?l000<00?l01`000005
0?ooo`0300000000o`000?l000<00?l01`00000^0?ooo`8000005@3oool2000000@0oooo0`000003
0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103oool2000000<0oooo0P00000Y0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool00`0000000?l0003o0004003o
000300000000o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o
00030000003oool0oooo02L0oooo0P00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000002P0oooo00<00000003o0000o`000`00o`000`000000oooo0?oo
o`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000;P3oool00`0000000?l0003o0003003o0003
0000003oool0oooo00T0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o0003
0000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0
:03oool00`0000000?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`00
1000o`000`0000000?l0003o0003003o00030000003oool0oooo00T0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000:03oool00`0000000?l0003o0003003o
00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000^0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003o
ool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`0300000000
o`000?l000<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2
000002T0oooo1`0000050?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`090?ooo`L00000:@3oool2000001D0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0V0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool00`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`8000000`3oool2
000002d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`090?ooo`0300000000o`00
0?l000<00?l000<000000?ooo`3oool0<P3oool200000240oooo00<000000?ooo`3oool0=03oool0
0`0000000?l0003o0003003o00030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool0
01d0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0004003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02H0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
0380oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool02@3oool00`0000000?l0003o0003003o00030000003oool0oooo
03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000
0?l0003o0003003o00030000003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0Q0?ooo`800000;@3oool7000000/0oooo00<00000003o0000o`000`00o`000`000000
oooo0?ooo`0b0?ooo`8000008@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<0
0?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`004@3oool5000000030?oo
o`0000000000008000000P3oool2000003D0oooo00<00000003o0000o`001000o`000`0000000?l0
003o0003003o00030000003oool0oooo03T0oooo0P00000Q0?ooo`030000003oool0oooo02H0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0n0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo
000C0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0d0?ooo`030000
0000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`0000000?l0003o0003003o00030000
003oool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03h0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`0000000?l0003o0003003o00030000
003oool0oooo0400oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`800000=@3oool00`0000000?l0003o0004003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0>@3oool2000001@0oooo1@0000000`3oool000000000
0002000000<0oooo00<000000?ooo`3oool09P3oool00`0000000?l0003o0003003o00030000003o
ool0oooo00<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`D0000000<0
oooo0000000000000P0000020?ooo`800000?`3oool00`0000000?l0003o0003003o00030000003o
ool0oooo0380oooo0P00000Q0?ooo`030000003oool0oooo03@0oooo00<00000003o0000o`000`00
o`000`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`0300000000o`000?l000@00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo02H0oooo00<00000003o0000o`00
0`00o`000`000000oooo0?ooo`030?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool0
5`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0?P3oool00`000000
0?l0003o0003003o00030000003oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000=P3oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`L000001@3oool00`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0a0?oo
o`8000006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000o0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool200000240oooo00<000000?oo
o`3oool0=03oool00`0000000?l0003o0003003o00030000003oool0oooo0400oooo00<000000?oo
o`3oool04@3oool00180oooo0P0000040?ooo`8000000`3oool2000003D0oooo00<00000003o0000
o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo03T0oooo0P00000F0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo0380oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000@03oool00`0000000?l0003o0003003o00030000003oool0oooo
03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l0
00<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000
oooo0?ooo`0d0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000=03oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000400oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0180oooo
100000030?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003D0oooo00<0
0000003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo03T0oooo0P00
000E0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0<P3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`8000000`3oool2000003l0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`800000503oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool00`0000000?l0
003o0003003o00030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool001d0oooo00<0
00000?ooo`3oool0=03oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0380oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03@0oooo
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0o0?ooo`8000004`3oool001d0oooo00<0
00000?ooo`3oool0=03oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0380oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<0
0000003o0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000
0?l0003o0003003o00030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool00140oooo
1@0000030?ooo`<0000000<0oooo000000000000=@3oool00`0000000?l0003o0004003o00030000
0000o`000?l000<00?l000<000000?ooo`3oool0>@3oool200000240oooo00<000000?ooo`3oool0
<P3oool=000000D00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`800000
?`3oool00`0000000?l0003o0003003o00030000003oool0oooo0380oooo0P00000D0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0d0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?oo
o`004`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000003H0oooo00<00000003o
0000o`001000o`000`0000000?l0003o0003003o00030000003oool0oooo03X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0n0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01<0oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`004`3oool010000000oooo0?ooo`3oool50000
00030?ooo`000000000003D0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o
00030000003oool0oooo03T0oooo0P00000Q0?ooo`030000003oool0oooo03h0oooo00<00000003o
0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0240oooo0P00000o0?oo
o`0300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool200000240oooo00<000000?oo
o`3oool0=03oool00`0000000?l0003o0003003o00030000003oool0oooo0400oooo00<000000?oo
o`3oool04@3oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000003H0oooo00<00000003o0000o`001000o`000`0000000?l0003o0003003o00030000003oool0
oooo03X0oooo00<000000?ooo`3oool04P3oool5000000<0oooo0`0000020?ooo`030000003oool0
oooo03h0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo01D0oooo1@0000030?ooo`<0000000<0oooo0000003oool0?`3oool00`0000000?l0003o0003
003o00030000003oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d
0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A
0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0=03oool00`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000100?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000@03o
ool00`0000000?l0003o0003003o00030000003oool0oooo03<0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0A0?ooo`004P3oool2000000D0oooo0P0000020?ooo`800000=@3oool0
0`0000000?l0003o0004003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>@3oool2
000001H0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo03h0oooo1`00
000c0?ooo`8000006@3oool010000000oooo0?ooo`3oool5000000030?ooo`000000000003l0oooo
1`00000d0?ooo`8000008@3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l0
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?oo
o`0d0?ooo`0300000000o`000?l000@00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`0300000000o`000?l000<00?l000<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003D0oooo3P00000k0?oo
o`8000005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0ooooO@00000I0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000P3ooomn00000240oooo00<000000?oo
o`3oool0=03oool700000480oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`0C0?ooo`8000001@3oool2000009P0oooo0P0000050?ooo`80
0000X@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0140oooo000M0?oooh800000
o`3ooomQ0?oooh4000004`3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?oo
ool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3o
ool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0oooo
o`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 553.125}, {448.188, 39.5625}} -> {-0.311491, \
0.237982, 0.00638204, 0.00638204}, {{39, 155.625}, {438.438, 366.375}} -> \
{-466.663, 4.97573, 3.59328, 0.232562}, {{167.313, 283.875}, {438.438, \
366.375}} -> {-928.596, 4.90824, 3.2663, 0.198187}, {{295.563, 412.188}, \
{438.438, 366.375}} -> {-1452.35, 6.87153, 3.2663, 0.277461}, {{423.813, \
540.438}, {438.438, 366.375}} -> {-2043.2, 6.79874, 3.37756, 0.27325}, {{39, \
155.625}, {359.125, 287.063}} -> {-466.663, -19.2106, 3.59328, 0.247096}, \
{{167.313, 283.875}, {359.125, 287.063}} -> {-1043.57, -19.2297, 3.59577, \
0.247267}, {{295.563, 412.188}, {359.125, 287.063}} -> {-1452.35, -12.7748, \
3.2663, 0.171762}, {{423.813, 540.438}, {359.125, 287.063}} -> {-1975.98, \
-14.7401, 3.2663, 0.198187}, {{39, 155.625}, {279.875, 207.813}} -> \
{-466.663, -41.1187, 3.59328, 0.232562}, {{167.313, 283.875}, {279.875, \
207.813}} -> {-928.596, -34.3729, 3.2663, 0.198187}, {{295.563, 412.188}, \
{279.875, 207.813}} -> {-1619.04, -48.8285, 3.59328, 0.276167}, {{423.813, \
540.438}, {279.875, 207.813}} -> {-2043.2, -33.1522, 3.37756, 0.191275}, \
{{39, 155.625}, {200.625, 128.563}} -> {-466.663, -76.1863, 3.59328, \
0.276167}, {{167.313, 283.875}, {200.625, 128.563}} -> {-928.596, -79.2087, \
3.2663, 0.290674}, {{295.563, 412.188}, {200.625, 128.563}} -> {-1619.04, \
-64.1569, 3.59328, 0.232562}, {{423.813, 540.438}, {200.625, 128.563}} -> \
{-2195.08, -64.1569, 3.59328, 0.232562}, {{39, 155.625}, {121.313, 49.25}} -> \
{-404.839, -73.6541, 3.2663, 0.198187}, {{167.313, 283.875}, {121.313, \
49.25}} -> {-960.137, -71.0636, 3.37756, 0.191275}, {{295.563, 412.188}, \
{121.313, 49.25}} -> {-1501.73, -71.0636, 3.37756, 0.191275}, {{423.813, \
540.438}, {121.313, 49.25}} -> {-1975.98, -112.936, 3.2663, 0.303886}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plots3\  = \ 
        Map[Histogram[#[\([3]\)], \ Frame \[Rule] True, \ 
              HistogramRange \[Rule] {\(-200\), \ 200}, \ 
              HistogramCategories \[Rule] 20, \ 
              DisplayFunction \[Rule] Identity, \ 
              BarStyle \[Rule] {RGBColor[0, 0, 1]}] &, \ 
          rbeats];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[plots3, \ 4]], \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0184794 0.238095 [
[ 0 0 0 0 ]
[ 1 .77614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .77614 L
0 .77614 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0184794 0.245293 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .07358 L
.09524 .07358 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .07358 L
.09524 .07358 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07358 L
.19048 .07358 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07358 L
.19048 .07358 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .22073 L
.2381 .22073 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .22073 L
.2381 .22073 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .1913 L
.28571 .1913 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .1913 L
.28571 .1913 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16187 L
.33333 .16187 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .27959 L
.42857 .27959 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .27959 L
.42857 .27959 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .1913 L
.47619 .1913 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .33845 L
.57143 .33845 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .33845 L
.57143 .33845 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .39731 L
.61905 .39731 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04415 L
.85714 .04415 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0184794 0.488926 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .10765 L
.14286 .10765 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .10765 L
.14286 .10765 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .29353 L
.2381 .29353 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .29353 L
.2381 .29353 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .20059 L
.28571 .20059 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .20059 L
.28571 .20059 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .16961 L
.38095 .16961 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16961 L
.38095 .16961 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .35549 L
.47619 .35549 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .35549 L
.47619 .35549 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .32451 L
.61905 .32451 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .32451 L
.61905 .32451 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .32451 L
.66667 .32451 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .32451 L
.66667 .32451 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .04569 L
.71429 .04569 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .04569 L
.71429 .04569 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .04569 L
.80952 .04569 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04569 L
.80952 .04569 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .07667 L
.85714 .07667 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .07667 L
.85714 .07667 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0184794 0.732558 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0420431 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -6 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -6 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -6 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(2)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(4)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(6)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(8)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(10)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(12)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(14)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .11982 m
.00375 .11982 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .20391 m
.00375 .20391 L
s
0 .22493 m
.00375 .22493 L
s
0 .24595 m
.00375 .24595 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .33004 m
.00375 .33004 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .54025 m
.00375 .54025 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .11982 m
1 .11982 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .22493 m
1 .22493 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33004 m
1 .33004 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0988 L
.04762 .0988 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0988 L
.04762 .0988 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .05676 L
.09524 .05676 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05676 L
.09524 .05676 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .18289 L
.14286 .18289 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .18289 L
.14286 .18289 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .05676 L
.19048 .05676 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .05676 L
.19048 .05676 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .18289 L
.28571 .18289 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .18289 L
.28571 .18289 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .14084 L
.33333 .14084 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .14084 L
.33333 .14084 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .3931 L
.38095 .3931 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .3931 L
.38095 .3931 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .47719 L
.42857 .47719 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .47719 L
.42857 .47719 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .56128 L
.52381 .56128 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .56128 L
.52381 .56128 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .56128 L
.57143 .56128 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .56128 L
.57143 .56128 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .43515 L
.61905 .43515 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .30902 L
.66667 .30902 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .14084 L
.71429 .14084 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14084 L
.71429 .14084 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .05676 L
.7619 .05676 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .05676 L
.7619 .05676 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0988 L
.80952 .0988 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0988 L
.80952 .0988 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .05676 L
.95238 .05676 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .05676 L
.95238 .05676 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0184794 0.97619 0.155364 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .0988 L
.09524 .0988 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .0988 L
.09524 .0988 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .04274 L
.14286 .04274 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04274 L
.14286 .04274 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .12683 L
.2381 .12683 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12683 L
.2381 .12683 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .0988 L
.28571 .0988 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0988 L
.28571 .0988 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .18289 L
.33333 .18289 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .0988 L
.38095 .0988 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .0988 L
.38095 .0988 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .23895 L
.42857 .23895 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .23895 L
.42857 .23895 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .35106 L
.47619 .35106 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .35106 L
.47619 .35106 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .43515 L
.57143 .43515 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .43515 L
.57143 .43515 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .26697 L
.61905 .26697 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .26697 L
.61905 .26697 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .12683 L
.66667 .12683 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .12683 L
.66667 .12683 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .12683 L
.71429 .12683 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .12683 L
.71429 .12683 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0988 L
.7619 .0988 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .07077 L
.80952 .07077 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07077 L
.80952 .07077 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.169052 0.245293 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.04762 .05396 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .0932 L
.14286 .0932 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .21092 L
.19048 .21092 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .21092 L
.19048 .21092 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .17168 L
.2381 .17168 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .25016 L
.28571 .25016 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .25016 L
.28571 .25016 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .17168 L
.38095 .17168 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .2894 L
.42857 .2894 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .60332 L
.47619 .60332 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .4856 L
.52381 .4856 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .52484 L
.61905 .52484 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .52484 L
.61905 .52484 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .13244 L
.66667 .13244 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .13244 L
.66667 .13244 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .25016 L
.71429 .25016 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0932 L
.80952 .0932 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .05396 L
.90476 .05396 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.169052 0.488926 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0294302 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -12 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(10)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(15)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .07358 L
.04762 .07358 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .07358 L
.04762 .07358 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .07358 L
.14286 .07358 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .07358 L
.14286 .07358 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07358 L
.19048 .07358 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07358 L
.19048 .07358 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .10301 L
.2381 .10301 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .10301 L
.2381 .10301 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .10301 L
.33333 .10301 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .10301 L
.33333 .10301 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .27959 L
.38095 .27959 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .27959 L
.38095 .27959 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .25016 L
.42857 .25016 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .25016 L
.42857 .25016 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .4856 L
.47619 .4856 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .42674 L
.57143 .42674 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .42674 L
.57143 .42674 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .1913 L
.61905 .1913 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .1913 L
.61905 .1913 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .1913 L
.66667 .1913 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .1913 L
.66667 .1913 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .07358 L
.80952 .07358 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07358 L
.80952 .07358 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.169052 0.732558 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .08829 L
.09524 .08829 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08829 L
.09524 .08829 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .23544 L
.19048 .23544 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .23544 L
.19048 .23544 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .0515 L
.28571 .0515 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0515 L
.28571 .0515 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .49296 L
.47619 .49296 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .38259 L
.52381 .38259 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .38259 L
.52381 .38259 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49296 L
.57143 .49296 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .3458 L
.61905 .3458 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .3458 L
.66667 .3458 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .3458 L
.66667 .3458 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .08829 L
.71429 .08829 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .08829 L
.71429 .08829 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .0515 L
1 .0515 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0515 L
1 .0515 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.169052 0.97619 0.305937 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .07667 L
.04762 .07667 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .07667 L
.04762 .07667 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .01472 L
.14286 .01472 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .13863 L
.19048 .13863 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .13863 L
.19048 .13863 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .10765 L
.28571 .10765 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .10765 L
.28571 .10765 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .16961 L
.33333 .16961 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .16961 L
.33333 .16961 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .20059 L
.38095 .20059 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .20059 L
.38095 .20059 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .38646 L
.42857 .38646 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .38646 L
.42857 .38646 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .29353 L
.47619 .29353 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .29353 L
.47619 .29353 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .29353 L
.61905 .29353 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .29353 L
.61905 .29353 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .16961 L
.66667 .16961 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16961 L
.66667 .16961 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .16961 L
.71429 .16961 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .16961 L
.71429 .16961 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .07667 L
.7619 .07667 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .07667 L
.7619 .07667 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.319626 0.245293 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08396 L
.14286 .08396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08396 L
.14286 .08396 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .25708 L
.19048 .25708 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .25708 L
.19048 .25708 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .08396 L
.2381 .08396 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .08396 L
.2381 .08396 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .22246 L
.33333 .22246 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .08396 L
.38095 .08396 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .08396 L
.38095 .08396 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .29171 L
.42857 .29171 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .29171 L
.42857 .29171 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .49945 L
.47619 .49945 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .49945 L
.47619 .49945 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .36095 L
.57143 .36095 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .36095 L
.57143 .36095 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .53407 L
.61905 .53407 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .53407 L
.61905 .53407 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .22246 L
.66667 .22246 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .22246 L
.66667 .22246 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .11859 L
.71429 .11859 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11859 L
.71429 .11859 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04934 L
.95238 .04934 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.319626 0.488926 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0280288 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -6 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(5)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(10)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(15)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(20)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04274 L
.04762 .04274 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04274 L
.04762 .04274 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .15486 L
.14286 .15486 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .15486 L
.14286 .15486 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07077 L
.19048 .07077 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18289 L
.2381 .18289 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .21092 L
.28571 .21092 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .0988 L
.33333 .0988 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .0988 L
.33333 .0988 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .12683 L
.38095 .12683 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12683 L
.38095 .12683 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .26697 L
.42857 .26697 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .26697 L
.42857 .26697 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .37909 L
.47619 .37909 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .37909 L
.47619 .37909 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .295 L
.57143 .295 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .295 L
.57143 .295 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .23895 L
.61905 .23895 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .23895 L
.61905 .23895 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .15486 L
.66667 .15486 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .15486 L
.66667 .15486 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .0988 L
.71429 .0988 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04274 L
.7619 .04274 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04274 L
.7619 .04274 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0988 L
.80952 .0988 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0988 L
.80952 .0988 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .04274 L
.85714 .04274 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.319626 0.732558 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .08829 L
.09524 .08829 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08829 L
.09524 .08829 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .19865 L
.2381 .19865 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .27223 L
.33333 .27223 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .27223 L
.33333 .27223 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .3458 L
.42857 .3458 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .3458 L
.42857 .3458 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .56653 L
.57143 .56653 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .56653 L
.57143 .56653 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .19865 L
.61905 .19865 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .19865 L
.61905 .19865 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .27223 L
.66667 .27223 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .27223 L
.66667 .27223 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .27223 L
.71429 .27223 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .27223 L
.71429 .27223 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .0515 L
.7619 .0515 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .0515 L
.7619 .0515 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .0515 L
.80952 .0515 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.319626 0.97619 0.45651 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .11859 L
.14286 .11859 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .11859 L
.14286 .11859 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .11859 L
.19048 .11859 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .11859 L
.19048 .11859 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .18783 L
.2381 .18783 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .18783 L
.2381 .18783 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .18783 L
.28571 .18783 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .18783 L
.28571 .18783 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .04934 L
.33333 .04934 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .04934 L
.33333 .04934 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .15321 L
.38095 .15321 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .15321 L
.38095 .15321 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .60332 L
.42857 .60332 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .49945 L
.52381 .49945 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .49945 L
.52381 .49945 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .5687 L
.57143 .5687 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .5687 L
.57143 .5687 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .15321 L
.61905 .15321 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .15321 L
.61905 .15321 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .29171 L
.66667 .29171 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .11859 L
.71429 .11859 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .11859 L
.71429 .11859 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08396 L
.7619 .08396 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.470199 0.245293 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .12508 L
.09524 .12508 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .12508 L
.09524 .12508 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .19865 L
.19048 .19865 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .19865 L
.19048 .19865 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .3458 L
.33333 .3458 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .3458 L
.33333 .3458 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .12508 L
.38095 .12508 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .19865 L
.42857 .19865 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .19865 L
.42857 .19865 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .45617 L
.47619 .45617 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .45617 L
.57143 .45617 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .45617 L
.57143 .45617 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .30902 L
.61905 .30902 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .38259 L
.66667 .38259 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .38259 L
.66667 .38259 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .23544 L
.71429 .23544 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .23544 L
.71429 .23544 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.470199 0.488926 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .10765 L
.09524 .10765 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .10765 L
.09524 .10765 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .04569 L
.14286 .04569 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .04569 L
.14286 .04569 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .26255 L
.19048 .26255 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .26255 L
.19048 .26255 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .04569 L
.2381 .04569 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .04569 L
.2381 .04569 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .23157 L
.38095 .23157 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .23157 L
.38095 .23157 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .20059 L
.42857 .20059 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .20059 L
.42857 .20059 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .41744 L
.47619 .41744 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .41744 L
.47619 .41744 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .32451 L
.57143 .32451 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .32451 L
.57143 .32451 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .26255 L
.61905 .26255 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .26255 L
.61905 .26255 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .26255 L
.66667 .26255 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .26255 L
.66667 .26255 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .20059 L
.7619 .20059 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .20059 L
.7619 .20059 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .07667 L
.80952 .07667 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.470199 0.732558 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0392403 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -6 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -6 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -6 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -6 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(2)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(4)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(6)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(8)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(10)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(12)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(14)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .11282 m
.00375 .11282 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .1913 m
.00375 .1913 L
s
0 .21092 m
.00375 .21092 L
s
0 .23054 m
.00375 .23054 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .30902 m
.00375 .30902 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .50522 m
.00375 .50522 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .5837 m
.00375 .5837 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0932 L
.04762 .0932 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0932 L
.04762 .0932 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .05396 L
.09524 .05396 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .17168 L
.14286 .17168 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .17168 L
.14286 .17168 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .2894 L
.19048 .2894 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .2894 L
.19048 .2894 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .05396 L
.2381 .05396 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .05396 L
.2381 .05396 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .0932 L
.28571 .0932 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17168 L
.33333 .17168 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .25016 L
.38095 .25016 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .25016 L
.38095 .25016 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .4856 L
.42857 .4856 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .52484 L
.47619 .52484 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .52484 L
.47619 .52484 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .21092 L
.61905 .21092 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .21092 L
.61905 .21092 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .32864 L
.66667 .32864 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .13244 L
.71429 .13244 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .13244 L
.80952 .13244 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .05396 L
.85714 .05396 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.470199 0.97619 0.607083 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0309791 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09216 -18 -4.5 ]
[-0.0125 .09216 0 4.5 ]
[-0.0125 .16961 -6 -4.5 ]
[-0.0125 .16961 0 4.5 ]
[-0.0125 .24706 -18 -4.5 ]
[-0.0125 .24706 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .40195 -24 -4.5 ]
[-0.0125 .40195 0 4.5 ]
[-0.0125 .4794 -12 -4.5 ]
[-0.0125 .4794 0 4.5 ]
[-0.0125 .55685 -24 -4.5 ]
[-0.0125 .55685 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09216 m
.00625 .09216 L
s
[(2.5)] -0.0125 .09216 1 0 Mshowa
0 .16961 m
.00625 .16961 L
s
[(5)] -0.0125 .16961 1 0 Mshowa
0 .24706 m
.00625 .24706 L
s
[(7.5)] -0.0125 .24706 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(10)] -0.0125 .32451 1 0 Mshowa
0 .40195 m
.00625 .40195 L
s
[(12.5)] -0.0125 .40195 1 0 Mshowa
0 .4794 m
.00625 .4794 L
s
[(15)] -0.0125 .4794 1 0 Mshowa
0 .55685 m
.00625 .55685 L
s
[(17.5)] -0.0125 .55685 1 0 Mshowa
.125 Mabswid
0 .0302 m
.00375 .0302 L
s
0 .04569 m
.00375 .04569 L
s
0 .06118 m
.00375 .06118 L
s
0 .07667 m
.00375 .07667 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .13863 m
.00375 .13863 L
s
0 .15412 m
.00375 .15412 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .21608 m
.00375 .21608 L
s
0 .23157 m
.00375 .23157 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .29353 m
.00375 .29353 L
s
0 .30902 m
.00375 .30902 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .37098 m
.00375 .37098 L
s
0 .38646 m
.00375 .38646 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .44842 m
.00375 .44842 L
s
0 .46391 m
.00375 .46391 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .52587 m
.00375 .52587 L
s
0 .54136 m
.00375 .54136 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09216 m
1 .09216 L
s
.99375 .16961 m
1 .16961 L
s
.99375 .24706 m
1 .24706 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .40195 m
1 .40195 L
s
.99375 .4794 m
1 .4794 L
s
.99375 .55685 m
1 .55685 L
s
.125 Mabswid
.99625 .0302 m
1 .0302 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .06118 m
1 .06118 L
s
.99625 .07667 m
1 .07667 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .21608 m
1 .21608 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .29353 m
1 .29353 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .37098 m
1 .37098 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .44842 m
1 .44842 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .52587 m
1 .52587 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04569 L
.04762 .04569 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04569 L
.04762 .04569 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .07667 L
.09524 .07667 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .13863 L
.14286 .13863 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .13863 L
.14286 .13863 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .07667 L
.19048 .07667 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .13863 L
.2381 .13863 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16961 L
.28571 .16961 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .07667 L
.33333 .07667 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .26255 L
.38095 .26255 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .26255 L
.38095 .26255 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .26255 L
.42857 .26255 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .32451 L
.47619 .32451 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .32451 L
.47619 .32451 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .41744 L
.57143 .41744 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .44842 L
.61905 .44842 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .44842 L
.61905 .44842 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .16961 L
.66667 .16961 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .16961 L
.66667 .16961 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .07667 L
.71429 .07667 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .04569 L
.7619 .04569 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04569 L
.7619 .04569 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .04569 L
.95238 .04569 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04569 L
.95238 .04569 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.620772 0.245293 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0267547 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -6 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(5)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(10)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(15)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(20)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .04147 L
.09524 .04147 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .04147 L
.09524 .04147 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .14849 L
.14286 .14849 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .14849 L
.14286 .14849 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12173 L
.19048 .12173 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .06822 L
.2381 .06822 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .06822 L
.2381 .06822 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .12173 L
.28571 .12173 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12173 L
.28571 .12173 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .12173 L
.33333 .12173 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .09498 L
.38095 .09498 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .09498 L
.38095 .09498 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .30902 L
.42857 .30902 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .202 L
.47619 .202 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .202 L
.47619 .202 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .38928 L
.57143 .38928 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .38928 L
.57143 .38928 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .202 L
.61905 .202 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .202 L
.61905 .202 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .202 L
.66667 .202 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .202 L
.66667 .202 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .14849 L
.71429 .14849 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .06822 L
.80952 .06822 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .04147 L
.95238 .04147 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .04147 L
.95238 .04147 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.620772 0.488926 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04762 .01472 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .12508 L
.09524 .12508 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .12508 L
.09524 .12508 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08829 L
.14286 .08829 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .12508 L
.19048 .12508 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .16187 L
.2381 .16187 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .12508 L
.28571 .12508 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19865 L
.33333 .19865 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .19865 L
.38095 .19865 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .27223 L
.42857 .27223 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .27223 L
.42857 .27223 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .38259 L
.47619 .38259 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .38259 L
.47619 .38259 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .52974 L
.52381 .52974 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .60332 L
.57143 .60332 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .45617 L
.61905 .45617 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .45617 L
.61905 .45617 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .27223 L
.66667 .27223 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .27223 L
.66667 .27223 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .08829 L
.7619 .08829 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .12508 L
.80952 .12508 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .12508 L
.80952 .12508 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.620772 0.732558 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0346238 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -18 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -6 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -18 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -24 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(2.5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(5)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(7.5)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(10)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(12.5)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(15)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04934 L
.04762 .04934 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .08396 L
.09524 .08396 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .08396 L
.14286 .08396 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .08396 L
.14286 .08396 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .18783 L
.19048 .18783 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .18783 L
.19048 .18783 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .22246 L
.2381 .22246 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .22246 L
.2381 .22246 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .08396 L
.28571 .08396 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .08396 L
.33333 .08396 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .08396 L
.33333 .08396 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .04934 L
.38095 .04934 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .04934 L
.38095 .04934 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .32633 L
.42857 .32633 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .32633 L
.42857 .32633 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .46482 L
.47619 .46482 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .49945 L
.57143 .49945 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .36095 L
.61905 .36095 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .36095 L
.61905 .36095 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .36095 L
.66667 .36095 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .36095 L
.66667 .36095 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .22246 L
.71429 .22246 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .22246 L
.71429 .22246 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .01472 L
.7619 .01472 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .04934 L
.80952 .04934 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.620772 0.97619 0.757656 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.47619 0.00238095 0.0147151 0.0367877 [
[.2381 -0.0125 -12 -9 ]
[.2381 -0.0125 12 0 ]
[.47619 -0.0125 -3 -9 ]
[.47619 -0.0125 3 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.95238 -0.0125 -9 -9 ]
[.95238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10668 -18 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -6 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -18 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -24 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(-100)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(0)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(100)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(200)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10668 m
.00625 .10668 L
s
[(2.5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(5)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(7.5)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(10)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(12.5)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(15)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10668 m
1 .10668 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .47456 m
1 .47456 L
s
.99375 .56653 m
1 .56653 L
s
.125 Mabswid
.99625 .03311 m
1 .03311 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .0699 m
1 .0699 L
s
.99625 .08829 m
1 .08829 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25384 m
1 .25384 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0515 L
.04762 .0515 L
.04762 .01472 L
0 .01472 L
s
0 0 1 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
0 0 1 r
.09524 .01472 m
.09524 .16187 L
.14286 .16187 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .16187 L
.14286 .16187 L
.14286 .01472 L
.09524 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .30902 L
.19048 .30902 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .30902 L
.19048 .30902 L
.19048 .01472 L
.14286 .01472 L
s
0 0 1 r
.19048 .01472 m
.19048 .12508 L
.2381 .12508 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .12508 L
.2381 .12508 L
.2381 .01472 L
.19048 .01472 L
s
0 0 1 r
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .16187 L
.28571 .16187 L
.28571 .01472 L
.2381 .01472 L
s
0 0 1 r
.28571 .01472 m
.28571 .08829 L
.33333 .08829 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .08829 L
.33333 .08829 L
.33333 .01472 L
.28571 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .16187 L
.38095 .16187 L
.38095 .01472 L
.33333 .01472 L
s
0 0 1 r
.38095 .01472 m
.38095 .19865 L
.42857 .19865 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .19865 L
.42857 .19865 L
.42857 .01472 L
.38095 .01472 L
s
0 0 1 r
.42857 .01472 m
.42857 .56653 L
.47619 .56653 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .56653 L
.47619 .56653 L
.47619 .01472 L
.42857 .01472 L
s
0 0 1 r
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .60332 L
.52381 .60332 L
.52381 .01472 L
.47619 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .52974 L
.57143 .52974 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .52974 L
.57143 .52974 L
.57143 .01472 L
.52381 .01472 L
s
0 0 1 r
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .41938 L
.61905 .41938 L
.61905 .01472 L
.57143 .01472 L
s
0 0 1 r
.61905 .01472 m
.61905 .19865 L
.66667 .19865 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .19865 L
.66667 .19865 L
.66667 .01472 L
.61905 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .12508 L
.71429 .12508 L
.71429 .01472 L
.66667 .01472 L
s
0 0 1 r
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .12508 L
.7619 .12508 L
.7619 .01472 L
.71429 .01472 L
s
0 0 1 r
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .08829 L
.80952 .08829 L
.80952 .01472 L
.7619 .01472 L
s
0 0 1 r
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .01472 L
.85714 .01472 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .0515 L
.90476 .0515 L
.90476 .01472 L
.85714 .01472 L
s
0 0 1 r
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .01472 L
.95238 .01472 L
.95238 .01472 L
.90476 .01472 L
s
0 0 1 r
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .01472 L
1 .01472 L
1 .01472 L
.95238 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.375, 511.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C0001ob000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo000h0?ooo`D000000P3oool2000000@0oooo
0P00000B0?ooo`8000005@3oool500000080oooo0P0000040?ooo`8000003`3oool4000000<0oooo
0P0000040?ooo`800000f`3oool500000080oooo0P0000040?ooo`8000004`3oool2000001D0oooo
1@0000020?ooo`800000103oool2000000h0oooo100000030?ooo`800000103oool2000003/0oooo
1@0000020?ooo`800000103oool2000001<0oooo0P00000F0?ooo`D000000P3oool2000000@0oooo
0P00000@0?ooo`@000000`3oool2000000@0oooo0P00000C0?ooo`00>P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000g03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000?03oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000004P3oool003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000F0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000=`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000F0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo
000b0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`3B0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0b0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000
01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000@P3oool500000080oooo0P0000040?ooo`8000004@3oool20000
01<0oooo1@0000020?ooo`800000103oool2000000`0oooo100000030?ooo`800000103oool20000
03/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003`0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo000i0?oo
o`800000103oool2000000@0oooo0P00000B0?ooo`8000005P3oool2000000@0oooo0P0000040?oo
o`800000403oool2000000@0oooo0P0000040?ooo`800000A@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000>@3oool2000000@0oooo0P0000040?ooo`8000004`3o
ool2000001H0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`800000103o
ool2000003`0oooo0P0000040?ooo`800000103oool2000001<0oooo0P00000G0?ooo`800000103o
ool2000000@0oooo0P00000A0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`00hP3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooomD0?ooo`00fP3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0o`3ooomB0?ooo`00hP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000o`3ooomD0?ooo`006P3oool2000000<0ooooOP0000140?ooo`800000103oool20000
00@0oooo0P00000A0?ooo`800000503oool2000000@0oooo0P0000040?ooo`8000003@3oool20000
00@0oooo0P0000040?ooo`8000006`3oool2000000@0ooooO@00000L0?ooo`8000000`3ooon20000
01<0oooo000I0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0A0?ooo`006@3oool010000000oooo0?ooo`0000020?ooogh00000_03o
ool010000000oooo0?ooo`0000030?ooogh000006P3oool010000000oooo0?ooo`0000020?oooh80
00004`3oool001T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`090?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2j0?ooo`04
0000003oool0oooo000000<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0140oooo000I0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool02@3oool00`000000003o0000o`030000o`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool09@3oool2000000<0ooooMP00000J0?ooo`040000003oool0oooo000000<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00P0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo
000J0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo
0P0000040?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0J0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo
000O0?ooo`800000103oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool02@3oool700000100oooo0P00000V0?ooo`040000003oool0oooo00000080oooo
MP00000Q0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0O0?ooo`800000103oool00`000000003o0000o`030000o`P000001@000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`P00000403oool2000001<0oooo000O0?ooo`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0903oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo
00<000000000o`000?l00`000?l7000000D0003o1`0000040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
1`0000050000o`030000003oool0oooo00P0oooo1`0000050?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0T0?ooo`040000003oool0oooo00000080oooo0P0000090?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0U0?ooo`8000000`3oool2000000T0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o1`0000040?ooo`L0000010000?l00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01l0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`007`3oool2000000@0oooo1`0000050?ooo`L000001@000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo0200oooo0P00000/0?ooo`030000003oool0oooo00P0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool03P3oool00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool07`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0O0?ooo`800000103oool00`000000003o0000o`03
0000o`030000003oool0oooo00@0oooo1`0000050000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l7000001L0oooo0P00000C0?ooo`007`3oool00`000000oooo0?ooo`0E0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02X0oooo0P0000090?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00h0oooo00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo100000030?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`030000003oool0oooo00X0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?oo
o`007`3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0203oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool02P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo000O0?ooo`800000
5P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
803oool2000001X0oooo100000030?ooo`800000103oool2000000<0oooo0P0000090?ooo`030000
00000?l0003o00<0003o1P0000050000o`03000000000?l0003o0080003o1`0000050000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo00h0oooo1P00000@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0`3oool7000000D0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`L00000
5@3oool200000240oooo0P0000040?ooo`L00000303oool00`000000003o0000o`030000o`L00000
1@000?l7000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o1`00000M0?ooo`8000004`3oool001l0oooo00<000000?ooo`3oool05@3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5P3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000000T0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool08`3oool2000001X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo0280oooo00<000000?ooo`3oool04@3oool001l0oooo00<0
00000?ooo`3oool05@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo0P00
00030?ooo`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?oo
o`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0I0?ooo`800000103oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo0280oooo00<0
00000?ooo`3oool04@3oool001l0oooo0P00000F0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o1`00000R
0?ooo`8000006P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo0P00
00090?ooo`L00000103oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`8000005`3oool7000000D0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l=000002<0oooo0P00000C0?ooo`007`3oool00`000000oooo0?ooo`0E
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I
0?ooo`8000002P3oool300000080oooo0P00000D0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l7000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o1`00000R0?ooo`030000003oool0oooo01X0oooo0P000003
0?ooo`030000003oool0oooo0280oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0140oooo000J0?ooo`8000000`3oool00`000000oooo0?ooo`0E0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A
0?ooo`006@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02X0oooo0P00000D
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo008000008`3oool00`000000003o0000o`030000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo02d0oooo0P00000C0?ooo`00703oool00`000000oooo0?ooo`02000001H0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`d0000010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool09P3oool2000002`0oooo00<000000?oo
o`3oool04`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?oo
o`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?oo
o`3oool06P3oool300000080oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01X0oooo0P0000030?ooo`030000003oool0oooo0280oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000J0?ooo`80
00000`3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09@3oool2000000<0oooo0P00000D0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`00
0000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0R0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0A0?ooo`006P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00T0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0603oool500000080oooo0P00000:0?ooo`L000001@3oool<0000
00D0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0U0?ooo`800000703oool30000
0080oooo00<000000?ooo`3oool08P3oool00`000000003o0000o`030000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02h0oooo00<000000?ooo`3oool04@3oool001X0oooo0`0000020?ooo`8000005P3oool00`000000
003o0000o`030000o`L000002`3oool00`000000003o0000o`020000o`L000001@000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0V0?ooo`800000:@3oool00`000000oooo0?ooo`02000001@0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo1`0000040000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`80
00006P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo0P00000S0?oo
o`L000001@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0;@3oool2000001<0oooo000O0?ooo`030000003oool0oooo01D0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0?0?ooo`03000000000?l0003o0080003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09@3oool2000000<0oooo00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool02@3oool00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0V0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0
5@3oool00`000000003o0000o`030000o`030000003oool0oooo00l0oooo00<000000000o`000?l0
0P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo0P00000D0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo02@0oooo00<000000?ooo`3oool06P3oool2000000<0oooo00<000000?ooo`3oool0
9P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000003o
ool0oooo01D0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0?0?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool09@3oool300000080oooo0P00000D0?ooo`0300000000
0?l0003o00<0003o1P00000;0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3o
ool001l0oooo0P00000F0?ooo`L000004@3oool00`000000003o0000o`020000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0V0?ooo`800000;03oool0
0`000000oooo0?ooo`0C0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool03P3oool0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool2
000002l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo02d0oooo0P00000C0?ooo`007`3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0:P3oool2000001@0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001l0
oooo00<000000?ooo`3oool0;@3oool00`000000003o0000o`020000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`030000003oool0oooo00h0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02H0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo
0?ooo`0]0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo02L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`800000103oool2000000<0oooo0P00000D0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool03P3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool09P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02H0oooo
00<000000?ooo`3oool07`3oool2000002l0oooo1`0000050000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02d0oooo
0P00000C0?ooo`007`3oool2000002h0oooo00<000000000o`000?l00P000?l00`000000oooo0?oo
o`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09P3oool2000001`0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0603oool3000000@0oooo00<000000?ooo`3oool09P3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o0080003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00800000503o
ool00`000000003o0000o`030000o`030000003oool0oooo00h0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08`3o
ool2000001X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0V0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0140oooo000O0?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00P00
0?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003o
ool0oooo01<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0>0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`800000
9`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02D0oooo0P00000Q0?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0140oooo000O0?ooo`800000;P3oool6000000D0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0V0?ooo`8000006P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo0080oooo0P00000D0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
3P3oool6000000D0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01P0oooo0`0000040?ooo`030000003oool0oooo02H0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo0P00000e0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`L00000
;`3oool2000001<0oooo000O0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01P0oooo100000090?ooo`<000000P3o
ool00`000000oooo0?ooo`0C0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3o
ool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02H0oooo00<000000?ooo`3oool04`3o
ool500000080oooo0P0000030?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0A0?ooo`004`3oool500000080oooo0P0000030?ooo`030000003oool0
oooo03P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02X0oooo0P00000D0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0I0?ooo`<000000`3oool00`000000oooo0?ooo`0V0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000f0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo
00<000000?ooo`3oool04@3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000003X0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02X0oooo0P00000D0?ooo`L000005@3oool00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo02H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00800000=@3oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`8000004`3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00800000>@3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l7000002P0oooo0P00000/0?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`L00000:03oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000f0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l01000
0?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003X0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0N0?ooo`D000000P3oool2000000<0oooo
0P00000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000003H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000>P3oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000340oooo00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0503oool2000000@0oooo
0P0000030?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0A0?ooo`00503oool2000000@0oooo0P0000030?ooo`030000003oool0oooo03P0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0200000300oooo00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o3000000U0?ooo`8000006`3oool2000000@0oooo
00<000000?ooo`3oool09P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01l0oooo
0P00000e0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o
0000o`030000o`030000003oool0oooo03<0oooo0P00000C0?ooo`007`3oool2000003T0oooo00<0
00000000o`000?l00`000?l7000000D0003o00<000000?ooo`3oool0;03oool200000280oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000340oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool09P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000O0?ooo`03
0000003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000300oooo00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo0P00000W
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo02/0oooo0P00000Q0?ooo`030000003oool0oooo03@0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0h0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool07`3oool2000000@0oooo0P0000030?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0I0?oo
o`800000103oool00`000000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02`0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool001l0oooo0P00000i0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`030000o`030000003oool0oooo02`0oooo0P00000/0?ooo`80
0000<03oool7000000@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0V0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool07`3oool2000003D0oooo1`0000060000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<`3oool2000001<0oooo000O0?ooo`03
0000003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Z0?ooo`80
0000=P3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0I0?ooo`800000103oool00`000000oooo0?ooo`0V0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo000O0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000003o
ool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`D0000000<0
oooo0000000000000P0000030?ooo`800000103oool2000000<0oooo0P00000f0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool09P3oool7000000D0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01l0oooo0P00000k0?ooo`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`8000004`3o
ool001l0oooo0P00000i0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool7
000002h0oooo0P00000F0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0/0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3oool00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`02000003H0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000Q0?ooo`030000003o
ool0oooo02`0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0140oooo000O0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0;03oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03X0oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0>03oool00`00
0000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`800000=P3oool00`000000003o0000o`020000o`L00000<@3oool00`000000oooo0?ooo`0B
0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0;03oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0O
0?ooo`800000>`3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0<`3oool2000001<0oooo000O0?ooo`800000>@3oool00`000000003o0000o`030000
o`030000003oool0oooo03P0oooo0P00000E0?ooo`800000103oool2000000X0oooo0`0000020?oo
o`030000003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?ooo`D000000P3oool2000000<0oooo00<0
00000?ooo`3oool0>P3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`004`3oool500000080oooo0P000003
0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo02X0oooo0P00000f0?ooo`03000000000?l0003o0080003o00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`3oool2000002d0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l7000002d0oooo
0P00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000l0?oo
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0140oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000j0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0Z0?ooo`800000=P3oool00`000000003o0000o`020000o`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000^0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P00000k0?ooo`03000000000?l0003o00@0003o1`00000e0?ooo`8000004`3oool001D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`02000003T0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0h0?ooo`800000;03oool00`000000oooo0?ooo`0e0?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002h0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00P3oool2000000<0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000o`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool001D0oooo00<000000?ooo`3oool0
0P3oool2000000<0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`030000o`030000
003oool0oooo03T0oooo00<000000?ooo`3oool07P3oool500000080oooo0P0000030?ooo`800000
=P3oool00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
4`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02`0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l0
10000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0P0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000g0?ooo`03000000000?l0003o0080
003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02`0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01@0
oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0
003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`00503oool2000000@0oooo
0`0000020?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`02000003H0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0d0?ooo`800000
8@3oool00`000000oooo0?ooo`0/0?ooo`L000001@000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0O0?ooo`800000
>`3oool00`000000003o0000o`040000o`030000003oool0oooo03T0oooo0P00000C0?ooo`007`3o
ool2000003T0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0h0?ooo`8000008P3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0e0?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0380oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo03X0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0140oooo000O0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`800000=P3oool00`000000003o0000o`020000o`030000003oool0
oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo0380oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0
003o00@0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`00
0000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0O0?ooo`800000103oool300000080oooo00<000000?ooo`3oool0=@3oool00`00
0000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool50000
00030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`0b0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
0380oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o
00@0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000
oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0Z0?ooo`800000=P3oool00`000000003o0000o`020000o`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0<P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01l0oooo0P00000k0?oo
o`03000000000?l0003o00@0003o00<000000?ooo`3oool0>@3oool2000001<0oooo000O0?ooo`80
0000>@3oool00`000000003o0000o`030000o`030000003oool0oooo03P0oooo0P00000/0?ooo`03
0000003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80
0000<`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0a0?ooo`8000008@3oool00`000000oooo0?ooo`0j0?ooo`03
000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`00
7`3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0Z0?ooo`800000=P3oool00`000000003o0000o`020000o`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000
003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0>03o
ool00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool04P3o
ool5000000<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000030?ooo`800000=P3o
ool00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0503o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000d0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo0380oooo00<000000?ooo`3oool07`3oool2000003/0oooo00<000000000o`00
0?l010000?l00`000000oooo0?ooo`0i0?ooo`8000004`3oool001l0oooo0P00000i0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0=@3oool00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0380oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03X0oooo00<000000000o`00
0?l010000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000
003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00800000=P3oool00`000000003o0000o`020000o`030000003oool0oooo03@0oooo
0P00000Q0?ooo`030000003oool0oooo0380oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0140oooo000O0?ooo`030000003oool0oooo03P0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?oo
o`0e0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0380oooo00<000000000o`000?l00`000?l=000003@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`000000oooo0?ooo`0h
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo0P00000f0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0380oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo0P00000k0?ooo`0300000000
0?l0003o00@0003o00<000000?ooo`3oool0>@3oool2000001<0oooo000O0?ooo`800000>@3oool0
0`000000003o0000o`030000o`030000003oool0oooo03P0oooo0P00000E0?ooo`8000000`3oool4
000000T0oooo0`0000020?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<P3oool0
0`000000003o0000o`030000o`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool4
000000<0oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo000C0?ooo`@000000`3oool20000
00<0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`030000o`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0:P3oool2000003H0oooo00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo1@0000030?ooo`<000000P3oool00`00
0000oooo0?ooo`0b0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`030000o`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0
003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000d0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool2000003/0oooo00<000000000o`000?l010000?l00`000000oooo
0?ooo`0i0?ooo`8000004`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`800000>@3oool7000003X0oooo0P00000/0?ooo`800000=P3oool6000003L0oooo
00<000000?ooo`3oool0503oool010000000oooo0?ooo`3oool500000080oooo0P00000c0?ooo`L0
0000?`3oool2000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000003`0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0140oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
001l0?ooo`030000003oool0oooo02X0ooooMP00000F0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000007/0oooo00<000000?ooo`3oool04`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>P3oool0
0`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool0
01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooogh00000^03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0ooooO@00000F0?ooo`800000103o
ool2000000<0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool04@3oool001@0oooo0P0000040?ooo`800000o`3oooli
0?ooo`8000001@3oool200000:40oooo0P00000k0?ooo`P00000>`3oool2000001<0oooo003o0?oo
ool0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0140oooo003o0?ooool0ooooPP00000C0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3o
ool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0oooo
o`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?oo
o`00=`3oool500000080oooo0P0000040?ooo`8000004`3oool2000001H0oooo1@0000020?ooo`80
0000103oool200000100oooo100000030?ooo`800000103oool2000003T0oooo1@0000020?ooo`80
0000103oool2000001<0oooo0P00000D0?ooo`D000000P3oool2000000@0oooo0P00000?0?ooo`@0
00000`3oool2000000@0oooo0P00003o0?oooeL0oooo000i0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
5@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00003o0?oooeH0oooo000i0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
00005`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00003o0?oooeH0oooo000a0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`@00000103oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo000001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oooe@0oooo000i0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000120?ooo`D000000P3oool2000000@0oooo
0P00000A0?ooo`8000004`3oool500000080oooo0P0000040?ooo`8000003@3oool4000000<0oooo
0P0000040?ooo`800000@@3oool500000080oooo0P0000040?ooo`800000403oool2000001<0oooo
1@0000020?ooo`800000103oool2000000d0oooo100000030?ooo`800000103oool2000001<0oooo
000h0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3oool2000000@0oooo0P00
00040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000>P3oool2000000@0oooo0P00
00040?ooo`8000004`3oool2000001D0oooo0P0000040?ooo`800000103oool200000100oooo0P00
00040?ooo`800000103oool2000004D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000180oooo003o0?oooh<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180
oooo003o0?ooog/0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03P0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0100oooo003o0?oooh<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000480oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00
000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000180oooo000H0?ooo`800000X03oool200000<D0oooo0P000004
0?ooo`800000103oool200000140oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>
0?ooo`800000103oool2000000@0oooo0P0000120?ooo`800000103oool2000000@0oooo0P00000@
0?ooo`800000503oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo0P000004
0?ooo`8000004`3oool001L0oooo00@000000?ooo`3oool000000P3ooon2000001X0oooo00@00000
0?ooo`3oool000000`3ooomm00000?l0ooooE`3oool001L0oooo00@000000?ooo`3oool000000P3o
oon2000001X0oooo00@000000?ooo`3oool000000`3ooomm00000?l0ooooE`3oool001L0oooo00@0
00000?ooo`3oool000000P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?ooo`03000000000?l0003o0080
003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooE@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000030?oo
o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02D0oooo0P0000030?ooogH000009@3oool2000000@0ooooMP00000C0?oo
o`00603oool2000000<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03
0000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`080?ooo`80
00006`3oool2000000@0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool00`3oool00`000000003o0000o`040000o`030000003oool0oooo00T0oooo00<000000?oo
o`3oool07`3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0503oool2000002H0oooo00@000000?ooo`3oool000000P3ooomf000002@0oooo00@00000
0?ooo`3oool000000`3ooomf000001<0oooo000M0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`03000000000?l0003o0080003o00<00000
0?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool000000P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool03P3oool00`000000003o0000o`020000o`030000003oool0oooo0280oooo00@0
00000?ooo`3oool000000`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`007@3oool=000000H0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo2000
000:0?ooo`8000008@3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo00000080oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00h0oooo
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo0080
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo01<0
oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01H0oooo
00<000000?ooo`3oool07`3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`8000000`3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool03P3oool00`000000003o
0000o`020000o`030000003oool0oooo02<0oooo0P0000040?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0C0?ooo`8000004`3oool001d0oooo0P00
000:0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`030000003oool0oooo01D0oooo0P00000Q0?ooo`H000001@3oool=000000D0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`L000005P3oool2000002`0oooo1`00
00050000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`L0000010000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00h0oooo1P00
000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0140oooo000G0?ooo`@000000P3oool00`000000oooo0?ooo`09
0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000?ooo`3oool04`3oool2000001<0oooo000G0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?oo
o`800000103oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0:@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo0?ooo`020?ooo`80
00002P3oool8000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo00<0oooo1`00000G0?ooo`8000008@3oool00`000000oooo0?ooo`0D0?ooo`L0
00001@000?l7000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0P0?ooo`80
0000;03oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P0000040?ooo``0
0000103oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l<000001D0oooo0P00000C0?ooo`006@3oool01@000000oooo0?ooo`3oool000000180
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02X0
oooo0P0000040?ooo``000001@000?l00`000000003o0000o`020000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`L0000010000?l7000001D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0140oooo000G0?ooo`040000003oool0oooo00000080oooo0P00000A0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
0240oooo0P00000Q0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo100000030?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool03P3oool00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo
01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo
0?ooo`8000003P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0N0?ooo`8000004`3oool001P0oooo0P0000030?oo
o`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<00000
0?ooo`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo000M0?oo
o`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o1`00000R0?ooo`8000006`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo008000003`3oool00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo
01T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o1P0000050000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0N0?ooo`8000004`3oool001d0oooo0P00000A0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o1`0000050000o`030000003oool0oooo0240oooo0P00000Q0?ooo`030000003oool0oooo
01X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00P0oooo0P0000030?ooo`030000003oool0oooo00h0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`<000000`3oool00`00
0000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool001d0
oooo00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01T0
oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0H0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool20000
00l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00P000?l7000000@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo1P00000K0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0N0?ooo`8000004`3oool001d0
oooo0P00000A0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`030000o`030000003oool0oooo0240oooo0P00000J0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool06P3oool00`000000003o0000o`030000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01T0oooo0P00000:0?ooo`<000000P3oool00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool03@3oool=000000@0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool07P3oool20000
01<0oooo000I0?ooo`<0000000<0oooo0000003oool04@3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`L000001@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02H0oooo0P00000/0?ooo`8000003`3oool00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0A0?ooo`006P3oool010000000oooo0?ooo`00000B0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo
0280oooo00<000000?ooo`3oool06@3oool2000000@0oooo00<000000?ooo`3oool09P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0>0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo
01h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool07P3oool2000001<0oooo000G0?ooo`D0000000<0oooo00000000
00004@3oool00`000000003o0000o`030000o`L000001@000?l=000000D0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool08@3oool2000001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Z0?ooo`80
00003`3oool00`000000003o0000o`030000o`H000001@3oool00`000000003o0000o`020000o`03
0000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0403oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`<000000`3oool00`000000oooo0?ooo`0V0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l<000002P0oooo0P00000/0?oo
o`030000003oool0oooo00h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?oo
o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02D0oooo00@000000?ooo`3oool0oooo0P00000O0?ooo`L0000010000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o3000000P0?ooo`8000004`3oool0
01P0oooo00<000000?ooo`0000000P3oool200000140oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`030000003oool0oooo0240oooo0P00000Q0?ooo`030000003oool0oooo
02H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
0380oooo00<000000?ooo`3oool09@3oool2000000<0oooo0P00000?0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`800000103oool00`00
0000oooo0?ooo`0T0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001T0
oooo0P0000020?ooo`030000003oool0oooo0100oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool02@3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`030000o`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0>0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0203oool00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0Y0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0403oool00`000000
003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo02H0oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo0380oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`02000000l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`H0
00001@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0`0000030?ooo`03
0000003oool0oooo02@0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00
7@3oool200000140oooo1`0000050?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
2@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`030000003oool0oooo0240oooo0P00000Q0?ooo`030000
003oool0oooo02H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo0340oooo0P00000W0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool04`3oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0903oool6000000D0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0703o
ool00`000000003o0000o`030000o`030000003oool0oooo00T0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`007@3oool2
000001d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`090?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool08@3oool200000240oooo00<000000?ooo`3oool09P3oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0U0?ooo`<000000P3oool2000000l0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0C0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000G0?ooo`<000000`3oool00`00
0000oooo0?ooo`0L0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool03P3oool00`00
0000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0Y0?ooo`8000004`3oool001L0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0L0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0V0?ooo`03000000000?l0003o00<0003o1`0000050000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0a0?ooo`800000;03oool20000
00l0oooo1`00000E0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0A0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`8000007@3oool7
000000/0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo00<0oooo1`00000S0?ooo`8000008@3oool00`000000oooo0?ooo`0V0?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000002X0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02T0oooo0P00
000C0?ooo`005`3oool3000000<0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo02H0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo0380oooo00<000000?ooo`3oool0:P3oool2000002/0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo0P000004
0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001P0oooo00<000000?oo
o`3oool00P3oool2000002l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02d0oooo0P00000Q0?ooo`030000003oool0oooo02H0oooo1`0000050?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo0340oooo0P00000/0?ooo`030000003oool0oooo02X0oooo00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool001P0oooo0`0000020?oo
o`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo0380oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`800000103oool2000000<0oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?oo
o`3oool05P3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo02T0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?oo
o`3oool04@3oool001d0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`D0
00000P3oool2000000@0oooo00<000000?ooo`3oool0<P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`030000003oool0oooo02T0oooo0P00000C0?ooo`007@3oool2000002l0oooo1`0000050000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo02d0oooo0P00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000003@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000[0?ooo`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0
003o00<0003o1P0000050000o`03000000000?l0003o00<0003o1P00000[0?ooo`8000004`3oool0
01d0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo0000000d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo0340oooo0P00000M0?ooo`030000003o
ool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo02X0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000M0?ooo`800000=@3oool0
0`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02d0oooo0P00000F0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003@0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool00P3oool2000002/0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0L0?ooo`D0
00000P3oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`03
0000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo02h0oooo0P00000C0?ooo`00603oool2000000<0oooo00<000000?ooo`3oool0
=03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000d0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0603oool4000000T0oooo0`0000020?oo
o`030000003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000G
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0=03oool00`000000003o0000
o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo0380oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0Z0?ooo`800000:`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000:P3oool00`000000
003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C0?ooo`005`3oool010000000oooo
0?ooo`0000020?ooo`800000=@3oool00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02d0
oooo0P00000Q0?ooo`030000003oool0oooo0380oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<@3oool2000002`0
oooo00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000:`3oool0
0`000000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool0
01P0oooo0P0000030?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000003o0000o`030000o`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02h0oooo0P00000C0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`800000=@3o
ool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo02d0oooo0P00000Q0?ooo`030000003o
ool0oooo0380oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Z0?ooo`800000:`3o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o``000009P3oool00`000000oooo0?ooo`0M0?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool04@3oool001P0oooo0P0000030?ooo`030000003oool0
oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0<P3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0a0?ooo`800000;03oool0
0`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0^0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0=03oool00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0b0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo0380oooo00<000000?ooo`3oool07P3oool50000
0080oooo0P0000030?ooo`800000:`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003D0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0]0?ooo`8000008@3oool00`000000
oooo0?ooo`0b0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo0380oooo00<000000?ooo`3oool0803oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000;03oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000M0?oo
o`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<P3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000:`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o1`000004
0000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0403oool5000000030?ooo`000000
0000008000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo1`000004
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^
0?ooo`8000004`3oool001d0oooo0P00000e0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0;@3oool200000240oooo00<000000?ooo`3oool0<P3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0a0?oo
o`8000008P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000;03o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3o
ool00`000000003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000A0?ooo`D000000P3oool2000000<0oooo
00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo0380oooo
00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`3oool2000003D0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02h0oooo0P00000C0?ooo`004`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000=P3oool00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo02h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo0380oooo00<000000?ooo`3oool07`3oool2000000@0oooo0P0000030?ooo`030000003oool0
oooo02X0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000103oool0
0`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`02000003D0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0]0?ooo`8000008@3oool00`000000oooo0?ooo`0b0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo0380oooo00<000000?ooo`3oool0:P3oool2000002/0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0d0?ooo`03000000000?l0003o00<0003o1`00000`0?ooo`8000004`3oool001<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003H0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
<P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o1`00000c0?ooo`800000
;03oool00`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`0000030?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`02000003D0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0]0?ooo`800000
503oool500000080oooo0P0000040?ooo`030000003oool0oooo0380oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
:P3oool2000002/0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`030000
003oool0oooo03@0oooo0P00000C0?ooo`004P3oool2000000@0oooo0P0000030?ooo`030000003o
ool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000=03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0=03oool00`000000003o0000o`030000o`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04@3oool001d0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`030000
00000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000=03oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0=`3oool2000002`0oooo0P00000[0?ooo`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080
003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03@0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`8000004`3oool001d0oooo
0P00000e0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;@3oool2000001H0oooo
00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0<P3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0B0?ooo`D0000000<0oooo0000000000000P0000030?ooo`800000103oool2000000<0oooo
00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0703oool500000080oooo0P0000040?ooo`030000003oool0oooo03@0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`8000004`3oool001d0oooo00<0
00000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000
2`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02X0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3oool00`000000003o0000o`03
0000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?oo
o`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?oo
o`3oool04`3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo0380oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000e
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000A0?oo
o`D0000000<0oooo0000000000000P0000020?ooo`800000=@3oool00`000000003o0000o`030000
o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02d0oooo0P00000Q0?ooo`030000003oool0oooo0380oooo1`0000050000
o`030000003oool0oooo03L0oooo0P00000F0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool2000000<0oooo00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?oo
o`800000103oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P00000[
0?ooo`03000000000?l0003o0080003o1`0000050?ooo`H00000<@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000003D0oooo00<000000000
o`000?l00`000?l8000000D0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0]0?oo
o`8000008@3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`800000103oool2000000X0oooo0`0000020?oo
o`030000003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`100?oo
o`030000003oool0oooo01d0oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0d0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?oo
o`004`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000=P3oool00`00
0000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0Z0?ooo`800000:`3oool00`000000003o0000o`020000o`030000003oool0oooo
0400oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000f0?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0103oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0g0?ooo`800000;03oool00`000000oooo0?ooo`0Z
0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0140oooo000B0?ooo`800000103oool2000000<0oooo0P00000e0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;@3oool200000240oooo00<000000?oo
o`3oool0>03oool00`000000003o0000o`030000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0:P3oool2000002/0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`100?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000
o`030000003oool0oooo03@0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0d0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo03P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000o`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0403oool5000000<0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0d0?ooo`8000004`3oool001d0oooo0P00000e0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`L00000
;`3oool200000240oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`030000o`030000
003oool0oooo03L0oooo0P00000P0?ooo`D000000P3oool2000000<0oooo0P00000[0?ooo`030000
00000?l0003o0080003o00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000002`0oooo00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`800000=@3oool00`000000003o0000o`03
0000o`030000003oool0oooo03@0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0d0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0h0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000[0?ooo`03000000000?l0003o
0080003o00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`00
0000003o0000o`030000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00140
oooo1@0000030?ooo`<0000000<0oooo000000000000=@3oool00`000000003o0000o`030000o`03
0000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`80
00008@3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`03
0000003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000C0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool00000=P3oool00`000000003o0000o`030000o`030000003oool0oooo
00@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`030000o`030000003oool0oooo
03L0oooo0P00000R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0A0?ooo`8000000`3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo
03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0140oooo000C0?ooo`040000003oool0oooo0?ooo`D0000000<0oooo000000000000=@3oool00`00
0000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0c0?ooo`8000008@3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0O0?ooo`800000103oool30000
0080oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0d0?ooo`8000004`3oool001<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000003H0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`04
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B
0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`03
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z
0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0103oool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0>03oool00`000000003o0000o`030000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0:P3oool2000002/0oooo1P0000120?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0=03oool7000003H0oooo0P00000C0?ooo`004P3oool2000000D0oooo0P0000020?oo
o`800000=@3oool00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`8000005@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>03oool7000003T0oooo0P00000/
0?ooogH00000:`3ooomf000001<0oooo000M0?ooo`030000003oool0oooo03@0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`3ooomm00000?l0ooooE`3oool001d0oooo0P00000e0?ooo`L000001P3oool7
000003D0oooo0P00000D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
o`3ooooG0?ooo`007@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04`3oool2000000@0oooo0P00003o0?ooomP0oooo000M0?oooh800000o`3ooooe
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3o
oooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0
oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00e`3oool500000080oooo0P000004
0?ooo`800000503oool2000001D0oooo1@0000020?ooo`800000103oool200000100oooo10000003
0?ooo`800000103oool200000?l0ooooE@3oool00=T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000?l0ooooE03oool00=T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000?l0ooooE03oool00=40oooo100000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooDP3oool00400oooo
1@0000020?ooo`800000103oool200000100oooo0P00000C0?ooo`D000000P3oool2000000@0oooo
0P00000=0?ooo`@000000`3oool2000000@0oooo0P00000j0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000100?ooo`D000000P3oool2000000@0oooo0P00000A
0?ooo`8000004`3oool500000080oooo0P0000040?ooo`8000003@3oool4000000<0oooo0P000004
0?ooo`800000@@3oool500000080oooo0P0000040?ooo`800000403oool2000001<0oooo1@000002
0?ooo`800000103oool2000000d0oooo100000030?ooo`800000103oool2000001<0oooo00120?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000h0?ooo`800000103o
ool2000000@0oooo0P00000D0?ooo`8000005P3oool2000000@0oooo0P0000040?ooo`8000004@3o
ool2000000@0oooo0P0000040?ooo`800000@`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000004P3oool00480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000>80oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000480
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo000j0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3H0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0h0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`00@P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000hP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000@P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00004P3oool00440oooo0P0000040?ooo`800000103oool200000100oooo0P00000D0?ooo`800000
103oool2000000@0oooo0P00000>0?ooo`800000103oool2000000@0oooo0P00003R0?ooo`800000
103oool2000000@0oooo0P00000A0?ooo`800000503oool2000000@0oooo0P0000040?ooo`800000
3P3oool2000000@0oooo0P0000040?ooo`800000@P3oool2000000@0oooo0P0000040?ooo`800000
403oool2000001@0oooo0P0000040?ooo`800000103oool2000000h0oooo0P0000040?ooo`800000
103oool2000001<0oooo002h0?ooo`800000103ooon100000?l0ooooE@3oool00;L0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooe<0oooo002g0?ooo`040000003oool0
oooo000000<0ooooP@00003o0?oooeD0oooo000S0?ooo`800000103ooomf000001P0oooo00@00000
0?ooo`3oool000000`3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo0P00
00030?ooogH000009@3oool2000000@0ooooMP00000C0?ooo`008P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000003o
0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00280
oooo00@000000?ooo`3oool000000`3ooomf000001T0oooo0P0000040?ooo`L000001@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`P000001@000?l700000140oooo00<000000?ooo`3oool08P3oool01000
0000oooo0?ooo`0000020?ooogL000008`3oool010000000oooo0?ooo`0000030?ooogH000004`3o
ool00280oooo00@000000?ooo`3oool000000`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool0203oool00`000000003o0000o`030000o`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o0080003o00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`040000
003oool0oooo000000<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00280oooo00@000000?ooo`3oool0
00000`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3o
ool0203oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo0P00000O0?ooo`03
0000003oool0oooo00T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0R0?ooo`04
0000003oool0oooo00000080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000?ooo`3oool04`3oool2000001<0oooo000S0?oo
o`800000103oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?oo
o`3oool0203oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0103oool00`000000003o0000o`030000o`030000003oool0oooo01D0oooo00<000000?oo
o`3oool08`3oool2000000<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02<0oooo0P0000040?ooo`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000Y0?ooo`H0
00001@000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o1P00000:0?ooo`L0
0000103oool2000001l0oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`030000o`L0
00001@000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02P0oooo1`0000050000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o300000050?ooo`H000002P3oool00`000000oooo0?ooo`0Y0?ooo`H0
00001@000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`L0000010000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o1P00000E0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0
0P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
2@3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo01P0oooo0P00000O0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0X0?ooo`800000103oool00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0603oool2000001<0oooo000Y0?ooo`030000003oool0
oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00T0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l7000000H0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o1`0000060?ooo`L000005`3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool0
01H0oooo100000030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00P3oool<0000
00D0003o300000050000o`H000001@000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l7000001X0oooo0P00000O0?ooo`030000003oool0oooo
00T0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo
01h0oooo00<000000?ooo`3oool05P3oool4000000<0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`L0000010000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l7000001X0oooo0P00000C0?ooo`005P3oool00`000000
oooo0?ooo`090?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool00`00
0000003o0000o`030000o`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0F0?ooo`@000000`3oool2000000@0oooo0P0000030?ooo`800000103oool<0000
00D0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo
01h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04@3oool001L0oooo00<000000?ooo`3oool02`3oool01@00
0000oooo0?ooo`3oool0000000l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`08
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo01h0oooo0P00000O0?ooo`030000003oool0oooo00T0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`800000
2@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`030000003oool0oooo01h0oooo0P00000C0?ooo`00603o
ool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0203oool00`000000003o0000o`030000o`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`030000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo00<0oooo200000050000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`02000000l0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo000F
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0203oool00`000000003o0000
o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o1P00000P0?ooo`8000007`3oool00`000000oooo0?oo
o`090?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool02P3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool2000000<0oooo00<0
00000?ooo`3oool03P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
300000050000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`H00000803oool2000001<0oooo000G0?ooo`8000002P3oool3000000<0oooo00<0
00000?ooo`3oool03@3oool00`000000003o0000o`030000o`030000003oool0oooo00P0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000003o0000
o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo00X0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool2000000l0oooo
1`0000040000o`L0000010000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`8000002P3oool3000000<0oooo
00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool03@3oool00`000000003o0000
o`030000o`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo02<0oooo0P00000H0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool02@3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00X0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0G0?ooo`8000002P3oool300000080oooo
00<000000?ooo`3oool0503oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool002T0oooo00<0
00000?ooo`3oool03@3oool00`000000003o0000o`030000o`030000003oool0oooo00P0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0000000/0oooo1`0000050?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0:0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l7000002T0oooo0P00000Z0?ooo`800000
5@3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003o
ool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000006@3o
ool2000000@0oooo00<000000?ooo`3oool05@3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01@0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`H000001@00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l6000000D0003o00<000000?ooo`3oool08`3oool2000001<0oooo000Y0?ooo`030000003oool0
oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02P0oooo0P00000E0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`020000o`L0000010000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000?ooo`3oool0203oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0140oooo000S0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0203oool00`000000003o0000o`030000o`030000003oool0oooo
0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool08`3oool2000001T0oooo0`0000030?ooo`030000003oool0oooo
01D0oooo1`0000050000o`030000003oool0oooo00X0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0D0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo
01<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
00P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool08`3oool2000001<0oooo000R0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`030000003oool0oooo
00P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`8000000`3oool20000
01D0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo01<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo00P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`009@3oool01@00
0000oooo0?ooo`3oool0000000l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`08
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S
0?ooo`8000007`3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0503oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo0?ooo`800000
503oool<000000X0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool08`3oool2000001<0oooo000S0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0203o
ool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P00
000E0?ooo`H000001@3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l7000000@0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`08
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S
0?ooo`8000007`3oool00`000000oooo0?ooo`0K0?ooo`L00000303oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S
0?ooo`8000000`3oool00`000000oooo0?ooo`0O0?ooo`03000000000?l0003o0080003o00<00000
0?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool08`3oool2000001<0oooo000S0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0203oool00`000000003o0000o`030000
o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01l0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?oo
o`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00P3oool00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool002T0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`03
0000003oool0oooo00P0oooo1`0000040?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l7000002D0oooo0P00000O0?ooo`030000003oool0oooo02h0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool08`3oool300000080oooo0P00000P0?ooo`03000000000?l0003o0080003o00<000000?ooo`3o
ool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00P3oool00`000000003o0000o`030000o`030000003oool0oooo02<0oooo0P00000C0?ooo`00
:@3oool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
4`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l700000300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0O0?ooo`030000
00000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000
003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool03@3o
ool00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo02T0oooo0P00000O0?ooo`030000003o
ool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02P0oooo0P00000P0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3o
ool00`000000003o0000o`030000o`030000003oool0oooo02<0oooo0P00000C0?ooo`00:@3oool0
0`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool0
0`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`L000005@3oool00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool20000
01l0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:03oool200000200oooo00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`00
0000003o0000o`030000o`030000003oool0oooo02<0oooo0P00000C0?ooo`00603oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo1`0000050000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool07`3oool00`000000003o0000o`020000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo02T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`00603oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool2000001l0oooo00<00000
0?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P0000030?ooo`800000803oool6000000D0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`030?ooo``00000803oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P00000Z0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000003o
ool0oooo02<0oooo0P00000C0?ooo`006@3oool00`000000oooo0?ooo`070?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`800000103oool0
0`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:P3o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool04@3oool001H0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo1`0000040000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo02T0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000003H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000[0?ooo`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00P3oool7000002D0oooo0P00000C0?ooo`005P3oool4000000T0
oooo0`0000030?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000=P3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o1`00000e0?ooo`8000006`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool0
0`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0F0?ooo`@000002@3oool3000000<0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool0
02T0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo
02T0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000003H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo0080oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0^0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0;`3o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01H0oooo100000090?ooo`<000000P3oool00`000000oooo0?ooo`0Z0?ooo`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0^0?ooo`800000
4`3oool002T0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo02P0oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000L0?ooo`D000000P3oool2
000000@0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo02T0oooo0P00000O0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0L0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C0?ooo`007P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0:03oool2000002/0oooo1P0000050000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000:`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool04@3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000<@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o1P0000050000
o`030000003oool0oooo02T0oooo0P00000O0?ooo`030000003oool0oooo03@0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?oo
o`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00
000Z0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000N
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo0080oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0L0?ooo`D000000P3oool2000000<0oooo
0P00000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000[0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`007P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool0:@3oool2000001l0oooo00<000000?ooo`3oool0=03oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000a0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000[0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000M0?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000003oool0oooo02X0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0d0?ooo`L000001@000?l00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00800000<03oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01d0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool2000001l0
oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`030000o`030000003oool0oooo03X0
oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000<@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C
0?ooo`00:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00800000<03oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00P3oool00`000000003o0000o`030000o`030000003oool0oooo02T0oooo0P00000O0?oo
o`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo01d0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0_0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000Y0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
0000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`030000o`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0:03oool200000300oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000
003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`030000o`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00403o
ool5000000030?ooo`0000000000008000000`3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`8000004P3o
ool500000080oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02P0oooo0P00000`0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0403oool5000000030?ooo`0000000000008000000`3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0^0?ooo`8000004`3oool00180oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o
0000o`030000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000l0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo
0?ooo`0000002`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3o
ool000000340oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0Y0?ooo`800000503o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000003o
0000o`030000o`030000003oool0oooo03T0oooo0P00000Z0?ooo`030000003oool0oooo02l0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool2000002X0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0^0?ooo`8000004`3oool00180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0100oooo1@0000000`3oool00000
00000002000000<0oooo0P0000040?ooo`8000000`3oool200000300oooo1`0000050000o`030000
00000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool0
:@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool0:@3oool2000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000;0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`H000001@000?l0
0`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C0?ooo`004@3oool20000
00@0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`800000103oool30000
00<0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`030000o`030000003oool0oooo
03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P00000f0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo0P0000040?oo
o`8000002P3oool3000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000
o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3o
ool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool00P3oool00`000000003o0000o`030000o`030000003oool0oooo02T0oooo0P00000O0?ooo`03
0000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`80
00000`3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:@3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C0?ooo`00
:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool2000003H0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0
003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo
0?ooo`0_0?ooo`H000001@000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool0:@3oool2000001l0oooo00<000000?ooo`3oool0>P3oool00`000000003o
0000o`030000o`030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool2000000@0oooo
0P00000:0?ooo`<000000P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo
1`0000050000o`030000003oool0oooo02h0oooo0P00000C0?ooo`00:@3oool00`000000oooo0?oo
o`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000
o`030000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0j0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0X0?ooo`800000=P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00703oool500000080oooo0P000004
0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`02
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0:@3oool2000001l0oooo00<00000
0?ooo`3oool0>P3oool00`000000003o0000o`030000o`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo1@000002
0?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0203oool00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C
0?ooo`007P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000f0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000
o`030000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0j0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0X0?ooo`800000=P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000=P3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo1`00000[0?ooo`80
00007`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03D0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000:P3oool00`00
0000003o0000o`030000o`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0^0?ooo`8000004`3oool001h0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`030000003oool0oooo03D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0
003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0L0?ooo`D000000P3oool2000000<0
oooo0P00000f0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`030000003oool0oooo00P0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140
oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001l0oooo
00<000000?ooo`3oool0>P3oool00`000000003o0000o`030000o`030000003oool0oooo03X0oooo
00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000=`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0203oool00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00000C0?oo
o`007@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0>P3oool00`000000003o0000o`030000o`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00800000=P3oool00`000000
003o0000o`030000o`H00000<@3oool00`000000oooo0?ooo`0M0?ooo`800000103oool3000000<0
oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`030000o`030000003oool0oooo00P0
oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140
oooo000Y0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0d0?ooo`8000007`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000003o
0000o`030000o`030000003oool0oooo00P0oooo1`00000`0?ooo`8000004`3oool002T0oooo00<0
00000?ooo`3oool0=03oool00`000000003o0000o`030000o`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d
0?ooo`8000004P3oool4000000<0oooo0P0000040?ooo`030000003oool0oooo03X0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01d0oooo0P000004
0?ooo`<000000P3oool2000003H0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`03
0000o`030000003oool0oooo03l0oooo0P00000C0?ooo`00:@3oool00`000000oooo0?ooo`0d0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0j
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`03
0000o`030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?oo
o`3oool0=03oool7000003H0oooo0P00000C0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0>@3oool2000002X0oooo0P00000f0?ooo`L00000=P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo1`0000110?ooo`8000004`3oool002T0ooooMP00000D0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003`0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02P0ooooMP00
000[0?ooogH000004`3oool00;40oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooD`3oool00;80oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`0j0?ooo`L00000?03oool00`000000oooo0?ooo`3o0?oooe<0oooo002n
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?oooe<0oooo002n0?oooh400000o`3ooomE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0oooo
U@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooomi0?ooo`D000000P3oool2000000@0oooo0P00000C0?ooo`8000005P3oool50000
0080oooo0P0000040?ooo`8000003`3oool4000000<0oooo0P0000040?ooo`800000]03oool00?l0
ooooN`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000/`3oool0
0?l0ooooN`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001L0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000/`3o
ool00?l0ooooL`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0/@3oool00400oooo1@0000020?ooo`800000103oool200000100oooo0P00
000C0?ooo`D000000P3oool2000000@0oooo0P00000=0?ooo`@000000`3oool2000000@0oooo0P00
00110?ooo`D000000P3oool2000000@0oooo0P00000A0?ooo`8000004`3oool500000080oooo0P00
00040?ooo`800000303oool4000000<0oooo0P0000040?ooo`800000>`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`04
0000003oool0oooo000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000@@3oool500000080oooo0P0000040?oo
o`800000403oool2000001<0oooo1@0000020?ooo`800000103oool2000000d0oooo100000030?oo
o`800000103oool2000001<0oooo00120?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000503o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000120?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000503oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000i0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3oool2000000@0oooo
0P0000040?ooo`800000403oool2000000@0oooo0P0000040?ooo`800000A03oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool00480oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000480oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000><0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000180oooo000j0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0h0?ooo`@00000103oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`3I0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`00@P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000h`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000004P3oool00440oooo0P0000040?ooo`800000103o
ool200000100oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000>0?ooo`800000103o
ool2000000@0oooo0P0000120?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000503o
ool2000000@0oooo0P0000040?ooo`8000003@3oool2000000@0oooo0P0000040?ooo`800000h`3o
ool2000000@0oooo0P0000040?ooo`800000403oool2000001@0oooo0P0000040?ooo`800000103o
ool2000000h0oooo0P0000040?ooo`800000103oool2000001<0oooo003o0?oooeT0oooo0P000004
0?oooh400000]03oool00?l0ooooF03oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`800000/`3oool00?l0ooooF03oool010000000oooo0?ooo`000003
0?oooh400000]03oool002<0oooo0P0000040?ooogH000009@3oool2000000<0ooooMP00000H0?oo
o`040000003oool0oooo000000<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S
0?ooo`800000103ooomf000001<0oooo000R0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool000000`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`008P3oool010000000oooo
0?ooo`0000030?ooogH00000903oool010000000oooo0?ooo`0000020?ooogH000006@3oool20000
00@0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo
000000<0ooooMP00000C0?ooo`008P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo000R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0H0?ooo`800000903oool010000000oooo0?ooo`0000020?ooo`80
0000103oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool07@3oool00`000000003o0000o`030000o`L000001@000?l00`000000003o0000o`030000o`P0
00001@000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o1`00000A0?ooo`03
0000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?oo
o`8000004`3oool002<0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0S0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0103oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`03
0000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02<0oooo0P0000040?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool03@3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04@3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0H0?ooo`800000
:P3oool2000000@0oooo00<000000000o`000?l00P000?l7000000@0003o1`0000040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`040?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0:@3oool6000000D0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l7000000l0oooo1`0000040?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool00P3o
ool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo0P0000040?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`@000000`3o
ool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo00@0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo01h0oooo0P00000C0?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`040?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`030000o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo
0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0603oool2000001P0oooo100000030?ooo`800000103oool20000
00<0oooo0P0000040?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l70000
00D0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o1`0000040000o`L000005@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00<0oooo1`0000050?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`040?ooo`L000001@000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool4000000<0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`L0000010000?l7000000D0003o00<000000000o`000?l00P000?l70000
00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o1P00000P0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool02P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`080?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool0
01H0oooo100000030?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000003o0000o`030000o`H000001@000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0H0?ooo`8000006@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000103oool00`000000003o0000o`020000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0H0?oo
o`800000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00X0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`8000002@3o
ool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool001H0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`800000103o
ool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l01000
0?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203o
ool2000000@0oooo00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0140oooo000G0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`030000003oool0oooo01P0oooo0P00000H0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00P3oool2000000@0oooo1P0000050?ooo`03000000000?l0003o0080003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00X0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool001P0oooo
00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o
0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`<000000P3oool00`000000oooo
0?ooo`0>0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo00X0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`040000o`L000001@3oool7000001L0oooo00<000000?ooo`3oool05`3oool2000000X0oooo
0`0000030?ooo`030000003oool0oooo00P0oooo00<000000000o`000?l00P000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0A0?ooo`005P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool7000000@0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`H000001@000?l6000000D0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o1`00000J0?ooo`800000:P3oool2000000l0oooo
00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool02@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool02P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo
00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool08`3oool2000001<0oooo000G0?ooo`8000002P3oool3000000<0oooo00<0
00000?ooo`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool03P3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0203oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`02
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000?ooo`3oool07P3oool2000002X0oooo0P00000?
0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H
0?ooo`<000000P3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0203oool6000000D0oooo1`0000040000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool002T0oooo00<000000?oo
o`3oool03@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00P3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo0P0000030?oo
o`8000003`3oool00`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000
o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00`3oool00`000000003o0000o`020000o`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo00X0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`030000003oool0oooo02L0oooo00<000000?ooo`3oool08`3oool2
000000@0oooo00<000000?ooo`3oool06@3oool00`000000003o0000o`020000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool0
02T0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`L00000103oool00`00
0000003o0000o`030000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0N0?ooo`800000903oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00h0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01H0oooo1@0000020?ooo`8000002P3oool7000000D0003o00<000000?ooo`3oool02P3oool7
000000D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool06@3oool00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0140oooo000Y0?ooo`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`030000003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`02000000l0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`03
0?ooo`H000001@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0H0?ooo`800000603oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0@0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00@0003o00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0U0?ooo`040000003oool0oooo0?ooo`8000006P3oool6000000D0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o1`00000U0?ooo`800000
4`3oool002T0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`030000003o
ool0oooo00P0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool07P3oool2000002D0oooo0P0000030?ooo`030000003o
ool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0@0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00@0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0S0?ooo`800000103o
ool00`000000oooo0?ooo`0T0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`080?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`020?ooo`8000003`3oool00`000000003o0000o`020000o`030000003oool0
oooo00h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o0080003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool0
0`000000oooo0?ooo`0?0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0403oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`030000003oool0oooo02L0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool2
000001<0oooo000R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool0
0`000000003o0000o`030000o`030000003oool0oooo00P0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0S0?ooo`<000000P3oool00`000000oooo0?ooo`0>0?ooo`03000000000?l0
003o0080003o00<000000?ooo`3oool03P3oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000003o0000o`030000o`030000003oool0
oooo0100oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02<0oooo0`0000030?ooo`030000003oool0oooo02@0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0A0?ooo`009@3oool01@000000oooo0?ooo`3oool0000000l0oooo1`00000:
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool7000000@0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo01h0oooo0P00000Z
0?ooo`8000003`3oool00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<00000
0000o`000?l00`000?l6000000D0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`H000006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0@0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l7000000H0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02@0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool2000001<0oooo000S0?oo
o`800000103oool00`000000oooo0?ooo`0N0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0203oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool03P3oool00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool03`3oool00`000000003o0000o`030000o`030000003oool0oooo0100oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000
o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0903oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000o`03
0000003oool0oooo00P0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool07P3oool2000002X0oooo0P00000?0?ooo`03
000000000?l0003o0080003o00<000000?ooo`3oool03P3oool00`000000003o0000o`030000o`03
0000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0T0?ooo`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
0000003oool0oooo02T0oooo0P00000C0?ooo`008`3oool3000000<0oooo00<000000?ooo`3oool0
7P3oool00`000000003o0000o`030000o`030000003oool0oooo00P0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000
0`3oool2000000l0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`L00000
103oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0F0?ooo`<00000103oool00`000000oooo0?ooo`0?0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool0903oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Y0?ooo`800000
4`3oool002T0oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000o`030000003o
ool0oooo00P0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`H00000803o
ool2000001X0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0I0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0403oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000o`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0903oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`080?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`02000000l0oooo00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0I0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0S0?ooo`800000603oool010000000oooo0?ooo`0000030?ooo`800000403oool00`00
0000003o0000o`030000o`030000003oool0oooo0100oooo1`0000050000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
00<0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000002D0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0?ooo`3oool0:@3oool2000001<0oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`080?ooo`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000006`3oool00`000000oooo0?ooo`070?oo
o`8000000`3oool00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o00<000000?oo
o`3oool06@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0F0?ooo`<00000103oool00`000000oooo0?ooo`0?0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool05P3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?oo
o`3oool0903oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03
0000003oool0oooo01h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?oo
o`8000003`3oool6000001/0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o3000000V0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool05P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000
o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo30000004
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo02T0oooo0P00000C0?ooo`00603oool00`000000oooo0?ooo`020?oo
o`800000103oool2000000@0oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000
o`030000003oool0oooo00P0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02<0oooo0P00000H0?ooo`@000002@3oool300000080oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo0`0000030?oo
o`030000003oool0oooo00l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0F0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`040000
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool4000000T0oooo0`0000030?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0140oooo000H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0N0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0203oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0X0?ooo`800000<03oool00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000003o0000o`030000
o`030000003oool0oooo01H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o00@0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Y0?oo
o`8000004`3oool001P0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool00000
0200oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`080?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`800000:P3oool00`00
0000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0?0?ooo`L00000603oool00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
00<0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
02X0oooo00<000000?ooo`3oool04@3oool001T0oooo00<000000?ooo`3oool01`3oool2000000@0
oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000o`030000003oool0oooo00P0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0:03oool200000300oooo00<000000000o`000?l00`000?l00`000000
003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0Y0?ooo`8000004`3oool001H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`080?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
003o0000o`020000o`L000001@000?l00`000000oooo0?ooo`0S0?ooo`8000007P3oool500000080
oooo0P0000030?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0
oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01`0
oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0:@3oool2000001<0oooo000F0?ooo`@000002@3oool3000000<0oooo
00<000000?ooo`3oool07P3oool00`000000003o0000o`030000o`030000003oool0oooo00P0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000<@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo0P0000040?oo
o`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?oo
o`03000000000?l0003o00@0003o00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000340oooo00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000Y
0?ooo`030000003oool0oooo01h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`08
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00800000<03oool00`000000003o0000o`030000o`03000000000?l0003o0080003o1`00
000`0?ooo`800000603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`3oool200000300oooo1P0000050000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool002T0
oooo00<000000?ooo`3oool07P3oool00`000000003o0000o`030000o`030000003oool0oooo00P0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo02<0
oooo0P00000P0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000a
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool2000002l0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`P00000:@3oool00`000000oooo0?oo
o`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo
0?ooo`0N0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0203oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000300
oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo03D0
oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo02T0oooo0P00000C0?ooo`00:@3oool00`000000oooo0?ooo`0N0?ooo`L000002P3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool08`3oool20000
01l0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0140oooo000Y0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool20000
0300oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
03D0oooo00<000000?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool0;P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`00703oool500000080
oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`030000o`030000003oool0oooo02<0oooo0P00000Z0?ooo`030000003oool0oooo02l0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo03D0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03@0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`007P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02P0oooo0P00000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`007P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0
oooo00<0oooo1`00000U0?ooo`8000004P3oool5000000030?ooo`0000000000008000000`3oool2
000000@0oooo0P0000030?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0100oooo1@0000000`3oool0000000000002000000<0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`007P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo0300oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03@0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool04@3oool001h0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`000000<@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`800000503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P00000`0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0d0?ooo`8000004P3o
ool500000080oooo0P0000040?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`800000=@3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo
0?ooo`0Y0?ooo`8000004`3oool001d0oooo0P0000040?ooo`800000103oool00`000000oooo0?oo
o`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`030000003oool0oooo0300oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`030000003oool0oooo02l0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0
oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140
oooo000Y0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool2000001@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool200000300oooo1`0000040000o`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000_
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`L000001000
0?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool002T0oooo00<000000?ooo`3oool0;`3oool0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`8000002P3oool3
00000080oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`020000o`030000003oool0
oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000X0oooo0`0000030?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00:@3o
ool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo0P00000Z0?ooo`800000=P3o
ool00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000`0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool2000001<0oooo000Y0?ooo`030000
003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`030000
00000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00:@3o
ool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`030000003oool0oooo0300oooo00<000000?ooo`3oool0:03o
ool2000003H0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`0300000000
0?l0003o00<0003o00<000000?ooo`3oool00`3oool6000002/0oooo0P00000C0?ooo`00403oool5
000000030?ooo`0000000000008000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo02l0oooo1P0000050000o`H00000<@3oool2000001h0oooo1@0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`0e0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0oooo1@0000020?ooo`800000103oool0
0`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0A0?ooo`004P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`02000003H0oooo00<000000000o`000?l00P000?l00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;P3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`800000803oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00800000=P3oool00`000000003o0000o`020000o`030000003oool0oooo
03@0oooo0P00000O0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool2000003D0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d
0?ooo`8000004`3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`800000103oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`030000003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0oooo00<000000?oo
o`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0d0?oo
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?oo
o`004P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0d0?ooo`800000803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0P00000f0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0^
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000A0?oo
o`800000103oool2000000X0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo0P0000040?oo
o`<000000P3oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0003o0080003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool2000002l0oooo1`0000050000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo0P0000040?oo
o`<000000`3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0d0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000002X0oooo0P00000f0?ooo`03
000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000Y0?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`020000o`030000
003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`000000oooo0?ooo`0d0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000002X0oooo0P00000f0?ooo`03
000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03
0000003oool0oooo03@0oooo0P00000C0?ooo`00:@3oool00`000000oooo0?ooo`0d0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`D00000
0`3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0
=@3oool00`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
403oool5000000<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo03@0oooo00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0d0?ooo`800000503oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000000P3oool2000003H0oooo00<000000000o`000?l0
0P000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
=03oool7000000D0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0=03oool00`000000003o0000o`030000o`03
0000003oool0oooo03@0oooo0P00000C0?ooo`00703oool500000080oooo0P0000040?ooo`030000
003oool0oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00800000=P3oool00`000000003o0000o`020000o`030000003oool0oooo03@0oooo
0P00000O0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P00000e0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000001<0oooo000N0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0e0?oo
o`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo000N0?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0=03oool2000001@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool2000003H0oooo00<00000
0000o`000?l00P000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0100oooo1@000003
0?ooo`<000000P3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03o
ool2000001<0oooo000N0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0
oooo03@0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0140oooo0P0000030?ooo`@000002@3oool300000080oooo00<000000?ooo`3oool0=@3oool0
0`000000003o0000o`020000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0A0?ooo`8000000`3oool4000000T0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo000N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool2000002X0oooo0P00000f
0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B
0?ooo`040000003oool0oooo0?ooo`D000000P3oool2000003/0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03o
ool2000001<0oooo000M0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0=03oool0
0`000000003o0000o`030000o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0e0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000003`0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`00:@3o
ool00`000000oooo0?ooo`0d0?ooo`L00000=P3oool2000002X0oooo0P00000f0?ooo`H00000=`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=03o
ool7000003H0oooo0P00000C0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo0P0000050?ooo`8000000`3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04@3oool002T0ooooMP00000Z0?ooogH000007`3oool00`00
0000oooo0?ooo`0j0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02T0ooooMP00000C0?ooo`00o`3ooomO0?ooo`03
0000003oool0oooo03X0oooo3@00000f0?ooo`030000003oool0oooo0;80oooo003o0?oooel0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo
003o0?oooel0ooooP@00002d0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0
ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE
0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00=`3o
ool500000080oooo0P0000040?ooo`8000004`3oool2000001H0oooo1@0000020?ooo`800000103o
ool200000100oooo100000030?ooo`800000103oool200000?l0oooom@3oool003T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooom03oool003T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooom03oool00340oooo
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0?l0oooolP3oool003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000G0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000400oooo1@0000020?ooo`800000103oool200000140oooo0P00000C0?ooo`D000000P3o
ool2000000@0oooo0P00000<0?ooo`@000000`3oool2000000@0oooo0P0000110?ooo`D000000P3o
ool2000000@0oooo0P00000A0?ooo`8000004`3oool500000080oooo0P0000040?ooo`8000003@3o
ool4000000<0oooo0P0000040?ooo`800000@@3oool500000080oooo0P0000040?ooo`800000403o
ool2000001<0oooo1@0000020?ooo`800000103oool2000000d0oooo100000030?ooo`800000103o
ool2000001<0oooo000h0?ooo`800000103oool2000000@0oooo0P00000C0?ooo`8000005`3oool2
000000@0oooo0P0000040?ooo`8000004@3oool2000000@0oooo0P0000040?ooo`800000@`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000004P3oool00>80oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000480oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000D
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000480oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000D0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000180oooo003J0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool02`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0h0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0h0?ooo`@00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`00hP3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000@P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000004P3oool00>40oooo0P0000040?ooo`800000103oool200000140
oooo0P00000D0?ooo`800000103oool2000000@0oooo0P00000=0?ooo`800000103oool2000000@0
oooo0P0000120?ooo`800000103oool2000000@0oooo0P00000A0?ooo`800000503oool2000000@0
oooo0P0000040?ooo`8000003P3oool2000000@0oooo0P0000040?ooo`800000@P3oool2000000@0
oooo0P0000040?ooo`800000403oool2000001@0oooo0P0000040?ooo`800000103oool2000000h0
oooo0P0000040?ooo`800000103oool2000001<0oooo000H0?ooo`8000000`3ooon200000?l0oooo
m@3oool001L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooooc0?ooo`005`3oool010000000oooo0?oo
o`0000020?oooh800000o`3ooooe0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0:0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`800000
0`3ooomf000002D0oooo0P0000030?ooogH000009@3oool2000000@0ooooMP00000C0?ooo`005`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
10000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0:0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00603oool2000000<0oooo0P0000040?oo
o`L000001P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?oo
o`3oool02P3oool7000000@0oooo0P00000T0?ooo`040000003oool0oooo00000080ooooMP00000T
0?ooo`040000003oool0oooo00000080ooooM`00000S0?ooo`040000003oool0oooo000000<0oooo
MP00000C0?ooo`007@3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo
00@000000?ooo`3oool000000P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0003o00<0
003o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo0000
00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0140oooo000M0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l010000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo
00000080oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`030000o`030000003oool0
oooo01<0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000030?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o0080003o00<000000?ooo`3oool0203oool2000001<0oooo000M0?ooo`030000003oool0
oooo00T0oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`8000000`3oool0
0`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0S0?ooo`8000000`3oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`020?ooo`03000000000?l0
003o00<0003o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`800000103oool0
0`000000003o0000o`020000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l0
0`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool0
0`000000003o0000o`020000o`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool0
01d0oooo0P00000:0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l70000
00D0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool00`3oool7000001L0oooo0P00000Z0?ooo`800000103oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool70000
00D0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`L0000010000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`020?ooo`L000005@3oool00`000000oooo0?ooo`0Y0?ooo`H000001@3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`030?ooo`H000002P3oool2000001<0oooo000M0?ooo`030000003oool0oooo00T0
oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00<0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140
oooo000M0?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l010000?l00`000000003o
0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool2000000@0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool001d0oooo0P00000:0?ooo`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l7000000D0003o00<000000000o`000?l00`000?l00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08@3oool2000002X0oooo0P00
00040?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`080?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`030000003oool0oooo01<0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`09
0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01H0oooo100000030?ooo`800000103oool2000000<0oooo0P000004
0?ooo``000001@000?l00`000000003o0000o`020000o``000001@3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`08
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?oo
o`3oool02@3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo0280oooo00<000000?oo
o`3oool05P3oool4000000<0oooo0P0000040?ooo`8000000`3oool2000000@0oooo00<000000000
o`000?l00P000?l7000000@0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`H000001@000?l00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo10000003
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`L0000010000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o1P00000E
0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l010000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00P3oool00`000000003o0000o`03
0000o`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo008000003`3oool00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000?ooo`3oool03P3oool00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo01h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2
000000X0oooo00<000000000o`000?l010000?l7000000D0oooo3@0000050?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000?ooo`3oool08@3oool2000001T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`02000000@0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0B
0?ooo`8000006P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`0>
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0>
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0H0?ooo`8000004`3o
ool001P0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<000000000o`000?l010000?l0
0`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`030000003oool0
oooo00<0oooo00<000000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo0080oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`8000003`3o
ool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool03P3o
ool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P00
0?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`080?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0140oooo000G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3o
ool00`000000003o0000o`040000o`030000003oool0oooo01/0oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`020?ooo`800000103oool6000000D0oooo1P0000050000o`H00000
1@000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`L00000103oool7000001D0oooo00<000000?ooo`3oool0
5`3oool2000000X0oooo0`0000020?ooo`030000003oool0oooo00h0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`L0000010000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03
000000000?l0003o00<0003o3000000J0?ooo`8000004`3oool001X0oooo00<000000?ooo`3oool0
0P00000:0?ooo`P000007@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l7000002<0oooo0P00000I0?ooo`8000002P3oool300000080oooo
00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0:03oool2000000l0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`030000003oool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`<000000`3oool00`000000oooo
0?ooo`080?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool04@3oool001P0oooo0P00
00030?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0X0?ooo`800000503oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool08`3oool2000001<0oooo000H0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04`3oool00`000000003o0000o`030000o`030000003oool0oooo0080oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0:03oool2000000l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`02
0000o`030000003oool0oooo00<0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0140oooo000H0?ooo`<000000P3oool2000002l0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool09`3oool2000002X0oooo0P00000D0?ooo`L00000103oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00h0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`030000003oool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool6000000D0003o00<000000?oo
o`3oool00`3oool6000000D0oooo1P0000050000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0S0?ooo`8000004`3oool001d0oooo00<000000?ooo`3o
ool0;P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool07P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0S0?ooo`8000000`3oool2000000l0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool03@3oool00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`040000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool2000001l0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
8P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo00h0oooo00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool03@3oool00`000000003o0000o`030000o`030000003oool0oooo01<0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool08`3oool2000001<0oooo000M0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0S0?ooo`8000000`3oool00`000000oooo0?ooo`0N0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00P00000?0?ooo`L0000010000?l00`000000oooo
0?ooo`0>0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0S0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o
00<000000?ooo`3oool04`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo
000M0?ooo`800000;`3oool00`000000003o0000o`030000o`L000001P000?l00`000000003o0000
o`030000o`d00000:@3oool2000002@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0N0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02<0oooo0P0000030?ooo`030000003oool0oooo01@0oooo
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0>0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`030000o`030000003oool0oooo01<0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`000000oooo
0?ooo`0^0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo008000007`3oool=000000@0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02<0oooo0P00000U0?ooo`030000
003oool0oooo0080oooo0P00000E0?ooo`03000000000?l0003o0080003o00<000000?ooo`3oool0
3P3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
9@3oool010000000oooo0?ooo`3oool2000000h0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0C0?ooo`L0000010000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l7000002D0oooo0P00000C0?ooo`007@3oool00`000000oooo
0?ooo`0^0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o
0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0S0?ooo`8000000`3oool00`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool300000080oooo00<000000?ooo`3oool0503oool00`000000003o
0000o`020000o`030000003oool0oooo00h0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0I0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000002l0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`8000009@3oool00`000000oooo0?oo
o`020?ooo`800000:`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo0P00
000E0?ooo`H00000403oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l700000200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0I0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool2000001<0oooo000M
0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`03
0?ooo`03000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo02<0oooo0`0000020?ooo`030000003oool0oooo02X0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool00`000000oooo0?ooo`0=
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool06@3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?oo
o`3oool0;P3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000
o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0:03oool2000002/0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?oo
o`800000:`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool03@3oool00`000000003o0000o`030000o`030000003oool0oooo01T0oooo00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0Y0?ooo`8000004`3oool001d0oooo00<000000?ooo`3o
ool0;P3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`00
0?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Z0?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool06@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool04@3oool001d0oooo0P00000_0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
<`3oool2000002X0oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`020?ooo`800000103oool2000000<0oooo0P00000[0?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`030000
00000?l0003o00<0003o00<000000?ooo`3oool06@3oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
003oool0oooo02T0oooo0P00000C0?ooo`004@3oool500000080oooo0P0000030?ooo`030000003o
ool0oooo02h0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000003o0000o`020000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0I0?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`004`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<03oool00`000000
003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`000000
003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`020?ooo`800000103oool2000000<0oooo0P00000[0?ooo`H000001@000?l00`000000
003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l7000002H0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
0000:`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000000o`00
0?l00`000?l00`000000oooo0?ooo`0I0?ooo`03000000000?l0003o0080003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3o
ool0:@3oool2000001<0oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`02000002l0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00@0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`80
00006P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0Z0?oo
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool00`000000003o0000o`03
0000o`030000003oool0oooo01T0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000`0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3o
ool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00
000`0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool2000001P0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool0oooo0P00000>0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3o
ool06@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`00
4`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<03oool00`00
0000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l010000?l00`00
0000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0F0?ooo`@000002@3oool30000
0080oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool06@3oool00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo
02X0oooo00<000000?ooo`3oool04@3oool00180oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`0^0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool06@3oool0
0`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool0
01d0oooo0P00000_0?ooo`L000001@3oool00`000000003o0000o`040000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0<`3oool2000001P0oooo100000090?ooo`<000000P3oool20000
0300oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o
00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02P0oooo0P00000[0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05P3oool40000
00T0oooo0`0000030?ooo`030000003oool0oooo00d0oooo1`00000K0?ooo`03000000000?l0003o
0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
0080003o00<000000?ooo`3oool0:@3oool2000001<0oooo000M0?ooo`030000003oool0oooo03X0
oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o0080
003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0
oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140
oooo000M0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000003o
0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:03oool200000300oooo
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo
0P00000[0?ooo`H000001@000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0:@3oool2000001<0oooo000M0?ooo`800000>`3oool00`000000003o0000
o`040000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0<`3oool2000002X0oooo00<0
00000?ooo`3oool0;`3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`04
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0X
0?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0003o0080003o00<00000
0000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0703oool500000080oooo0P0000030?ooo`800000<03oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o0080003o00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Y
0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000340oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2
000003/0oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0
oooo03<0oooo0P00000N0?ooo`D000000P3oool2000000<0oooo0P00000`0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03000000000?l0
003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000300oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o0080003o3000000V0?ooo`030000003o
ool0oooo01`0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`0300000000
0?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o0080003o00<000000?ooo`3oool0:@3oool2000001<0oooo000M0?ooo`030000003oool0
oooo03X0oooo00<000000000o`000?l010000?l00`000000003o0000o`030000o`030000003oool0
oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000<@3oool00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02X0oooo
00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000<@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000003o0000
o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool001d0oooo00<00000
0?ooo`3oool0>P3oool00`000000003o0000o`040000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0200000300oooo1`0000040000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00P000?l00`000000oooo0?ooo`0Y0?ooo`800000803oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P00000`0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo
00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool0oooo0P00000`0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:@3oool20000
01<0oooo000M0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000
003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000=`3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`02
0000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o0080003o
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool2000003/0oooo00<0
00000000o`000?l010000?l7000003D0oooo0P00000P0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`02000003H0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0X0?ooo`800000<03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00P000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<@3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`020000o`030000003oool0oooo02T0oooo0P00000C0?ooo`004@3oool500000080
oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`0e0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000
003o0000o`020000o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0_0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo000C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000l0?ooo`03000000000?l0003o00@0003o00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0X0?ooo`800000=P3oool00`000000003o0000o`020000
o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02P0oooo0P00000`0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`H00000:`3oool2000001<0oooo000C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000k0?ooo`03000000000?l0003o00@0
003o00<000000?ooo`3oool0>@3oool2000002X0oooo00<000000?ooo`3oool0=@3oool00`000000
003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;`3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`000000
003o0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=@3oool00`000000003o
0000o`020000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0oooo
0P0000040?ooo`8000000`3oool200000300oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0:03oool2000003H0oooo00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0B0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000B0?ooo`800000
103oool300000080oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`030000
00000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000
003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P00000`0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`020000o`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo
00<000000?ooo`3oool04@3oool001d0oooo0P00000k0?ooo`03000000000?l0003o00@0003o00<0
00000?ooo`3oool0>@3oool200000180oooo1@0000000`3oool0000000000002000000<0oooo0P00
00040?ooo`8000000`3oool2000003H0oooo00<000000000o`000?l00P000?l00`000000003o0000
o`030000o`H00000;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0100oooo1@0000000`3oool0000000000002000000<0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02h0oooo0P00
000C0?ooo`007@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03D0oooo00<000000000o`000?l0
0P000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`800000<03oool7000000D0003o00<000000000o`000?l00P000?l00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`02
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo03X0oooo00<000000000
o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000=P3oool00`00
0000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool20000
01<0oooo0P0000040?ooo`8000002P3oool300000080oooo00<000000?ooo`3oool0=@3oool00`00
0000003o0000o`030000o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`3oool200000300oooo00<000000000o`000?l00P000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000M0?oo
o`800000>`3oool00`000000003o0000o`040000o`030000003oool0oooo03T0oooo0P00000D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000<0oooo00<000000?oo
o`3oool0=@3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`800000=P3oool00`000000003o0000o`030000
o`03000000000?l0003o0080003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?oo
o`3oool0;`3oool00`000000003o0000o`020000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000M0?ooo`03
0000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool2000003H0oooo00<000000000o`000?l00P000?l00`00
0000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0e0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00P000?l00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_
0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo02h0oooo0P00000C0?ooo`007@3oool00`000000oooo0?ooo`0j0?oo
o`03000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?oo
o`800000103oool2000000X0oooo0`0000020?ooo`030000003oool0oooo03D0oooo00<000000000
o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0:03oool2000003H0oooo00<000000000o`000?l00`000?l600000340oooo00<000000?oo
o`3oool04@3oool2000000@0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0_0?oo
o`03000000000?l0003o0080003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3o
ool0>P3oool00`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0:03oool2000003H0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000001<0oooo000M0?ooo`800000
>`3oool00`000000003o0000o`040000o`030000003oool0oooo03T0oooo0P00000Z0?ooo`030000
003oool0oooo03D0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0703oool500000080oooo0P0000030?ooo`800000
=P3oool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool001d0oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0:03oool2000003H0oooo1P0000050000o`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000=`3oool00`000000003o0000o`030000o`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l700000300oooo0P00000C0?ooo`007@3oool00`000000oooo
0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`02000003H0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`000000003o0000o`020000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`007@3o
ool2000003/0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0i0?ooo`800000:P3o
ool2000003/0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0=@3o
ool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0_0?ooo`03000000000?l0003o0080003o00<000000000o`000?l00`00
0?l00`000000oooo0?ooo`0d0?ooo`8000004`3oool001d0oooo00<000000?ooo`3oool0>P3oool0
0`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0703oool5
00000080oooo0P0000030?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`800000=P3oool00`000000003o0000o`030000o`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0703oool500000080oooo0P0000040?ooo`030000003oool0
oooo02l0oooo00<000000000o`000?l00P000?l00`000000003o0000o`030000o`030000003oool0
oooo03D0oooo00<000000?ooo`3oool04@3oool00140oooo100000030?ooo`8000000`3oool00`00
0000oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000l0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0M0?ooo`800000103oool300000080oooo00<000000?ooo`3oool0=@3oool00`000000003o0000
o`030000o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03000000000?l0003o0080
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140
oooo000A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0j0?ooo`03000000000?l0003o00@0003o00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000k0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0;P3oool2000002X0oooo0P00000f0?ooo`03
000000000?l0003o00<0003o00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000`0?ooo`H000001@000?l00`00
0000oooo0?ooo`0d0?ooo`8000004`3oool00180oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`800000>`3oool00`000000003o0000o`040000o`030000003oool0oooo
03T0oooo0P00000P0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo
03X0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo
03@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`00
0000oooo0?ooo`0d0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0A0?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000?03oool00`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000k
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0X
0?ooo`800000=P3oool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=03oool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo0P00000C
0?ooo`004@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0>P3oool00`000000003o0000o`040000o`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool07@3oool2000000@0oooo0`0000020?ooo`030000003oool0oooo03X0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0=@3oool00`000000003o0000o`030000o`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool07@3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo000B
0?ooo`800000103oool2000000<0oooo0P00000k0?ooo`03000000000?l0003o00@0003o00<00000
0?ooo`3oool0>@3oool2000002X0oooo0P00000k0?ooo`L00000<@3oool00`000000oooo0?ooo`0X
0?ooo`800000=P3oool7000003H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0d
0?ooo`L00000=P3oool2000001<0oooo000M0?ooo`030000003oool0oooo03X0oooo00<000000000
o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo000M0?ooo`03
0000003oool0oooo03X0oooo00<000000000o`000?l010000?l00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo02P0ooooMP00000Z0?ooogH00000:`3ooomf000001<0oooo000M0?ooo`800000
>`3oool8000003/0oooo0P00003o0?ooooD0oooo000M0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0o`3ooooc0?ooo`007@3ooon200000?l0oooom@3oool00?l0ooooo`3ooonE0?oo
o`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 552.875}, {448, 39.5625}} -> {-0.311555, \
0.238127, 0.00638497, 0.00638497}, {{39, 155.563}, {438.25, 366.188}} -> \
{-418.408, 6.79874, 3.37756, 0.27325}, {{167.188, 283.75}, {438.25, 366.188}} -> \
{-1043.01, 5.90633, 3.59577, 0.276359}, {{295.438, 412}, {438.25, 366.188}} -> \
{-1501.07, 4.75913, 3.37756, 0.191275}, {{423.625, 540.188}, {438.25, \
366.188}} -> {-1975.09, 6.87153, 3.2663, 0.277461}, {{39, 155.563}, {359, \
287}} -> {-405.1, -14.7381, 3.26945, 0.198378}, {{167.188, 283.75}, {359, \
287}} -> {-960.587, -20.2898, 3.38101, 0.273529}, {{295.438, 412}, {359, \
287}} -> {-1619.46, -18.0713, 3.59577, 0.232723}, {{423.625, 540.188}, {359, \
287}} -> {-2195.62, -21.4596, 3.59577, 0.276359}, {{39, 155.563}, {279.75, \
207.75}} -> {-466.844, -43.6956, 3.59577, 0.247267}, {{167.188, 283.75}, \
{279.75, 207.75}} -> {-928.978, -48.1459, 3.26945, 0.277729}, {{295.438, \
412}, {279.75, 207.75}} -> {-1619.46, -41.1254, 3.59577, 0.232723}, \
{{423.625, 540.188}, {279.75, 207.75}} -> {-2195.62, -43.6956, 3.59577, \
0.247267}, {{39, 155.563}, {200.563, 128.5}} -> {-466.844, -64.1704, 3.59577, \
0.232723}, {{167.188, 283.75}, {200.563, 128.5}} -> {-1043.01, -76.2024, \
3.59577, 0.276359}, {{295.438, 412}, {200.563, 128.5}} -> {-1451.71, \
-53.9748, 3.2663, 0.198187}, {{423.625, 540.188}, {200.563, 128.5}} -> \
{-2195.62, -76.2024, 3.59577, 0.276359}, {{39, 155.563}, {121.313, 49.25}} -> \
{-404.712, -107.958, 3.2663, 0.290674}, {{167.188, 283.75}, {121.313, 49.25}} -> \
{-1043.01, -87.2245, 3.59577, 0.232723}, {{295.438, 412}, {121.313, 49.25}} -> \
{-1619.46, -92.6758, 3.59577, 0.247267}, {{423.625, 540.188}, {121.313, \
49.25}} -> {-2195.62, -87.2245, 3.59577, 0.232723}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[{#[\([1]\)], \ DispersionReport[\ #[\([2]\)]\ ]} &, \ 
        Transpose[{Range[20], rdifs}]]\  // \ TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1", GridBox[{
                {\(Variance \[Rule] 6929.881877022638`\)},
                {\(StandardDeviation \[Rule] 83.24591207394293`\)},
                {\(SampleRange \[Rule] 571.`\)},
                {\(MeanDeviation \[Rule] 61.15769629559817`\)},
                {\(MedianDeviation \[Rule] 44.`\)},
                {\(QuartileDeviation \[Rule] 45.99999999999966`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {\(Variance \[Rule] 6213.442567141599`\)},
                {\(StandardDeviation \[Rule] 78.82539290826021`\)},
                {\(SampleRange \[Rule] 564.`\)},
                {\(MeanDeviation \[Rule] 60.31765482137807`\)},
                {\(MedianDeviation \[Rule] 45.`\)},
                {\(QuartileDeviation \[Rule] 45.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"3", GridBox[{
                {\(Variance \[Rule] 6318.3335855083415`\)},
                {\(StandardDeviation \[Rule] 79.48794616486416`\)},
                {\(SampleRange \[Rule] 495.`\)},
                {\(MeanDeviation \[Rule] 60.6429760894838`\)},
                {\(MedianDeviation \[Rule] 44.`\)},
                {\(QuartileDeviation \[Rule] 44.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {\(Variance \[Rule] 6061.479847013828`\)},
                {\(StandardDeviation \[Rule] 77.8555062087058`\)},
                {\(SampleRange \[Rule] 577.`\)},
                {\(MeanDeviation \[Rule] 56.51955886511453`\)},
                {\(MedianDeviation \[Rule] 36.`\)},
                {\(QuartileDeviation \[Rule] 36.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"5", GridBox[{
                {\(Variance \[Rule] 5768.640293363566`\)},
                {\(StandardDeviation \[Rule] 75.95156544379823`\)},
                {\(SampleRange \[Rule] 525.`\)},
                {\(MeanDeviation \[Rule] 57.883976916873436`\)},
                {\(MedianDeviation \[Rule] 45.`\)},
                {\(QuartileDeviation \[Rule] 44.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"6", GridBox[{
                {\(Variance \[Rule] 5112.253057621987`\)},
                {\(StandardDeviation \[Rule] 71.50002138196874`\)},
                {\(SampleRange \[Rule] 459.`\)},
                {\(MeanDeviation \[Rule] 53.99069972036308`\)},
                {\(MedianDeviation \[Rule] 38.00000000000182`\)},
                {\(QuartileDeviation \[Rule] 39.75000000000034`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"7", GridBox[{
                {\(Variance \[Rule] 5022.269890303883`\)},
                {\(StandardDeviation \[Rule] 70.8679750684601`\)},
                {\(SampleRange \[Rule] 484.0000000000018`\)},
                {\(MeanDeviation \[Rule] 53.39497910579084`\)},
                {\(MedianDeviation \[Rule] 36.99999999999818`\)},
                {\(QuartileDeviation \[Rule] 36.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"8", GridBox[{
                {\(Variance \[Rule] 4940.243538015383`\)},
                {\(StandardDeviation \[Rule] 70.28686604206638`\)},
                {\(SampleRange \[Rule] 511.0000000000018`\)},
                {\(MeanDeviation \[Rule] 52.78876425676309`\)},
                {\(MedianDeviation \[Rule] 38.99999999999818`\)},
                {\(QuartileDeviation \[Rule] 38.75000000000023`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"9", GridBox[{
                {\(Variance \[Rule] 5812.308662211596`\)},
                {\(StandardDeviation \[Rule] 76.23849855690756`\)},
                {\(SampleRange \[Rule] 606.9999999999982`\)},
                {\(MeanDeviation \[Rule] 57.95243032645242`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 43.12499999999818`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"10", GridBox[{
                {\(Variance \[Rule] 5003.897932164927`\)},
                {\(StandardDeviation \[Rule] 70.73823529156581`\)},
                {\(SampleRange \[Rule] 509.`\)},
                {\(MeanDeviation \[Rule] 53.325289848242015`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 40.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"11", GridBox[{
                {\(Variance \[Rule] 5031.982494851447`\)},
                {\(StandardDeviation \[Rule] 70.93646801787813`\)},
                {\(SampleRange \[Rule] 548.0000000000146`\)},
                {\(MeanDeviation \[Rule] 51.86535541102416`\)},
                {\(MedianDeviation \[Rule] 38.00000000000182`\)},
                {\(QuartileDeviation \[Rule] 37.87500000000034`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"12", GridBox[{
                {\(Variance \[Rule] 4646.278674400034`\)},
                {\(StandardDeviation \[Rule] 68.16361694041795`\)},
                {\(SampleRange \[Rule] 454.`\)},
                {\(MeanDeviation \[Rule] 52.406426409442695`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 37.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"13", GridBox[{
                {\(Variance \[Rule] 5111.118711385698`\)},
                {\(StandardDeviation \[Rule] 71.49208845309876`\)},
                {\(SampleRange \[Rule] 565.`\)},
                {\(MeanDeviation \[Rule] 54.791969082854145`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 41.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"14", GridBox[{
                {\(Variance \[Rule] 4243.780691800102`\)},
                {\(StandardDeviation \[Rule] 65.1443066721882`\)},
                {\(SampleRange \[Rule] 445.99999999998545`\)},
                {\(MeanDeviation \[Rule] 49.72771546171482`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 38.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"15", GridBox[{
                {\(Variance \[Rule] 5554.755411255405`\)},
                {\(StandardDeviation \[Rule] 74.53023152557226`\)},
                {\(SampleRange \[Rule] 458.`\)},
                {\(MeanDeviation \[Rule] 57.92880258899679`\)},
                {\(MedianDeviation \[Rule] 44.`\)},
                {\(QuartileDeviation \[Rule] 47.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"16", GridBox[{
                {\(Variance \[Rule] 4486.746753246754`\)},
                {\(StandardDeviation \[Rule] 66.98318261509193`\)},
                {\(SampleRange \[Rule] 463.`\)},
                {\(MeanDeviation \[Rule] 50.86731391585765`\)},
                {\(MedianDeviation \[Rule] 37.99999999999818`\)},
                {\(QuartileDeviation \[Rule] 38.124999999999886`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"17", GridBox[{
                {\(Variance \[Rule] 4654.581662673926`\)},
                {\(StandardDeviation \[Rule] 68.22449459449243`\)},
                {\(SampleRange \[Rule] 482.`\)},
                {\(MeanDeviation \[Rule] 50.228799447010395`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 37.12500000000182`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"18", GridBox[{
                {\(Variance \[Rule] 4496.060290841842`\)},
                {\(StandardDeviation \[Rule] 67.05266803671456`\)},
                {\(SampleRange \[Rule] 396.`\)},
                {\(MeanDeviation \[Rule] 51.599187272860625`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 39.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"19", GridBox[{
                {\(Variance \[Rule] 4734.579897448846`\)},
                {\(StandardDeviation \[Rule] 68.80828363975407`\)},
                {\(SampleRange \[Rule] 399.`\)},
                {\(MeanDeviation \[Rule] 52.6681748201213`\)},
                {\(MedianDeviation \[Rule] 37.99999999999909`\)},
                {\(QuartileDeviation \[Rule] 39.24999999999983`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"20", GridBox[{
                {\(Variance \[Rule] 4475.603727987222`\)},
                {\(StandardDeviation \[Rule] 66.89995312395385`\)},
                {\(SampleRange \[Rule] 442.`\)},
                {\(MeanDeviation \[Rule] 48.93937013646692`\)},
                {\(MedianDeviation \[Rule] 35.`\)},
                {\(QuartileDeviation \[Rule] 36.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{1, {Variance -> 6929.881877022638, StandardDeviation -> 
        83.245912073942932, SampleRange -> 571.0, MeanDeviation -> 
        61.157696295598171, MedianDeviation -> 44.0, QuartileDeviation -> 
        45.999999999999659}}, {2, {Variance -> 6213.4425671415993, 
        StandardDeviation -> 78.825392908260213, SampleRange -> 564.0, 
        MeanDeviation -> 60.317654821378071, MedianDeviation -> 45.0, 
        QuartileDeviation -> 45.125}}, {3, {Variance -> 6318.3335855083415, 
        StandardDeviation -> 79.487946164864155, SampleRange -> 495.0, 
        MeanDeviation -> 60.642976089483803, MedianDeviation -> 44.0, 
        QuartileDeviation -> 44.375}}, {4, {Variance -> 6061.4798470138276, 
        StandardDeviation -> 77.855506208705805, SampleRange -> 577.0, 
        MeanDeviation -> 56.519558865114533, MedianDeviation -> 36.0, 
        QuartileDeviation -> 36.75}}, {5, {Variance -> 5768.6402933635663, 
        StandardDeviation -> 75.951565443798231, SampleRange -> 525.0, 
        MeanDeviation -> 57.883976916873436, MedianDeviation -> 45.0, 
        QuartileDeviation -> 44.875}}, {6, {Variance -> 5112.253057621987, 
        StandardDeviation -> 71.500021381968736, SampleRange -> 459.0, 
        MeanDeviation -> 53.990699720363082, MedianDeviation -> 
        38.000000000001819, QuartileDeviation -> 39.750000000000341}}, {7, {
        Variance -> 5022.2698903038827, StandardDeviation -> 
        70.867975068460098, SampleRange -> 484.00000000000182, MeanDeviation -> 
        53.394979105790839, MedianDeviation -> 36.999999999998181, 
        QuartileDeviation -> 36.625}}, {8, {Variance -> 4940.2435380153829, 
        StandardDeviation -> 70.286866042066379, SampleRange -> 
        511.00000000000182, MeanDeviation -> 52.788764256763088, 
        MedianDeviation -> 38.999999999998181, QuartileDeviation -> 
        38.750000000000227}}, {9, {Variance -> 5812.3086622115961, 
        StandardDeviation -> 76.238498556907558, SampleRange -> 
        606.99999999999818, MeanDeviation -> 57.952430326452422, 
        MedianDeviation -> 42.0, QuartileDeviation -> 43.124999999998181}}, {
        10, {Variance -> 5003.8979321649267, StandardDeviation -> 
        70.738235291565815, SampleRange -> 509.0, MeanDeviation -> 
        53.325289848242015, MedianDeviation -> 39.0, 
        QuartileDeviation -> .4*^2}}, {11, {Variance -> 5031.982494851447, 
        StandardDeviation -> 70.936468017878127, SampleRange -> 
        548.00000000001455, MeanDeviation -> 51.865355411024161, 
        MedianDeviation -> 38.000000000001819, QuartileDeviation -> 
        37.875000000000341}}, {12, {Variance -> 4646.2786744000341, 
        StandardDeviation -> 68.163616940417953, SampleRange -> 454.0, 
        MeanDeviation -> 52.406426409442695, MedianDeviation -> 38.0, 
        QuartileDeviation -> 37.375}}, {13, {Variance -> 5111.1187113856977, 
        StandardDeviation -> 71.492088453098759, SampleRange -> 565.0, 
        MeanDeviation -> 54.791969082854145, MedianDeviation -> 42.0, 
        QuartileDeviation -> 41.75}}, {14, {Variance -> 4243.7806918001024, 
        StandardDeviation -> 65.144306672188193, SampleRange -> 
        445.99999999998545, MeanDeviation -> 49.727715461714823, 
        MedianDeviation -> 39.0, QuartileDeviation -> 38.0}}, {15, {Variance -> 
        5554.7554112554053, StandardDeviation -> 74.530231525572262, 
        SampleRange -> 458.0, MeanDeviation -> 57.928802588996788, 
        MedianDeviation -> 44.0, QuartileDeviation -> 47.0}}, {16, {Variance -> 
        4486.7467532467545, StandardDeviation -> 66.983182615091934, 
        SampleRange -> 463.0, MeanDeviation -> 50.86731391585765, 
        MedianDeviation -> 37.999999999998181, QuartileDeviation -> 
        38.124999999999886}}, {17, {Variance -> 4654.5816626739261, 
        StandardDeviation -> 68.224494594492427, SampleRange -> 482.0, 
        MeanDeviation -> 50.228799447010395, MedianDeviation -> 38.0, 
        QuartileDeviation -> 37.125000000001819}}, {18, {Variance -> 
        4496.0602908418423, StandardDeviation -> 67.052668036714564, 
        SampleRange -> 396.0, MeanDeviation -> 51.599187272860625, 
        MedianDeviation -> 39.0, QuartileDeviation -> 39.875}}, {19, {
        Variance -> 4734.5798974488462, StandardDeviation -> 
        68.808283639754066, SampleRange -> 399.0, MeanDeviation -> 
        52.668174820121301, MedianDeviation -> 37.999999999999091, 
        QuartileDeviation -> 39.249999999999829}}, {20, {Variance -> 
        4475.6037279872216, StandardDeviation -> 66.89995312395385, 
        SampleRange -> 442.0, MeanDeviation -> 48.93937013646692, 
        MedianDeviation -> 35.0, QuartileDeviation -> 36.0}}}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(rstats\  = \ 
        Map[DispersionReport, Flatten[rbeats, \ 1]]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Partition[rstats, \ 3]]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(Variance \[Rule] 6460.59013896818`\)},
                {\(StandardDeviation \[Rule] 80.37779630574715`\)},
                {\(SampleRange \[Rule] 401.`\)},
                {\(MeanDeviation \[Rule] 63.140918088415454`\)},
                {\(MedianDeviation \[Rule] 47.99999999999999`\)},
                {\(QuartileDeviation \[Rule] 49.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6656.645535884286`\)},
                {\(StandardDeviation \[Rule] 81.5882683716494`\)},
                {\(SampleRange \[Rule] 486.`\)},
                {\(MeanDeviation \[Rule] 57.92195305872375`\)},
                {\(MedianDeviation \[Rule] 46.99999999999909`\)},
                {\(QuartileDeviation \[Rule] 45.874999999999886`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 7470.478012564204`\)},
                {\(StandardDeviation \[Rule] 86.43192704414385`\)},
                {\(SampleRange \[Rule] 514.`\)},
                {\(MeanDeviation \[Rule] 63.86106136299371`\)},
                {\(MedianDeviation \[Rule] 37.000000000001364`\)},
                {\(QuartileDeviation \[Rule] 41.00000000000023`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 5385.180468303826`\)},
                {\(StandardDeviation \[Rule] 73.38378886582395`\)},
                {\(SampleRange \[Rule] 360.`\)},
                {\(MeanDeviation \[Rule] 58.131774908096894`\)},
                {\(MedianDeviation \[Rule] 44.00000000000001`\)},
                {\(QuartileDeviation \[Rule] 50.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5861.653721682848`\)},
                {\(StandardDeviation \[Rule] 76.56143756280213`\)},
                {\(SampleRange \[Rule] 410.`\)},
                {\(MeanDeviation \[Rule] 57.95532095390706`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 44.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 7195.954502189222`\)},
                {\(StandardDeviation \[Rule] 84.82897206844618`\)},
                {\(SampleRange \[Rule] 477.`\)},
                {\(MeanDeviation \[Rule] 64.23150155528322`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 48.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 6835.667808871122`\)},
                {\(StandardDeviation \[Rule] 82.67809751603578`\)},
                {\(SampleRange \[Rule] 493.`\)},
                {\(MeanDeviation \[Rule] 62.44358563483834`\)},
                {\(MedianDeviation \[Rule] 46.`\)},
                {\(QuartileDeviation \[Rule] 43.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6166.355035217972`\)},
                {\(StandardDeviation \[Rule] 78.52614236811823`\)},
                {\(SampleRange \[Rule] 383.`\)},
                {\(MeanDeviation \[Rule] 61.4001319634273`\)},
                {\(MedianDeviation \[Rule] 48.`\)},
                {\(QuartileDeviation \[Rule] 47.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5956.72929754426`\)},
                {\(StandardDeviation \[Rule] 77.17985033377727`\)},
                {\(SampleRange \[Rule] 410.`\)},
                {\(MeanDeviation \[Rule] 58.56725421811671`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 38.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 5499.17094993337`\)},
                {\(StandardDeviation \[Rule] 74.15639520589826`\)},
                {\(SampleRange \[Rule] 400.`\)},
                {\(MeanDeviation \[Rule] 56.740503346215476`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 43.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5635.452122596612`\)},
                {\(StandardDeviation \[Rule] 75.06964847790758`\)},
                {\(SampleRange \[Rule] 474.`\)},
                {\(MeanDeviation \[Rule] 50.70411914412286`\)},
                {\(MedianDeviation \[Rule] 35.`\)},
                {\(QuartileDeviation \[Rule] 30.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6901.568246716163`\)},
                {\(StandardDeviation \[Rule] 83.07567782880957`\)},
                {\(SampleRange \[Rule] 485.`\)},
                {\(MeanDeviation \[Rule] 62.256763125648`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 46.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 5839.719779173746`\)},
                {\(StandardDeviation \[Rule] 76.41805924762645`\)},
                {\(SampleRange \[Rule] 399.99999999998545`\)},
                {\(MeanDeviation \[Rule] 59.595626354981334`\)},
                {\(MedianDeviation \[Rule] 50.`\)},
                {\(QuartileDeviation \[Rule] 48.62500000000068`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4670.699790595878`\)},
                {\(StandardDeviation \[Rule] 68.34251817569995`\)},
                {\(SampleRange \[Rule] 428.`\)},
                {\(MeanDeviation \[Rule] 52.15760203600713`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 40.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6548.704359413609`\)},
                {\(StandardDeviation \[Rule] 80.92406539104181`\)},
                {\(SampleRange \[Rule] 414.`\)},
                {\(MeanDeviation \[Rule] 62.668866057121136`\)},
                {\(MedianDeviation \[Rule] 50.`\)},
                {\(QuartileDeviation \[Rule] 54.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4624.132495716753`\)},
                {\(StandardDeviation \[Rule] 68.00097422623261`\)},
                {\(SampleRange \[Rule] 359.`\)},
                {\(MeanDeviation \[Rule] 51.24121029314733`\)},
                {\(MedianDeviation \[Rule] 39.99999999998636`\)},
                {\(QuartileDeviation \[Rule] 39.49999999999454`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4402.380544450749`\)},
                {\(StandardDeviation \[Rule] 66.35043740964146`\)},
                {\(SampleRange \[Rule] 342.`\)},
                {\(MeanDeviation \[Rule] 50.86304081440255`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 38.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6239.652960213218`\)},
                {\(StandardDeviation \[Rule] 78.99147397164595`\)},
                {\(SampleRange \[Rule] 419.99999999998545`\)},
                {\(MeanDeviation \[Rule] 60.27618060137613`\)},
                {\(MedianDeviation \[Rule] 45.`\)},
                {\(QuartileDeviation \[Rule] 43.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4710.559870550141`\)},
                {\(StandardDeviation \[Rule] 68.6335185645479`\)},
                {\(SampleRange \[Rule] 345.`\)},
                {\(MeanDeviation \[Rule] 52.200584409463396`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 41.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 3955.1966495336424`\)},
                {\(StandardDeviation \[Rule] 62.89035418515022`\)},
                {\(SampleRange \[Rule] 346.0000000000018`\)},
                {\(MeanDeviation \[Rule] 49.218965029692114`\)},
                {\(MedianDeviation \[Rule] 36.`\)},
                {\(QuartileDeviation \[Rule] 35.500000000005684`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6087.880639634507`\)},
                {\(StandardDeviation \[Rule] 78.02487192962579`\)},
                {\(SampleRange \[Rule] 472.0000000000018`\)},
                {\(MeanDeviation \[Rule] 58.363087944198455`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 38.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4337.330287454749`\)},
                {\(StandardDeviation \[Rule] 65.85841090897007`\)},
                {\(SampleRange \[Rule] 355.`\)},
                {\(MeanDeviation \[Rule] 50.656046752756815`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 35.249999999999545`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4498.464306110821`\)},
                {\(StandardDeviation \[Rule] 67.07059196183393`\)},
                {\(SampleRange \[Rule] 388.0000000000018`\)},
                {\(MeanDeviation \[Rule] 50.59590913375454`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 42.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5663.01408718828`\)},
                {\(StandardDeviation \[Rule] 75.25300051950275`\)},
                {\(SampleRange \[Rule] 461.0000000000018`\)},
                {\(MeanDeviation \[Rule] 57.624281270619285`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 43.12500000000023`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 5151.861222158821`\)},
                {\(StandardDeviation \[Rule] 71.7764670498543`\)},
                {\(SampleRange \[Rule] 325.`\)},
                {\(MeanDeviation \[Rule] 58.003393345273246`\)},
                {\(MedianDeviation \[Rule] 45.999999999998636`\)},
                {\(QuartileDeviation \[Rule] 46.24999999999949`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5252.494193794003`\)},
                {\(StandardDeviation \[Rule] 72.47409325955036`\)},
                {\(SampleRange \[Rule] 489.9999999999982`\)},
                {\(MeanDeviation \[Rule] 54.79253464039954`\)},
                {\(MedianDeviation \[Rule] 40.00000000000182`\)},
                {\(QuartileDeviation \[Rule] 44.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6846.800685322701`\)},
                {\(StandardDeviation \[Rule] 82.74539676213234`\)},
                {\(SampleRange \[Rule] 501.9999999999982`\)},
                {\(MeanDeviation \[Rule] 61.274955226694225`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 42.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4834.713877784125`\)},
                {\(StandardDeviation \[Rule] 69.53210681249436`\)},
                {\(SampleRange \[Rule] 366.`\)},
                {\(MeanDeviation \[Rule] 50.13328306155153`\)},
                {\(MedianDeviation \[Rule] 34.`\)},
                {\(QuartileDeviation \[Rule] 34.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4197.975061869408`\)},
                {\(StandardDeviation \[Rule] 64.7917823637335`\)},
                {\(SampleRange \[Rule] 330.`\)},
                {\(MeanDeviation \[Rule] 52.0476953530022`\)},
                {\(MedianDeviation \[Rule] 43.`\)},
                {\(QuartileDeviation \[Rule] 44.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5657.9267085474985`\)},
                {\(StandardDeviation \[Rule] 75.21919109208433`\)},
                {\(SampleRange \[Rule] 444.`\)},
                {\(MeanDeviation \[Rule] 56.810066924309574`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 44.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4249.866552446213`\)},
                {\(StandardDeviation \[Rule] 65.19100054797605`\)},
                {\(SampleRange \[Rule] 348.`\)},
                {\(MeanDeviation \[Rule] 49.09001790932227`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 37.87500000000017`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4535.508090614951`\)},
                {\(StandardDeviation \[Rule] 67.34618096532981`\)},
                {\(SampleRange \[Rule] 441.00000000001455`\)},
                {\(MeanDeviation \[Rule] 48.243755302101995`\)},
                {\(MedianDeviation \[Rule] 34.`\)},
                {\(QuartileDeviation \[Rule] 34.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6146.141062250158`\)},
                {\(StandardDeviation \[Rule] 78.39732815759832`\)},
                {\(SampleRange \[Rule] 476.00000000001455`\)},
                {\(MeanDeviation \[Rule] 59.04571590159307`\)},
                {\(MedianDeviation \[Rule] 40.`\)},
                {\(QuartileDeviation \[Rule] 43.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 3910.154387968779`\)},
                {\(StandardDeviation \[Rule] 62.531227302594814`\)},
                {\(SampleRange \[Rule] 317.`\)},
                {\(MeanDeviation \[Rule] 48.752757093034205`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 40.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4626.359984770607`\)},
                {\(StandardDeviation \[Rule] 68.01735061563782`\)},
                {\(SampleRange \[Rule] 337.`\)},
                {\(MeanDeviation \[Rule] 53.584126684890194`\)},
                {\(MedianDeviation \[Rule] 43.`\)},
                {\(QuartileDeviation \[Rule] 43.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5187.409099562156`\)},
                {\(StandardDeviation \[Rule] 72.0236704116234`\)},
                {\(SampleRange \[Rule] 415.`\)},
                {\(MeanDeviation \[Rule] 53.725139032896614`\)},
                {\(MedianDeviation \[Rule] 34.`\)},
                {\(QuartileDeviation \[Rule] 34.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4380.154197601371`\)},
                {\(StandardDeviation \[Rule] 66.18273337964648`\)},
                {\(SampleRange \[Rule] 369.`\)},
                {\(MeanDeviation \[Rule] 50.78141200867188`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 38.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4369.612031220257`\)},
                {\(StandardDeviation \[Rule] 66.10304101340768`\)},
                {\(SampleRange \[Rule] 268.`\)},
                {\(MeanDeviation \[Rule] 54.188330662644944`\)},
                {\(MedianDeviation \[Rule] 49.`\)},
                {\(QuartileDeviation \[Rule] 49.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 6395.663811155528`\)},
                {\(StandardDeviation \[Rule] 79.97289422770397`\)},
                {\(SampleRange \[Rule] 532.`\)},
                {\(MeanDeviation \[Rule] 59.70006598171367`\)},
                {\(MedianDeviation \[Rule] 43.`\)},
                {\(QuartileDeviation \[Rule] 46.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4507.613744526961`\)},
                {\(StandardDeviation \[Rule] 67.13876484213097`\)},
                {\(SampleRange \[Rule] 347.`\)},
                {\(MeanDeviation \[Rule] 51.98303327363567`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 41.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 3357.141823719744`\)},
                {\(StandardDeviation \[Rule] 57.94084762686635`\)},
                {\(SampleRange \[Rule] 271.99999999998545`\)},
                {\(MeanDeviation \[Rule] 46.64775190875669`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 40.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4771.987055016171`\)},
                {\(StandardDeviation \[Rule] 69.07957046056505`\)},
                {\(SampleRange \[Rule] 442.`\)},
                {\(MeanDeviation \[Rule] 49.90140446790448`\)},
                {\(MedianDeviation \[Rule] 31.000000000001364`\)},
                {\(QuartileDeviation \[Rule] 37.875`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 5989.193032552825`\)},
                {\(StandardDeviation \[Rule] 77.38987680926249`\)},
                {\(SampleRange \[Rule] 427.`\)},
                {\(MeanDeviation \[Rule] 59.429917994155936`\)},
                {\(MedianDeviation \[Rule] 47.`\)},
                {\(QuartileDeviation \[Rule] 47.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4697.269750618694`\)},
                {\(StandardDeviation \[Rule] 68.53663072123325`\)},
                {\(SampleRange \[Rule] 337.`\)},
                {\(MeanDeviation \[Rule] 54.903760957677406`\)},
                {\(MedianDeviation \[Rule] 50.`\)},
                {\(QuartileDeviation \[Rule] 52.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5921.607652769846`\)},
                {\(StandardDeviation \[Rule] 76.95198277347924`\)},
                {\(SampleRange \[Rule] 457.`\)},
                {\(MeanDeviation \[Rule] 58.461494957111874`\)},
                {\(MedianDeviation \[Rule] 40.`\)},
                {\(QuartileDeviation \[Rule] 39.25`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4415.820293165771`\)},
                {\(StandardDeviation \[Rule] 66.45163875455421`\)},
                {\(SampleRange \[Rule] 348.`\)},
                {\(MeanDeviation \[Rule] 50.64360448675616`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 40.12499999999966`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 3582.4999048163277`\)},
                {\(StandardDeviation \[Rule] 59.85398821144943`\)},
                {\(SampleRange \[Rule] 298.00000000001455`\)},
                {\(MeanDeviation \[Rule] 46.28202469601278`\)},
                {\(MedianDeviation \[Rule] 34.`\)},
                {\(QuartileDeviation \[Rule] 34.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5404.45155149439`\)},
                {\(StandardDeviation \[Rule] 73.51497501526059`\)},
                {\(SampleRange \[Rule] 419.`\)},
                {\(MeanDeviation \[Rule] 55.54039023470646`\)},
                {\(MedianDeviation \[Rule] 36.`\)},
                {\(QuartileDeviation \[Rule] 37.125`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4968.391966495368`\)},
                {\(StandardDeviation \[Rule] 70.48682122564024`\)},
                {\(SampleRange \[Rule] 482.`\)},
                {\(MeanDeviation \[Rule] 50.99085681968144`\)},
                {\(MedianDeviation \[Rule] 42.`\)},
                {\(QuartileDeviation \[Rule] 42.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 3507.169236626691`\)},
                {\(StandardDeviation \[Rule] 59.22135794311619`\)},
                {\(SampleRange \[Rule] 376.`\)},
                {\(MeanDeviation \[Rule] 43.076444528230795`\)},
                {\(MedianDeviation \[Rule] 29.99999999999818`\)},
                {\(QuartileDeviation \[Rule] 30.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5410.855891871364`\)},
                {\(StandardDeviation \[Rule] 73.55852018543715`\)},
                {\(SampleRange \[Rule] 446.`\)},
                {\(MeanDeviation \[Rule] 57.25742294278439`\)},
                {\(MedianDeviation \[Rule] 41.`\)},
                {\(QuartileDeviation \[Rule] 45.75`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4057.869407957388`\)},
                {\(StandardDeviation \[Rule] 63.70140821015959`\)},
                {\(SampleRange \[Rule] 326.`\)},
                {\(MeanDeviation \[Rule] 49.722122725987674`\)},
                {\(MedianDeviation \[Rule] 40.`\)},
                {\(QuartileDeviation \[Rule] 39.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4440.292404340351`\)},
                {\(StandardDeviation \[Rule] 66.63551908959928`\)},
                {\(SampleRange \[Rule] 392.`\)},
                {\(MeanDeviation \[Rule] 50.09671034027714`\)},
                {\(MedianDeviation \[Rule] 38.`\)},
                {\(QuartileDeviation \[Rule] 40.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4904.635446411554`\)},
                {\(StandardDeviation \[Rule] 70.03310250454105`\)},
                {\(SampleRange \[Rule] 395.99999999998545`\)},
                {\(MeanDeviation \[Rule] 54.54877933829757`\)},
                {\(MedianDeviation \[Rule] 41.00000000000091`\)},
                {\(QuartileDeviation \[Rule] 42.62499999999977`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 4888.125071387759`\)},
                {\(StandardDeviation \[Rule] 69.91512762906007`\)},
                {\(SampleRange \[Rule] 332.`\)},
                {\(MeanDeviation \[Rule] 54.577057215571614`\)},
                {\(MedianDeviation \[Rule] 44.`\)},
                {\(QuartileDeviation \[Rule] 42.375`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4352.38853988199`\)},
                {\(StandardDeviation \[Rule] 65.9726347805057`\)},
                {\(SampleRange \[Rule] 365.`\)},
                {\(MeanDeviation \[Rule] 49.53850504288806`\)},
                {\(MedianDeviation \[Rule] 31.`\)},
                {\(QuartileDeviation \[Rule] 32.74999999999966`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 4921.374833428577`\)},
                {\(StandardDeviation \[Rule] 70.15251124107088`\)},
                {\(SampleRange \[Rule] 390.00000000001455`\)},
                {\(MeanDeviation \[Rule] 53.08398529550394`\)},
                {\(MedianDeviation \[Rule] 39.`\)},
                {\(QuartileDeviation \[Rule] 39.5`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Variance \[Rule] 3911.067961165047`\)},
                {\(StandardDeviation \[Rule] 62.53853181171626`\)},
                {\(SampleRange \[Rule] 353.`\)},
                {\(MeanDeviation \[Rule] 46.08973513054951`\)},
                {\(MedianDeviation \[Rule] 37.`\)},
                {\(QuartileDeviation \[Rule] 37.`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 3866.8964401294497`\)},
                {\(StandardDeviation \[Rule] 62.18437456571747`\)},
                {\(SampleRange \[Rule] 350.`\)},
                {\(MeanDeviation \[Rule] 46.43434819492885`\)},
                {\(MedianDeviation \[Rule] 33.`\)},
                {\(QuartileDeviation \[Rule] 33.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Variance \[Rule] 5683.603464686848`\)},
                {\(StandardDeviation \[Rule] 75.38967744119117`\)},
                {\(SampleRange \[Rule] 416.`\)},
                {\(MeanDeviation \[Rule] 55.01536431331886`\)},
                {\(MedianDeviation \[Rule] 35.`\)},
                {\(QuartileDeviation \[Rule] 37.625`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{Variance -> 6460.5901389681803, StandardDeviation -> 
        80.377796305747154, SampleRange -> 401.0, MeanDeviation -> 
        63.140918088415454, MedianDeviation -> 47.999999999999993, 
        QuartileDeviation -> 49.125}, {Variance -> 6656.6455358842859, 
        StandardDeviation -> 81.588268371649406, SampleRange -> 486.0, 
        MeanDeviation -> 57.921953058723751, MedianDeviation -> 
        46.999999999999091, QuartileDeviation -> 45.874999999999886}, {
        Variance -> 7470.4780125642037, StandardDeviation -> 
        86.431927044143848, SampleRange -> 514.0, MeanDeviation -> 
        63.861061362993709, MedianDeviation -> 37.000000000001364, 
        QuartileDeviation -> 41.000000000000227}}, {{Variance -> 
        5385.1804683038263, StandardDeviation -> 73.383788865823945, 
        SampleRange -> .36*^3, MeanDeviation -> 58.131774908096894, 
        MedianDeviation -> 44.000000000000007, QuartileDeviation -> .5*^2}, {
        Variance -> 5861.6537216828483, StandardDeviation -> 
        76.561437562802126, SampleRange -> .41*^3, MeanDeviation -> 
        57.955320953907062, MedianDeviation -> 42.0, QuartileDeviation -> 
        44.0}, {Variance -> 7195.9545021892218, StandardDeviation -> 
        84.828972068446177, SampleRange -> 477.0, MeanDeviation -> 
        64.231501555283216, MedianDeviation -> 39.0, QuartileDeviation -> 
        48.625}}, {{Variance -> 6835.6678088711224, StandardDeviation -> 
        82.678097516035777, SampleRange -> 493.0, MeanDeviation -> 
        62.443585634838342, MedianDeviation -> 46.0, QuartileDeviation -> 
        43.875}, {Variance -> 6166.3550352179718, StandardDeviation -> 
        78.526142368118229, SampleRange -> 383.0, MeanDeviation -> 
        61.400131963427299, MedianDeviation -> 48.0, QuartileDeviation -> 
        47.875}, {Variance -> 5956.7292975442597, StandardDeviation -> 
        77.179850333777267, SampleRange -> .41*^3, MeanDeviation -> 
        58.567254218116709, MedianDeviation -> 38.0, QuartileDeviation -> 
        38.75}}, {{Variance -> 5499.1709499333701, StandardDeviation -> 
        74.156395205898264, SampleRange -> .4*^3, MeanDeviation -> 
        56.740503346215476, MedianDeviation -> 42.0, QuartileDeviation -> 
        43.125}, {Variance -> 5635.4521225966118, StandardDeviation -> 
        75.069648477907577, SampleRange -> 474.0, MeanDeviation -> 
        50.704119144122863, MedianDeviation -> 35.0, QuartileDeviation -> 
        30.25}, {Variance -> 6901.5682467161632, StandardDeviation -> 
        83.075677828809575, SampleRange -> 485.0, MeanDeviation -> 
        62.256763125648, MedianDeviation -> 38.0, QuartileDeviation -> 
        46.25}}, {{Variance -> 5839.7197791737462, StandardDeviation -> 
        76.418059247626445, SampleRange -> 399.99999999998545, MeanDeviation -> 
        59.595626354981334, MedianDeviation -> .5*^2, QuartileDeviation -> 
        48.625000000000682}, {Variance -> 4670.6997905958779, 
        StandardDeviation -> 68.342518175699951, SampleRange -> 428.0, 
        MeanDeviation -> 52.157602036007127, MedianDeviation -> 41.0, 
        QuartileDeviation -> 40.375}, {Variance -> 6548.7043594136094, 
        StandardDeviation -> 80.924065391041808, SampleRange -> 414.0, 
        MeanDeviation -> 62.668866057121136, MedianDeviation -> .5*^2, 
        QuartileDeviation -> 54.5}}, {{Variance -> 4624.1324957167526, 
        StandardDeviation -> 68.000974226232614, SampleRange -> 359.0, 
        MeanDeviation -> 51.241210293147333, MedianDeviation -> 
        39.999999999986358, QuartileDeviation -> 39.499999999994543}, {
        Variance -> 4402.3805444507489, StandardDeviation -> 
        66.350437409641458, SampleRange -> 342.0, MeanDeviation -> 
        50.863040814402552, MedianDeviation -> 38.0, QuartileDeviation -> 
        38.75}, {Variance -> 6239.6529602132177, StandardDeviation -> 
        78.991473971645945, SampleRange -> 419.99999999998545, MeanDeviation -> 
        60.276180601376133, MedianDeviation -> 45.0, QuartileDeviation -> 
        43.625}}, {{Variance -> 4710.5598705501407, StandardDeviation -> 
        68.633518564547899, SampleRange -> 345.0, MeanDeviation -> 
        52.200584409463396, MedianDeviation -> 41.0, QuartileDeviation -> 
        41.375}, {Variance -> 3955.1966495336424, StandardDeviation -> 
        62.890354185150223, SampleRange -> 346.00000000000182, MeanDeviation -> 
        49.218965029692114, MedianDeviation -> 36.0, QuartileDeviation -> 
        35.500000000005684}, {Variance -> 6087.8806396345071, 
        StandardDeviation -> 78.024871929625789, SampleRange -> 
        472.00000000000182, MeanDeviation -> 58.363087944198455, 
        MedianDeviation -> 38.0, QuartileDeviation -> 38.75}}, {{Variance -> 
        4337.3302874547489, StandardDeviation -> 65.858410908970072, 
        SampleRange -> 355.0, MeanDeviation -> 50.656046752756815, 
        MedianDeviation -> 39.0, QuartileDeviation -> 35.249999999999545}, {
        Variance -> 4498.4643061108209, StandardDeviation -> 
        67.070591961833927, SampleRange -> 388.00000000000182, MeanDeviation -> 
        50.595909133754539, MedianDeviation -> 42.0, QuartileDeviation -> 
        42.5}, {Variance -> 5663.0140871882804, StandardDeviation -> 
        75.253000519502748, SampleRange -> 461.00000000000182, MeanDeviation -> 
        57.624281270619285, MedianDeviation -> 41.0, QuartileDeviation -> 
        43.125000000000227}}, {{Variance -> 5151.861222158821, 
        StandardDeviation -> 71.776467049854304, SampleRange -> 325.0, 
        MeanDeviation -> 58.003393345273246, MedianDeviation -> 
        45.999999999998636, QuartileDeviation -> 46.249999999999488}, {
        Variance -> 5252.494193794003, StandardDeviation -> 
        72.474093259550358, SampleRange -> 489.99999999999818, MeanDeviation -> 
        54.792534640399538, MedianDeviation -> 40.000000000001819, 
        QuartileDeviation -> 44.125}, {Variance -> 6846.8006853227007, 
        StandardDeviation -> 82.745396762132344, SampleRange -> 
        501.99999999999818, MeanDeviation -> 61.274955226694225, 
        MedianDeviation -> 42.0, QuartileDeviation -> 42.625}}, {{Variance -> 
        4834.7138777841246, StandardDeviation -> 69.532106812494362, 
        SampleRange -> 366.0, MeanDeviation -> 50.133283061551531, 
        MedianDeviation -> 34.0, QuartileDeviation -> 34.25}, {Variance -> 
        4197.9750618694079, StandardDeviation -> 64.791782363733503, 
        SampleRange -> .33*^3, MeanDeviation -> 52.047695353002197, 
        MedianDeviation -> 43.0, QuartileDeviation -> 44.375}, {Variance -> 
        5657.9267085474985, StandardDeviation -> 75.21919109208433, 
        SampleRange -> 444.0, MeanDeviation -> 56.810066924309574, 
        MedianDeviation -> 39.0, QuartileDeviation -> 44.25}}, {{Variance -> 
        4249.8665524462131, StandardDeviation -> 65.191000547976046, 
        SampleRange -> 348.0, MeanDeviation -> 49.09001790932227, 
        MedianDeviation -> 38.0, QuartileDeviation -> 37.875000000000171}, {
        Variance -> 4535.5080906149506, StandardDeviation -> 
        67.346180965329808, SampleRange -> 441.00000000001455, MeanDeviation -> 
        48.243755302101995, MedianDeviation -> 34.0, QuartileDeviation -> 
        34.875}, {Variance -> 6146.141062250158, StandardDeviation -> 
        78.397328157598324, SampleRange -> 476.00000000001455, MeanDeviation -> 
        59.04571590159307, MedianDeviation -> .4*^2, QuartileDeviation -> 
        43.125}}, {{Variance -> 3910.1543879687788, StandardDeviation -> 
        62.531227302594814, SampleRange -> 317.0, MeanDeviation -> 
        48.752757093034205, MedianDeviation -> 41.0, QuartileDeviation -> 
        40.375}, {Variance -> 4626.3599847706073, StandardDeviation -> 
        68.017350615637824, SampleRange -> 337.0, MeanDeviation -> 
        53.584126684890194, MedianDeviation -> 43.0, QuartileDeviation -> 
        43.125}, {Variance -> 5187.4090995621564, StandardDeviation -> 
        72.023670411623399, SampleRange -> 415.0, MeanDeviation -> 
        53.725139032896614, MedianDeviation -> 34.0, QuartileDeviation -> 
        34.875}}, {{Variance -> 4380.1541976013714, StandardDeviation -> 
        66.182733379646479, SampleRange -> 369.0, MeanDeviation -> 
        50.781412008671879, MedianDeviation -> 38.0, QuartileDeviation -> 
        38.375}, {Variance -> 4369.6120312202574, StandardDeviation -> 
        66.103041013407676, SampleRange -> 268.0, MeanDeviation -> 
        54.188330662644944, MedianDeviation -> 49.0, QuartileDeviation -> 
        49.25}, {Variance -> 6395.6638111555276, StandardDeviation -> 
        79.972894227703975, SampleRange -> 532.0, MeanDeviation -> 
        59.700065981713671, MedianDeviation -> 43.0, QuartileDeviation -> 
        46.125}}, {{Variance -> 4507.6137445269615, StandardDeviation -> 
        67.138764842130968, SampleRange -> 347.0, MeanDeviation -> 
        51.98303327363567, MedianDeviation -> 39.0, QuartileDeviation -> 
        41.5}, {Variance -> 3357.141823719744, StandardDeviation -> 
        57.940847626866351, SampleRange -> 271.99999999998545, MeanDeviation -> 
        46.647751908756689, MedianDeviation -> 41.0, QuartileDeviation -> 
        40.375}, {Variance -> 4771.9870550161713, StandardDeviation -> 
        69.079570460565051, SampleRange -> 442.0, MeanDeviation -> 
        49.901404467904477, MedianDeviation -> 31.000000000001364, 
        QuartileDeviation -> 37.875}}, {{Variance -> 5989.1930325528247, 
        StandardDeviation -> 77.389876809262489, SampleRange -> 427.0, 
        MeanDeviation -> 59.429917994155936, MedianDeviation -> 47.0, 
        QuartileDeviation -> 47.5}, {Variance -> 4697.2697506186942, 
        StandardDeviation -> 68.536630721233252, SampleRange -> 337.0, 
        MeanDeviation -> 54.903760957677406, MedianDeviation -> .5*^2, 
        QuartileDeviation -> 52.125}, {Variance -> 5921.607652769846, 
        StandardDeviation -> 76.951982773479244, SampleRange -> 457.0, 
        MeanDeviation -> 58.461494957111874, MedianDeviation -> .4*^2, 
        QuartileDeviation -> 39.25}}, {{Variance -> 4415.8202931657706, 
        StandardDeviation -> 66.45163875455421, SampleRange -> 348.0, 
        MeanDeviation -> 50.643604486756161, MedianDeviation -> 41.0, 
        QuartileDeviation -> 40.124999999999659}, {Variance -> 
        3582.4999048163277, StandardDeviation -> 59.853988211449433, 
        SampleRange -> 298.00000000001455, MeanDeviation -> 
        46.282024696012783, MedianDeviation -> 34.0, QuartileDeviation -> 
        34.0}, {Variance -> 5404.4515514943896, StandardDeviation -> 
        73.514975015260589, SampleRange -> 419.0, MeanDeviation -> 
        55.540390234706457, MedianDeviation -> 36.0, QuartileDeviation -> 
        37.125}}, {{Variance -> 4968.3919664953683, StandardDeviation -> 
        70.486821225640242, SampleRange -> 482.0, MeanDeviation -> 
        50.99085681968144, MedianDeviation -> 42.0, QuartileDeviation -> 
        42.0}, {Variance -> 3507.1692366266911, StandardDeviation -> 
        59.221357943116189, SampleRange -> 376.0, MeanDeviation -> 
        43.076444528230795, MedianDeviation -> 29.999999999998181, 
        QuartileDeviation -> 30.5}, {Variance -> 5410.8558918713643, 
        StandardDeviation -> 73.558520185437146, SampleRange -> 446.0, 
        MeanDeviation -> 57.257422942784387, MedianDeviation -> 41.0, 
        QuartileDeviation -> 45.75}}, {{Variance -> 4057.8694079573879, 
        StandardDeviation -> 63.701408210159592, SampleRange -> 326.0, 
        MeanDeviation -> 49.722122725987674, MedianDeviation -> .4*^2, 
        QuartileDeviation -> 39.625}, {Variance -> 4440.2924043403509, 
        StandardDeviation -> 66.635519089599285, SampleRange -> 392.0, 
        MeanDeviation -> 50.096710340277141, MedianDeviation -> 38.0, 
        QuartileDeviation -> .4*^2}, {Variance -> 4904.6354464115539, 
        StandardDeviation -> 70.033102504541048, SampleRange -> 
        395.99999999998545, MeanDeviation -> 54.548779338297571, 
        MedianDeviation -> 41.000000000000909, QuartileDeviation -> 
        42.624999999999773}}, {{Variance -> 4888.1250713877589, 
        StandardDeviation -> 69.915127629060066, SampleRange -> 332.0, 
        MeanDeviation -> 54.577057215571614, MedianDeviation -> 44.0, 
        QuartileDeviation -> 42.375}, {Variance -> 4352.3885398819903, 
        StandardDeviation -> 65.9726347805057, SampleRange -> 365.0, 
        MeanDeviation -> 49.538505042888062, MedianDeviation -> 31.0, 
        QuartileDeviation -> 32.749999999999659}, {Variance -> 
        4921.3748334285774, StandardDeviation -> 70.152511241070883, 
        SampleRange -> 390.00000000001455, MeanDeviation -> 
        53.083985295503943, MedianDeviation -> 39.0, QuartileDeviation -> 
        39.5}}, {{Variance -> 3911.0679611650471, StandardDeviation -> 
        62.538531811716261, SampleRange -> 353.0, MeanDeviation -> 
        46.089735130549514, MedianDeviation -> 37.0, QuartileDeviation -> 
        37.0}, {Variance -> 3866.8964401294497, StandardDeviation -> 
        62.184374565717469, SampleRange -> .35*^3, MeanDeviation -> 
        46.434348194928852, MedianDeviation -> 33.0, QuartileDeviation -> 
        33.625}, {Variance -> 5683.6034646868484, StandardDeviation -> 
        75.389677441191168, SampleRange -> 416.0, MeanDeviation -> 
        55.015364313318862, MedianDeviation -> 35.0, QuartileDeviation -> 
        37.625}}}]]], "Output"]
}, Open  ]],

Cell["\<\
Here is a table of the average deviation from the correct beat position, and \
the standard deviation for each beat:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ravg\  = \ 
        Partition[Map[Mean, \ Flatten[rbeats, \ 1]], 
          3];\)\), "\[IndentingNewLine]", 
    \(\(rerr\  = \ 
        Partition[\ Map[Mean, \ Abs[Flatten[rbeats, 1]]], 
          3];\)\), "\[IndentingNewLine]", 
    \(\(rsd\  = \ 
        Partition[Map[\((StandardDeviation\  /. \ #)\) &, \ rstats], 
          3];\)\ \), "\[IndentingNewLine]", 
    \(\(rrange\  = \ 
        Flatten[Transpose[{Range[20]*100\  + \ 
                Table[Range[3], \ {x, \ 1, \ 20}]}], 
          1\ ];\)\), "\[IndentingNewLine]", 
    \(Transpose[{rrange, \ ravg, \ rerr, \ rsd}]\  // \ TableForm\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"101"},
                {"102"},
                {"103"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10.773462783171464`"},
                {"3.5695792880258366`"},
                {\(-14.343042071197306`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"64.58035630125354`"},
                {"58.019825933955495`"},
                {"60.8729066515853`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"80.37779630574715`"},
                {"81.5882683716494`"},
                {"86.43192704414385`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"201"},
                {"202"},
                {"203"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12.980582524271847`"},
                {\(-0.854368932038833`\)},
                {\(-12.126213592233054`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"60.85125836553871`"},
                {"57.96361579790744`"},
                {"62.13809030068812`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"73.38378886582395`"},
                {"76.56143756280213`"},
                {"84.82897206844618`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"301"},
                {"302"},
                {"303"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6.59870550161813`"},
                {"1.8802588996763823`"},
                {\(-8.478964401294492`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"63.82753636849212`"},
                {"61.56442643038928`"},
                {"56.53696546956985`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"82.67809751603578`"},
                {"78.52614236811823`"},
                {"77.17985033377727`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"401"},
                {"402"},
                {"403"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10.440129449838183`"},
                {"1.8867313915857549`"},
                {\(-12.326860841423938`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"58.29057089892231`"},
                {"50.5123008766142`"},
                {"60.75580481980709`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"74.15639520589826`"},
                {"75.06964847790758`"},
                {"83.07567782880957`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"501"},
                {"502"},
                {"503"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"13.139158576051724`"},
                {"0.41100323624591534`"},
                {\(-13.550161812297702`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"60.827787727401166`"},
                {"52.16957300405313`"},
                {"60.65457001916592`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"76.41805924762645`"},
                {"68.34251817569995`"},
                {"80.92406539104181`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"601"},
                {"602"},
                {"603"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8.524271844660237`"},
                {"1.223300970873824`"},
                {\(-9.747572815534069`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"52.30106513337745`"},
                {"51.02460175322813`"},
                {"58.64643227448385`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"68.00097422623261`"},
                {"66.35043740964146`"},
                {"78.99147397164595`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"701"},
                {"702"},
                {"703"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14.300970873786364`"},
                {\(-0.04854368932043567`\)},
                {\(-14.252427184465915`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"53.54538599302476`"},
                {"49.22132151946495`"},
                {"57.418229804882856`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"68.6335185645479`"},
                {"62.89035418515022`"},
                {"78.02487192962579`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"801"},
                {"802"},
                {"803"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"13.776699029126178`"},
                {"1.1747572815533565`"},
                {\(-14.951456310679506`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"52.23027618060102`"},
                {"50.63012536525605`"},
                {"55.50589122443216`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"65.85841090897007`"},
                {"67.07059196183393`"},
                {"75.25300051950275`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"901"},
                {"902"},
                {"903"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"11.485436893203934`"},
                {"1.2912621359223804`"},
                {\(-12.776699029126283`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"59.45546234329379`"},
                {"54.89047035535859`"},
                {"59.511358280704904`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"71.7764670498543`"},
                {"72.47409325955036`"},
                {"82.74539676213234`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1001"},
                {"1002"},
                {"1003"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14.029126213592244`"},
                {"0.7281553398058359`"},
                {\(-14.757281553398045`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"52.83900461871991`"},
                {"52.12545951550565`"},
                {"55.01140541050048`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"69.53210681249436`"},
                {"64.7917823637335`"},
                {"75.21919109208433`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1101"},
                {"1102"},
                {"1103"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10.236245954692514`"},
                {"2.0711974110031868`"},
                {\(-12.307443365695672`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"49.76180601376188`"},
                {"48.22364658937384`"},
                {"57.61061362993702`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"65.19100054797605`"},
                {"67.34618096532981`"},
                {"78.39732815759832`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1201"},
                {"1202"},
                {"1203"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10.433656957928818`"},
                {"3.1423948220064837`"},
                {\(-13.576051779935261`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"50.328463254469476`"},
                {"53.87692839413077`"},
                {"53.0138875797279`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"62.531227302594814`"},
                {"68.01735061563782`"},
                {"72.0236704116234`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1301"},
                {"1302"},
                {"1303"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"11.689320388349525`"},
                {"0.4951456310679672`"},
                {\(-12.184466019417465`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"51.550193232161334`"},
                {"54.2123668583278`"},
                {"58.613347158073296`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"66.18273337964648`"},
                {"66.10304101340768`"},
                {"79.97289422770397`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1401"},
                {"1402"},
                {"1403"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7.074433656957962`"},
                {"3.5695792880259387`"},
                {\(-10.644012944983887`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"53.28350142960389`"},
                {"46.890344675904124`"},
                {"49.00930027963658`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"67.13876484213097`"},
                {"57.94084762686635`"},
                {"69.07957046056505`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1501"},
                {"1502"},
                {"1503"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8.190938511326845`"},
                {"1.5113268608414243`"},
                {\(-9.702265372168265`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"60.760517799352776`"},
                {"55.01941747572819`"},
                {"58.006472491909406`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"77.38987680926249`"},
                {"68.53663072123325`"},
                {"76.95198277347924`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1601"},
                {"1602"},
                {"1603"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7.300970873786374`"},
                {"2.009708737864044`"},
                {\(-9.310679611650384`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"51.65048543689309`"},
                {"46.281553398058215`"},
                {"54.66990291262143`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"66.45163875455421`"},
                {"59.85398821144943`"},
                {"73.51497501526059`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1701"},
                {"1702"},
                {"1703"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7.113268608414277`"},
                {"3.190938511326898`"},
                {\(-10.304207119741186`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"51.95268168536156`"},
                {"43.31397869733251`"},
                {"55.419737958337144`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"70.48682122564024`"},
                {"59.22135794311619`"},
                {"73.55852018543715`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1801"},
                {"1802"},
                {"1803"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8.72168284789648`"},
                {"1.012944983818821`"},
                {\(-9.734627831715331`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"51.330034247651426`"},
                {"50.18522009614481`"},
                {"53.28230747478543`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"63.70140821015959`"},
                {"66.63551908959928`"},
                {"70.03310250454105`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1901"},
                {"1902"},
                {"1903"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8.249190938511285`"},
                {\(-0.16828478964405416`\)},
                {\(-8.080906148867218`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"55.51516008420515`"},
                {"49.536871209978926`"},
                {"52.95249316617981`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"69.91512762906007`"},
                {"65.9726347805057`"},
                {"70.15251124107088`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"2001"},
                {"2002"},
                {"2003"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3.896440129449842`"},
                {"1.906148867313919`"},
                {\(-5.802588996763768`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"46.23860244446541`"},
                {"46.57168441888966`"},
                {"54.00782354604584`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"62.53853181171626`"},
                {"62.18437456571747`"},
                {"75.38967744119117`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{101, 102, 103}, {10.773462783171464, 
        3.5695792880258366, -14.343042071197306}, {64.580356301253545, 
        58.019825933955495, 60.872906651585303}, {80.377796305747154, 
        81.588268371649406, 86.431927044143848}}, {{201, 202, 203}, {
        12.980582524271847, -.85436893203883302, -12.126213592233054}, {
        60.851258365538712, 57.963615797907437, 62.13809030068812}, {
        73.383788865823945, 76.561437562802126, 84.828972068446177}}, {{301, 
        302, 303}, {6.59870550161813, 
        1.8802588996763823, -8.4789644012944922}, {63.827536368492119, 
        61.564426430389283, 56.53696546956985}, {82.678097516035777, 
        78.526142368118229, 77.179850333777267}}, {{401, 402, 403}, {
        10.440129449838183, 1.8867313915857549, -12.326860841423938}, {
        58.290570898922311, 50.512300876614198, 60.755804819807089}, {
        74.156395205898264, 75.069648477907577, 83.075677828809575}}, {{501, 
        502, 503}, {
        13.139158576051724, .41100323624591534, -13.550161812297702}, {
        60.827787727401166, 52.169573004053127, 60.654570019165917}, {
        76.418059247626445, 68.342518175699951, 80.924065391041808}}, {{601, 
        602, 603}, {8.5242718446602375, 
        1.2233009708738241, -9.7475728155340686}, {52.301065133377449, 
        51.024601753228133, 58.64643227448385}, {68.000974226232614, 
        66.350437409641458, 78.991473971645945}}, {{701, 702, 703}, {
        14.300970873786364, -.048543689320435672, -14.252427184465915}, {
        53.545385993024759, 49.221321519464951, 57.418229804882856}, {
        68.633518564547899, 62.890354185150223, 78.024871929625789}}, {{801, 
        802, 803}, {13.776699029126178, 
        1.1747572815533565, -14.951456310679506}, {52.230276180601017, 
        50.630125365256049, 55.505891224432162}, {65.858410908970072, 
        67.070591961833927, 75.253000519502748}}, {{901, 902, 903}, {
        11.485436893203934, 1.2912621359223804, -12.776699029126283}, {
        59.455462343293789, 54.890470355358588, 59.511358280704904}, {
        71.776467049854304, 72.474093259550358, 82.745396762132344}}, {{1001, 
        1002, 1003}, {
        14.029126213592244, .72815533980583591, -14.757281553398045}, {
        52.839004618719912, 52.125459515505653, 55.01140541050048}, {
        69.532106812494362, 64.791782363733503, 75.21919109208433}}, {{1101, 
        1102, 1103}, {10.236245954692514, 
        2.0711974110031868, -12.307443365695672}, {49.761806013761877, 
        48.223646589373843, 57.610613629937021}, {65.191000547976046, 
        67.346180965329808, 78.397328157598324}}, {{1201, 1202, 1203}, {
        10.433656957928818, 3.1423948220064837, -13.576051779935261}, {
        50.328463254469476, 53.876928394130772, 53.0138875797279}, {
        62.531227302594814, 68.017350615637824, 72.023670411623399}}, {{1301, 
        1302, 1303}, {
        11.689320388349525, .49514563106796722, -12.184466019417465}, {
        51.550193232161334, 54.212366858327798, 58.613347158073296}, {
        66.182733379646479, 66.103041013407676, 79.972894227703975}}, {{1401, 
        1402, 1403}, {7.0744336569579618, 
        3.5695792880259387, -10.644012944983887}, {53.283501429603888, 
        46.890344675904124, 49.009300279636577}, {67.138764842130968, 
        57.940847626866351, 69.079570460565051}}, {{1501, 1502, 1503}, {
        8.1909385113268449, 1.5113268608414243, -9.7022653721682648}, {
        60.760517799352776, 55.01941747572819, 58.006472491909406}, {
        77.389876809262489, 68.536630721233252, 76.951982773479244}}, {{1601, 
        1602, 1603}, {7.3009708737863743, 
        2.0097087378640439, -9.310679611650384}, {51.650485436893092, 
        46.281553398058215, 54.669902912621431}, {66.45163875455421, 
        59.853988211449433, 73.514975015260589}}, {{1701, 1702, 1703}, {
        7.1132686084142769, 3.1909385113268982, -10.304207119741186}, {
        51.952681685361561, 43.313978697332509, 55.419737958337144}, {
        70.486821225640242, 59.221357943116189, 73.558520185437146}}, {{1801, 
        1802, 1803}, {8.7216828478964796, 
        1.0129449838188209, -9.734627831715331}, {51.330034247651426, 
        50.18522009614481, 53.282307474785433}, {63.701408210159592, 
        66.635519089599285, 70.033102504541048}}, {{1901, 1902, 1903}, {
        8.2491909385112852, -.16828478964405416, -8.0809061488672178}, {
        55.515160084205149, 49.536871209978926, 52.952493166179813}, {
        69.915127629060066, 65.9726347805057, 70.152511241070883}}, {{2001, 
        2002, 2003}, {3.8964401294498421, 
        1.9061488673139191, -5.8025889967637676}, {46.238602444465407, 
        46.57168441888966, 54.007823546045842}, {62.538531811716261, 
        62.184374565717469, 75.389677441191168}}}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking the relation to pre-beat event durations", "Subsection"],

Cell[CellGroupData[{

Cell["Macurka in A minor, Op. 7, No. 2", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(b2t1\  = \ 2/88\  // \ N\), "\[IndentingNewLine]", 
    \(b3t1\  = \ 65\ /\ 88\  // \ N\), "\[IndentingNewLine]", 
    \(b3p5t1\  = \ 17\ /\ 88\  // \ N\), "\[IndentingNewLine]", 
    \(b3p75t1\  = \ 4/88\  // \ N\)}], "Input"],

Cell[BoxData[
    \(0.022727272727272728`\)], "Output"],

Cell[BoxData[
    \(0.7386363636363636`\)], "Output"],

Cell[BoxData[
    \(0.19318181818181818`\)], "Output"],

Cell[BoxData[
    \(0.045454545454545456`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b2t1\  + \ b3t1\)], "Input"],

Cell[BoxData[
    \(0.7613636363636364`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(b1t2\  = \ 28/88\  // N\), "\[IndentingNewLine]", 
    \(b1p5t2\  = \ 15/88\  // N\), "\[IndentingNewLine]", 
    \(b1p67t2\  = \ 25/88\  // N\), "\[IndentingNewLine]", 
    \(b1p75t2\  = \ 20/88\  // \ N\)}], "Input"],

Cell[BoxData[
    \(0.3181818181818182`\)], "Output"],

Cell[BoxData[
    \(0.17045454545454544`\)], "Output"],

Cell[BoxData[
    \(0.2840909090909091`\)], "Output"],

Cell[BoxData[
    \(0.22727272727272727`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(76/\ 87\  // N\)], "Input"],

Cell[BoxData[
    \(0.8735632183908046`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(7/87\  // \ N\)], "Input"],

Cell[BoxData[
    \(0.08045977011494253`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((76\  + \ 28\  + \ 2 + \ 65)\)\ /\ \((88\  + \ 88\  + \ 87)\)\  // \ 
      N\)], "Input"],

Cell[BoxData[
    \(0.6501901140684411`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No 3", "Subsubsection"],

Cell["Beat 1:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(10/104\  // \ N\), "\[IndentingNewLine]", 
    \(47/104\  // \ N\), "\[IndentingNewLine]", 
    \(42/\ 104\  // \ N\), "\[IndentingNewLine]", 
    \(5/104\  // \ N\)}], "Input"],

Cell[BoxData[
    \(0.09615384615384616`\)], "Output"],

Cell[BoxData[
    \(0.4519230769230769`\)], "Output"],

Cell[BoxData[
    \(0.40384615384615385`\)], "Output"],

Cell[BoxData[
    \(0.04807692307692308`\)], "Output"]
}, Open  ]],

Cell["Beat 2:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(17/105\  // \ N\), "\[IndentingNewLine]", 
    \(27/105\  // \ N\), "\[IndentingNewLine]", 
    \(15/105\  // \ N\), "\[IndentingNewLine]", 
    \(46/105\  // \ N\)}], "Input"],

Cell[BoxData[
    \(0.1619047619047619`\)], "Output"],

Cell[BoxData[
    \(0.2571428571428571`\)], "Output"],

Cell[BoxData[
    \(0.14285714285714285`\)], "Output"],

Cell[BoxData[
    \(0.4380952380952381`\)], "Output"]
}, Open  ]],

Cell["Beat 3:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(60\ /\ 95\  // \ N\), "\[IndentingNewLine]", 
    \(35/95\  // \ N\)}], "Input"],

Cell[BoxData[
    \(0.631578947368421`\)], "Output"],

Cell[BoxData[
    \(0.3684210526315789`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((57\  + \ 17\  + \ 60)\)\ /\ \((104\ \  + 105\  + \ 95)\)\  // \ 
      N\)], "Input"],

Cell[BoxData[
    \(0.4407894736842105`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((57\  + \ 17\  + \ 60\  + \ 76\  + \ 28\  + \ 2\  + \ 
            65)\)\ /\ \((104\  + \ 105\  + \ 95\  + \ 88\  + \ 88\  + \ 
            87)\)\  // \ N\)], "Input"],

Cell[BoxData[
    \(0.5379188712522046`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Beat durations for each beat", "Section"],

Cell["\<\
This section measures the average beat duration for each beat in the triple \
meter of the Mazurkas.  Averaging for the \"exact\" performance by the \
pianists, and the average uncorrected reverse conducted taps of a listener.  \
Durations are averaged over one measure to compensate for long-term tempo \
changes, but short-term tempo changes within a measures are more difficult to \
remove so they are ignored.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2; Chiu 1999", "Subsection"],

Cell[CellGroupData[{

Cell["corrected timing data", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ Drop[pid9048x06corrected, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats1cor\  = \ 
        Drop[RotateLeft[pid9048x06corrected, \ 1]\  - \ 
            pid9048x06corrected, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats1cor\  = \ Drop[beats1cor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure1durs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats1cor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata1\  = \ 
        Transpose[{measure1durs, 
            Partition[beats1cor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions1\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \[IndentingNewLine]\ \ \
\ \ \ \ N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \ \ \ \
N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ \
\[IndentingNewLine]newdata1]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot1\  = \ 
        Histogram[Flatten[fractions1], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00981006 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04545 .01472 m
.04545 .02453 L
.09091 .02453 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02453 L
.09091 .02453 L
.09091 .01472 L
.04545 .01472 L
s
.5 .5 .5 r
.09091 .01472 m
.09091 .02453 L
.13636 .02453 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02453 L
.13636 .02453 L
.13636 .01472 L
.09091 .01472 L
s
.5 .5 .5 r
.13636 .01472 m
.13636 .03434 L
.18182 .03434 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .03434 L
.18182 .03434 L
.18182 .01472 L
.13636 .01472 L
s
.5 .5 .5 r
.18182 .01472 m
.18182 .18149 L
.22727 .18149 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .18149 L
.22727 .18149 L
.22727 .01472 L
.18182 .01472 L
s
.5 .5 .5 r
.22727 .01472 m
.22727 .33845 L
.27273 .33845 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .33845 L
.27273 .33845 L
.27273 .01472 L
.22727 .01472 L
s
.5 .5 .5 r
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
.27273 .01472 L
s
.5 .5 .5 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
.5 .5 .5 r
.36364 .01472 m
.36364 .56408 L
.40909 .56408 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .56408 L
.40909 .56408 L
.40909 .01472 L
.36364 .01472 L
s
.5 .5 .5 r
.40909 .01472 m
.40909 .50522 L
.45455 .50522 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .50522 L
.45455 .50522 L
.45455 .01472 L
.40909 .01472 L
s
.5 .5 .5 r
.45455 .01472 m
.45455 .29921 L
.5 .29921 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .29921 L
.5 .29921 L
.5 .01472 L
.45455 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .39731 L
.54545 .39731 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .39731 L
.54545 .39731 L
.54545 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.54545 .01472 m
.54545 .15206 L
.59091 .15206 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .15206 L
.59091 .15206 L
.59091 .01472 L
.54545 .01472 L
s
.5 .5 .5 r
.59091 .01472 m
.59091 .0932 L
.63636 .0932 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0932 L
.63636 .0932 L
.63636 .01472 L
.59091 .01472 L
s
.5 .5 .5 r
.63636 .01472 m
.63636 .02453 L
.68182 .02453 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .02453 L
.68182 .02453 L
.68182 .01472 L
.63636 .01472 L
s
.5 .5 .5 r
.68182 .01472 m
.68182 .04415 L
.72727 .04415 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04415 L
.72727 .04415 L
.72727 .01472 L
.68182 .01472 L
s
.5 .5 .5 r
.72727 .01472 m
.72727 .03434 L
.77273 .03434 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .03434 L
.77273 .03434 L
.77273 .01472 L
.72727 .01472 L
s
.5 .5 .5 r
.77273 .01472 m
.77273 .02453 L
.81818 .02453 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02453 L
.81818 .02453 L
.81818 .01472 L
.77273 .01472 L
s
.5 .5 .5 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
.5 .5 .5 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
.5 .5 .5 r
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
.90909 .01472 L
s
.5 .5 .5 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`002P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo
0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000040?ooool00000300000030?ooo`002P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo01D0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool02@3ooolI000000/0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl=000000/0Ogmo00<0000007moO`1oOgl02@1oOgl=000001L0oooo3@00000;0?ooo`030000
003oool0oooo0080oooo000;0?ooo`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00000R0?ooo`d000002`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo
00T0Ogmo3@00000j0?ooo`800000103oool00180oooo00<000000?ooo`3oool0;@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02d0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool02@3oool=000004L0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000^0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G03oool2000000@0oooo000B0?ooo`03
0000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000;P3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo05`0oooo0P0000040?ooo`004P3oool00`000000
oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0]0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?oo
o`004P3oool2000002h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo3@00001N0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`020?ooo`00103oool5
00000080oooo0P0000050?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo0`00000]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo06P0oooo0P0000040?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo06T0oooo00<000000?ooo`3oool00P3oool000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0080oooo00050?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0J@3oool00`000000
oooo0?ooo`020?ooo`004P3oool2000002h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0J03oool2000000@0oooo
000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000002h0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`d00000JP3oool2000000@0oooo000B0?ooo`030000003o
ool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo02d0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo
0P00000^0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1d0?ooo`800000103oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo02d0oooo3@00000;07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000j0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M03o
ool2000000@0oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
0080oooo00040?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080
oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000003T0
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1d0?ooo`800000103oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000j0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0M03oool2000000@0oooo000B0?ooo`030000003oool0
oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03T0
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>P3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo07@0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0i
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003X0oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1d0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
07D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000j
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M03oool2000000@0oooo000B0?oo
o`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`d000002`1oOgl00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
2@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo0080oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`<00000>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07@0
oooo0P0000040?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0
oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo00050?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo
07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo0P00
000j0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`090?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M03oool2000000@0oooo000B
0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo03T0oooo3@00000;07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo04D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000
001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`004P3o
ool2000004H0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0M03oool2000000@0oooo000B0?ooo`030000003oool0
oooo04D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`00
0000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo
0?ooo`090?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool00P3oool00180oooo0P0000160?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07@0oooo0P000004
0?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo00T0oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool00P3oool00180oooo0P0000160?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0
oooo07@0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo
07D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool=000000/0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo00T0
oooo3@00001g0?ooo`030000003oool0oooo0080oooo00060?ooo`<000000P3oool2000000D0oooo
00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool000@0oooo1@00
00001@3oool000000?ooo`3oool0000000@0oooo0`00001A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08`0oooo
0P0000040?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080
oooo00050?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool000H0oooo
0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2<
0?ooo`800000103oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0D@3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`2<0?ooo`800000103oool00180oooo00<000000?ooo`3oool0D@3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0540
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B
0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool200000580oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S03oool2000000@0oooo000B0?ooo`03
0000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`020?ooo`004P3oool200000580oooo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S03oool20000
00@0oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo
00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0540oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`001`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo0`00001A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl>000008h0oooo0P0000040?ooo`001@3oool2000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0080oooo
00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo0080oooo00050?ooo`<000000`3oool2000000D0oooo00<0
00000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0V@3oool2000000@0oooo000B0?ooo`03
0000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo09X0oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00001B0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`2I0?ooo`800000103oool00180oooo00<000000?ooo`3oool0D@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0VP3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000003oool0oooo09X0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0VP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool00`000000Ogmo07moO`0907moO`d0
0000V`3oool2000000@0oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
0540oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0080oooo000B0?ooo`800000DP3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo0:D0
oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`020?ooo`00103oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0540oooo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0080oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`020?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
0`00001A0?ooo`d00000Y`3oool2000000@0oooo00040?ooo`<000000`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`020?ooo`001@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00050?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`004P3ooooo
000000/00000103oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {554.313, 413}} -> {0.0745211, 192.41, \
0.00166092, 0.384791}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot11\  = 
        Histogram[fractions1[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .46556 L
.55556 .46556 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .46556 L
.55556 .46556 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .06481 L
.77778 .06481 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .06481 L
.77778 .06481 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .02724 L
.88889 .02724 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .02724 L
.88889 .02724 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000K0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo7`00000M0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o
000N000001d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001/0o`00
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000K0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03P0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000703ooolO000001`0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`007`00000i0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000>P3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05D0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00050?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0
oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<0
0000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05@0oooo0`0000030?ooo`00
1@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo03T0oooo7P00000M0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000E`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l001l00000F03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<0
0000EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0LP3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00
001F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1b0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
E`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o000N0000
07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000D0oooo0`0000020?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000001@3oool000000?ooo`3oool0000000@0
oooo0`00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool3000000<0
oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000D0oooo0P0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oooal00000T`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0040oooo000A0?ooool000003@0000030?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.26215, 0.00169256, 0.300334}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot12\  = 
        Histogram[fractions1[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00997634 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11448 -12 -4.5 ]
[-0.0125 .11448 0 4.5 ]
[-0.0125 .21424 -12 -4.5 ]
[-0.0125 .21424 0 4.5 ]
[-0.0125 .31401 -12 -4.5 ]
[-0.0125 .31401 0 4.5 ]
[-0.0125 .41377 -12 -4.5 ]
[-0.0125 .41377 0 4.5 ]
[-0.0125 .51353 -12 -4.5 ]
[-0.0125 .51353 0 4.5 ]
[-0.0125 .6133 -12 -4.5 ]
[-0.0125 .6133 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11448 m
.00625 .11448 L
s
[(10)] -0.0125 .11448 1 0 Mshowa
0 .21424 m
.00625 .21424 L
s
[(20)] -0.0125 .21424 1 0 Mshowa
0 .31401 m
.00625 .31401 L
s
[(30)] -0.0125 .31401 1 0 Mshowa
0 .41377 m
.00625 .41377 L
s
[(40)] -0.0125 .41377 1 0 Mshowa
0 .51353 m
.00625 .51353 L
s
[(50)] -0.0125 .51353 1 0 Mshowa
0 .6133 m
.00625 .6133 L
s
[(60)] -0.0125 .6133 1 0 Mshowa
.125 Mabswid
0 .03467 m
.00375 .03467 L
s
0 .05462 m
.00375 .05462 L
s
0 .07457 m
.00375 .07457 L
s
0 .09453 m
.00375 .09453 L
s
0 .13443 m
.00375 .13443 L
s
0 .15438 m
.00375 .15438 L
s
0 .17434 m
.00375 .17434 L
s
0 .19429 m
.00375 .19429 L
s
0 .23419 m
.00375 .23419 L
s
0 .25415 m
.00375 .25415 L
s
0 .2741 m
.00375 .2741 L
s
0 .29405 m
.00375 .29405 L
s
0 .33396 m
.00375 .33396 L
s
0 .35391 m
.00375 .35391 L
s
0 .37386 m
.00375 .37386 L
s
0 .39382 m
.00375 .39382 L
s
0 .43372 m
.00375 .43372 L
s
0 .45367 m
.00375 .45367 L
s
0 .47363 m
.00375 .47363 L
s
0 .49358 m
.00375 .49358 L
s
0 .53348 m
.00375 .53348 L
s
0 .55344 m
.00375 .55344 L
s
0 .57339 m
.00375 .57339 L
s
0 .59334 m
.00375 .59334 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11448 m
1 .11448 L
s
.99375 .21424 m
1 .21424 L
s
.99375 .31401 m
1 .31401 L
s
.99375 .41377 m
1 .41377 L
s
.99375 .51353 m
1 .51353 L
s
.99375 .6133 m
1 .6133 L
s
.125 Mabswid
.99625 .03467 m
1 .03467 L
s
.99625 .05462 m
1 .05462 L
s
.99625 .07457 m
1 .07457 L
s
.99625 .09453 m
1 .09453 L
s
.99625 .13443 m
1 .13443 L
s
.99625 .15438 m
1 .15438 L
s
.99625 .17434 m
1 .17434 L
s
.99625 .19429 m
1 .19429 L
s
.99625 .23419 m
1 .23419 L
s
.99625 .25415 m
1 .25415 L
s
.99625 .2741 m
1 .2741 L
s
.99625 .29405 m
1 .29405 L
s
.99625 .33396 m
1 .33396 L
s
.99625 .35391 m
1 .35391 L
s
.99625 .37386 m
1 .37386 L
s
.99625 .39382 m
1 .39382 L
s
.99625 .43372 m
1 .43372 L
s
.99625 .45367 m
1 .45367 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .49358 m
1 .49358 L
s
.99625 .53348 m
1 .53348 L
s
.99625 .55344 m
1 .55344 L
s
.99625 .57339 m
1 .57339 L
s
.99625 .59334 m
1 .59334 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .04464 L
.22222 .04464 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04464 L
.22222 .04464 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .43372 L
.33333 .43372 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .43372 L
.33333 .43372 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .16436 L
.55556 .16436 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .16436 L
.55556 .16436 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:P3oool2000000@0oooo0P0000030?ooo`@00000:`3oool2000000@0oooo0P0000040?oo
o`800000;03oool2000000@0oooo0P0000050?ooo`<00000:P3oool2000000@0oooo0P0000040?oo
o`800000>P3oool002T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0[0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`00:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0
oooo000000P0oooo1@00000Y0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool002T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Y0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002X0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000Y
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002X0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000Z0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002X0oooo0P00000:0?ooo`800000;03oool2000000X0oooo0P00000/0?ooo`8000002`3oool2
000002/0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001@0ooooo`000007000000H0oooo000D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`00
3@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003oool0oooo00@0oooo
000<0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool000`0oooo00@0
00000?ooo`3oool00000103ooooo000000L000001P3oool000`0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6P00o`000`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`040?ooo`00303oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000
0000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo00@0oooo000=0?ooo`8000001@3oool00`000000oooo0?ooo`0J0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006P00o`000`0000000?l0003o000J003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`00503oool0
0`000000oooo0?ooo`0J0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`00
0`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`040?ooo`00503oool2000001/0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000J003o000300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1`0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool06P3oool00`000000
0?l0003o000J003o000300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000
0?l0003o000J003o00030000003oool0oooo0740oooo00<000000?ooo`3oool0103oool001@0oooo
00<000000?ooo`3oool06P3ooolN000001`00?l000<00000003o0000o`006P00o`000`0000000?l0
003o000J003o00030000003oool0oooo0740oooo00<000000?ooo`3oool0103oool001@0oooo00<0
00000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo000D
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`04
0?ooo`00503oool2000003P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L03oool2000000H0oooo000D0?ooo`03
0000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`00
503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6P00o`000`0000000?l0003o000J003o00030000003oool0oooo0740oooo00<000000?ooo`3oool0
103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000
o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`040?ooo`00503oool2000003P0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L03oool20000
00H0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo0740oooo
00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o
000J003o000300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000J003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`0000000?l0003o000J003o
00030000003oool0oooo0740oooo00<000000?ooo`3oool0103oool001@0oooo0P00000h0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006P00o`000`0000000?l0003o000J003o0003
0000003oool0oooo0700oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000
003oool0oooo0740oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0=`3o
ool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo00060?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`00
0?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo00@0oooo00080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`04
0?ooo`00203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3
000003L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0L03oool2000000H0oooo00080?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000J003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`00203oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0g0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0
oooo0740oooo00<000000?ooo`3oool0103oool000L0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`00
00000?l0003o000J003o00030000003oool0oooo0740oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0
oooo000D0?ooo`800000>03oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1`0?ooo`8000001P3oool001@0oooo00<0
00000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0oooo000D
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`04
0?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o
0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo0740oooo00<000000?oo
o`3oool0103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o0003
00000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`800000>03oool00`0000000?l0003o000J003o00030000
0000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1`0?ooo`800000
1P3oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000
o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006P00o`0N000007<0oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool2000003P0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo08d0oooo
0P0000060?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?oo
o`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0
103oool001@0oooo0P00000h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`2=0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0=`3oool0
0`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00@0oooo00060?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0=`3oool00`000000
0?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000g0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2=0?ooo`8000001P3oool000P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`040?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?oo
o`001`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03L0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503o
ool2000003P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003o
ool0oooo08d0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo
0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000>03oool00`0000000?l0003o
000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0S@3oool2000000H0oooo000D
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?oo
o`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0
103oool001@0oooo0P00000h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`2=0?ooo`8000001P3oool001@0oooo00<000000?ooo`3oool0=`3oool0
0`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo
00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?oo
o`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000>03oool00`0000000?l0003o000J
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0S@3oool2000000H0oooo000D0?oo
o`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o
00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3o
ool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`040?ooo`001`3oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000
003oool0oooo08h0oooo00<000000?ooo`3oool0103oool000H0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03L0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0103oool000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo0`00000g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`2=0?ooo`8000001P3oool000T0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool000H0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo
08h0oooo00<000000?ooo`3oool0103oool000L0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo
00<000000?ooo`3oool0103oool001@0oooo0P00000h0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`2=0?ooo`8000001P3oool001@0oooo00<00000
0?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503o
ool2000003P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003o
ool0oooo08d0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0
oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo
0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000>03oool00`0000000?l0003o
000J003o000300000000o`000?l001X00?l000<000000?ooo`3oool0S@3oool2000000H0oooo000D
0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J
003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?oo
o`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0
103oool001@0oooo00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool2
000003P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000J003o00030000003oool0
oooo08d0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
00@0oooo000D0?ooo`030000003oool0oooo03L0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool000P0oooo
0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo
00090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo00060?ooo`D0000000D0oooo0000003oool0oooo
000000040?ooo`<00000=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0S@3oool2000000H0oooo00060?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0g0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0
oooo00070?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo00080?ooo`8000000`3oool2000000D0oooo
00<000000?ooo`3oool0=`3oool00`0000000?l0003o000J003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?oo
o`0g0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000>03ooolN000001`00?l000<00000
0?ooo`3oool0S@3oool2000000H0oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o
0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`03
0000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`00
6P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003o
ool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`800000E@3oool00`0000000?l0003o000J003o00030000003oool0
oooo08d0oooo0P0000060?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l0
01X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000
oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l0
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?oo
o`1D0?ooo`0300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`040?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l000<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool2000005D0oooo00<00000003o
0000o`006P00o`000`000000oooo0?ooo`2=0?ooo`8000001P3oool001@0oooo00<000000?ooo`3o
ool0E03oool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0103oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000
003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03o
ool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103o
ool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000003oool0
oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo0P00001E0?ooo`0300000000o`000?l0
01X00?l000<000000?ooo`3oool0S@3oool2000000H0oooo000D0?ooo`030000003oool0oooo05@0
oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0
oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo00070?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0103oool000H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo00090?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool3000005@0oooo00<00000003o0000o`006P00o`000`000000oooo
0?ooo`2=0?ooo`8000001P3oool000L0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo
00<000000?ooo`3oool0103oool000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo00070?ooo`<000000`3oool2000000D0oooo00<0
00000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o000J
003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo0P00001E0?oo
o`0300000000o`000?l001X00?l000<000000?ooo`3oool0S@3oool2000000H0oooo000D0?ooo`03
0000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`00
6P00o`000`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003o
ool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00@0oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`006P00o`00
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`800000E@3oool00`00
00000?l0003o000J003o00030000003oool0oooo08d0oooo0P0000060?ooo`00503oool00`000000
oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l0
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?oo
o`1D0?ooo`0300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`040?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`0300000000o`000?l001X00?l000<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`1D0?oo
o`0300000000o`000?l001X00?l000<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`040?oo
o`00503oool2000005D0oooo00<00000003o0000o`006P00o`000`000000oooo0?ooo`2=0?ooo`80
00001P3oool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000
003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03o
ool00`0000000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103o
ool001@0oooo00<000000?ooo`3oool0E03oool00`0000000?l0003o000J003o00030000003oool0
oooo08h0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0E03oool00`00
00000?l0003o000J003o00030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool001@0
oooo0P00001E0?ooo`0300000000o`000?l001X00?l000<000000?ooo`3oool0S@3oool2000000H0
oooo000D0?ooo`030000003oool0oooo05@0oooo00<00000003o0000o`006P00o`000`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00@0oooo000D0?ooo`030000003oool0oooo05@0oooo7P00
002@0?ooo`030000003oool0oooo00@0oooo00060?ooo`<00000103oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`030000003oool0oooo00@0oooo00060?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<0
00000?ooo`3oool0103oool000H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`<000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`8000001P3oool000H0oooo0`00
00030?ooo`040000003oool0oooo000000@0ooooo`000007000000H0oooo00070?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000o`3ooolA0?ooo`001`3oool3000000<0oooo0P00
003o0?oooa80oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0575611, \
82.6087, 0.0017262, 0.384509}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot13\  = 
        Histogram[fractions1[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0136885 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1516 -12 -4.5 ]
[-0.0125 .1516 0 4.5 ]
[-0.0125 .28848 -12 -4.5 ]
[-0.0125 .28848 0 4.5 ]
[-0.0125 .42537 -12 -4.5 ]
[-0.0125 .42537 0 4.5 ]
[-0.0125 .56225 -12 -4.5 ]
[-0.0125 .56225 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1516 m
.00625 .1516 L
s
[(10)] -0.0125 .1516 1 0 Mshowa
0 .28848 m
.00625 .28848 L
s
[(20)] -0.0125 .28848 1 0 Mshowa
0 .42537 m
.00625 .42537 L
s
[(30)] -0.0125 .42537 1 0 Mshowa
0 .56225 m
.00625 .56225 L
s
[(40)] -0.0125 .56225 1 0 Mshowa
.125 Mabswid
0 .04209 m
.00375 .04209 L
s
0 .06947 m
.00375 .06947 L
s
0 .09685 m
.00375 .09685 L
s
0 .12422 m
.00375 .12422 L
s
0 .17898 m
.00375 .17898 L
s
0 .20635 m
.00375 .20635 L
s
0 .23373 m
.00375 .23373 L
s
0 .26111 m
.00375 .26111 L
s
0 .31586 m
.00375 .31586 L
s
0 .34324 m
.00375 .34324 L
s
0 .37062 m
.00375 .37062 L
s
0 .39799 m
.00375 .39799 L
s
0 .45275 m
.00375 .45275 L
s
0 .48012 m
.00375 .48012 L
s
0 .5075 m
.00375 .5075 L
s
0 .53488 m
.00375 .53488 L
s
0 .58963 m
.00375 .58963 L
s
0 .61701 m
.00375 .61701 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1516 m
1 .1516 L
s
.99375 .28848 m
1 .28848 L
s
.99375 .42537 m
1 .42537 L
s
.99375 .56225 m
1 .56225 L
s
.125 Mabswid
.99625 .04209 m
1 .04209 L
s
.99625 .06947 m
1 .06947 L
s
.99625 .09685 m
1 .09685 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23373 m
1 .23373 L
s
.99625 .26111 m
1 .26111 L
s
.99625 .31586 m
1 .31586 L
s
.99625 .34324 m
1 .34324 L
s
.99625 .37062 m
1 .37062 L
s
.99625 .39799 m
1 .39799 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .48012 m
1 .48012 L
s
.99625 .5075 m
1 .5075 L
s
.99625 .53488 m
1 .53488 L
s
.99625 .58963 m
1 .58963 L
s
.99625 .61701 m
1 .61701 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06947 L
.22222 .06947 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06947 L
.22222 .06947 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .39799 L
.33333 .39799 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .39799 L
.33333 .39799 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .48012 L
.44444 .48012 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .48012 L
.44444 .48012 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .12422 L
.66667 .12422 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .12422 L
.66667 .12422 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .0284 L
.77778 .0284 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0284 L
.77778 .0284 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .0284 L
1 .0284 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .0284 L
1 .0284 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
003oool0oooo01X0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o7`00000L0?oooal000000`3oool00140oooo00<000000?ooo`3oool06`3oool0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00000L0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00000L0?oooal0000070000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0
E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?lO000005L0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`<00000>@3oool00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oo
o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000
003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3ooolN000001d0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo0`00001F0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool000H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?oooal0000070000?l00`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0M03o
ool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001e0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000M@3o
ool00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo07@0oooo00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00060?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d
0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`000`3oool5000000050?ooo`000000oooo0?ooo`000000103oool3000007@0oooo00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07@0oooo00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0004
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo07@0oooo00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000M@3oool00`000000003o0000o`0J0000o`030000003o
ool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1d0?oooah00000MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000A0?ooool000003@0000030?oo
o`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0636924, \
117.748, 0.00169256, 0.274774}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot1, \ xplot11, \ xplot12, \ 
            xplot13}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00981006 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04545 .01472 m
.04545 .02453 L
.09091 .02453 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02453 L
.09091 .02453 L
.09091 .01472 L
.04545 .01472 L
s
.5 .5 .5 r
.09091 .01472 m
.09091 .02453 L
.13636 .02453 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02453 L
.13636 .02453 L
.13636 .01472 L
.09091 .01472 L
s
.5 .5 .5 r
.13636 .01472 m
.13636 .03434 L
.18182 .03434 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .03434 L
.18182 .03434 L
.18182 .01472 L
.13636 .01472 L
s
.5 .5 .5 r
.18182 .01472 m
.18182 .18149 L
.22727 .18149 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .18149 L
.22727 .18149 L
.22727 .01472 L
.18182 .01472 L
s
.5 .5 .5 r
.22727 .01472 m
.22727 .33845 L
.27273 .33845 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .33845 L
.27273 .33845 L
.27273 .01472 L
.22727 .01472 L
s
.5 .5 .5 r
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
.27273 .01472 L
s
.5 .5 .5 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
.5 .5 .5 r
.36364 .01472 m
.36364 .56408 L
.40909 .56408 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .56408 L
.40909 .56408 L
.40909 .01472 L
.36364 .01472 L
s
.5 .5 .5 r
.40909 .01472 m
.40909 .50522 L
.45455 .50522 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .50522 L
.45455 .50522 L
.45455 .01472 L
.40909 .01472 L
s
.5 .5 .5 r
.45455 .01472 m
.45455 .29921 L
.5 .29921 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .29921 L
.5 .29921 L
.5 .01472 L
.45455 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .39731 L
.54545 .39731 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .39731 L
.54545 .39731 L
.54545 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.54545 .01472 m
.54545 .15206 L
.59091 .15206 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .15206 L
.59091 .15206 L
.59091 .01472 L
.54545 .01472 L
s
.5 .5 .5 r
.59091 .01472 m
.59091 .0932 L
.63636 .0932 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0932 L
.63636 .0932 L
.63636 .01472 L
.59091 .01472 L
s
.5 .5 .5 r
.63636 .01472 m
.63636 .02453 L
.68182 .02453 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .02453 L
.68182 .02453 L
.68182 .01472 L
.63636 .01472 L
s
.5 .5 .5 r
.68182 .01472 m
.68182 .04415 L
.72727 .04415 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04415 L
.72727 .04415 L
.72727 .01472 L
.68182 .01472 L
s
.5 .5 .5 r
.72727 .01472 m
.72727 .03434 L
.77273 .03434 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .03434 L
.77273 .03434 L
.77273 .01472 L
.72727 .01472 L
s
.5 .5 .5 r
.77273 .01472 m
.77273 .02453 L
.81818 .02453 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02453 L
.81818 .02453 L
.81818 .01472 L
.77273 .01472 L
s
.5 .5 .5 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
.5 .5 .5 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
.5 .5 .5 r
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
.90909 .01472 L
s
.5 .5 .5 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .46556 L
.55556 .46556 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .46556 L
.55556 .46556 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .06481 L
.77778 .06481 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .06481 L
.77778 .06481 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .02724 L
.88889 .02724 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .02724 L
.88889 .02724 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00997634 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11448 -12 -4.5 ]
[-0.0125 .11448 0 4.5 ]
[-0.0125 .21424 -12 -4.5 ]
[-0.0125 .21424 0 4.5 ]
[-0.0125 .31401 -12 -4.5 ]
[-0.0125 .31401 0 4.5 ]
[-0.0125 .41377 -12 -4.5 ]
[-0.0125 .41377 0 4.5 ]
[-0.0125 .51353 -12 -4.5 ]
[-0.0125 .51353 0 4.5 ]
[-0.0125 .6133 -12 -4.5 ]
[-0.0125 .6133 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11448 m
.00625 .11448 L
s
[(10)] -0.0125 .11448 1 0 Mshowa
0 .21424 m
.00625 .21424 L
s
[(20)] -0.0125 .21424 1 0 Mshowa
0 .31401 m
.00625 .31401 L
s
[(30)] -0.0125 .31401 1 0 Mshowa
0 .41377 m
.00625 .41377 L
s
[(40)] -0.0125 .41377 1 0 Mshowa
0 .51353 m
.00625 .51353 L
s
[(50)] -0.0125 .51353 1 0 Mshowa
0 .6133 m
.00625 .6133 L
s
[(60)] -0.0125 .6133 1 0 Mshowa
.125 Mabswid
0 .03467 m
.00375 .03467 L
s
0 .05462 m
.00375 .05462 L
s
0 .07457 m
.00375 .07457 L
s
0 .09453 m
.00375 .09453 L
s
0 .13443 m
.00375 .13443 L
s
0 .15438 m
.00375 .15438 L
s
0 .17434 m
.00375 .17434 L
s
0 .19429 m
.00375 .19429 L
s
0 .23419 m
.00375 .23419 L
s
0 .25415 m
.00375 .25415 L
s
0 .2741 m
.00375 .2741 L
s
0 .29405 m
.00375 .29405 L
s
0 .33396 m
.00375 .33396 L
s
0 .35391 m
.00375 .35391 L
s
0 .37386 m
.00375 .37386 L
s
0 .39382 m
.00375 .39382 L
s
0 .43372 m
.00375 .43372 L
s
0 .45367 m
.00375 .45367 L
s
0 .47363 m
.00375 .47363 L
s
0 .49358 m
.00375 .49358 L
s
0 .53348 m
.00375 .53348 L
s
0 .55344 m
.00375 .55344 L
s
0 .57339 m
.00375 .57339 L
s
0 .59334 m
.00375 .59334 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11448 m
1 .11448 L
s
.99375 .21424 m
1 .21424 L
s
.99375 .31401 m
1 .31401 L
s
.99375 .41377 m
1 .41377 L
s
.99375 .51353 m
1 .51353 L
s
.99375 .6133 m
1 .6133 L
s
.125 Mabswid
.99625 .03467 m
1 .03467 L
s
.99625 .05462 m
1 .05462 L
s
.99625 .07457 m
1 .07457 L
s
.99625 .09453 m
1 .09453 L
s
.99625 .13443 m
1 .13443 L
s
.99625 .15438 m
1 .15438 L
s
.99625 .17434 m
1 .17434 L
s
.99625 .19429 m
1 .19429 L
s
.99625 .23419 m
1 .23419 L
s
.99625 .25415 m
1 .25415 L
s
.99625 .2741 m
1 .2741 L
s
.99625 .29405 m
1 .29405 L
s
.99625 .33396 m
1 .33396 L
s
.99625 .35391 m
1 .35391 L
s
.99625 .37386 m
1 .37386 L
s
.99625 .39382 m
1 .39382 L
s
.99625 .43372 m
1 .43372 L
s
.99625 .45367 m
1 .45367 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .49358 m
1 .49358 L
s
.99625 .53348 m
1 .53348 L
s
.99625 .55344 m
1 .55344 L
s
.99625 .57339 m
1 .57339 L
s
.99625 .59334 m
1 .59334 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .04464 L
.22222 .04464 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04464 L
.22222 .04464 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .43372 L
.33333 .43372 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .43372 L
.33333 .43372 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .16436 L
.55556 .16436 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .16436 L
.55556 .16436 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0136885 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1516 -12 -4.5 ]
[-0.0125 .1516 0 4.5 ]
[-0.0125 .28848 -12 -4.5 ]
[-0.0125 .28848 0 4.5 ]
[-0.0125 .42537 -12 -4.5 ]
[-0.0125 .42537 0 4.5 ]
[-0.0125 .56225 -12 -4.5 ]
[-0.0125 .56225 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1516 m
.00625 .1516 L
s
[(10)] -0.0125 .1516 1 0 Mshowa
0 .28848 m
.00625 .28848 L
s
[(20)] -0.0125 .28848 1 0 Mshowa
0 .42537 m
.00625 .42537 L
s
[(30)] -0.0125 .42537 1 0 Mshowa
0 .56225 m
.00625 .56225 L
s
[(40)] -0.0125 .56225 1 0 Mshowa
.125 Mabswid
0 .04209 m
.00375 .04209 L
s
0 .06947 m
.00375 .06947 L
s
0 .09685 m
.00375 .09685 L
s
0 .12422 m
.00375 .12422 L
s
0 .17898 m
.00375 .17898 L
s
0 .20635 m
.00375 .20635 L
s
0 .23373 m
.00375 .23373 L
s
0 .26111 m
.00375 .26111 L
s
0 .31586 m
.00375 .31586 L
s
0 .34324 m
.00375 .34324 L
s
0 .37062 m
.00375 .37062 L
s
0 .39799 m
.00375 .39799 L
s
0 .45275 m
.00375 .45275 L
s
0 .48012 m
.00375 .48012 L
s
0 .5075 m
.00375 .5075 L
s
0 .53488 m
.00375 .53488 L
s
0 .58963 m
.00375 .58963 L
s
0 .61701 m
.00375 .61701 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1516 m
1 .1516 L
s
.99375 .28848 m
1 .28848 L
s
.99375 .42537 m
1 .42537 L
s
.99375 .56225 m
1 .56225 L
s
.125 Mabswid
.99625 .04209 m
1 .04209 L
s
.99625 .06947 m
1 .06947 L
s
.99625 .09685 m
1 .09685 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23373 m
1 .23373 L
s
.99625 .26111 m
1 .26111 L
s
.99625 .31586 m
1 .31586 L
s
.99625 .34324 m
1 .34324 L
s
.99625 .37062 m
1 .37062 L
s
.99625 .39799 m
1 .39799 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .48012 m
1 .48012 L
s
.99625 .5075 m
1 .5075 L
s
.99625 .53488 m
1 .53488 L
s
.99625 .58963 m
1 .58963 L
s
.99625 .61701 m
1 .61701 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06947 L
.22222 .06947 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06947 L
.22222 .06947 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .39799 L
.33333 .39799 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .39799 L
.33333 .39799 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .48012 L
.44444 .48012 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .48012 L
.44444 .48012 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .12422 L
.66667 .12422 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .12422 L
.66667 .12422 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .0284 L
.77778 .0284 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0284 L
.77778 .0284 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .0284 L
1 .0284 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .0284 L
1 .0284 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:@3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000@03oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000@03oool2000000@0oooo
0P0000030?ooo`@000003@3oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo
0P0000050?ooo`<000002`3oool2000000@0oooo0P0000040?ooo`800000@03oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002P0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000n0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003h0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`00:03oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0?03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo
000000P0oooo1@00000:0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0?03o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool002P0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003l0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000002@3oool20000
03l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002`0oooo000X0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000/0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0n0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:`3oool002T0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000>0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?`3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000o0?ooo`8000002P3oool2000000h0oooo0P00
000:0?ooo`8000003P3oool2000000/0oooo0P00000<0?ooo`8000002P3oool3000003l0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000:`3oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`007P3oool2000000@0ooooP000000L0?ooo`8000000`3o
oon5000001`0oooo0P0000040?ooogh000007@3oool2000000<0ooooQ@00000E0?ooo`007@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000M
0?ooo`040000003oool0oooo000000<0ooooP@00000J0?ooo`040000003oool0oooo00000080oooo
Q@00000K0?ooo`040000003oool0oooo000000<0ooooOP00000L0?ooo`040000003oool0oooo0000
0080ooooQ@00000E0?ooo`007@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo3000000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000001oOgl0Ogmo
0080Ogmo1`00000;0?ooo`L00000103oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo
00000080oooo00<000000?l0003o0000303o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0
oooo00`0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o000300000000
o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo01X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0<0000o`030000
003oool0oooo00/0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`0C0?ooo`007@3o
ool010000000oooo0?ooo`0000030?ooo`8000003`3oool7000000D0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
0`3oool00`000000Ogmo07moO`0307moO`H00000703oool00`000000oooo0?ooo`0I0?ooo`040000
003oool0oooo00000080oooo4000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
0000303o000?000000h0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o
000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l@000000d0oooo4000000E
0?ooo`007P3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01X0oooo0P0000030?ooo`8000003@3oool00`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0I0?oo
o`800000703oool2000000@0oooo00<000000?ooo`3oool02`3oool00`0000000?l0003o000;003o
000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o
00030000003oool0oooo03@0oooo00<000000?ooo`3oool06`3oool2000000<0oooo00<000000?oo
o`3oool0303oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool700000240oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000<0?l000030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0;0?ooo`l000003@00o`000`0000000?l0003o000;003o0003
00000000o`000?l000/00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`80
00003@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0:03oool2000001D0oooo000T0?ooo`8000005@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000<0?l000030000
003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`030000
0000o`000?l000/00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0<0?ooo`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01<0oooo000T0?ooo`030000003oool0oooo01@0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000303o
00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3o
ool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0303o
ool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0C0?ooo`00903oool2000001D0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo0P00000=0?oooa0000003@3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o000@
000001/0oooo0P00000R0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`00
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0P0?ooo`8000003@3oool@000000d0003o00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2
000001D0oooo000T0?ooo`030000003oool0oooo01@0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06`3oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000;003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`000?l000/0
0?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0
003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02T0
oooo00<000000?ooo`3oool04`3oool001L0oooo1@0000020?ooo`800000103oool2000001D0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo
1`00000]0?ooo`030000003oool0oooo01l0oooo0P00000L0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0:03oool2000001D0oooo1@0000020?ooo`800000103oool00`000000oooo
0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000;003o00030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`006@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000F0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0340oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000001/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o000300000000o`00
0?l000/00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`800000703oool0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000003o0000o`0<0000o`030000003oool0oooo02P0oooo0P00000E0?ooo`006@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000E0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo0340oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000001X0oooo00<00000003o0000
o`002`00o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3o
ool0<`3oool200000280oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool001T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo01l0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?oo
o`3oool0:03oool2000001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000006`3oool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool04`3oool001T0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000005P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01<0oooo
1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000001/0oooo00<00000003o0000o`002`00o`000`00
00000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0P0?ooo`800000703oool00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l@000002X0oooo0P00000E0?ooo`00603oool2000000@0
oooo0P0000040?ooo`8000005@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000
003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo02P0oooo0P00000R
0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;
003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0D
0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo000T0?ooo`8000005@3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo1`00000c0?ooo`030000003oool0oooo01D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo00<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3o
ool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000001d0oooo00<000000000o`000?l02`000?l00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0D0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo3`00000>0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o
000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000703oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<00000
0000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool002@0oooo00<000000?oo
o`3oool0503oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool06@3oool00`0000000?l0003o000;003o000300000000o`000?l000/00?l03`00000f0?oo
o`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000001d0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool2
000001D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0
oooo03L0oooo00<000000?ooo`3oool07`3oool2000002X0oooo00<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:03oool2
00000280oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`00
0?l000/00?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool0503oool7000000D0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo00<0
0000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<0
00000?ooo`3oool05@3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool2000001/0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`800000703oool00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g
0?ooo`8000005@3oool001L0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0J0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?oo
o`800000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0X0?ooo`8000005@3oool4000000<0oooo0P0000040?oo
o`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o
00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?oo
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01X0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01T0oooo00<00000
003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`8000006`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o000@000002/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo0P00000J0?ooo`0300000000o`000?l000/00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`110?ooo`8000008P3oool2000001`0oooo00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0=`3oool2000001D0oooo000I0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000001`0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000005`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000K0?ooo`0300000000o`000?l0
00/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`120?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
01<0oooo000G0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000001/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0I0?ooo`030000
0000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`120?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01<0oooo000H0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool06P3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`120?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`030000003oool0
oooo01X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0
oooo0480oooo00<000000?ooo`3oool0803oool2000001`0oooo00<000000000o`000?l02`000?l0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2
000001D0oooo000T0?ooo`8000006`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo
03L0oooo00<000000?ooo`3oool07`3oool2000002X0oooo00<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000R0?ooo`030000003oool0oooo
01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo
0480oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o
00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo
03P0oooo00<000000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool06P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool4000000<0
oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`120?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool00`000000
003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`8000006`3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`000000
0?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool2000001`0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o00<000000?ooo`3oool0=`3oool2000001D0oooo000T0?ooo`030000003oool0oooo01X0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000:P3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=`3oool200000280
oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`000?l000/0
0?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01/0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo
0?ooo`0J0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000[0?oo
o`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o
000300000000o`000?l000/00?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?oo
o`@000000`3oool2000000<0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01<0oooo000H0?ooo`800000103oool2000000@0oooo0P00000K0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0I
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`12
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0C0?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
1`00000407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool2000000@0oooo
0P0000030?ooo`800000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0=`3oool2000001D0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`00
00000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000L0?ooo`03000000000?l0
003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0
oooo03L0oooo0P00000E0?ooo`006@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool0oooo0P00000K0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000J0?ooo`03
00000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`110?ooo`80
0000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000007@3oool0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000J0?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
00006`3oool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool001L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo01X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000005@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06@3oool00`000000
0?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0E0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool06`3oool00`000000
003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000H0?ooo`800000103oool2000000@0oooo
0P00000K0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0503oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0
003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool2000001`0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0=`3oool2000001D0oooo000T0?ooo`030000003oool0oooo01X0oooo1`00
000507moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o
000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002@0oooo0P00000Q
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`02
07moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;
003o000300000000o`000?l000/00?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C
0?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo07moO`0207moO`030000003oool0oooo03L0oooo00<000000?oo
o`3oool07`3oool2000002X0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003oool0oooo03L0oooo0P00000R0?ooo`030000003oool0oooo01T0oooo00<00000003o
0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?oo
o`3oool0803oool2000001`0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000T0?ooo`03
0000003oool0oooo0200oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`03
0000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003oool0oooo03P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`03
00000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000T0?ooo`8000008@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo00<0oooo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000
003oool0oooo0480oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool0803o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000008P3o
ool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`120?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`8000008@3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P1oOgl0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06@3oool0
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0P0?ooo`800000703oool00`000000003o0000o`0;0000o`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool0
01T0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0207moO`030000003oool0oooo
03L0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0E0?ooo`<000000P3o
ool2000000@0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000
o`000?l000/00?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`006P3oool0
10000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000008P3oool7000000@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo
1P00000i0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00800000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?ooo`3oool0=`3oool2000001P0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000001/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;
003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001L0oooo1@0000001@3o
ool000000?ooo`3oool0000000<0oooo0P00000W0?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<00000
0?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool5000000050?ooo`000000oooo0?ooo`0000000`3oool2000001X0
oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo0440
oooo0P00000R0?ooo`800000703oool?000000h0003o00<000000000o`000?l02`000?l00`000000
oooo0?ooo`0g0?ooo`8000005@3oool001L0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01T0oooo00<00000003o0000
o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000
003oool000000080oooo00@000000?ooo`3oool000000`3oool2000002L0oooo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0D0?ooo`800000103oool2000000<0oooo00<000000?ooo`3o
ool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0D0?ooo`030000003oool000000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0I0?ooo`l000003@00o`000`000000oooo0?ooo`120?oo
o`030000003oool0oooo01D0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0Y0?oo
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01<0oooo000I0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3o
ool09P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`03
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`80
00005`3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo02L0oooo00<00000003o0000
o`002`00o`000`000000oooo0?ooo`120?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool09P3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo02L0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`120?oo
o`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0=`3oool2000001D0oooo000T0?ooo`8000009`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo02L0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`120?oo
o`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000[0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`030000003oool0oooo02H0oooo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0O0?ooo`800000:P3oool00`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=`3oool200000280oooo00<00000
0?ooo`3oool09`3oool00`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool2000002L0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000/00?l000<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0V
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000;
003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0803oool2000002X0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E
0?ooo`00903oool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?oo
o`3oool07`3oool2000002X0oooo00<000000?l0003o0000303o000?000003T0oooo0P00000R0?oo
o`030000003oool0oooo02L0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`120?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`00603oool2000000@0oooo0P0000040?ooo`8000009`3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l00003
0000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo02L0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03
000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00
5`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool09P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?oo
o`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool09`3oool00`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<0
00000?ooo`3oool0803oool2000002X0oooo4000000=0000o`030000003oool0oooo03L0oooo0P00
000E0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`800000
9`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo1`0000140?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000
003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo0?ooo`800000:03oool00`0000000?l0003o000;003o00030000003oool0oooo
0440oooo0P00000R0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000H0?ooo`8000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo04P0oooo00<000000?ooo`3oool07`3oool20000
02X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000005P3oool20000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`00
0?l000/00?l000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01<0oooo000H0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo0`0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000H0?ooo`<000000`3oool2
000000@0oooo0P00000W0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000[0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`<000000`3oool2000000@0oooo00<000000?ooo`3oool0
9`3oool00`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0
803oool2000003T0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`800000
5@3oool002@0oooo00<000000?ooo`3oool09P3oool00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0C0?ooo`D0000000D0
oooo0000003oool0oooo000000020?ooo`800000:P3oool00`000000o`000?l0000<0?l000030000
003oool0oooo04D0oooo0P00000R0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`00
2`00o`000`000000oooo0?ooo`120?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
>03oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
4`3oool002@0oooo0P00000W0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`180?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000?l0003o
0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool09`3oool00`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0V0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`180?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000;003o0003
0000003oool0oooo0480oooo00<000000?ooo`3oool0803oool2000003T0oooo00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool002@0oooo00<000000?ooo`3oool0
9P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0E0?ooo`8000000`3oool2000000<0oooo0P00000Z0?ooo`030000
003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool200000280oooo00<000000?ooo`3oool0
9`3oool00`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0C0?ooo`00903oool2000002L0oooo00<0000007moO`1oOgl00P1o
Ogl7000004X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02L0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`120?ooo`030000003o
ool0oooo01H0oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`0h0?ooo`0300000000
0?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool0
0`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o0000
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09`3oool0
0`0000000?l0003o000;003o00030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003X0oooo00<000000000o`000?l0
2`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`8000009`3o
ool00`000000Ogmo07moO`0207moO`030000003oool0oooo04h0oooo00<000000?ooo`3oool07`3o
ool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000008P3o
ool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0D0?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`800000
>@3oool00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`005`3o
ool3000000@0oooo0P0000040?ooo`030000003oool0oooo02H0oooo00<0000007moO`1oOgl00P1o
Ogl00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3o
ool3000000@0oooo0P0000040?ooo`030000003oool0oooo02L0oooo3`0000140?ooo`030000003o
ool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000G0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0
003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool001L0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`8000009`3oool600000500oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3ooomn
000001P0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0
003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`005`3oool30000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01l0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2
000001D0oooo0`0000030?ooo`040000003oool0oooo00000:<0oooo0P00000i0?ooo`0300000000
0?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000H0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3ooon000000240oooo00<000000?ooo`3oool0:@3o
ool@000004P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000:<0oooo00<000000?ooo`3oool0>03oool?000003X0oooo00<000000?ooo`3oool0
4`3oool001P0oooo0`0000030?ooo`800000Y@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0503oool3000000<0oooo0P00002T0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`00a@3ooon5
00000<80ooooQ@00000E0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {90.625, 13.6875}} -> {-0.331812, \
0.0930199, 0.00627702, 0.00627702}, {{42.25, 160.813}, {88.75, 15.5}} -> \
{-0.0838924, 1.86198, 0.00347111, 0.804163}, {{172.688, 291.25}, {88.75, \
15.5}} -> {-0.644723, 1.34262, 0.00343669, 0.60982}, {{303.063, 421.625}, \
{88.75, 15.5}} -> {-1.28319, 1.90483, 0.00360753, 0.803575}, {{433.5, \
552.063}, {88.75, 15.5}} -> {-1.76514, 1.22835, 0.00343669, 0.557919}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions1]\)], "Input"],

Cell[BoxData[
    \({0.3507566487855899`, 0.31010469574486194`, 
      0.339138655469548`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions1]]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333336`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions1]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.002647269636951143`, 
      StandardDeviation \[Rule] 0.051451624240165084`, 
      SampleRange \[Rule] 0.3657437218287186`, 
      MeanDeviation \[Rule] 0.0405669178849755`, 
      MedianDeviation \[Rule] 0.03344502767598739`, 
      QuartileDeviation \[Rule] 0.033331630100282394`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats1\  = \ 
        Map[DispersionReport, fractions1]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats1]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0032051975017303334`\), \(Variance \[Rule] 
              0.0010772173791171015`\), \(Variance \[Rule] 
              0.002819988840888206`\)},
          {\(StandardDeviation \[Rule] 
              0.056614463714940666`\), \(StandardDeviation \[Rule] 
              0.032820989916775845`\), \(StandardDeviation \[Rule] 
              0.053103567120187004`\)},
          {\(SampleRange \[Rule] 0.3179167641057352`\), \(SampleRange \[Rule] 
              0.14188389913988306`\), \(SampleRange \[Rule] 
              0.33255238458038994`\)},
          {\(MeanDeviation \[Rule] 
              0.04446369306265951`\), \(MeanDeviation \[Rule] 
              0.027272434458954383`\), \(MeanDeviation \[Rule] 
              0.04374433875096641`\)},
          {\(MedianDeviation \[Rule] 
              0.0373626409546714`\), \(MedianDeviation \[Rule] 
              0.025334600294545317`\), \(MedianDeviation \[Rule] 
              0.041655792373495704`\)},
          {\(QuartileDeviation \[Rule] 
              0.0373020928190764`\), \(QuartileDeviation \[Rule] 
              0.025676735141807544`\), \(QuartileDeviation \[Rule] 
              0.03974536310577606`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["uncorrected average tapping data", "Subsubsection"],

Cell[BoxData[{
    \(\(data1b\  = \ Drop[pid9048x06avg, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats1bcor\  = \ 
        Drop[RotateLeft[pid9048x06avg, \ 1]\  - \ 
            pid9048x06avg, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats1bcor\  = \ Drop[beats1bcor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure1bdurs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats1bcor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata1b\  = \ 
        Transpose[{measure1bdurs, 
            Partition[beats1bcor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions1b\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ 
            newdata1b]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot1b\  = \ 
        Histogram[Flatten[fractions1b], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00981006 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02453 L
.04545 .02453 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02453 L
.04545 .02453 L
.04545 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
.5 .5 .5 r
.09091 .01472 m
.09091 .01472 L
.13636 .01472 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .01472 L
.13636 .01472 L
.13636 .01472 L
.09091 .01472 L
s
.5 .5 .5 r
.13636 .01472 m
.13636 .08339 L
.18182 .08339 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .08339 L
.18182 .08339 L
.18182 .01472 L
.13636 .01472 L
s
.5 .5 .5 r
.18182 .01472 m
.18182 .15206 L
.22727 .15206 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .15206 L
.22727 .15206 L
.22727 .01472 L
.18182 .01472 L
s
.5 .5 .5 r
.22727 .01472 m
.22727 .25997 L
.27273 .25997 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .25997 L
.27273 .25997 L
.27273 .01472 L
.22727 .01472 L
s
.5 .5 .5 r
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
.27273 .01472 L
s
.5 .5 .5 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
.5 .5 .5 r
.36364 .01472 m
.36364 .57389 L
.40909 .57389 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .57389 L
.40909 .57389 L
.40909 .01472 L
.36364 .01472 L
s
.5 .5 .5 r
.40909 .01472 m
.40909 .5837 L
.45455 .5837 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .5837 L
.45455 .5837 L
.45455 .01472 L
.40909 .01472 L
s
.5 .5 .5 r
.45455 .01472 m
.45455 .3875 L
.5 .3875 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .3875 L
.5 .3875 L
.5 .01472 L
.45455 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .21092 L
.54545 .21092 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .21092 L
.54545 .21092 L
.54545 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.54545 .01472 m
.54545 .16187 L
.59091 .16187 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .16187 L
.59091 .16187 L
.59091 .01472 L
.54545 .01472 L
s
.5 .5 .5 r
.59091 .01472 m
.59091 .15206 L
.63636 .15206 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .15206 L
.63636 .15206 L
.63636 .01472 L
.59091 .01472 L
s
.5 .5 .5 r
.63636 .01472 m
.63636 .08339 L
.68182 .08339 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .08339 L
.68182 .08339 L
.68182 .01472 L
.63636 .01472 L
s
.5 .5 .5 r
.68182 .01472 m
.68182 .02453 L
.72727 .02453 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .02453 L
.72727 .02453 L
.72727 .01472 L
.68182 .01472 L
s
.5 .5 .5 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
.5 .5 .5 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
.5 .5 .5 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
.5 .5 .5 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
.5 .5 .5 r
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
.90909 .01472 L
s
.5 .5 .5 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`002P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo
0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000040?ooool00000300000030?ooo`002P3o
ool010000000oooo0?ooo`0000040?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
5@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo02d0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003o
ool0oooo000000@0oooo3@00000G0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`d00000;`3oool=000000/0oooo00<000000?ooo`3oool0
0P3oool000/0oooo0P0000050?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0
oooo0540oooo00<000000?ooo`3oool00P3oool00180oooo0P00000R0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
0500oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0540
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool08@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0240oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0Q
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool00180oooo0P00000R0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000003oool0oooo0500oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
8@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo0240oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?ooo`004P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00000R0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000003oool0oooo0500oooo0P0000040?ooo`004P3oool00`000000
oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo0240oooo3@00000;07moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`d00000D`3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0]0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?oo
o`004P3oool2000002h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1L0?ooo`80
0000103oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3o
ool000@0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`001P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`02
0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3
000002d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1L0?ooo`800000103oool0
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0
oooo05d0oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000002h0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1L0?ooo`800000103oool00180oooo00<0
00000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0;@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo05d0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0;@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000^0?ooo`d00000
2`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`d00000GP3oool2000000@0oooo000B0?ooo`030000003o
ool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo3@00001[0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03T0
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0080
oooo000B0?ooo`800000>P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07@0oooo
0P0000040?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0i
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003X0oooo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000oooo0?ooo`1d0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo
07D0oooo00<000000?ooo`3oool00P3oool000@0oooo100000030?ooo`8000001@3oool00`000000
oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo07D0
oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`<00000>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<0000007moO`1oOgl02@1oOgl=000007H0oooo0P0000040?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`03
0000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000j0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000Ogmo07moO`0907moO`030000003oool0oooo0800oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo
00<000000?ooo`3oool00P3oool00180oooo0P00000j0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0800oooo0P00
00040?ooo`004P3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03T0oooo3@00000;07moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B0?ooo`800000AP3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P03o
ool2000000@0oooo000B0?ooo`030000003oool0oooo04D0oooo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo04D0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`020?ooo`004P3oool2000004H0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo0800oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`150?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo04D0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<000000?ooo`3o
ool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`150?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0080oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000A@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P03oool2000000@0
oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0A@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000AP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<0
00000?ooo`3oool0P03oool2000000@0oooo000B0?ooo`030000003oool0oooo04D0oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo04D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000
003oool0oooo0840oooo00<000000?ooo`3oool00P3oool00180oooo0P0000160?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`200?ooo`800000103o
ool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo04D0
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B
0?ooo`800000AP3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00T0Ogmo00<00000
0?ooo`3oool0P03oool2000000@0oooo000B0?ooo`030000003oool0oooo04D0oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0840oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0A@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`150?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo04D0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo0840oooo00<000000?ooo`3oool00P3oool00180oooo0P0000160?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo3@0000220?ooo`800000103oool00180oooo00<000000?ooo`3oool0A@3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0A@3oool=000000/0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool000H0oooo
0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo
00<000000?ooo`3oool00P3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`020?ooo`00103oool5000000050?ooo`000000oooo0?ooo`000000103oool300000540oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0S03oool2000000@0oooo00040?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0
oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`020?ooo`001P3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo0540oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001B
0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:
07moO`030000003oool0oooo08`0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1A0?oo
o`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3o
ool00180oooo0P00001B0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl0
0`000000Ogmo07moO`0:07moO`030000003oool0oooo08`0oooo0P0000040?ooo`004P3oool00`00
0000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool00`000000Ogmo07moO`0907mo
O`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2<0?oo
o`800000103oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001o
Ogl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0D@3oool0
0`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000DP3oool00`00
0000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`00
0000oooo0?ooo`2<0?ooo`800000103oool00180oooo00<000000?ooo`3oool0D@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`020?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool300000540oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo
00<000000?ooo`3oool0S03oool2000000@0oooo00050?ooo`8000000`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`020?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo
00050?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo0540oooo00<00000
07moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool200000580oooo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?oo
o`3oool0S03oool2000000@0oooo000B0?ooo`030000003oool0oooo0540oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000
003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0D@3o
ool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02P1o
Ogl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool20000
0580oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
00X0Ogmo00<000000?ooo`3oool0S03oool2000000@0oooo000B0?ooo`030000003oool0oooo0540
oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B
0?ooo`030000003oool0oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007mo
O`1oOgl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?oo
o`3oool00P3oool00180oooo0P00001B0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08`0oooo0P0000040?ooo`00
4P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0D@3oool00`000000Ogmo07moO`0907moO`d00000301o
Ogl00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo0540oooo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool02@3oool00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo08d0oooo00<000000?ooo`3oool00P3oool00180
oooo0P00001B0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool02@3oool>000008h0
oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`020?ooo`00103oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0540oooo00<00000
07moO`1oOgl02@1oOgl00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0080oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1A0?ooo`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`020?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
0`00001A0?ooo`d00000Y`3oool2000000@0oooo00040?ooo`<000000`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`020?ooo`001@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00050?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`004P3ooooo
000000/00000103oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0745211, \
0.345893, 0.00166092, 0.384791}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot1b1\  = 
        Histogram[fractions1b[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0140144 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -12 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(10)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(20)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(30)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(40)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02873 L
.11111 .02873 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02873 L
.11111 .02873 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .12683 L
.22222 .12683 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .12683 L
.22222 .12683 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .21092 L
.33333 .21092 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .42113 L
.55556 .42113 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .42113 L
.55556 .42113 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .32303 L
.66667 .32303 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .32303 L
.66667 .32303 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .05676 L
.77778 .05676 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05676 L
.77778 .05676 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo7`00000M0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03P0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03L0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o000O000003X0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo7`00000L0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo
03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
05@0oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000003X0oooo7P00000M0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo0`00001F0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05@0oooo0`00
00030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001G0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o000O000005L0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05L0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3o
ool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000E`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o000N000007H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo0`00001F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0S`3oool3000000<0oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000005L0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000E`3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000oooo
0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool000D0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`001P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000<0oooo1@0000001@3oool000000?ooo`3oool0000000@0oooo0`00001F0?ooo`030000
003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool3000000<0oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
103oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool000D0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
7`00002B0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
57.6223, 0.00169256, 0.268384}}]
}, Open  ]],

Cell[RawData["\<\
000oooo0?ooo`0]0?ooo`040000003o

ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?\
oo

o`00C@3oool2000000@0oooo0P0000040?ooo`800000=03oool2000003P0oooo0P0000040?ooo`\
80

0000103oool200000340ooo\
\>"], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00949361 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -12 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(10)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(20)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(30)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(40)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(50)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(60)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .02421 L
.22222 .02421 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .02421 L
.22222 .02421 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .40395 L
.33333 .40395 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .40395 L
.33333 .40395 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .15712 L
.55556 .15712 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .15712 L
.55556 .15712 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?oooal00000
7000o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool20000
03X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0
oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0005
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o
0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o01h00000MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0
oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0
003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000i0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`<000000`3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0
oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0
003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo
000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo0`00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2?0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0
oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0
003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo00050?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool50000
00050?ooo`000000oooo0?ooo`000000103oool3000003T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo08l0oooo0`0000030?ooo`000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0>@3ooolN000001d00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
0?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo0`00001F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0S`3o
ool3000000<0oooo00040?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool3000000<0oooo0P0000050?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
0?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool30000
00@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0S`3oool3000000<0oooo00030?ooo`<000000`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool3
000000<0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000E`3ooolO00000980oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000A0?ooool000003@000003
0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0636924, \
169.777, 0.00169256, 0.396186}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot1b3\  = 
        Histogram[fractions1b[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .22761 L
.33333 .22761 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .22761 L
.33333 .22761 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .49061 L
.55556 .49061 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .49061 L
.55556 .49061 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .165 L
.66667 .165 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .165 L
.66667 .165 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .02724 L
1 .02724 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .02724 L
1 .02724 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0
>03oool00`000000003o0000o`0K0000o`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000003o0000o`0K0000o`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?oooal000000`3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0E@3oool2000000<0
oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703o
oolO000001`0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`80
00001@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000003T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`1D0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o7`00001G0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3ooolN000001d0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`@0
00000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo0`00001F0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000005H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo0780oooo0`0000030?ooo`001P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
E`3oool00`000000003o0000o`0K0000oah00000M@3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo00050?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000H0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo00030?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo08l0oooo0`0000030?ooo`000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo00050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000003oool0oooo0900oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3ooolO000009<0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo0000
00d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.26215, 0.00169256, 0.300334}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot1b, \ xplot1b1, \ xplot1b2, \ 
            xplot1b3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00981006 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(10)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(20)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(40)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(50)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(60)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02453 L
.04545 .02453 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02453 L
.04545 .02453 L
.04545 .01472 L
0 .01472 L
s
.5 .5 .5 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
.5 .5 .5 r
.09091 .01472 m
.09091 .01472 L
.13636 .01472 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .01472 L
.13636 .01472 L
.13636 .01472 L
.09091 .01472 L
s
.5 .5 .5 r
.13636 .01472 m
.13636 .08339 L
.18182 .08339 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .08339 L
.18182 .08339 L
.18182 .01472 L
.13636 .01472 L
s
.5 .5 .5 r
.18182 .01472 m
.18182 .15206 L
.22727 .15206 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .15206 L
.22727 .15206 L
.22727 .01472 L
.18182 .01472 L
s
.5 .5 .5 r
.22727 .01472 m
.22727 .25997 L
.27273 .25997 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .25997 L
.27273 .25997 L
.27273 .01472 L
.22727 .01472 L
s
.5 .5 .5 r
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .39731 L
.31818 .39731 L
.31818 .01472 L
.27273 .01472 L
s
.5 .5 .5 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
.5 .5 .5 r
.36364 .01472 m
.36364 .57389 L
.40909 .57389 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .57389 L
.40909 .57389 L
.40909 .01472 L
.36364 .01472 L
s
.5 .5 .5 r
.40909 .01472 m
.40909 .5837 L
.45455 .5837 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .5837 L
.45455 .5837 L
.45455 .01472 L
.40909 .01472 L
s
.5 .5 .5 r
.45455 .01472 m
.45455 .3875 L
.5 .3875 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .3875 L
.5 .3875 L
.5 .01472 L
.45455 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .21092 L
.54545 .21092 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .21092 L
.54545 .21092 L
.54545 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.54545 .01472 m
.54545 .16187 L
.59091 .16187 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .16187 L
.59091 .16187 L
.59091 .01472 L
.54545 .01472 L
s
.5 .5 .5 r
.59091 .01472 m
.59091 .15206 L
.63636 .15206 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .15206 L
.63636 .15206 L
.63636 .01472 L
.59091 .01472 L
s
.5 .5 .5 r
.63636 .01472 m
.63636 .08339 L
.68182 .08339 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .08339 L
.68182 .08339 L
.68182 .01472 L
.63636 .01472 L
s
.5 .5 .5 r
.68182 .01472 m
.68182 .02453 L
.72727 .02453 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .02453 L
.72727 .02453 L
.72727 .01472 L
.68182 .01472 L
s
.5 .5 .5 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
.5 .5 .5 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
.5 .5 .5 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
.5 .5 .5 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
.5 .5 .5 r
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02453 L
.95455 .02453 L
.95455 .01472 L
.90909 .01472 L
s
.5 .5 .5 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0140144 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15486 -12 -4.5 ]
[-0.0125 .15486 0 4.5 ]
[-0.0125 .295 -12 -4.5 ]
[-0.0125 .295 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .57529 -12 -4.5 ]
[-0.0125 .57529 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15486 m
.00625 .15486 L
s
[(10)] -0.0125 .15486 1 0 Mshowa
0 .295 m
.00625 .295 L
s
[(20)] -0.0125 .295 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(30)] -0.0125 .43515 1 0 Mshowa
0 .57529 m
.00625 .57529 L
s
[(40)] -0.0125 .57529 1 0 Mshowa
.125 Mabswid
0 .04274 m
.00375 .04274 L
s
0 .07077 m
.00375 .07077 L
s
0 .0988 m
.00375 .0988 L
s
0 .12683 m
.00375 .12683 L
s
0 .18289 m
.00375 .18289 L
s
0 .21092 m
.00375 .21092 L
s
0 .23895 m
.00375 .23895 L
s
0 .26697 m
.00375 .26697 L
s
0 .32303 m
.00375 .32303 L
s
0 .35106 m
.00375 .35106 L
s
0 .37909 m
.00375 .37909 L
s
0 .40712 m
.00375 .40712 L
s
0 .46318 m
.00375 .46318 L
s
0 .4912 m
.00375 .4912 L
s
0 .51923 m
.00375 .51923 L
s
0 .54726 m
.00375 .54726 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15486 m
1 .15486 L
s
.99375 .295 m
1 .295 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .57529 m
1 .57529 L
s
.125 Mabswid
.99625 .04274 m
1 .04274 L
s
.99625 .07077 m
1 .07077 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .12683 m
1 .12683 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .32303 m
1 .32303 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37909 m
1 .37909 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .46318 m
1 .46318 L
s
.99625 .4912 m
1 .4912 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .54726 m
1 .54726 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02873 L
.11111 .02873 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02873 L
.11111 .02873 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .12683 L
.22222 .12683 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .12683 L
.22222 .12683 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .21092 L
.33333 .21092 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .21092 L
.33333 .21092 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .42113 L
.55556 .42113 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .42113 L
.55556 .42113 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .32303 L
.66667 .32303 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .32303 L
.66667 .32303 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .05676 L
.77778 .05676 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05676 L
.77778 .05676 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00949361 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10965 -12 -4.5 ]
[-0.0125 .10965 0 4.5 ]
[-0.0125 .20459 -12 -4.5 ]
[-0.0125 .20459 0 4.5 ]
[-0.0125 .29952 -12 -4.5 ]
[-0.0125 .29952 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .4894 -12 -4.5 ]
[-0.0125 .4894 0 4.5 ]
[-0.0125 .58433 -12 -4.5 ]
[-0.0125 .58433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10965 m
.00625 .10965 L
s
[(10)] -0.0125 .10965 1 0 Mshowa
0 .20459 m
.00625 .20459 L
s
[(20)] -0.0125 .20459 1 0 Mshowa
0 .29952 m
.00625 .29952 L
s
[(30)] -0.0125 .29952 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(40)] -0.0125 .39446 1 0 Mshowa
0 .4894 m
.00625 .4894 L
s
[(50)] -0.0125 .4894 1 0 Mshowa
0 .58433 m
.00625 .58433 L
s
[(60)] -0.0125 .58433 1 0 Mshowa
.125 Mabswid
0 .0337 m
.00375 .0337 L
s
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .12864 m
.00375 .12864 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .22357 m
.00375 .22357 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .31851 m
.00375 .31851 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .41345 m
.00375 .41345 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .50838 m
.00375 .50838 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10965 m
1 .10965 L
s
.99375 .20459 m
1 .20459 L
s
.99375 .29952 m
1 .29952 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .58433 m
1 .58433 L
s
.125 Mabswid
.99625 .0337 m
1 .0337 L
s
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .12864 m
1 .12864 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .31851 m
1 .31851 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .41345 m
1 .41345 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .50838 m
1 .50838 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .02421 L
.22222 .02421 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .02421 L
.22222 .02421 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .40395 L
.33333 .40395 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .40395 L
.33333 .40395 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .15712 L
.55556 .15712 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .15712 L
.55556 .15712 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .01472 L
.66667 .01472 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .22761 L
.33333 .22761 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .22761 L
.33333 .22761 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .49061 L
.55556 .49061 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .49061 L
.55556 .49061 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .165 L
.66667 .165 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .165 L
.66667 .165 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .02724 L
1 .02724 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .02724 L
1 .02724 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:@3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000@03oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002P0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000n0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`00:03oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool002P0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003l0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002`0oooo000X0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:`3oool002T0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000>0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?`3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000m0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003d0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000:`3oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`007P3oool2000000@0ooooP000000L0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`007@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`007@3oool010000000oooo0?oo
o`0000030?oooh4000006P3oool010000000oooo0?ooo`0000020?ooohD00000603oool010000000
oooo0?ooo`0000030?ooohD00000603oool010000000oooo0?ooo`0000020?ooohD000005@3oool0
01d0oooo00@000000?ooo`3oool000000`3oool7000000X0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00000F0?ooo`L00000103oool0
0`000000oooo0?ooo`0I0?ooo`040000003oool0oooo00000080oooo00<000000?l0003o0000303o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000303o
00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0<0?ooo`l000003P00o`000`0000000?l0003o000;003o00030000
0000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0G0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0303oool00`000000003o0000o`0<0000o`03
000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03
000000000?l0003o00`0003o00<000000?ooo`3oool06P3oool00`000000003o0000o`0<0000o`03
0000003oool0oooo01<0oooo000M0?ooo`040000003oool0oooo000000<0oooo0P00000?0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000020?oo
oa0000003P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000`0o`0000<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000
003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000000o`000?l030000?l00`000000oooo0?ooo`0J0?oooa0000005@3oool001h0oooo0P000004
0?ooo`030000003oool0oooo00h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0J
0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000<0?l000030000003oool0oooo01X0oooo00<00000
0?ooo`3oool05`3oool2000000@0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01P0oooo0P0000030?ooo`8000003@3oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo000T0?oo
o`030000003oool0oooo00h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?oo
o`8000003@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0I0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?oo
o`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o
00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?oo
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo01<0oooo000T0?ooo`8000003`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`004000000L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo02D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
00000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`00903o
ool2000000l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`8000003@3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:03o
ool2000001l0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000
o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo01d0oooo0P00000=0?oooa0000003@000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`8000005@3o
ool002@0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`00
0?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0
003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo01<0oooo000T0?ooo`030000003oool0oooo00h0oooo1`00000507moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`L000009`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0C0?ooo`005`3oool500000080oooo0P0000040?ooo`8000005@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo1@0000020?ooo`800000103oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
0?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000001`0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`8000005@3oool001T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000005P3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool20000
00d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo
02P0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000001`0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo000I0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`3oool2000001D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000001/0oooo00<00000003o
0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?oo
o`3oool0=P3oool2000001l0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool001T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000703oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l0
00<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo
0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo
000I0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001H0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo00<00000003o0000o`003000o`00
0`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3oool06`3oool0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000003o0000o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool0
01P0oooo0P0000040?ooo`800000103oool2000001D0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo0P00000=0?oooa0000003@3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000oooo0?ooo`0X0?ooo`8000004`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l0
00`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`03000000000?l0003o00/0003o00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0D
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0C
0?ooo`D000000P3oool2000000<0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J
0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<
003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P00000L0?ooo`03000000000?l0003o00/0003o00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0:03oool2000001D0oooo000T0?ooo`8000005@3oool7000000D0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl00`1oOgl7000002d0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000007@3oool00`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000
003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000007@3oool00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo
02T0oooo00<000000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool06P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020000
01`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0X0?ooo`8000007`3oool00`00
0000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000007@3oool00`000000003o0000
o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000
o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool002@0oooo00<00000
0?ooo`3oool06P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`L00000<`3oool00`000000oooo0?ooo`0E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o01000000
>@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4`3oool002@0oooo0P00000K0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`00000M0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000001`0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o4000000Z0?ooo`8000005@3oool002@0oooo00<000000?ooo`3oool06P3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0207moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool2000000@0oooo
0P0000030?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o
0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0C0?ooo`00903oool2000001/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01l0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?ooo`3oool0:03oool2000001l0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0C0?ooo`005`3oool4000000<0oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00P1oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0403oool4000000<0oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<00000
003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<00000
0?ooo`3oool07@3oool2000001`0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000G0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o
000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001P0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000006`3oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl6000003T0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000`3oool2000001/0oooo00<00000003o0000o`003000o`000`0000000?l0
003o000;003o00030000003oool0oooo04D0oooo0P00000O0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`006@3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03`0
oooo00<000000?ooo`3oool07`3oool2000001`0oooo3`00000>0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0X0?ooo`800000503oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`0300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`005`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00000K0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o0003
00000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03
000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00
603oool2000000@0oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
6P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo3`00000>0000o`030000
00000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903o
ool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3o
ool2000002X0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?ooo`3oool0:03oool2000001l0oooo00<000000?ooo`3oool06P3o
ool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool002@0oooo0P00000K0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool0
02@0oooo00<000000?ooo`3oool06P3oool7000000D0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`00
00000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0C0?ooo`00903oool200000240oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`160?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002@0
oooo00<000000?ooo`3oool0803oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0O0?ooo`800000:P3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
oooo0?ooo`0X0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`0
0?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000:P3oool00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool20000
01D0oooo000T0?ooo`030000003oool0oooo0200oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000002/0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001P0oooo0P0000040?oo
o`800000103oool200000240oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool4000000<0oooo0P0000030?oo
o`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?oo
o`800000103oool2000000@0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o
000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01<0oooo000G0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0
oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo0180oooo0P0000040?ooo`8000000`3oool2000002X0oooo00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`006@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000Q0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000
:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000oooo0?ooo`0X0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool0oooo0P00000K0?ooo`0300000000o`000?l000`00?l000<00000003o
0000o`002`00o`000`000000oooo0?ooo`150?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?oo
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01<0oooo000J0?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo0000000R0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000002/0oooo00<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000L0?oo
o`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0803oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo02T0oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l0
00/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000:P3oool00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool20000
01D0oooo000H0?ooo`800000103oool2000000@0oooo0P00000Q0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01@0
oooo0P0000040?ooo`8000000`3oool2000002X0oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l001000000:P3oool2000001<0oooo0P0000040?ooo`800000103oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo
00<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo04H0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o
00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo
000T0?ooo`8000008@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool00`000000oooo0?ooo`0P
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E
0?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01l0oooo0P00000Z0?oo
o`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?oo
o`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o
0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00903oool200000240oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool04`3oool002@0oooo00<000000?ooo`3oool0803oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000
003oool0oooo01d0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool002@0oooo0P00000Q0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo1`00000n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000
o`000`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool001T0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0P0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0O0?ooo`800000:P3oool0
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=`3oool2
000001@0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`0300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001X0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000280oooo1`00000407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`0300000000o`000?l000`00?l000<00000
003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00800000:P3oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000G
0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`8000009`3oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`120?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0@0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`8000006`3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0A@3oool2000001H0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000[0?ooo`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
01<0oooo000G0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01X0oooo4000000=003o00030000
003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`00603oool00`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo0P00000W0?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo0480oooo00<000000?ooo`3oool07`3oool2000002X0oooo00<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000C0?oo
o`030000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C
0?ooo`006@3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo02H0oooo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000l00000>P3oool00`000000oooo0?ooo`0B0?oo
o`8000000`3oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o
00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?oo
o`00903oool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool002@0oooo0P00000W0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000Z
0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0oooo00<00000
0?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<00000
0000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?oo
o`030000003oool0oooo02H0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0F0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`000000o`000?l0
000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0M0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0=`3oool2000001D0oooo000T0?ooo`8000009`3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo
0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000T0?ooo`030000003oool0oooo02H0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool09P3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<00000
0?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E
0?ooo`00603oool2000000@0oooo0P0000040?ooo`8000009`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l0
00030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P0000040?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`005`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool09P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o
00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo
000J0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P00000W0?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P00000Z0?ooo`0300000000o`00
0?l000/00?l000<000000?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0C0?ooo`00603oool2000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0480oooo00<000000?ooo`3oool07`3oool2
000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000004`3oool2
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000:P3o
ool00`000000003o0000o`0<0000o`l00000>@3oool2000001D0oooo000H0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0V0?ooo`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`<00000
0P3oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000
003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool001P0oooo0`0000030?ooo`800000103o
ool2000002L0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0140oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`000000003o0000o`0<0000o`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool002@0oooo00<000000?ooo`3oool0
9P3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`030000
003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0
:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4@3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool2000002X0oooo00<000000000o`00
0?l030000?l00`000000oooo0?ooo`150?ooo`8000005@3oool002@0oooo0P00000W0?ooo`030000
001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo000T0?ooo`030000003oool0oooo02H0oooo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o
0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?oo
o`3oool04`3oool002@0oooo00<000000?ooo`3oool09P3oool00`000000Ogmo07moO`0207moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l00003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03
00000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`80
00000`3oool2000000<0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0A@3oool2000001D0oooo000T0?ooo`8000009`3oool00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`120?ooo`030000
003oool0oooo01l0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0
A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000
003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000
00000?l0003o00`0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`00903o
ool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo0080Ogmo1`00000507moO`030000003o
ool0oooo0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04`3oool002@0oooo0P00000W0?ooo`030000001oOgl0
Ogmo0080Ogmo00<000000?ooo`3oool00`3oool7000004@0oooo00<000000?ooo`3oool05@3oool3
00000080oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o0000
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool0
0`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2
000002X0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`8000005@3oool0
01L0oooo0`0000040?ooo`800000103oool00`000000oooo0?ooo`0V0?ooo`030000001oOgl0Ogmo
0080Ogmo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000:`3oool00`000000o`000?l0000<0?l000030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0403oool3000000@0oooo0P0000040?ooo`030000003o
ool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04`3oool001L0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0oooo00<0000007moO`1oOgl0
0P1oOgl00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01<0oooo1@0000001@3oool00000
0?ooo`3oool000000080oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0A@3oool200000180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool001L0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`8000009`3oool600000500oooo00<0
00000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo0P00000Z0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0A@3oool2
000001l0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0
oooo04H0oooo00<000000?ooo`3oool04`3oool001L0oooo0`0000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@0?ooo`<000000`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
2`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000
00000?l0003o00`0003o00<000000?ooo`3oool0A@3oool2000001D0oooo000H0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3ooon0000001L0oooo0P0000030?ooo`800000
0`3oool2000002X0oooo400000170?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool?000004P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0Y0?oooa000000B03oool00`000000oooo0?ooo`0C0?ooo`00
603oool3000000<0oooo0P00002U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0A0?ooo`<000000`3oool2000000@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo00350?ooohD000007`3o
oon4000001l0ooooQ@00000E0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00001
\
\>"],
  ImageRangeCache->{{{26.375, 568}, {261.688, 184.75}} -> {-0.331812, \
1.43522, 0.00627702, 0.00627702}, {{42.25, 160.813}, {259.813, 186.563}} -> \
{-0.0838924, 173.815, 0.00347111, 0.804163}, {{172.688, 291.25}, {259.813, \
186.563}} -> {-0.644723, 117.724, 0.00343669, 0.544945}, {{303.063, 421.625}, \
{259.813, 186.563}} -> {-1.20656, 173.981, 0.00344053, 0.805344}, {{433.5, \
552.063}, {259.813, 186.563}} -> {-1.76514, 131.739, 0.00343669, 0.60982}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions1b]\)], "Input"],

Cell[BoxData[
    \({0.34680390308943393`, 0.312708508503046`, 
      0.34048758840752014`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions1b]]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333332`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions1b]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.002575959423568526`, 
      StandardDeviation \[Rule] 0.05075391042637528`, 
      SampleRange \[Rule] 0.4005505849965588`, 
      MeanDeviation \[Rule] 0.0394515965484393`, 
      MedianDeviation \[Rule] 0.031294576298066146`, 
      QuartileDeviation \[Rule] 0.03067241687021366`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats1b\  = \ 
        Map[DispersionReport, fractions1b]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats1b]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0034996484009565624`\), \(Variance \[Rule] 
              0.001013342748700531`\), \(Variance \[Rule] 
              0.0025949479695363824`\)},
          {\(StandardDeviation \[Rule] 
              0.05915782620208895`\), \(StandardDeviation \[Rule] 
              0.03183304491720092`\), \(StandardDeviation \[Rule] 
              0.05094063181328224`\)},
          {\(SampleRange \[Rule] 
              0.30754433661236763`\), \(SampleRange \[Rule] 
              0.15916750596676485`\), \(SampleRange \[Rule] 
              0.3356080116037268`\)},
          {\(MeanDeviation \[Rule] 
              0.0479918528526657`\), \(MeanDeviation \[Rule] 
              0.02683042686154577`\), \(MeanDeviation \[Rule] 
              0.03886744390995533`\)},
          {\(MedianDeviation \[Rule] 
              0.04092721035169894`\), \(MedianDeviation \[Rule] 
              0.02561395386477111`\), \(MedianDeviation \[Rule] 
              0.031878402466637756`\)},
          {\(QuartileDeviation \[Rule] 
              0.041809361491621955`\), \(QuartileDeviation \[Rule] 
              0.026633890001490496`\), \(QuartileDeviation \[Rule] 
              0.03030046776219028`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2; Friedman 1930", "Subsection"],

Cell[CellGroupData[{

Cell["corrected timing data", "Subsubsection"],

Cell[BoxData[{
    \(\(data2\  = \ Drop[pid5667230x09corrected, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats2cor\  = \ 
        Drop[RotateLeft[pid5667230x09corrected, \ 1]\  - \ 
            pid5667230x09corrected, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats2cor\  = \ Drop[beats2cor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure2durs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats2cor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata2\  = \ 
        Transpose[{measure2durs, 
            Partition[beats2cor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions2\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ newdata2]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot2\  = \ 
        Histogram[Flatten[fractions2], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0105108 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11982 -12 -4.5 ]
[-0.0125 .11982 0 4.5 ]
[-0.0125 .22493 -12 -4.5 ]
[-0.0125 .22493 0 4.5 ]
[-0.0125 .33004 -12 -4.5 ]
[-0.0125 .33004 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .54025 -12 -4.5 ]
[-0.0125 .54025 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11982 m
.00625 .11982 L
s
[(10)] -0.0125 .11982 1 0 Mshowa
0 .22493 m
.00625 .22493 L
s
[(20)] -0.0125 .22493 1 0 Mshowa
0 .33004 m
.00625 .33004 L
s
[(30)] -0.0125 .33004 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(40)] -0.0125 .43515 1 0 Mshowa
0 .54025 m
.00625 .54025 L
s
[(50)] -0.0125 .54025 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .0988 m
.00375 .0988 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .18289 m
.00375 .18289 L
s
0 .20391 m
.00375 .20391 L
s
0 .24595 m
.00375 .24595 L
s
0 .26697 m
.00375 .26697 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .35106 m
.00375 .35106 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .51923 m
.00375 .51923 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11982 m
1 .11982 L
s
.99375 .22493 m
1 .22493 L
s
.99375 .33004 m
1 .33004 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .54025 m
1 .54025 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .04625 L
.05556 .04625 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04625 L
.05556 .04625 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .01472 L
.11111 .01472 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .05676 L
.16667 .05676 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .05676 L
.16667 .05676 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .20391 L
.22222 .20391 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .20391 L
.22222 .20391 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .18289 L
.27778 .18289 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .18289 L
.27778 .18289 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .43515 L
.33333 .43515 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .43515 L
.33333 .43515 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .51923 L
.5 .51923 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .51923 L
.5 .51923 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .37208 L
.55556 .37208 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .37208 L
.55556 .37208 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .11982 L
.61111 .11982 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .11982 L
.61111 .11982 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .17238 L
.66667 .17238 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .17238 L
.66667 .17238 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .05676 L
.72222 .05676 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .05676 L
.72222 .05676 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02523 L
.77778 .02523 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02523 L
.77778 .02523 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .02523 L
.83333 .02523 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .02523 L
.83333 .02523 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .02523 L
.88889 .02523 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .02523 L
.88889 .02523 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moObd000007@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000Ogmo07moO`0<07moO`030000003oool0
oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0
oooo04L0oooo00<000000?ooo`3oool00@3oool00140oooo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`160?ooo`8000000`3oool00140oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0040oooo000A0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`010?ooo`004@3oool@000000h0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`170?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000703oool@000000h0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moOa00
0000B03oool2000000<0oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0:P3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00000[0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00000[0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05D0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo02X0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo0`00000Z0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo4000000>07moO`030000003oool0oooo05@0oooo0`0000030?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo00`0oooo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000002/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0<
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?oo
o`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0<0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000[0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo
05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0<0?oooa000000F03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool2000002/0oooo00<0000007moO`1oOgl0301oOgl?000000h0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
:P3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo00/0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo00/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0:P3oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo00/0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo
00/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000[0?oooa0000003@3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`17
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`0000170?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1b0?oo
o`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1c0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1c0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000
A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
LP3oool3000000<0oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`170?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl?000007D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000
003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo00050?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool000H0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo00030?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000A`3oool@0000
00h0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0800oooo0`0000030?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo00040?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool0
00D0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000005L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0
oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl@000008<0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000EP3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0S`3oool3000000<0oooo
00040?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo0`00
00030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000E`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo7`00002B0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`01
0?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {352.375, 211.063}} -> {0.0636924, \
88.5994, 0.00169256, 0.357845}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot21\  = 
        Histogram[fractions2[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0150924 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(10)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(20)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(30)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .0449 m
.00375 .0449 L
s
0 .07508 m
.00375 .07508 L
s
0 .10527 m
.00375 .10527 L
s
0 .13545 m
.00375 .13545 L
s
0 .19582 m
.00375 .19582 L
s
0 .22601 m
.00375 .22601 L
s
0 .25619 m
.00375 .25619 L
s
0 .28638 m
.00375 .28638 L
s
0 .34675 m
.00375 .34675 L
s
0 .37693 m
.00375 .37693 L
s
0 .40712 m
.00375 .40712 L
s
0 .4373 m
.00375 .4373 L
s
0 .49767 m
.00375 .49767 L
s
0 .52786 m
.00375 .52786 L
s
0 .55804 m
.00375 .55804 L
s
0 .58823 m
.00375 .58823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .0449 m
1 .0449 L
s
.99625 .07508 m
1 .07508 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .13545 m
1 .13545 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .22601 m
1 .22601 L
s
.99625 .25619 m
1 .25619 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .34675 m
1 .34675 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4373 m
1 .4373 L
s
.99625 .49767 m
1 .49767 L
s
.99625 .52786 m
1 .52786 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .58823 m
1 .58823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .0449 L
.11111 .0449 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0449 L
.11111 .0449 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .25619 L
.22222 .25619 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .25619 L
.22222 .25619 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .34675 L
.33333 .34675 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .34675 L
.33333 .34675 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .28638 L
.55556 .28638 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .28638 L
.55556 .28638 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .09018 L
.66667 .09018 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09018 L
.66667 .09018 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003o
0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3ooolO000001d0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`007`00001H0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000001`0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000001/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000703ooolO000001`0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o000N000007D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo100000030?ooo`8000001@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0i0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3
000003T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo08l0oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3ooolN
000001d0o`0000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
E`3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo08l0oooo0`0000030?ooo`001P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000E`3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`00
0?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001G0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool2000000<0oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo7`00002C0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {523.438, 382.125}} -> {0.0636924, \
114.992, 0.00169256, 0.249214}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot22\  = 
        Histogram[fractions2[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .27506 L
.33333 .27506 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .27506 L
.33333 .27506 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .20714 L
.55556 .20714 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .20714 L
.55556 .20714 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .07131 L
.66667 .07131 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .07131 L
.66667 .07131 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .03735 L
.88889 .03735 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03735 L
.88889 .03735 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo01/0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
01/0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oooal000007000o`000`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`0l000001`0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`0O0000
05P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo0`00000i0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0`00
00030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000>P3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2
000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0
003o000J003o000300000000o`000?l001/00?l07P00001f0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P0000050?ooo`030000003oool0
oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0S`3oool3
000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3ooolN000001d00?l000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005L0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000E`3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000005H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2?0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l0
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K
003o00030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`001@3o
ool300000080oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00060?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool5
000000050?ooo`000000oooo0?ooo`000000103oool3000005H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2?0?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`001@3o
ool2000000<0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
0?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005L0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
0?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o00030000003oool0oooo
0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo0`00001F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0S`3oool3000000<0oooo00040?ooo`8000000`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool3000000<0oooo0P000005
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o
0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000E`3ooolO00000980oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000A0?oo
ool000003@0000030?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.290039, 0.00169256, 0.332285}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot23\  = 
        Histogram[fractions2[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .27771 L
.44444 .27771 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .27771 L
.44444 .27771 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .05229 L
.77778 .05229 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05229 L
.77778 .05229 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3ooolO000001d0003o00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0=`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000oal00000>P3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oooal000007000
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?oo
o`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`<00000>@3oool00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
0000003oool0oooo05@0oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03T0oooo7P00000M0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000oal00000F03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0
003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`<00000EP3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?oooal0000070000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000M@3oool00`000000003o0000o`0J
0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1d0?oo
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000007D0oooo00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001e0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000M@3oool00`000000003o0000o`0J
0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1d0?oo
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000007@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1b0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
M@3oool00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool2000007D0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001e0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
M@3oool00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo07@0
oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`000`3oool5000000050?ooo`000000oooo0?ooo`000000103oool3000007@0
oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo00040?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo07@0
oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000M@3oool00`000000003o0000o`0J0000
o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1d0?ooo`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000007D0oooo00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0M03oool00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0M03oool00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001e0?ooo`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0
oooo07@0oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0
oooo00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo07@0oooo7P00001f0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
0140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
64.4821, 0.00169256, 0.300334}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot2, \ xplot21, \ xplot22, \ 
            xplot23}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0105108 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11982 -12 -4.5 ]
[-0.0125 .11982 0 4.5 ]
[-0.0125 .22493 -12 -4.5 ]
[-0.0125 .22493 0 4.5 ]
[-0.0125 .33004 -12 -4.5 ]
[-0.0125 .33004 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .54025 -12 -4.5 ]
[-0.0125 .54025 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11982 m
.00625 .11982 L
s
[(10)] -0.0125 .11982 1 0 Mshowa
0 .22493 m
.00625 .22493 L
s
[(20)] -0.0125 .22493 1 0 Mshowa
0 .33004 m
.00625 .33004 L
s
[(30)] -0.0125 .33004 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(40)] -0.0125 .43515 1 0 Mshowa
0 .54025 m
.00625 .54025 L
s
[(50)] -0.0125 .54025 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .0988 m
.00375 .0988 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .18289 m
.00375 .18289 L
s
0 .20391 m
.00375 .20391 L
s
0 .24595 m
.00375 .24595 L
s
0 .26697 m
.00375 .26697 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .35106 m
.00375 .35106 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .51923 m
.00375 .51923 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11982 m
1 .11982 L
s
.99375 .22493 m
1 .22493 L
s
.99375 .33004 m
1 .33004 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .54025 m
1 .54025 L
s
.125 Mabswid
.99625 .03574 m
1 .03574 L
s
.99625 .05676 m
1 .05676 L
s
.99625 .07778 m
1 .07778 L
s
.99625 .0988 m
1 .0988 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18289 m
1 .18289 L
s
.99625 .20391 m
1 .20391 L
s
.99625 .24595 m
1 .24595 L
s
.99625 .26697 m
1 .26697 L
s
.99625 .288 m
1 .288 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .37208 m
1 .37208 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .41412 m
1 .41412 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .49821 m
1 .49821 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .5823 m
1 .5823 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .04625 L
.05556 .04625 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04625 L
.05556 .04625 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .01472 L
.11111 .01472 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .05676 L
.16667 .05676 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .05676 L
.16667 .05676 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .20391 L
.22222 .20391 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .20391 L
.22222 .20391 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .18289 L
.27778 .18289 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .18289 L
.27778 .18289 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .43515 L
.33333 .43515 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .43515 L
.33333 .43515 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .51923 L
.5 .51923 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .51923 L
.5 .51923 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .37208 L
.55556 .37208 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .37208 L
.55556 .37208 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .11982 L
.61111 .11982 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .11982 L
.61111 .11982 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .17238 L
.66667 .17238 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .17238 L
.66667 .17238 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .05676 L
.72222 .05676 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .05676 L
.72222 .05676 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02523 L
.77778 .02523 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02523 L
.77778 .02523 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .02523 L
.83333 .02523 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .02523 L
.83333 .02523 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .02523 L
.88889 .02523 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .02523 L
.88889 .02523 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0150924 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(10)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(20)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(30)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .0449 m
.00375 .0449 L
s
0 .07508 m
.00375 .07508 L
s
0 .10527 m
.00375 .10527 L
s
0 .13545 m
.00375 .13545 L
s
0 .19582 m
.00375 .19582 L
s
0 .22601 m
.00375 .22601 L
s
0 .25619 m
.00375 .25619 L
s
0 .28638 m
.00375 .28638 L
s
0 .34675 m
.00375 .34675 L
s
0 .37693 m
.00375 .37693 L
s
0 .40712 m
.00375 .40712 L
s
0 .4373 m
.00375 .4373 L
s
0 .49767 m
.00375 .49767 L
s
0 .52786 m
.00375 .52786 L
s
0 .55804 m
.00375 .55804 L
s
0 .58823 m
.00375 .58823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .0449 m
1 .0449 L
s
.99625 .07508 m
1 .07508 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .13545 m
1 .13545 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .22601 m
1 .22601 L
s
.99625 .25619 m
1 .25619 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .34675 m
1 .34675 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .4373 m
1 .4373 L
s
.99625 .49767 m
1 .49767 L
s
.99625 .52786 m
1 .52786 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .58823 m
1 .58823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .0449 L
.11111 .0449 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0449 L
.11111 .0449 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .25619 L
.22222 .25619 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .25619 L
.22222 .25619 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .34675 L
.33333 .34675 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .34675 L
.33333 .34675 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .28638 L
.55556 .28638 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .28638 L
.55556 .28638 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .09018 L
.66667 .09018 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09018 L
.66667 .09018 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .27506 L
.33333 .27506 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .27506 L
.33333 .27506 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .20714 L
.55556 .20714 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .20714 L
.55556 .20714 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .07131 L
.66667 .07131 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .07131 L
.66667 .07131 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .03735 L
.88889 .03735 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03735 L
.88889 .03735 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0125235 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -12 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -12 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -12 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13995 m
.00625 .13995 L
s
[(10)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(20)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(30)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(40)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13995 m
1 .13995 L
s
.99375 .26518 m
1 .26518 L
s
.99375 .39042 m
1 .39042 L
s
.99375 .51565 m
1 .51565 L
s
.125 Mabswid
.99625 .03976 m
1 .03976 L
s
.99625 .06481 m
1 .06481 L
s
.99625 .08986 m
1 .08986 L
s
.99625 .1149 m
1 .1149 L
s
.99625 .165 m
1 .165 L
s
.99625 .19004 m
1 .19004 L
s
.99625 .21509 m
1 .21509 L
s
.99625 .24014 m
1 .24014 L
s
.99625 .29023 m
1 .29023 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .36537 m
1 .36537 L
s
.99625 .41547 m
1 .41547 L
s
.99625 .44051 m
1 .44051 L
s
.99625 .46556 m
1 .46556 L
s
.99625 .49061 m
1 .49061 L
s
.99625 .5407 m
1 .5407 L
s
.99625 .56575 m
1 .56575 L
s
.99625 .5908 m
1 .5908 L
s
.99625 .61584 m
1 .61584 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02724 L
.11111 .02724 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06481 L
.22222 .06481 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .15247 L
.33333 .15247 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .27771 L
.44444 .27771 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .27771 L
.44444 .27771 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .20257 L
.66667 .20257 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .05229 L
.77778 .05229 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05229 L
.77778 .05229 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002T0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000l0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool002T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002`0oooo000Y0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:`3oool002X0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?@3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000m0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003d0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000:`3oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00703oool2000000@0ooooQ000000J0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`006`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool001/0oooo00@000000?ooo`3oool000000`3ooon5000001P0
oooo00@000000?ooo`3oool000000P3ooon5000001P0oooo00@000000?ooo`3oool000000`3ooon5
000001P0oooo00@000000?ooo`3oool000000P3ooon5000001D0oooo000K0?ooo`040000003oool0
oooo000000<0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`050?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOglG000000d0oooo00<000000?ooo`3oool05`3o
ool010000000oooo0?ooo`0000020?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool0
5P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<00000003o0000
o`002`00o`000`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3o
ool000000P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0<0000o`030000003oool0oooo01X0oooo00<000000?oo
o`3oool04`3oool001/0oooo00@000000?ooo`3oool000000`3oool00`000000Ogmo07moO`0407mo
O`030000003oool0oooo00D0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`000002
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool@000000h0003o
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0<0000o`030000003oool0oooo01X0oooo
00<000000?ooo`3oool04`3oool001`0oooo0P0000040?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool01@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool00`000000o`000?l0
000<0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo00`0oooo3`00
000>003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o
000<003o01h000003@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool2000000d0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00`0003o00<0
00000?ooo`3oool06@3oool2000001D0oooo000R0?ooo`P000001`3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M
0?oooa0000003P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo02P0oooo0P00000O
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo00`0oooo2000000607mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl8000002<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o
0000o`003000o`000`0000000?l0003o000<003o00030000003oool0oooo02P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l@000001`0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3o
ool04`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000
o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<00000003o0000o`003000o`0@000002X0oooo00<000000?ooo`3oool0
7@3oool2000000d0oooo4000000=0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02P0oooo0P00000E0?ooo`008P3o
ool00`000000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3o
ool2000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
ool0oooo02P0oooo0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000
o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0
oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00`0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0
oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0
oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0
003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0
003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`00
0000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`004000000[0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l0
00/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool20000
01D0oooo000R0?ooo`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`000000
0?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000
003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000
003o0000o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool001D0oooo
1@0000020?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo02P0oooo
00<000000?ooo`3oool07@3oool2000000d0oooo00<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l0
00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`005`3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo02P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?ooo`D000000P3oool2000000@0
oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/0
0?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0
oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000
003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0
oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool20000
01@0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl8000000L0Ogmo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000703oool00`0000000?l0003o000<003o000300000000
o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0140oooo1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`0300000000
0?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`005`3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`030000
003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0B0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000001/0oooo00<00000003o
0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000M0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0C0?ooo`005`3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000000E0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
103oool00`000000Ogmo07moO`0507moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
7@3oool2000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`800000
503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000L0?oo
o`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o
00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P00000L0?ooo`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<00000
0?ooo`3oool0:03oool2000001D0oooo000F0?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool04`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo00@0oooo00<0000007mo
O`1oOgl01@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?oo
o`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000L0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o
000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000007@3oool00`000000003o0000o`0;0000o`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0
4`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo00@0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo1@0000020?ooo`800000
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
6P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`00
3000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000001d0oooo3`00000>0000o`03000000000?l0003o
00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01<0oooo000R0?ooo`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`040?ooo`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000>
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01<0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`02000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g
0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000
003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<00000
0?ooo`3oool07@3oool2000002X0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo000R0?oo
o`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`040?oo
o`T00000:P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000>0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000
o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000001oOgl0
Ogmo00@0Ogmo2000000707moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000>0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0
003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<0
00000?ooo`3oool07@3oool2000002X0oooo00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo000R
0?ooo`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`04
0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01d0oooo0P00000=0?ooo`030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0=`3oool2000001l0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01<0oooo200000060?oo
o`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?oo
o`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`0@000003T0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l@000002/0oooo00<000000?ooo`3oool04`3oool001D0oooo100000030?ooo`80
0000103oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000
o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`80
00005@3oool001D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool200000280oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000000d0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004P3oool4000000<0oooo0P0000040?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01<0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000002<0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?oo
o`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J
0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C
0?ooo`005@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000006`3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0M0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0=`3oool2000001D0oooo000F0?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool00`000000
0?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo
0P00000=0?oooa0000003@3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0=`3oool200000180oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`00
00000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l0
00`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000:P3oool0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2
000001D0oooo000R0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0J0?oooa0000003@00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo
01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002/0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02T0oooo4000000=0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0M0?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`003`00
000i0?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00
000i0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000R
0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0h
0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C
0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo100000030?oo
o`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`005P3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?oo
o`030000003oool0oooo01d0oooo0P00000i0?ooo`03000000000?l0003o00/0003o00<000000?oo
o`3oool0=`3oool2000001D0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000703oool00`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0oooo00<0
00000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`005`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool0oooo0P00000R0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo00<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000H0?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01<0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`80
00000`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000>@3oool00`000000003o0000o`0;0000o`03
0000003oool0oooo03L0oooo0P00000E0?ooo`005P3oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000001`0oooo3`00000>0?l000030000
003oool0oooo04D0oooo0P00000B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`03
0000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000002X0oooo00<00000
003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3o
ool0000002/0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01d0oooo0P00000i0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3o
ool2000001D0oooo000R0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl8
000003T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`800000
103oool2000000<0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3o
ool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000004`3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00
o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03P0oooo00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000
003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000
003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000003T0oooo00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0
8@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
2`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000j0?ooo`03000000000?l0003o00/0003o00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?oo
o`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?oo
o`3oool07@3oool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?oo
o`8000007`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool0>03oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool04`3oool001L0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000003T0oooo00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool001P0oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool0000002<0oooo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`00
0000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000E0?ooo`D0000000D0oooo0000003o
ool0oooo000000030?ooo`8000008P3oool9000000H0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool20000
02X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000007`3oool00`00
0000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000E0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo01d0oooo0P00000i0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2
000001D0oooo000F0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool2
000000@0oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o0000
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo0`0000020?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000G0?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000002/0
oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0
oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00800000:P3oool00`000000o`000?l0000<0?l000030000003oool0oooo04D0
oooo0P00000B0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`800000:P3oool00`00
00000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool20000
03T0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool00280
oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000[0?ooo`030000003o0000
o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool000000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`03
0000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`80
0000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l00003
0000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool2000000<0oooo0P0000040?ooo`03
0000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0
:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
1@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000
003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0
:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0
7@3oool2000003T0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`800000
5@3oool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o
ool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`<000000P3o
ool2000000<0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0:@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool0
0`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
>P3oool00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo2@0000100?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0A0?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`800000
>@3oool00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`005P3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000007`3o
ool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0C0?ooo`005@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o
00030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`3oool2000002X0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00
o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`8000000`3o
ool2000003T0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3o
ool001H0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o
00000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3o
ool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0h0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000:P3o
ool00`000000o`000?l0000<0?l000030000003oool0oooo04D0oooo0P00000O0?ooo`030000003o
ool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0>03oool00`000000003o0000o`0;0000o`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool04`3oool001H0oooo0`0000030?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool0
0`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000i0?ooo`03000000000?l0
003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000R0?ooo`030000003oool0oooo
02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`00
00`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo
0P00000Z0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool07@3oool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?oo
o`150?ooo`8000004`3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03P0oooo00<000000000o`000?l02`000?l00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l0
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000>@3oool00`000000003o
0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`008P3oool00`000000oooo0?oo
o`0Y0?ooo`l00000B03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo4000
00180?ooo`030000003oool0oooo0140oooo0`0000030?ooo`800000103oool00`000000oooo0?oo
o`0Y0?ooo`l00000B03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03P0oooo3`00
000j0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`008P3ooon4000001l0ooooQ@00000O0?oo
oh@000007`3ooon5000001D0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 568}, {432.75, 355.813}} -> {-0.331812, \
2.77743, 0.00627702, 0.00627702}, {{42.25, 160.813}, {430.875, 357.625}} -> \
{-0.0843818, 312.332, 0.00343669, 0.726593}, {{172.688, 291.25}, {430.875, \
357.625}} -> {-0.644723, 217.517, 0.00343669, 0.506021}, {{303.063, 421.625}, \
{430.875, 357.625}} -> {-1.2048, 290.023, 0.00343669, 0.674695}, {{433.5, \
552.063}, {430.875, 357.625}} -> {-1.76514, 262.136, 0.00343669, 0.60982}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions2]\)], "Input"],

Cell[BoxData[
    \({0.3081938372432176`, 0.33146548418431654`, 
      0.3603406785724656`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions2]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0037659599685111824`, 
      StandardDeviation \[Rule] 0.0613674178087296`, 
      SampleRange \[Rule] 0.5027541311967951`, 
      MeanDeviation \[Rule] 0.046232598145191726`, 
      MedianDeviation \[Rule] 0.03474101028958132`, 
      QuartileDeviation \[Rule] 0.0367049049021429`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions2]]\)], "Input"],

Cell[BoxData[
    \(0.33333333333333337`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats2\  = \ 
        Map[DispersionReport, fractions2]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats2]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0032575098654892493`\), \(Variance \[Rule] 
              0.002777823151671236`\), \(Variance \[Rule] 
              0.00395812824500726`\)},
          {\(StandardDeviation \[Rule] 
              0.05707459912683793`\), \(StandardDeviation \[Rule] 
              0.05270505812226409`\), \(StandardDeviation \[Rule] 
              0.06291365706273369`\)},
          {\(SampleRange \[Rule] 
              0.29717154424130143`\), \(SampleRange \[Rule] 
              0.32803387065892964`\), \(SampleRange \[Rule] 
              0.4759147672279179`\)},
          {\(MeanDeviation \[Rule] 
              0.04302647178889033`\), \(MeanDeviation \[Rule] 
              0.03824062351424653`\), \(MeanDeviation \[Rule] 
              0.044534913923171014`\)},
          {\(MedianDeviation \[Rule] 
              0.03469422451061349`\), \(MedianDeviation \[Rule] 
              0.0246360153256705`\), \(MedianDeviation \[Rule] 
              0.030153594563050556`\)},
          {\(QuartileDeviation \[Rule] 
              0.031514753563224335`\), \(QuartileDeviation \[Rule] 
              0.025266757163027315`\), \(QuartileDeviation \[Rule] 
              0.03038906959013757`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["uncorrected average tapping data", "Subsubsection"],

Cell[BoxData[{
    \(\(data2b\  = \ Drop[pid5667230x09avg, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats2bcor\  = \ 
        Drop[RotateLeft[pid5667230x09avg, \ 1]\  - \ 
            pid5667230x09avg, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats2bcor\  = \ Drop[beats2bcor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure2bdurs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats2bcor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata2b\  = \ 
        Transpose[{measure2bdurs, 
            Partition[beats2bcor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions2b\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ 
            newdata2b]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot2b\  = \ 
        Histogram[Flatten[fractions2b], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0075462 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(20)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(40)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(60)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .05245 m
.00375 .05245 L
s
0 .09018 m
.00375 .09018 L
s
0 .12791 m
.00375 .12791 L
s
0 .20337 m
.00375 .20337 L
s
0 .2411 m
.00375 .2411 L
s
0 .27883 m
.00375 .27883 L
s
0 .35429 m
.00375 .35429 L
s
0 .39203 m
.00375 .39203 L
s
0 .42976 m
.00375 .42976 L
s
0 .50522 m
.00375 .50522 L
s
0 .54295 m
.00375 .54295 L
s
0 .58068 m
.00375 .58068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .05245 m
1 .05245 L
s
.99625 .09018 m
1 .09018 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .20337 m
1 .20337 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .27883 m
1 .27883 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39203 m
1 .39203 L
s
.99625 .42976 m
1 .42976 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .54295 m
1 .54295 L
s
.99625 .58068 m
1 .58068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .03735 L
.11111 .03735 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .03735 L
.11111 .03735 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .02981 L
.16667 .02981 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .02981 L
.16667 .02981 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .05245 L
.22222 .05245 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .05245 L
.22222 .05245 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .15055 L
.27778 .15055 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .15055 L
.27778 .15055 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .26374 L
.33333 .26374 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .26374 L
.33333 .26374 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .51276 L
.38889 .51276 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .51276 L
.38889 .51276 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .48258 L
.5 .48258 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .48258 L
.5 .48258 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .18828 L
.55556 .18828 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .18828 L
.55556 .18828 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .09018 L
.61111 .09018 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .09018 L
.61111 .09018 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .05999 L
.66667 .05999 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .05999 L
.66667 .05999 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .02981 L
.72222 .02981 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .02981 L
.72222 .02981 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .01472 L
.77778 .01472 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`170?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0<0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0303oool0
0`000000Ogmo07moO`0<07moOa0000003P1oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo400000190?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
00`0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0303oool@000000h0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000002/0oooo4000000=07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moOa000000
F03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo4000001V0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo3`00000>07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo0`0000170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3o
ool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl?000007H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0840oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`170?oooa0000003P1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000005L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`001@3oool300000080oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo0003
0?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000EP3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`200?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
00050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000E`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001G0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`000`3oool3000000@0oooo0P0000050?ooo`030000003o
ool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool3000005H0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0P03oool3000000<0oooo00030?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00040?ooo`<00000
0`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moOa000000Q03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?oooa0000003P1oOgl00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000IP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000006H0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool@000009<0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0o`3oool90?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {434.875, 293.563}} -> {0.0636924, \
174.807, 0.00169256, 0.498428}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot2b1\  = 
        Histogram[fractions2b[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0133774 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -12 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(10)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(20)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(30)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(40)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02809 L
.11111 .02809 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02809 L
.11111 .02809 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .04147 L
.22222 .04147 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04147 L
.22222 .04147 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .21538 L
.33333 .21538 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .21538 L
.33333 .21538 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .53643 L
.44444 .53643 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .53643 L
.44444 .53643 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .04147 L
.66667 .04147 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .04147 L
.66667 .04147 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?oooal000007@3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oooal00000703o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`007`00001G0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003X0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000
003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3o
ool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool3000003T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo7P00000M0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000005L0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool20000
00D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo0`00001F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool3000005H0oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo0780oooo0`0000030?ooo`001P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3ooolO
000001`0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool30000
0080oooo0P0000050?ooo`030000003oool0oooo07@0oooo00<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00060?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`030000003o0000o`00
01X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool500000005
0?ooo`000000oooo0?ooo`000000103oool3000007@0oooo00<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1b0?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo07@0oooo00<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1d0?ooo`030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool20000
00<0oooo0P0000050?ooo`030000003oool0oooo07@0oooo00<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0
oooo00<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo07@0oooo00<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo07@0oooo00<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000M@3oool00`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`03
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1d0?ooo`030000003o0000o`0001X0o`0000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`030000003o
0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1d0?ooo`030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1d0?ooo`030000003o0000o`00
01X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1d0?ooo`030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000007D0oooo7P00001e0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo0000
00d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.245417, 0.00169256, 0.281164}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot2b2\  = 
        Histogram[fractions2b[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02603 L
.11111 .02603 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02603 L
.11111 .02603 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .32034 L
.33333 .32034 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .32034 L
.33333 .32034 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .17319 L
.55556 .17319 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .17319 L
.55556 .17319 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .09395 L
.66667 .09395 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09395 L
.66667 .09395 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?oooal000007@00
o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703ooolO000001`0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
>P3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?oo
o`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K
003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<00000003o0000o`006P00o`0O000005P0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2
000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2000000D0oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0005
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000003T0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J
003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`0N000007D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000>P3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?oo
o`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3oool2
000000D0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo0`00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2?0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`000000
0?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo0900oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03T0oooo7P00000M003o00030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo08l0oooo0`0000030?ooo`001P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
0?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00050?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo00030?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000EP3o
ool00`0000000?l0003o000K003o00030000003oool0oooo08l0oooo0`0000030?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
00000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0
oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o
0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o00030000
003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l0
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo0004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo0006
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000005H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`<000000`3oool000@0oooo0P000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo0004
0?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oooal00000
TP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
71.342, 0.00169256, 0.332285}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot2b3\  = 
        Histogram[fractions2b[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0111057 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12577 -12 -4.5 ]
[-0.0125 .12577 0 4.5 ]
[-0.0125 .23683 -12 -4.5 ]
[-0.0125 .23683 0 4.5 ]
[-0.0125 .34789 -12 -4.5 ]
[-0.0125 .34789 0 4.5 ]
[-0.0125 .45894 -12 -4.5 ]
[-0.0125 .45894 0 4.5 ]
[-0.0125 .57 -12 -4.5 ]
[-0.0125 .57 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12577 m
.00625 .12577 L
s
[(10)] -0.0125 .12577 1 0 Mshowa
0 .23683 m
.00625 .23683 L
s
[(20)] -0.0125 .23683 1 0 Mshowa
0 .34789 m
.00625 .34789 L
s
[(30)] -0.0125 .34789 1 0 Mshowa
0 .45894 m
.00625 .45894 L
s
[(40)] -0.0125 .45894 1 0 Mshowa
0 .57 m
.00625 .57 L
s
[(50)] -0.0125 .57 1 0 Mshowa
.125 Mabswid
0 .03693 m
.00375 .03693 L
s
0 .05914 m
.00375 .05914 L
s
0 .08135 m
.00375 .08135 L
s
0 .10356 m
.00375 .10356 L
s
0 .14798 m
.00375 .14798 L
s
0 .1702 m
.00375 .1702 L
s
0 .19241 m
.00375 .19241 L
s
0 .21462 m
.00375 .21462 L
s
0 .25904 m
.00375 .25904 L
s
0 .28125 m
.00375 .28125 L
s
0 .30346 m
.00375 .30346 L
s
0 .32568 m
.00375 .32568 L
s
0 .3701 m
.00375 .3701 L
s
0 .39231 m
.00375 .39231 L
s
0 .41452 m
.00375 .41452 L
s
0 .43673 m
.00375 .43673 L
s
0 .48116 m
.00375 .48116 L
s
0 .50337 m
.00375 .50337 L
s
0 .52558 m
.00375 .52558 L
s
0 .54779 m
.00375 .54779 L
s
0 .59221 m
.00375 .59221 L
s
0 .61442 m
.00375 .61442 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12577 m
1 .12577 L
s
.99375 .23683 m
1 .23683 L
s
.99375 .34789 m
1 .34789 L
s
.99375 .45894 m
1 .45894 L
s
.99375 .57 m
1 .57 L
s
.125 Mabswid
.99625 .03693 m
1 .03693 L
s
.99625 .05914 m
1 .05914 L
s
.99625 .08135 m
1 .08135 L
s
.99625 .10356 m
1 .10356 L
s
.99625 .14798 m
1 .14798 L
s
.99625 .1702 m
1 .1702 L
s
.99625 .19241 m
1 .19241 L
s
.99625 .21462 m
1 .21462 L
s
.99625 .25904 m
1 .25904 L
s
.99625 .28125 m
1 .28125 L
s
.99625 .30346 m
1 .30346 L
s
.99625 .32568 m
1 .32568 L
s
.99625 .3701 m
1 .3701 L
s
.99625 .39231 m
1 .39231 L
s
.99625 .41452 m
1 .41452 L
s
.99625 .43673 m
1 .43673 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .50337 m
1 .50337 L
s
.99625 .52558 m
1 .52558 L
s
.99625 .54779 m
1 .54779 L
s
.99625 .59221 m
1 .59221 L
s
.99625 .61442 m
1 .61442 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02582 L
.11111 .02582 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02582 L
.11111 .02582 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .04803 L
.22222 .04803 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04803 L
.22222 .04803 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .11467 L
.33333 .11467 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .11467 L
.33333 .11467 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .31457 L
.55556 .31457 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .31457 L
.55556 .31457 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .09246 L
.66667 .09246 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09246 L
.66667 .09246 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .03693 L
.77778 .03693 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03693 L
.77778 .03693 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3ooolO000001d0003o00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000oal00000>@3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oooal0000070000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?lO000005P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?oooah000007@000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
0`00001F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000005L0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool3000005H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo0780oooo0`0000030?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000oah00000MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
0`00001F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0S`3oool3000000<0oooo
00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T03oool20000
00<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
00000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool000D0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
1P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool000<0oooo1@0000001@3oool000000?ooo`3oool0000000@0oooo0`00001F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0S`3oool3000000<0oooo00030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`00103oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool000D0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000005L0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
08l0oooo0`0000030?ooo`00103oool2000000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000@0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3ooolO000009<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`01
0?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0636924, \
145.133, 0.00169256, 0.338676}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot2b, \ xplot2b1, \ xplot2b2, \ 
            xplot2b3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0075462 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16564 -12 -4.5 ]
[-0.0125 .16564 0 4.5 ]
[-0.0125 .31656 -12 -4.5 ]
[-0.0125 .31656 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16564 m
.00625 .16564 L
s
[(20)] -0.0125 .16564 1 0 Mshowa
0 .31656 m
.00625 .31656 L
s
[(40)] -0.0125 .31656 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(60)] -0.0125 .46749 1 0 Mshowa
.125 Mabswid
0 .05245 m
.00375 .05245 L
s
0 .09018 m
.00375 .09018 L
s
0 .12791 m
.00375 .12791 L
s
0 .20337 m
.00375 .20337 L
s
0 .2411 m
.00375 .2411 L
s
0 .27883 m
.00375 .27883 L
s
0 .35429 m
.00375 .35429 L
s
0 .39203 m
.00375 .39203 L
s
0 .42976 m
.00375 .42976 L
s
0 .50522 m
.00375 .50522 L
s
0 .54295 m
.00375 .54295 L
s
0 .58068 m
.00375 .58068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16564 m
1 .16564 L
s
.99375 .31656 m
1 .31656 L
s
.99375 .46749 m
1 .46749 L
s
.125 Mabswid
.99625 .05245 m
1 .05245 L
s
.99625 .09018 m
1 .09018 L
s
.99625 .12791 m
1 .12791 L
s
.99625 .20337 m
1 .20337 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .27883 m
1 .27883 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .39203 m
1 .39203 L
s
.99625 .42976 m
1 .42976 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .54295 m
1 .54295 L
s
.99625 .58068 m
1 .58068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .03735 L
.11111 .03735 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .03735 L
.11111 .03735 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .02981 L
.16667 .02981 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .02981 L
.16667 .02981 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .05245 L
.22222 .05245 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .05245 L
.22222 .05245 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .15055 L
.27778 .15055 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .15055 L
.27778 .15055 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .26374 L
.33333 .26374 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .26374 L
.33333 .26374 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .51276 L
.38889 .51276 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .51276 L
.38889 .51276 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .48258 L
.5 .48258 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .48258 L
.5 .48258 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .18828 L
.55556 .18828 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .18828 L
.55556 .18828 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .09018 L
.61111 .09018 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .09018 L
.61111 .09018 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .05999 L
.66667 .05999 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .05999 L
.66667 .05999 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .02981 L
.72222 .02981 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .02981 L
.72222 .02981 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .01472 L
.77778 .01472 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0133774 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14849 -12 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .28226 -12 -4.5 ]
[-0.0125 .28226 0 4.5 ]
[-0.0125 .41604 -12 -4.5 ]
[-0.0125 .41604 0 4.5 ]
[-0.0125 .54981 -12 -4.5 ]
[-0.0125 .54981 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(10)] -0.0125 .14849 1 0 Mshowa
0 .28226 m
.00625 .28226 L
s
[(20)] -0.0125 .28226 1 0 Mshowa
0 .41604 m
.00625 .41604 L
s
[(30)] -0.0125 .41604 1 0 Mshowa
0 .54981 m
.00625 .54981 L
s
[(40)] -0.0125 .54981 1 0 Mshowa
.125 Mabswid
0 .04147 m
.00375 .04147 L
s
0 .06822 m
.00375 .06822 L
s
0 .09498 m
.00375 .09498 L
s
0 .12173 m
.00375 .12173 L
s
0 .17524 m
.00375 .17524 L
s
0 .202 m
.00375 .202 L
s
0 .22875 m
.00375 .22875 L
s
0 .25551 m
.00375 .25551 L
s
0 .30902 m
.00375 .30902 L
s
0 .33577 m
.00375 .33577 L
s
0 .36253 m
.00375 .36253 L
s
0 .38928 m
.00375 .38928 L
s
0 .44279 m
.00375 .44279 L
s
0 .46955 m
.00375 .46955 L
s
0 .4963 m
.00375 .4963 L
s
0 .52305 m
.00375 .52305 L
s
0 .57656 m
.00375 .57656 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .41604 m
1 .41604 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .04147 m
1 .04147 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .09498 m
1 .09498 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .202 m
1 .202 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25551 m
1 .25551 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .46955 m
1 .46955 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .52305 m
1 .52305 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02809 L
.11111 .02809 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02809 L
.11111 .02809 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .04147 L
.22222 .04147 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04147 L
.22222 .04147 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .21538 L
.33333 .21538 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .21538 L
.33333 .21538 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .53643 L
.44444 .53643 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .53643 L
.44444 .53643 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .04147 L
.66667 .04147 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .04147 L
.66667 .04147 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02603 L
.11111 .02603 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02603 L
.11111 .02603 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .32034 L
.33333 .32034 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .32034 L
.33333 .32034 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .17319 L
.55556 .17319 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .17319 L
.55556 .17319 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .09395 L
.66667 .09395 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09395 L
.66667 .09395 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0111057 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12577 -12 -4.5 ]
[-0.0125 .12577 0 4.5 ]
[-0.0125 .23683 -12 -4.5 ]
[-0.0125 .23683 0 4.5 ]
[-0.0125 .34789 -12 -4.5 ]
[-0.0125 .34789 0 4.5 ]
[-0.0125 .45894 -12 -4.5 ]
[-0.0125 .45894 0 4.5 ]
[-0.0125 .57 -12 -4.5 ]
[-0.0125 .57 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12577 m
.00625 .12577 L
s
[(10)] -0.0125 .12577 1 0 Mshowa
0 .23683 m
.00625 .23683 L
s
[(20)] -0.0125 .23683 1 0 Mshowa
0 .34789 m
.00625 .34789 L
s
[(30)] -0.0125 .34789 1 0 Mshowa
0 .45894 m
.00625 .45894 L
s
[(40)] -0.0125 .45894 1 0 Mshowa
0 .57 m
.00625 .57 L
s
[(50)] -0.0125 .57 1 0 Mshowa
.125 Mabswid
0 .03693 m
.00375 .03693 L
s
0 .05914 m
.00375 .05914 L
s
0 .08135 m
.00375 .08135 L
s
0 .10356 m
.00375 .10356 L
s
0 .14798 m
.00375 .14798 L
s
0 .1702 m
.00375 .1702 L
s
0 .19241 m
.00375 .19241 L
s
0 .21462 m
.00375 .21462 L
s
0 .25904 m
.00375 .25904 L
s
0 .28125 m
.00375 .28125 L
s
0 .30346 m
.00375 .30346 L
s
0 .32568 m
.00375 .32568 L
s
0 .3701 m
.00375 .3701 L
s
0 .39231 m
.00375 .39231 L
s
0 .41452 m
.00375 .41452 L
s
0 .43673 m
.00375 .43673 L
s
0 .48116 m
.00375 .48116 L
s
0 .50337 m
.00375 .50337 L
s
0 .52558 m
.00375 .52558 L
s
0 .54779 m
.00375 .54779 L
s
0 .59221 m
.00375 .59221 L
s
0 .61442 m
.00375 .61442 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12577 m
1 .12577 L
s
.99375 .23683 m
1 .23683 L
s
.99375 .34789 m
1 .34789 L
s
.99375 .45894 m
1 .45894 L
s
.99375 .57 m
1 .57 L
s
.125 Mabswid
.99625 .03693 m
1 .03693 L
s
.99625 .05914 m
1 .05914 L
s
.99625 .08135 m
1 .08135 L
s
.99625 .10356 m
1 .10356 L
s
.99625 .14798 m
1 .14798 L
s
.99625 .1702 m
1 .1702 L
s
.99625 .19241 m
1 .19241 L
s
.99625 .21462 m
1 .21462 L
s
.99625 .25904 m
1 .25904 L
s
.99625 .28125 m
1 .28125 L
s
.99625 .30346 m
1 .30346 L
s
.99625 .32568 m
1 .32568 L
s
.99625 .3701 m
1 .3701 L
s
.99625 .39231 m
1 .39231 L
s
.99625 .41452 m
1 .41452 L
s
.99625 .43673 m
1 .43673 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .50337 m
1 .50337 L
s
.99625 .52558 m
1 .52558 L
s
.99625 .54779 m
1 .54779 L
s
.99625 .59221 m
1 .59221 L
s
.99625 .61442 m
1 .61442 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02582 L
.11111 .02582 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02582 L
.11111 .02582 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .04803 L
.22222 .04803 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .04803 L
.22222 .04803 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .11467 L
.33333 .11467 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .11467 L
.33333 .11467 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .31457 L
.55556 .31457 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .31457 L
.55556 .31457 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .09246 L
.66667 .09246 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .09246 L
.66667 .09246 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .03693 L
.77778 .03693 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03693 L
.77778 .03693 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002T0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000l0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool002T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002`0oooo000Y0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:`3oool002X0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?@3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000m0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003d0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000:`3oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00703oool2000000@0ooooQ000000J0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`006`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool001/0oooo00@000000?ooo`3oool000000`3ooon5000001P0
oooo00@000000?ooo`3oool000000P3ooon5000001P0oooo00@000000?ooo`3oool000000`3ooon5
000001P0oooo00@000000?ooo`3oool000000P3ooon5000001D0oooo000K0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01L0oooo00@000000?ooo`3oool000000P3oool00`000000o`000?l0000<0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool@000000d00?l000<00000003o0000
o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3o
ool000000P3oool@000000h0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0<0000
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool001/0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo00D0Ogmo2000000607mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl8000002<0oooo00<000000?oo
o`3oool05`3oool010000000oooo0?ooo`0000020?oooa0000003P3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o
000<003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00`0oooo00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o
0000o`0<0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0C0?ooo`00703oool2000000@0oooo00<000000?ooo`3oool0103oool9000000H0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool2000000d0oooo4000
000=0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o000@000002X0oooo0P00
000I0?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`l000003P00o`000`0000000?l0003o
000;003o000300000000o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo01P0oooo0P0000030?ooo`8000003@3oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`03000000000?l0003o00`0003o4000000K0?ooo`8000005@3oool00280oooo00<00000
0?ooo`3oool04`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000
003o0000o`003000o`000`0000000?l0003o000<003o00030000003oool0oooo02P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?oooa0000003@000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01<0oooo2000000607mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o
000300000000o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3o
ool06P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`T00000:P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0:03oool2000001D0oooo000R0?ooo`030000003oool0oooo01X0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003oool0oooo03L0oooo0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`00
3000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`00
3000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
ool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000
o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o000300000000
o`000?l000`00?l000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo000R0?ooo`030000003oool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool0
0`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`0000000?l0003o000<003o00030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool2
000001`0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0
003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`8000005@3oool0
0280oooo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl800000380oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000<003o01000000:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01/0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o
00/0003o4000000[0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01X0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`800000703oool00`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`0
0?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0
oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool06P3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo
0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0403oool500000080oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<0
0000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo00<0
00000?ooo`3oool06`3oool?000000h0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01X0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`800000703oool00`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g
0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
0000000L0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:`3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`008P3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000K
0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<
003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P00000Z0?ooo`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool00280oooo00<00000
0?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo1@000002
0?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
0000000L0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:`3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`008P3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000007@3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000000703oool00`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
0000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0=`3oool2000001D0oooo000E0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0
6P3oool8000000L0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
0000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004`3oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B0?ooo`80
0000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03
000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00
5@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000M0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`00
0`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool200000280oooo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000007@3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o
00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool001L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo0P00000L0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03L0
oooo0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o01000000>@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0
oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0
oooo00<000000?ooo`3oool04`3oool001D0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0C0?ooo`005P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0240
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl01@1oOgl8000003T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03000000000?l0003o00`0
003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool00280oooo
00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l0
00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?oo
o`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0M0?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?oo
o`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?oo
o`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0C0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo3`00000>
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E
0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o
0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo100000030?oo
o`8000000`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`03
0000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01d0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004P3oool4000000<0oooo0P0000040?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?oo
o`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool2000002X0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0Q0?oo
o`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo0P00000K0?ooo`0300000000o`000?l000`00?l000<00000
003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002/0oooo00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000703oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<00000
0000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?oo
o`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0B0?ooo`800000103oool2000000<0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool00280oooo00<00000
0?ooo`3oool08@3oool9000000H0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04@3oool4000000<0oooo0P000003
0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P000004
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`800000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0=`3oool2000001l0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M
0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0=`3oool2000001D0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000[0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3o
ool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`005`3o
ool300000080oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000
o`000`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool2000002X0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003o
ool0oooo03L0oooo0P00000E0?ooo`00603oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0?ooo`000000:`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo
0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l0
00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`l00000>P3oool00`000000oooo
0?ooo`0C0?ooo`005@3oool5000000050?ooo`000000oooo0?ooo`0000000`3oool2000002X0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?oooa0000003@00o`000`000000oooo
0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o
0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool001D0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0
oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/0
0?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000:P3oool00`000000
003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`005P3oool00`000000oooo
000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000
oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0B0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000
003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool001L0oooo
0P0000030?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo
0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l0
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o
00`0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000
oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00800000:P3oool00`000000003o0000o`0<0000o`030000003o
ool0oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000
:P3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo00<000000000
o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`03
0000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`80
0000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0=`3oool2000001D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000002/0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0403o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3o
ool04P3oool2000000@0oooo0P0000030?ooo`800000:P3oool00`000000003o0000o`0<0000o`03
0000003oool0oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`030000
0000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0M0?ooo`800000:P3oool00`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0=`3oool2000001l0oooo00<000000?ooo`3oool0:@3o
ool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0
oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<000000000o`000?l030000?l0
0`000000oooo0?ooo`150?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0:@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`8000000`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`00
00000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0
oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0
oooo01d0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool2
000001D0oooo000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
000002X0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0
oooo03L0oooo0P00000O0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool0
0280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000[0?ooo`030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003o
ool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
0?l0003o00`0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`008P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`00
2`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000
00000?l0003o00`0003o00<000000?ooo`3oool0A@3oool2000001D0oooo000R0?ooo`030000003o
ool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`800000103o
ool2000000<0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000
o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`<000000P3o
ool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04`3oool001D0oooo0`0000040?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo0`0000020?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
:`3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4`3oool001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`000000:`3oool00`0000000?l0003o000;003o00030000003oool0
oooo04H0oooo00<000000?ooo`3oool04@3oool5000000050?ooo`000000oooo0?ooo`0000000P3o
ool2000002X0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`8000005@3o
ool001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
:P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
1@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:@3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0@0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`80
0000:P3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3o
ool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool04`3oool001D0oooo0`0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo0P00000Z
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g
0?ooo`8000004P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0
oooo00<000000?ooo`3oool04`3oool001H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`T00000@03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0
oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo
04H0oooo00<000000?ooo`3oool04`3oool2000000<0oooo0P0000030?ooo`800000:P3oool00`00
0000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`005P3oool3000000<0
oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo0P0000030?ooo`800000103oool00`000000
oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02T0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo
00<000000?ooo`3oool07@3oool2000002X0oooo00<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003oool0oooo03L0oooo0P00000O0?ooo`030000003oool0oooo02T0oooo
00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo
00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0M0?ooo`800000:P3oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00
000E0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`P000001P1oOgl00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?oo
o`3oool0<03oool00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`80
0000:P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0=`3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<000000000o`00
0?l030000?l00`000000oooo0?ooo`150?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0
<03oool00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4`3oool300000080oooo0P0000030?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l0
30000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003o
ool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000[0?oooa00
00003@3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`D00000
00D0oooo0000003oool0oooo000000020?ooo`800000>@3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo03L0oooo0P00000O0?ooo`030000003oool0oooo02T0oooo00<00000003o0000
o`002`00o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03
000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool2000001D0oooo000R0?ooo`030000
003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o
00030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?oo
o`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo0300oooo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03P0oooo00<000000?l0
003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo0P0000040?oo
o`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0`
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000;
0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00800000:P3oool00`000000003o0000o`0<0000o`03
0000003oool0oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`800000
>@3oool00`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000E0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P00000Z0?ooo`0300000000o`000?l0
00/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo
0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000;0?l000030000003oool0oooo
03P0oooo00<000000?ooo`3oool04@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03P0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0180oooo0`0000030?ooo`8000000`3oool2000002X0oooo00<000000000o`000?l03000
0?l00`000000oooo0?ooo`150?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0<03oool8
000004P0oooo00<000000?ooo`3oool07@3oool2000003T0oooo3`00000i0?ooo`8000004`3oool3
000000<0oooo0P0000040?ooo`030000003oool0oooo02T0oooo3`0000180?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0:@3oool@000004P0oooo00<000000?ooo`3oool04`3oool0
0280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01<0oooo000R0?oooh@000007`3ooon5000001l0ooooQ000000O0?ooohD000005@3oool00?l0oooo
o`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 568}, {90.625, 13.6875}} -> {-0.331812, \
0.0930199, 0.00627702, 0.00627702}, {{42.25, 160.813}, {88.75, 15.5}} -> \
{-0.0843818, 2.22818, 0.00343669, 1.01204}, {{172.688, 291.25}, {88.75, \
15.5}} -> {-0.644723, 1.25692, 0.00343669, 0.570894}, {{303.063, 421.625}, \
{88.75, 15.5}} -> {-1.2048, 1.48545, 0.00343669, 0.674695}, {{433.5, \
552.063}, {88.75, 15.5}} -> {-1.76514, 1.51402, 0.00343669, 0.687672}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions2b]\)], "Input"],

Cell[BoxData[
    \({0.3385201170261035`, 0.32017711916338004`, 
      0.3413027638105163`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions2b]]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333336`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions2b]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.002288933310059976`, 
      StandardDeviation \[Rule] 0.047842797891218446`, 
      SampleRange \[Rule] 0.4640957446808511`, 
      MeanDeviation \[Rule] 0.0346952319279896`, 
      MedianDeviation \[Rule] 0.0259774492048922`, 
      QuartileDeviation \[Rule] 0.026912826115299243`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats2b\  = \ 
        Map[DispersionReport, fractions2b]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats2b]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0017056944433123302`\), \(Variance \[Rule] 
              0.001907775169805363`\), \(Variance \[Rule] 
              0.0030321275054490246`\)},
          {\(StandardDeviation \[Rule] 
              0.04130005379309245`\), \(StandardDeviation \[Rule] 
              0.04367808569300357`\), \(StandardDeviation \[Rule] 
              0.05506475738118733`\)},
          {\(SampleRange \[Rule] 0.2577220977976857`\), \(SampleRange \[Rule] 
              0.26428017929262376`\), \(SampleRange \[Rule] 
              0.44717543541259774`\)},
          {\(MeanDeviation \[Rule] 
              0.031239063195518082`\), \(MeanDeviation \[Rule] 
              0.032274516316515005`\), \(MeanDeviation \[Rule] 
              0.03549674921739318`\)},
          {\(MedianDeviation \[Rule] 
              0.0197427007350211`\), \(MedianDeviation \[Rule] 
              0.019647692993151666`\), \(MedianDeviation \[Rule] 
              0.021044303797468356`\)},
          {\(QuartileDeviation \[Rule] 
              0.025398253882642302`\), \(QuartileDeviation \[Rule] 
              0.02299937363243107`\), \(QuartileDeviation \[Rule] 
              0.021588014639681408`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3; Friedman 1930", "Subsection"],

Cell[CellGroupData[{

Cell["corrected timing data", "Subsubsection"],

Cell[BoxData[{
    \(\(beats3cor\  = \ 
        Drop[RotateLeft[pid5667230x10corrected, \ 1]\  - \ 
            pid5667230x10corrected, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats3cor\  = \ Drop[beats3cor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure3durs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats3cor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata3\  = \ 
        Transpose[{measure3durs, 
            Partition[beats3cor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions3\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ newdata3]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot3\  = \ 
        Histogram[Flatten[fractions3], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0101483 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -12 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(10)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(20)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(30)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(40)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(50)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .04516 L
.11111 .04516 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .04516 L
.11111 .04516 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .1365 L
.16667 .1365 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .1365 L
.16667 .1365 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .15679 L
.22222 .15679 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .15679 L
.22222 .15679 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .28872 L
.27778 .28872 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .28872 L
.27778 .28872 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .42065 L
.33333 .42065 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .42065 L
.33333 .42065 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .44095 L
.38889 .44095 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .44095 L
.38889 .44095 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .44095 L
.5 .44095 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .44095 L
.5 .44095 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .34961 L
.55556 .34961 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .34961 L
.55556 .34961 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .16694 L
.61111 .16694 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .16694 L
.61111 .16694 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .08575 L
.66667 .08575 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .08575 L
.66667 .08575 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .06546 L
.72222 .06546 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .06546 L
.72222 .06546 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .06546 L
.77778 .06546 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .06546 L
.77778 .06546 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .03501 L
.83333 .03501 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .03501 L
.83333 .03501 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .02486 L
.88889 .02486 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .02486 L
.88889 .02486 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .02486 L
.94444 .02486 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .02486 L
.94444 .02486 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .03501 L
1 .03501 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .03501 L
1 .03501 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo7`00000>07moO`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`010?ooo`004@3oool20000
00d0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl?000001d0oooo400000030?ooo`004@3oool00`000000
oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0<0?oooa0000003P1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000703oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`0g0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
6`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOglO000003X0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000L0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0E@3oool2000000<0
oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo4000001H0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000001`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I03oool2000000<0oooo000A0?ooo`030000
003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0040oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool3000001/0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0H`3oool30000
00<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?oo
o`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool@000000h0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1T0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000:`3oool@
000000d0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0I03oool2000000<0oooo000A0?ooo`030000003oool0oooo
03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo4000001W0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P00
00050?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000003T0oooo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0>@3o
ool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool20000
03X0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0
oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000001oOgl0Ogmo00/0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo3`00000>
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool3000004L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000003oool0oooo0780oooo0`0000030?ooo`001P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`l00000MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00060?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
0`3oool5000000050?ooo`000000oooo0?ooo`000000103oool3000004L0oooo4000000>07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`200?ooo`<0
00000`3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`00103oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00050?ooo`80
00000`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo4000000>07moOa000000P`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000IP3oool00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1U0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000006H0oooo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0I@3oool00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001V0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`03
0000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00060?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000006D0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2?0?ooo`<000000`3oool000@0oooo0P0000030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001V0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool20000
00<0oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000IP3oool00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000006H0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0I@3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0I@3oool00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001V0?oooa000000
TP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.323506, 0.00169256, 0.370627}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot31\  = 
        Histogram[fractions3[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0196201 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .05396 L
.11111 .05396 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.11111 .05396 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .21092 L
.22222 .21092 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .21092 L
.22222 .21092 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .60332 L
.33333 .60332 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .60332 L
.33333 .60332 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .5837 L
.44444 .5837 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .5837 L
.44444 .5837 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .4856 L
.55556 .4856 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .4856 L
.55556 .4856 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .05396 L
.66667 .05396 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .05396 L
.66667 .05396 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .05396 L
.77778 .05396 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05396 L
.77778 .05396 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .07358 L
.88889 .07358 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .07358 L
.88889 .07358 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .03434 L
1 .03434 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .03434 L
1 .03434 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000:`3oool2000000@0oooo0P0000040?oo
o`800000>@3oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000h0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000Z0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=P3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool2000003T0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000[0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>03o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002`0oooo0P00000:0?ooo`<00000>03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
2`3oool2000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo
o`00000;000000@0oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
0P3oool000X0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`020?ooo`002`3o
ool2000000D0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?ooo`3oool00P3oool00180oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool00P3oool0
0180oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l001h00000103oool00180
oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo01X0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo01X0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00180oooo7P00000M0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
03`000007@3o00000`000000oooo0?ooo`0I0?ooo`800000103oool00180oooo00<000000?ooo`3o
ool06P3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo03P0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo01X0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`0h0?ooo`030000
003o0000o`0001/0o`0000<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0>03o
ool00`000000o`000?l0000K0?l000030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo03P0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0080oooo000B0?ooo`8000006`3oool00`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
03P0oooo7`00000K0?ooo`800000103oool00180oooo00<000000?ooo`3oool06P3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool06P3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool06P3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000K0?ooo`03
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0LP3oool2000000@0oooo000B0?ooo`030000
003oool0oooo01X0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000;0?ooo`8000001@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01X0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0080oooo000=0?ooo`030000003oool0oooo0080oooo0`00000J0?ooo`030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?ooo`3oool0LP3oool2000000@0oooo000;0?ooo`8000001@3oool00`000000
oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
000;0?ooo`<00000103oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0J
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`02
0?ooo`004P3oool2000001/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1b0?oo
o`800000103oool00180oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
6P3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00000K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0LP3oool20000
00@0oooo000B0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo01X0oooo
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo01X0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?oo
o`8000006`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo0P0000040?oo
o`004P3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0J0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`020?ooo`004P3oool2000001/0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1b0?ooo`800000103oool00180oooo00<000000?ooo`3oool06P3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool06P3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00P3oool000@0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0J
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`02
0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool3000001X0oooo7`00000L0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool0
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool00180oooo0P00000i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo0P0000040?ooo`004P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool00180oooo0P00000i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo
0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo0780oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool0
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<00000
0?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`00103oool500000080oooo0P0000050?ooo`030000003oool0oooo03P0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`<00000>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool000H0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo00060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool000D0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0h0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000
>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>03o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080
oooo000B0?ooo`800000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<0
00000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B
0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003T0oooo00<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0LP3o
ool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003T0oooo00<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0LP3oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool000@0oooo100000030?ooo`80
00001@3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000h0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo0780oooo0P0000040?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03P0
oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo0P00
000i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo0780oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h
0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1b
0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3oool0
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`007P00001d0?ooo`800000103oool0
0180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo00040?ooo`@000000`3oool2000000D0oooo
00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>03oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`020?ooo`001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00
000h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?oo
o`2?0?ooo`800000103oool000H0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<00000
0?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`02
0?ooo`001@3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo03P0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00
4P3oool2000003T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool2000000@0oooo
000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3o
ool2000003T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3oool00`000000o`000?l0
000J0?l001l00000T@3oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000
0?l0003o00006P3o00000`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0>03oool00`000000o`000?l0000J0?l000030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0080oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000>03ooolN00000:l0oooo0P0000040?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool70?oo
o`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00180ooooo`00000;000000@0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0625786, \
41.3125, 0.00169867, 0.192395}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot32\  = 
        Histogram[fractions3[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0196201 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .11282 L
.22222 .11282 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .11282 L
.22222 .11282 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .34826 L
.33333 .34826 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .34826 L
.33333 .34826 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .5837 L
.55556 .5837 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .5837 L
.55556 .5837 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .36788 L
.66667 .36788 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .36788 L
.66667 .36788 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0932 L
.77778 .0932 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0932 L
.77778 .0932 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000:`3oool2000000@0oooo0P0000040?oo
o`800000>@3oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000h0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000Z0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=P3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool2000003T0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000[0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>03o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002`0oooo0P00000:0?ooo`<00000>03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
2`3oool2000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo
o`00000<000000<0oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6P3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0080oooo000;0?ooo`8000001@3oool00`000000oooo0?ooo`0J0?ooo`0300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000B0?ooo`8000006`3oool00`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`0g0?ooo`800000103oool00180oooo00<000000?ooo`3oool06P3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo01X0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`0J0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool06P3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000B0?oo
o`8000006`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o
0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`0g0?ooo`800000103oool00180oooo00<000000?ooo`3o
ool06P3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo01X0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0080oooo000B0?ooo`8000006`3oool00`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`0g0?ooo`800000103oool00180
oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`006`00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo03P0oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo01X0oooo00<00000003o
0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`020?ooo`004P3oool2000001/0oooo00<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`0000000?l0003o000K003o01h00000>@3oool2000000@0oooo000B0?ooo`030000
003oool0oooo01X0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool06P3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<000000?ooo`3oool06P3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01X0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo05D0oooo00<000000?ooo`3oool00P3oool000d0oooo00<000000?ooo`3oool00P3oool30000
01X0oooo7`00000L003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
00000?l0003o000K003o00030000003oool0oooo05@0oooo0P0000040?ooo`002`3oool2000000D0
oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0
oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`020?ooo`002`3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o
000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00P3oool00180oooo0P00000i0?ooo`0300000000o`000?l001X00?l000<00000003o
0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?oo
o`3oool0E03oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0080oooo000B0?ooo`800000>@3oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo
05@0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool2000003T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1D0?oo
o`800000103oool00180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
0000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo
05D0oooo00<000000?ooo`3oool00P3oool00180oooo0P00000i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<000000?ooo`3oool0E03oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo00<00000
0?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo05D0oooo00<000000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo0`00000h0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0E03oool2000000@0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00050?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o
00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3o
ool00P3oool00180oooo0P00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0
E03oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0
oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080
oooo000B0?ooo`800000>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05@0oooo
0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h
0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o
0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
00000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`00
4P3oool2000003T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1D0?ooo`800000
103oool00180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo
05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
0?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo
00<000000?ooo`3oool00P3oool00180oooo0P00000i0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0E03oool2000000@0oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3o
ool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3o
ool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0
oooo00<000000?ooo`3oool00P3oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`<00000>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05@0oooo
0P0000040?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?oo
o`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`020?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00P3oool000D0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0h0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003T0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`000000oooo0?ooo`1D0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>03o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
00000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0
oooo00<000000?ooo`3oool00P3oool00180oooo0P00000i0?oooah000007@00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E03oool2000000@0oooo
000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`0300000000
o`000?l001/00?l000<00000003o0000o`006P00o`0O000005H0oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0LP3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`00103oool4000000<0oooo0P0000050?ooo`030000003oool0oooo05D0oooo00<00000003o0000
o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`<00000E@3oool00`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0LP3oool2000000@0oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05D0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool000D0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo0P00
001F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1b0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F
0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1b
0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000
003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool000@0oooo100000030?ooo`8000001@3oool00`000000oooo
0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000005D0oooo00<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0P00
00040?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo00050?oo
o`800000103oool3000000@0oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000
EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
LP3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`0300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<0
00000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o
0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?oo
o`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0LP3o
ool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`0300000000o`000?l001/00?l07P00
001d0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K
003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?oo
o`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00
103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?oo
o`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo0`00001E0?oooal00000T@3oool2000000@0oooo00070?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?oo
o`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`02
0?ooo`001@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`004P3ooooo000000/00000103oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0625786, \
82.4521, 0.00169867, 0.192395}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot33\  = 
        Histogram[fractions3[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0143562 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15828 -12 -4.5 ]
[-0.0125 .15828 0 4.5 ]
[-0.0125 .30184 -12 -4.5 ]
[-0.0125 .30184 0 4.5 ]
[-0.0125 .4454 -12 -4.5 ]
[-0.0125 .4454 0 4.5 ]
[-0.0125 .58896 -12 -4.5 ]
[-0.0125 .58896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15828 m
.00625 .15828 L
s
[(10)] -0.0125 .15828 1 0 Mshowa
0 .30184 m
.00625 .30184 L
s
[(20)] -0.0125 .30184 1 0 Mshowa
0 .4454 m
.00625 .4454 L
s
[(30)] -0.0125 .4454 1 0 Mshowa
0 .58896 m
.00625 .58896 L
s
[(40)] -0.0125 .58896 1 0 Mshowa
.125 Mabswid
0 .04343 m
.00375 .04343 L
s
0 .07214 m
.00375 .07214 L
s
0 .10085 m
.00375 .10085 L
s
0 .12956 m
.00375 .12956 L
s
0 .18699 m
.00375 .18699 L
s
0 .2157 m
.00375 .2157 L
s
0 .24441 m
.00375 .24441 L
s
0 .27313 m
.00375 .27313 L
s
0 .33055 m
.00375 .33055 L
s
0 .35926 m
.00375 .35926 L
s
0 .38798 m
.00375 .38798 L
s
0 .41669 m
.00375 .41669 L
s
0 .47411 m
.00375 .47411 L
s
0 .50283 m
.00375 .50283 L
s
0 .53154 m
.00375 .53154 L
s
0 .56025 m
.00375 .56025 L
s
0 .61768 m
.00375 .61768 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15828 m
1 .15828 L
s
.99375 .30184 m
1 .30184 L
s
.99375 .4454 m
1 .4454 L
s
.99375 .58896 m
1 .58896 L
s
.125 Mabswid
.99625 .04343 m
1 .04343 L
s
.99625 .07214 m
1 .07214 L
s
.99625 .10085 m
1 .10085 L
s
.99625 .12956 m
1 .12956 L
s
.99625 .18699 m
1 .18699 L
s
.99625 .2157 m
1 .2157 L
s
.99625 .24441 m
1 .24441 L
s
.99625 .27313 m
1 .27313 L
s
.99625 .33055 m
1 .33055 L
s
.99625 .35926 m
1 .35926 L
s
.99625 .38798 m
1 .38798 L
s
.99625 .41669 m
1 .41669 L
s
.99625 .47411 m
1 .47411 L
s
.99625 .50283 m
1 .50283 L
s
.99625 .53154 m
1 .53154 L
s
.99625 .56025 m
1 .56025 L
s
.99625 .61768 m
1 .61768 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02907 L
.11111 .02907 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02907 L
.11111 .02907 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .17263 L
.22222 .17263 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .17263 L
.22222 .17263 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .30184 L
.33333 .30184 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .30184 L
.33333 .30184 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .33055 L
.55556 .33055 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .33055 L
.55556 .33055 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .04343 L
.66667 .04343 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .04343 L
.66667 .04343 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .07214 L
.77778 .07214 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .07214 L
.77778 .07214 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .04343 L
1 .04343 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .04343 L
1 .04343 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000003o0000o`0K0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
003oool0oooo01X0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0J0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool00@3oool00140oooo7`00000M0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0J0?ooo`03000000000?l0
003o01/0003o00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06`000?l00`00
0000oooo0?ooo`0J0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
7`00000M0000o`030000003oool0oooo01X0oooo7`0000030?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool06`3oool00`000000003o0000
o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo01/0oooo00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`0K0?oo
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool06`3oool00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`030000003oool0
oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool06`3ooolO000003T0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000001`0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo0`00000K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0LP3oool3000000<0
oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3ooolO000001`0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?oo
o`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P0000050?oo
o`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000003T0oooo7P00000M0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o7P00001e0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0S`3oool3000000<0oooo00060?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000oooo
0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000
003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000
o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0
oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo
1@0000001@3oool000000?ooo`3oool0000000@0oooo0`00001F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0S`3oool3000000<0oooo00030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000
oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0
oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?oooal00000T`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000A0?ooool000003@0000030?oo
o`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.228684, 0.00169256, 0.261994}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot3, \ xplot31, \ xplot32, \ 
            xplot33}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0101483 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -12 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(10)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(20)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(30)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(40)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(50)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .04516 L
.11111 .04516 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .04516 L
.11111 .04516 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .1365 L
.16667 .1365 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .1365 L
.16667 .1365 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .15679 L
.22222 .15679 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .15679 L
.22222 .15679 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .28872 L
.27778 .28872 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .28872 L
.27778 .28872 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .42065 L
.33333 .42065 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .42065 L
.33333 .42065 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .44095 L
.38889 .44095 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .44095 L
.38889 .44095 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .44095 L
.5 .44095 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .44095 L
.5 .44095 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .34961 L
.55556 .34961 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .34961 L
.55556 .34961 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .16694 L
.61111 .16694 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .16694 L
.61111 .16694 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .08575 L
.66667 .08575 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .08575 L
.66667 .08575 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .06546 L
.72222 .06546 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .06546 L
.72222 .06546 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .06546 L
.77778 .06546 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .06546 L
.77778 .06546 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .03501 L
.83333 .03501 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .03501 L
.83333 .03501 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .02486 L
.88889 .02486 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .02486 L
.88889 .02486 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .02486 L
.94444 .02486 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .02486 L
.94444 .02486 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .03501 L
1 .03501 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .03501 L
1 .03501 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0196201 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .05396 L
.11111 .05396 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .05396 L
.11111 .05396 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .21092 L
.22222 .21092 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .21092 L
.22222 .21092 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .60332 L
.33333 .60332 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .60332 L
.33333 .60332 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .5837 L
.44444 .5837 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .5837 L
.44444 .5837 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .4856 L
.55556 .4856 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .4856 L
.55556 .4856 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .05396 L
.66667 .05396 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .05396 L
.66667 .05396 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .05396 L
.77778 .05396 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .05396 L
.77778 .05396 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .07358 L
.88889 .07358 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .07358 L
.88889 .07358 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .03434 L
1 .03434 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .03434 L
1 .03434 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0196201 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -12 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(5)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(10)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(20)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(25)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11282 m
1 .11282 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03434 m
1 .03434 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .2894 m
1 .2894 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .44636 m
1 .44636 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .52484 m
1 .52484 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .11282 L
.22222 .11282 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .11282 L
.22222 .11282 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .34826 L
.33333 .34826 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .34826 L
.33333 .34826 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .5837 L
.55556 .5837 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .5837 L
.55556 .5837 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .36788 L
.66667 .36788 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .36788 L
.66667 .36788 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .0932 L
.77778 .0932 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0932 L
.77778 .0932 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0143562 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15828 -12 -4.5 ]
[-0.0125 .15828 0 4.5 ]
[-0.0125 .30184 -12 -4.5 ]
[-0.0125 .30184 0 4.5 ]
[-0.0125 .4454 -12 -4.5 ]
[-0.0125 .4454 0 4.5 ]
[-0.0125 .58896 -12 -4.5 ]
[-0.0125 .58896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15828 m
.00625 .15828 L
s
[(10)] -0.0125 .15828 1 0 Mshowa
0 .30184 m
.00625 .30184 L
s
[(20)] -0.0125 .30184 1 0 Mshowa
0 .4454 m
.00625 .4454 L
s
[(30)] -0.0125 .4454 1 0 Mshowa
0 .58896 m
.00625 .58896 L
s
[(40)] -0.0125 .58896 1 0 Mshowa
.125 Mabswid
0 .04343 m
.00375 .04343 L
s
0 .07214 m
.00375 .07214 L
s
0 .10085 m
.00375 .10085 L
s
0 .12956 m
.00375 .12956 L
s
0 .18699 m
.00375 .18699 L
s
0 .2157 m
.00375 .2157 L
s
0 .24441 m
.00375 .24441 L
s
0 .27313 m
.00375 .27313 L
s
0 .33055 m
.00375 .33055 L
s
0 .35926 m
.00375 .35926 L
s
0 .38798 m
.00375 .38798 L
s
0 .41669 m
.00375 .41669 L
s
0 .47411 m
.00375 .47411 L
s
0 .50283 m
.00375 .50283 L
s
0 .53154 m
.00375 .53154 L
s
0 .56025 m
.00375 .56025 L
s
0 .61768 m
.00375 .61768 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15828 m
1 .15828 L
s
.99375 .30184 m
1 .30184 L
s
.99375 .4454 m
1 .4454 L
s
.99375 .58896 m
1 .58896 L
s
.125 Mabswid
.99625 .04343 m
1 .04343 L
s
.99625 .07214 m
1 .07214 L
s
.99625 .10085 m
1 .10085 L
s
.99625 .12956 m
1 .12956 L
s
.99625 .18699 m
1 .18699 L
s
.99625 .2157 m
1 .2157 L
s
.99625 .24441 m
1 .24441 L
s
.99625 .27313 m
1 .27313 L
s
.99625 .33055 m
1 .33055 L
s
.99625 .35926 m
1 .35926 L
s
.99625 .38798 m
1 .38798 L
s
.99625 .41669 m
1 .41669 L
s
.99625 .47411 m
1 .47411 L
s
.99625 .50283 m
1 .50283 L
s
.99625 .53154 m
1 .53154 L
s
.99625 .56025 m
1 .56025 L
s
.99625 .61768 m
1 .61768 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02907 L
.11111 .02907 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02907 L
.11111 .02907 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .17263 L
.22222 .17263 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .17263 L
.22222 .17263 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .30184 L
.33333 .30184 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .30184 L
.33333 .30184 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .33055 L
.55556 .33055 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .33055 L
.55556 .33055 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .04343 L
.66667 .04343 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .04343 L
.66667 .04343 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .07214 L
.77778 .07214 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .07214 L
.77778 .07214 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .04343 L
1 .04343 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .04343 L
1 .04343 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000@03oool2000000@0oooo
0P0000030?ooo`@000003@3oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo
0P0000050?ooo`<00000303oool2000000@0oooo0P0000040?ooo`800000@@3oool2000000@0oooo
0P0000030?ooo`@000003@3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<00000303oool2000000@0oooo0P0000040?ooo`800000?`3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000;@3oool002T0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000n0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003d0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00/0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool0oooo000000P0oooo1@00000;0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:P3oool002T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003l0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3o
ool000002@3oool200000400oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002@3oool20000
03h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool2000002d0oooo000Y0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03l0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000`0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0m0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0;03oool002X0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?`3oool2000000X0oooo0P00000>0?ooo`8000002P3oool2000000h0oooo0P00
000;0?ooo`8000003@3oool2000000X0oooo0`0000100?ooo`8000002P3oool2000000h0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000=0?ooo`8000002P3oool3000003h0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000;03oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00703oool2000000@0ooooQ000000L0?ooo`8000000`3o
oon1000001d0oooo0P0000040?oooh000000703oool2000000@0ooooP`00000F0?ooo`006`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0503oool001/0oooo00@000000?ooo`3oool000000`3ooon4000001/0oooo00@00000
0?ooo`3oool000000P3ooon1000001`0oooo00@000000?ooo`3oool000000`3ooon0000001/0oooo
00@000000?ooo`3oool000000`3ooon3000001H0oooo000K0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo3`00000607moO`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool00`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02`3oool0
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`002`00o`00
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000`3o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo00`0oooo00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0D0?ooo`006`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00@0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003o
ool0oooo00/0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0I0?ooo`040000003o
ool0oooo00000080oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000l00000
703oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00/0oooo00<00000003o0000
o`002`00o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`002`00o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000000<0oooo3`00000>0000
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0<0?oo
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0503oool001`0oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl9000000d0oooo2000000L0?ooo`80
00000`3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0K0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`03
00000000o`000?l000/00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o0003
00000000o`000?l000/00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o0003
0000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool2000000@0oooo00<000000?ooo`3o
ool02`3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0503oool00280oooo00<000000?ooo`3oool0103oool9000000H0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
7`3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00/0oooo00<00000003o0000o`00
2`00o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`00
2`00o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l@000000d0003o00<000000?ooo`3oool0303oool?000001H0oooo000R0?ooo`030000003o
ool0oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?oooa0000003@3o
00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o
000M000000h0o`0000<000000?ooo`3oool02P3oool2000002<0oooo00<000000?ooo`3oool02`3o
ool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`003000
o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3o
ool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo00`0oooo00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0
oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0I0?ooo`030000003o0000
o`0000`0o`0000<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000;003o000300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o000300000000o`00
0?l000/00?l000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00/0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0<0?ooo`03000000000?l0
003o00/0003o00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`008P3oool00`00
0000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo3`00000L0?ooo`030000003oool0oooo
01l0oooo0P00000=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool06@3oool@0000
00`0oooo0P00000S0?ooo`030000003oool0oooo00/0oooo00<00000003o0000o`002`00o`000`00
00000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0<0?ooo`l00000703oool00`000000oooo0?ooo`0D0?ooo`008P3oool00`000000
oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool00`000000
0?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000
0?l0003o000;003o000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000
003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool00280oooo
00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl9000002X0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0<0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00/0oooo00<00000003o0000o`002`00o`000`0000000?l0
003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo00`0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0J0?ooo`8000000`3oool2000000d0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0e0?ooo`8000007@3oool2000000@0oooo00<0
00000?ooo`3oool02`3oool00`0000000?l0003o000;003o000300000000o`000?l000/00?l000<0
0000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l03`00
000K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001D0oooo1@000002
0?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0300oooo00<00000
0?ooo`3oool06@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01X0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`0300000000o`000?l000/00?l0
00<00000003o0000o`002`00o`000`0000000?l0003o000<003o000300000000o`000?l000/00?l0
00<00000003o0000o`002`00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool02`3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0503oool001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool00P00000=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0=@3oool2000001l0oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`l000003@00o`000`00
00000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`00
0000oooo0?ooo`0V0?ooo`8000008P3oool00`000000oooo0?ooo`0;0?ooo`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o
00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`005`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000=0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo0300oooo00<000000?ooo`3oool06P3oool2000000<0oooo00<000000?ooo`3oool0303oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000;0?l000030000003oool0oooo03H0oooo00<000000?ooo`3oool06`3oool2
000000@0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`00
0?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0
oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0
003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`005`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo0300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`0300000000
o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000
o`000?l000/00?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00/0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`0300000000
0?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo01@0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000h0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0J0?ooo`<00000
0P3oool2000000d0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0e0?ooo`800000
7@3oool3000000<0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o00030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000
003oool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`005P3o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo00`0oooo2000000607moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`0300000000
0?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`008P3oool0
0`000000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01l0oooo0P00000=0?ooo`030000003o0000
o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0=@3oool2000002<0oooo00<000000?ooo`3oool06@3oool0
0`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`00
0`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool5
00000080oooo0P0000040?ooo`030000003oool0oooo00/0oooo00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo
01<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
0300oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`00
00/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o000300000000o`000?l0
00/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000003@3o
ool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503o
ool00280oooo00<000000?ooo`3oool04`3oool8000000H0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3oool0
0`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`00
0`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool05@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000?ooo`3oool0=P3oool2000001H0oooo000R0?ooo`030000003o
ool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo2000000b0?ooo`030000003oool0oooo01l0oooo0P00000=0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0=@3oool2000002<0oooo00<000000?ooo`3oool06@3o
ool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00
o`000`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000=0?oooa00
00003@000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000703oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000R0?ooo`03
0000003oool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?ooo`80
00003@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03D0oooo0P00000S0?ooo`03
0000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o0003
00000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`03
000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool0
6P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo1@0000020?ooo`800000
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0D0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool0
6@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`00
2`00o`000`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
503oool00280oooo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000h0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000006`3oool0
0`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`00
0`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool0
01D0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
03L0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P00000=0?ooo`l000003@3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0=@3oool2000001P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo0?ooo`8000006P3oool00`0000000?l0003o000;003o00030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000
003oool0oooo02H0oooo0P00000R0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
01`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001/0oooo00<00000003o0000o`002`00
o`000`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06P3o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000F0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool2000001/0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`02000001/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0=@3oool2000001P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`0000006`3oool00`0000000?l0003o000;003o
000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o
00030000003oool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?oo
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0J
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;
0?l000030000003oool0oooo03H0oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P000004
0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06P3oool00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01@0oooo000E0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<0
0000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool2000000@0oooo0P000004
0?ooo`030000003oool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O
0?ooo`8000006`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0e0?ooo`8000008`3oool00`000000oooo0?ooo`0I
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000/00?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D
0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03H0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o
0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool2000001/0oooo00<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0=@3oool2000002<0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o0003
0000003oool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?ooo`03
000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool0
6P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
6P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
6@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`00
2`00o`000`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
503oool00280oooo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?ooo`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool06P3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo1@0000020?ooo`8000000`3oool2
000001/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0=@3oool2000001H0oooo1@0000020?ooo`800000103oool0
0`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0C0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool06P3oool0
0`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo
01X0oooo2000000707moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000L0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000;0?l000030000003oool0oooo03H0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000K0?ooo`0300000000o`000?l000/0
0?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000/0
0?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o
00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool08@3oool00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000K0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l00003
0000003oool0oooo03D0oooo0P00000H0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0oooo0P00000J0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`00
00000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool09P3oool20000
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000006`3oool?
000000h0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0f0?ooo`8000005P3oool0
01H0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool06P3oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o000300000000o`000?l0
00`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000;003o00030000003oool0oooo
02L0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo0000000Z0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000E0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000
0000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000
0000o`000?l000/00?l000<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0X0?oo
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01@0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`3oool200000280oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool2000000@0oooo0`000002
0?ooo`8000006`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0e0?ooo`8000005`3oool2000000@0oooo0`000003
0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0X
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01@0oooo000H0?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo0000000S0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3o
ool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00
o`000`0000000?l0003o000;003o00030000003oool0oooo02L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o3`00000i0?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo0P00000K0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003oool0oooo03D0oooo0P00000S0?ooo`030000003oool0oooo01T0oooo3`00000>003o00030000
0000o`000?l000/00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0503oool001H0oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09`3o
ool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`002`00
o`000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03o
ool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503o
ool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`P00000>@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`00
0`0000000?l0003o000;003o000300000000o`000?l000/00?l000<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo
0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01l0oooo0P00000K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000;0?l000030000003oool0oooo03D0oooo0P00000S0?ooo`030000003oool0oooo
02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o00l00000:@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo0240
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/0
0?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0
oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0
oooo000R0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01l0oooo0P00000K0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03D0oooo
0P00000S0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0
003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`@000000`3oool2000000<0oooo00<0
00000?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo1000
00030?ooo`800000103oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`05
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`05
07moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0
000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0
003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool2000001/0oooo00<000000?l0003o00002`3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=@3oool2000001L0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000:03oool00`000000
0?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=03oool200000280
oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0503oool001L0oooo0`0000020?ooo`800000103oool00`000000oooo
0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000L0?oo
o`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l0
00030000003oool0oooo03H0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0503oool001P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`3oool0000002<0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`8000006`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`0e0?ooo`8000005P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01@0oooo000E0?ooo`D0000000D0oooo0000003oool0oooo0000
00030?ooo`8000008P3oool9000000H0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P00
00030?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0E0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01@0oooo000E0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03H0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l0
00<00000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01@0oooo
0P0000040?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0000
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01l0oooo0P00000K0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03D0oooo
0P00000S0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0
003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:03oool00`00
0000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool001L0
oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`P000001P1oOgl900000400
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo03H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`0
0?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000:@3oool0
0`000000003o0000o`0<0000o`030000003oool0oooo04@0oooo0P00000F0?ooo`008P3oool00`00
0000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0O0?ooo`8000006`3oool00`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0e0?ooo`8000008`3oool00`00
0000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool0000002X0oooo00<000000000o`000?l030000?l00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo0300oooo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`008P3oool00`000000oooo0?oo
o`0`0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o
000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo0300oooo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo10000003
0?ooo`8000000`3oool2000001/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;
0?l000l00000=`3oool2000001H0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0W
0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<
0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00280oooo00<000000?oo
o`3oool0<03oool00`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0503oool00280oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`04
07moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo008000006`3oool00`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0@`3oool2000001L0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`3oool2000002P0oooo00<00000003o0000o`003000o`000`0000000?l0003o
000;003o00030000003oool0oooo03@0oooo0P00000R0?ooo`030000003oool0oooo02P0oooo00<0
00000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo000R
0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<00000
0?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0X
0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D
0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
0000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`005P3oool2000000@0oooo0P000004
0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`<000000P3oool2000001/0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo04<0oooo0P00000G
0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<
003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01@0oooo000E0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0503oool001P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`3oool200000340oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01l0oooo0P00000K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000oooo0?ooo`130?ooo`8000008`3oool00`000000oooo0?ooo`0W0?ooo`030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<0000o`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0503oool001H0oooo0P0000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0<03oool00`000000Ogmo07moO`0407moO`030000
003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000
003oool0oooo01@0oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`00
2`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
:03oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
503oool001H0oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`0`0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0O0?ooo`8000006`3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0@`3o
ool2000002<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000
o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02P0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo01@0oooo000R0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`00
0`0000000?l0003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0O0?ooo`8000006`3oool00`00
0000o`000?l0000;0?l000l00000A@3oool2000002<0oooo00<000000?ooo`3oool09`3oool00`00
00000?l0003o000<003o00l00000=`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02P0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo
01@0oooo000R0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0E0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`000000
0?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool05@3oool300000080
oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000
oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo0300oooo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo02L0oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003o
ool0oooo01H0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000002X0
oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0
oooo000R0?ooo`030000003oool0oooo0300oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo008000006`3oool?000005<0oooo0P00000H0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`3oool2000002P0oooo400000140?ooo`8000005@3oool5
000000050?ooo`000000oooo0?ooo`0000000`3oool2000002T0oooo00<000000000o`000?l03000
0?l00`000000oooo0?ooo`140?ooo`8000005P3oool00280oooo00<000000?ooo`3oool0<03oool0
0`000000Ogmo07moO`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:03o
ool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503o
ool00280oooo00<000000?ooo`3oool0<03oool8000004P0oooo00<000000?ooo`3oool04`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080ooooP@00000F0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3ooon0000001H0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02P0oooo40000017
0?ooo`030000003oool0oooo01@0oooo000R0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`800000103oool2000009/0oooo0P0000040?oo
o`800000V`3oool2000000<0oooo0P0000040?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0503oool00280ooooQ000003o0?ooofP0ooooP`00000F0?ooo`00o`3ooooo0?ooojP0
oooo003o0?ooool0ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {261.688, 184.75}} -> {-0.331812, \
1.43522, 0.00627702, 0.00627702}, {{42.25, 160.813}, {259.813, 186.563}} -> \
{-0.0843818, 162.573, 0.00343669, 0.752548}, {{172.688, 291.25}, {259.813, \
186.563}} -> {-0.678252, 86.9074, 0.00355, 0.402082}, {{303.063, 421.625}, \
{259.813, 186.563}} -> {-1.25679, 86.9074, 0.00355, 0.402082}, {{433.5, \
552.063}, {259.813, 186.563}} -> {-1.78413, 115.959, 0.00346722, 0.536697}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions3]\)], "Input"],

Cell[BoxData[
    \({0.32313868797381323`, 0.34769513178468886`, 
      0.3291661802414981`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions3]]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333331`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions3]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0044704137282718425`, 
      StandardDeviation \[Rule] 0.06686115260950744`, 
      SampleRange \[Rule] 0.40504233064488837`, 
      MeanDeviation \[Rule] 0.05029840677688093`, 
      MedianDeviation \[Rule] 0.04040998052787925`, 
      QuartileDeviation \[Rule] 0.040049283650023304`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats3\  = \ 
        Map[DispersionReport, fractions3]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats3]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.004944171299758213`\), \(Variance \[Rule] 
              0.003507565056384236`\), \(Variance \[Rule] 
              0.00471639144092924`\)},
          {\(StandardDeviation \[Rule] 
              0.07031480142728282`\), \(StandardDeviation \[Rule] 
              0.05922469971544166`\), \(StandardDeviation \[Rule] 
              0.06867598882381847`\)},
          {\(SampleRange \[Rule] 0.3744748094441346`\), \(SampleRange \[Rule] 
              0.27731752220056316`\), \(SampleRange \[Rule] 
              0.40504233064488837`\)},
          {\(MeanDeviation \[Rule] 
              0.05247639438839895`\), \(MeanDeviation \[Rule] 
              0.04773204731372225`\), \(MeanDeviation \[Rule] 
              0.04804439847343415`\)},
          {\(MedianDeviation \[Rule] 
              0.04661479686802389`\), \(MedianDeviation \[Rule] 
              0.04319344579646017`\), \(MedianDeviation \[Rule] 
              0.036154932099756065`\)},
          {\(QuartileDeviation \[Rule] 
              0.0418633324819393`\), \(QuartileDeviation \[Rule] 
              0.04261497584610455`\), \(QuartileDeviation \[Rule] 
              0.035985781636628356`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["uncorrected average tapping data", "Subsubsection"],

Cell[BoxData[{
    \(\(data3b\  = \ Drop[pid5667230x10avg, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats3bcor\  = \ 
        Drop[RotateLeft[pid5667230x10avg, \ 1]\  - \ 
            pid5667230x10avg, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats3bcor\  = \ Drop[beats3bcor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure3bdurs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats3bcor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata3b\  = \ 
        Transpose[{measure3bdurs, 
            Partition[beats3bcor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions3b\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ 
            newdata3b]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot3b\  = \ 
        Histogram[Flatten[fractions3b], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00516319 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11798 -12 -4.5 ]
[-0.0125 .11798 0 4.5 ]
[-0.0125 .22124 -12 -4.5 ]
[-0.0125 .22124 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .42777 -12 -4.5 ]
[-0.0125 .42777 0 4.5 ]
[-0.0125 .53103 -18 -4.5 ]
[-0.0125 .53103 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11798 m
.00625 .11798 L
s
[(20)] -0.0125 .11798 1 0 Mshowa
0 .22124 m
.00625 .22124 L
s
[(40)] -0.0125 .22124 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(60)] -0.0125 .32451 1 0 Mshowa
0 .42777 m
.00625 .42777 L
s
[(80)] -0.0125 .42777 1 0 Mshowa
0 .53103 m
.00625 .53103 L
s
[(100)] -0.0125 .53103 1 0 Mshowa
.125 Mabswid
0 .04053 m
.00375 .04053 L
s
0 .06635 m
.00375 .06635 L
s
0 .09216 m
.00375 .09216 L
s
0 .14379 m
.00375 .14379 L
s
0 .16961 m
.00375 .16961 L
s
0 .19543 m
.00375 .19543 L
s
0 .24706 m
.00375 .24706 L
s
0 .27287 m
.00375 .27287 L
s
0 .29869 m
.00375 .29869 L
s
0 .35032 m
.00375 .35032 L
s
0 .37614 m
.00375 .37614 L
s
0 .40195 m
.00375 .40195 L
s
0 .45359 m
.00375 .45359 L
s
0 .4794 m
.00375 .4794 L
s
0 .50522 m
.00375 .50522 L
s
0 .55685 m
.00375 .55685 L
s
0 .58267 m
.00375 .58267 L
s
0 .60848 m
.00375 .60848 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11798 m
1 .11798 L
s
.99375 .22124 m
1 .22124 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .42777 m
1 .42777 L
s
.99375 .53103 m
1 .53103 L
s
.125 Mabswid
.99625 .04053 m
1 .04053 L
s
.99625 .06635 m
1 .06635 L
s
.99625 .09216 m
1 .09216 L
s
.99625 .14379 m
1 .14379 L
s
.99625 .16961 m
1 .16961 L
s
.99625 .19543 m
1 .19543 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .27287 m
1 .27287 L
s
.99625 .29869 m
1 .29869 L
s
.99625 .35032 m
1 .35032 L
s
.99625 .37614 m
1 .37614 L
s
.99625 .40195 m
1 .40195 L
s
.99625 .45359 m
1 .45359 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .55685 m
1 .55685 L
s
.99625 .58267 m
1 .58267 L
s
.99625 .60848 m
1 .60848 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01988 L
.05556 .01988 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01988 L
.05556 .01988 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .01988 L
.11111 .01988 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .01988 L
.11111 .01988 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .01472 L
.16667 .01472 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .01472 L
.16667 .01472 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .03537 L
.22222 .03537 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .03537 L
.22222 .03537 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .05086 L
.27778 .05086 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .05086 L
.27778 .05086 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .15412 L
.33333 .15412 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .15412 L
.33333 .15412 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .41744 L
.38889 .41744 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .41744 L
.38889 .41744 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .25222 L
.5 .25222 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .25222 L
.5 .25222 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .12314 L
.55556 .12314 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .12314 L
.55556 .12314 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .04053 L
.61111 .04053 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .04053 L
.61111 .04053 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .01988 L
.66667 .01988 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .01988 L
.66667 .01988 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .01472 L
.72222 .01472 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.72222 .01472 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02504 L
.77778 .02504 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02504 L
.77778 .02504 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01988 L
.88889 .01988 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01988 L
.88889 .01988 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01988 L
.94444 .01988 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01988 L
.94444 .01988 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:`3oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000:`3oool2000000@0oooo0P0000040?oo
o`800000=P3oool002X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000e0?ooo`00:P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000Z0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
<`3oool002X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool2000003H0oooo000Z
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000[0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=@3o
ool002/0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002`0oooo0P00000:0?ooo`<00000=@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool100000040oooo000>0?ooo`800000
1@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo0@0000010?ooo`003@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo
000=0?ooo`040000003oool0oooo000000@0ooooo`00000<000000003@3oool010000000oooo0?oo
o`0000040?oooah000003P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
4000000>0?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0303ooolO000000d0oooo
0@0000010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02T0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo01/0oooo
00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0h0?ooo`4000000@3oool000h0oooo0P00
00050?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo01/0oooo3`00000j0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0:@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0I03oool100000040oooo000E0?ooo`030000003oool0oooo02T0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06@0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0Y0?oooa0000003P1oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1T0?ooo`40
00000@3oool001D0oooo0P00000i0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moOa000000I@3oool200000040oooo000E0?ooo`030000003o
ool0oooo03P0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool100000040oooo000E0?ooo`030000003oool0
oooo03P0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool100000040oooo000E0?ooo`030000003oool0oooo
03P0oooo4000000=07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool10000
0040oooo000E0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo
0?ooo`1c0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool100000040oooo000E
0?ooo`800000B03oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0LP3oool200000040oooo000E0?ooo`030000003oool0oooo04L0oooo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`1c0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
A`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
L`3oool100000040oooo000E0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000oooo0?ooo`1c0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool10000
0040oooo000E0?ooo`800000B03oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0LP3oool200000040oooo000E0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1c0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0L`3oool100000040oooo00070?ooo`@000000`3oool2000000D0oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0L`3oool100000040oooo00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000oooo0?ooo`1c0?ooo`4000000@3oool000P0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`800000B03oool00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0LP3oool200000040oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07<0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`l00000M@3oool1
00000040oooo00080?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040
oooo000E0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`210?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool2000004P0oooo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`200?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0P@3oool100000040oooo000E0?ooo`030000003oool0oooo04L0oooo3`00000>07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`4000000@3oool001D0
oooo0P00001F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0800oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0840oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0840oooo0@0000010?ooo`005@3oool2000005H0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P03o
ool200000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool1
00000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool10000
0040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040
oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo
00090?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`210?ooo`4000000@3oool000X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo0007
0?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`800000EP3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`200?ooo`8000000@3oool000L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo
00080?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0840oooo0@0000010?ooo`002@3oool2000000<0oooo0P00
00050?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo000E
0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo000E0?oo
o`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo000E0?ooo`03
0000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool100000040oooo000E0?ooo`800000
EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`200?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0E@3o
ool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo400000230?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo
05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@00
00010?ooo`005@3oool2000005H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo08l0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000
003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`800000EP3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0S`3oool20000
0040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E
0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0@0000010?ooo`001`3oool3000000@0oooo0P0000050?oo
o`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0900oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo00070?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000005H0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo08l0oooo0P00
00010?ooo`001`3oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2@0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`00203oool3000000<0oooo0P000005
0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000
003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0900oooo0@0000010?ooo`005@3oool2000005H0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo08l0oooo0P0000010?ooo`005@3oool0
0`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool10000
0040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E
0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool2000005H0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo08l0oooo0P0000010?oo
o`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
T03oool100000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0E@3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool10000
0040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool2000005H0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo08l0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`1E0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0E@3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo05D0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1E0?oooa0000003P1oOgl00`000000oooo0?ooo`2@0?ooo`40
00000@3oool000P0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1T0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo00070?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1T0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo00070?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000006D0oooo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`2?0?ooo`8000000@3oool000P0oooo0P0000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0900oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0@0000010?ooo`00203oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003o
ool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3o
ool001D0oooo0P00001U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0S`3oool2
00000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I03oool00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo
000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool2000006D0oooo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`2?0?ooo`8000000@3oool001D0oooo00<000000?ooo`3o
ool0I03oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
T03oool100000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I03oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool10000
0040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo0P00001U0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0S`3oool200000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool000030?ooo`000000000000<00000
0P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040
oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo0P00001U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0S`3oool200000040oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I03oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2@0?ooo`4000000@3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
I03oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0@0000010?ooo`005@3o
ool2000006D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2?0?ooo`8000000@3o
ool001D0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`030000003oool0
oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo06@0
oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0oooo06@0oooo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool001D0oooo0P00001U0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0S`3oool200000040oooo000E0?ooo`03
0000003oool0oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0I03oool00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0900oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool100000040oooo000E0?ooo`030000003oool0
oooo06@0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0I03oool@00000980oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool200000040oooo
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool100000040oooo000E
0?ooool000002`0000010?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {308.625, 167.313}} -> {0.0579117, \
140.715, 0.00169635, 0.730105}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot3b1\  = 
        Histogram[fractions3b[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00840863 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -12 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(10)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(20)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(30)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(40)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(50)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(60)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(70)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03153 L
.11111 .03153 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03153 L
.11111 .03153 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .03153 L
.22222 .03153 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03153 L
.22222 .03153 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .16607 L
.33333 .16607 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .16607 L
.33333 .16607 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .08198 L
.55556 .08198 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .08198 L
.55556 .08198 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .03994 L
.66667 .03994 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .03994 L
.66667 .03994 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000:`3oool2000000@0oooo0P0000040?oo
o`800000>@3oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000h0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000Z0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=P3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool2000003T0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000[0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>03o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002`0oooo0P00000:0?ooo`<00000>03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
2`3oool2000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo
o`00000<000000<0oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000050?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo05D0oooo00<000000?ooo`3oool00P3oool00180oooo?000000L0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0
oooo05@0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l001l00000E`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B
0?ooo`800000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<000000?oo
o`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool00180oooo0P00000i0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o000N000007@0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h
0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo00<000000?oo
o`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
0080oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`<00000>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0S`3oool2000000@0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
>03oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000003T0oooo00<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
03P0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`020?ooo`004P3oool2000003T0oooo00<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?oo
o`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?oo
o`004P3oool2000003T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0>03oool00`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`0h0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3ooolN000001d0
o`0000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo
00040?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0005
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000005D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E@3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0E@3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`00
01/0o`0000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080
oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B
0?ooo`800000EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P000004
0?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2
000005H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool0
0180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo
00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo00050?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo
08l0oooo0P0000040?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo00050?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`000000o`000?l0000K0?l00003
0000003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool20000
05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool00180
oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`00
0?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?oo
o`030000003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`03
0000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo0080oooo00060?ooo`<000000P3oool2000000D0oooo00<000000?ooo`3oool0
E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool0
0P3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0080oooo00040?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000
E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P0000040?ooo`00103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool00P3oool000D0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo0080oooo00060?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0
E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo
05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo
000B0?ooo`800000EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P00
00040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?oo
o`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`00
0000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900
oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`0001/0o`00
00<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0005
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0007
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000005D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool000D0oooo0P000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0005
0?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?oo
o`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`00
0000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000
oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<000000?l0
003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3o
ool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool00180oooo0P00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool2
000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080
oooo00040?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000o`00
0?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05D0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080
oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool30000
05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`800000103oool000@0
oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool00`00
0000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000D0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
0080oooo00050?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0E@3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo
0P00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0S`3oool2000000@0oooo
000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000
EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo08l0oooo0P0000040?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<000000?l0003o00006`3o00000`000000
oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`00
0?l0000K0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?oo
o`3oool0E@3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo00<000000?oo
o`3oool00P3oool00180oooo0P00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo00060?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`030000003oool0oooo05D0oooo00<000000?l0003o00006`3o
00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo00060?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05D0oooo00<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000E@3o
oolO00000940oooo0P0000040?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo0080oooo0004
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool000@0oooo1000
00030?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00180ooooo`00000;000000@0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {479.688, 338.375}} -> {0.0625786, \
182.603, 0.00169867, 0.448922}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot3b2\  = 
        Histogram[fractions3b[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00840863 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -12 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(10)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(20)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(30)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(40)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(50)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(60)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(70)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .01472 L
.22222 .01472 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .01472 L
.22222 .01472 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .07358 L
.33333 .07358 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .07358 L
.33333 .07358 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .22493 L
.55556 .22493 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .22493 L
.55556 .22493 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .02312 L
.66667 .02312 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .02312 L
.66667 .02312 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000:`3oool2000000@0oooo0P0000040?oo
o`800000>@3oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000h0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000Z0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=P3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool2000003T0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000[0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>03o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002`0oooo0P00000:0?ooo`<00000>03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180ooooo`00000;000000@0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
2`3oool2000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo000000@0oooo
o`00000<000000<0oooo000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o00030000003oool0oooo05D0oooo00<000000?ooo`3oool0
0P3oool000X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0h0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o01l00000
E`3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000D0oooo00<000000?ooo`3oool0>03o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000>@3oool0
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<000000?ooo`3oool0>03oool00`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo03P0
oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<0
00000?ooo`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B
0?ooo`800000>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1b0?ooo`800000103oool00180oooo00<000000?oo
o`3oool0>03oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`03
0000003oool0oooo03P0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P3oool00180oooo0P00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`0h0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool0
0180oooo00<000000?ooo`3oool0>03ooolN000001d00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0
oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo00040?ooo`D000000P3oool2000000D0oooo00<000000?oo
o`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
0080oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`<00000E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0LP3oool2000000@0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`001@3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0
E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool0
0`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo
05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo0780oooo0P0000040?ooo`004P3oool00`000000oooo0?oo
o`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`004P3oool2000005H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo0780oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3o
ool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0LP3oool2000000@0
oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool000@0oooo1000
00030?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo00050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool3000005D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo0780oooo0P0000040?ooo`001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`0300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0080oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo00050?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool0
0`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0LP3oool20000
00@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?oo
o`1E0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0LP3oool2000000@0oooo000B0?oo
o`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0E@3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
0000o`000?l001/00?l07P00001e0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003o
ool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0080oooo000B0?ooo`800000EP3oool00`0000000?l0003o000K003o00030000003oool0
oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000
oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l0
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<00000
0?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001E0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0S`3oool2000000@0oooo00070?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`00103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool0
00D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0
oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo
00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo
00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o
000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000
003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo0080oooo000B0?ooo`800000EP3oool00`0000000?l0003o000K003o00030000003oool0oooo
08l0oooo0P0000040?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo
0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`02
0?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?oo
o`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000H0oooo0`0000020?ooo`800000
1@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`020?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000
003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000@0oooo1@0000001@3oool000000?oo
o`3oool0000000@0oooo0`00001E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
S`3oool2000000@0oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`020?ooo`001@3oool00`000000oooo000000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool000H0oooo0P0000030?ooo`800000
1@3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2
000005H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool0
0180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`000000
0?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo
00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo
00<000000?ooo`3oool00P3oool00180oooo0P00001F0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?oo
o`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo08l0oooo0P0000040?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<0
00000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`02
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`<00000E@3oool00`0000000?l0003o000K003o00030000003oool0oooo08l0oooo0P00
00040?ooo`001@3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`020?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool000D0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool0
0P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003o
ool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool0
0`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool0
0180oooo0P00001F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0S`3oool20000
00@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo
000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?oo
o`800000EP3oool00`0000000?l0003o000K003o00030000003oool0oooo08l0oooo0P0000040?oo
o`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3o
ool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`00
00000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180
oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900
oooo00<000000?ooo`3oool00P3oool000@0oooo0`0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`020?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900
oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`<00000E@3oool00`0000000?l0003o000K003o00030000003oool0oooo
08l0oooo0P0000040?ooo`00103oool3000000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`020?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo
0900oooo00<000000?ooo`3oool00P3oool000D0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000o`006`00o`000`000000oooo
0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o
000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<00000
0?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<00000
0?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0E@3oool00`0000000?l0003o000K003o
00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3o
ool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3o
ool00P3oool00180oooo0P00001F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
S`3oool2000000@0oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00
o`000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`030000003oool0
oooo05D0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo0080oooo000B0?ooo`030000003oool0oooo05D0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo000B0?ooo`800000EP3oool00`000000
0?l0003o000K003o00030000003oool0oooo08l0oooo0P0000040?ooo`004P3oool00`000000oooo
0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`1E
0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`02
0?ooo`004P3oool00`000000oooo0?ooo`1E0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`020?ooo`004P3oool2000005H0oooo00<00000003o0000
o`006`00o`000`000000oooo0?ooo`2?0?ooo`800000103oool00180oooo00<000000?ooo`3oool0
E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool0
0P3oool000H0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0E@3o
ool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<000000?ooo`3oool00P3o
ool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0E@3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo00<0
00000?ooo`3oool00P3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo0`00001E0?oooal00000T@3oool2000000@0oooo00070?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`020?ooo`00103oool4000000<0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`004P3ooooo000000/00000103oool0
0001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0625786, \
0.403542, 0.00169867, 0.448922}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot3b3\  = 
        Histogram[fractions3b[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .11659 L
.33333 .11659 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .11659 L
.33333 .11659 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .39957 L
.55556 .39957 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .39957 L
.55556 .39957 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .03735 L
.66667 .03735 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .03735 L
.66667 .03735 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .02603 L
.88889 .02603 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .02603 L
.88889 .02603 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .02603 L
1 .02603 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .02603 L
1 .02603 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06`000?ll000000<0oooo000A0?ooo`030000003oool0
oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000L0?oooal0000070000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o?@00000i0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool0
0`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?oooah000007@000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00
001F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2
000005L0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool3000005H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo0780oooo0`0000030?ooo`001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`<00000EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0LP3oool3000000<0oooo00060?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o
0000o`0K0000oah00000M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3o
ool00`000000003o0000o`0K0000o`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0oooo0`0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000001@3oool000000?ooo`3o
ool0000000@0oooo0`00001F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0S`3o
ool3000000<0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0oooo0P0000030?ooo`8000001@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000
oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000
00000?l0003o01/0003o00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000003oool0oooo0900oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
00000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05L0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`<00000EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo08l0oooo0`00
00030?ooo`00103oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005L0oooo7`00002B0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0o`3o
ool90?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001
\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
71.342, 0.00169256, 0.332285}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot3b, \ xplot3b1, \ xplot3b2, \ 
            xplot3b3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00516319 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11798 -12 -4.5 ]
[-0.0125 .11798 0 4.5 ]
[-0.0125 .22124 -12 -4.5 ]
[-0.0125 .22124 0 4.5 ]
[-0.0125 .32451 -12 -4.5 ]
[-0.0125 .32451 0 4.5 ]
[-0.0125 .42777 -12 -4.5 ]
[-0.0125 .42777 0 4.5 ]
[-0.0125 .53103 -18 -4.5 ]
[-0.0125 .53103 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11798 m
.00625 .11798 L
s
[(20)] -0.0125 .11798 1 0 Mshowa
0 .22124 m
.00625 .22124 L
s
[(40)] -0.0125 .22124 1 0 Mshowa
0 .32451 m
.00625 .32451 L
s
[(60)] -0.0125 .32451 1 0 Mshowa
0 .42777 m
.00625 .42777 L
s
[(80)] -0.0125 .42777 1 0 Mshowa
0 .53103 m
.00625 .53103 L
s
[(100)] -0.0125 .53103 1 0 Mshowa
.125 Mabswid
0 .04053 m
.00375 .04053 L
s
0 .06635 m
.00375 .06635 L
s
0 .09216 m
.00375 .09216 L
s
0 .14379 m
.00375 .14379 L
s
0 .16961 m
.00375 .16961 L
s
0 .19543 m
.00375 .19543 L
s
0 .24706 m
.00375 .24706 L
s
0 .27287 m
.00375 .27287 L
s
0 .29869 m
.00375 .29869 L
s
0 .35032 m
.00375 .35032 L
s
0 .37614 m
.00375 .37614 L
s
0 .40195 m
.00375 .40195 L
s
0 .45359 m
.00375 .45359 L
s
0 .4794 m
.00375 .4794 L
s
0 .50522 m
.00375 .50522 L
s
0 .55685 m
.00375 .55685 L
s
0 .58267 m
.00375 .58267 L
s
0 .60848 m
.00375 .60848 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11798 m
1 .11798 L
s
.99375 .22124 m
1 .22124 L
s
.99375 .32451 m
1 .32451 L
s
.99375 .42777 m
1 .42777 L
s
.99375 .53103 m
1 .53103 L
s
.125 Mabswid
.99625 .04053 m
1 .04053 L
s
.99625 .06635 m
1 .06635 L
s
.99625 .09216 m
1 .09216 L
s
.99625 .14379 m
1 .14379 L
s
.99625 .16961 m
1 .16961 L
s
.99625 .19543 m
1 .19543 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .27287 m
1 .27287 L
s
.99625 .29869 m
1 .29869 L
s
.99625 .35032 m
1 .35032 L
s
.99625 .37614 m
1 .37614 L
s
.99625 .40195 m
1 .40195 L
s
.99625 .45359 m
1 .45359 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .55685 m
1 .55685 L
s
.99625 .58267 m
1 .58267 L
s
.99625 .60848 m
1 .60848 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01988 L
.05556 .01988 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01988 L
.05556 .01988 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .01988 L
.11111 .01988 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .01988 L
.11111 .01988 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .01472 L
.16667 .01472 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .01472 L
.16667 .01472 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .03537 L
.22222 .03537 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .03537 L
.22222 .03537 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .05086 L
.27778 .05086 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .05086 L
.27778 .05086 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .15412 L
.33333 .15412 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .15412 L
.33333 .15412 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .41744 L
.38889 .41744 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .41744 L
.38889 .41744 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .25222 L
.5 .25222 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .25222 L
.5 .25222 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .12314 L
.55556 .12314 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .12314 L
.55556 .12314 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .04053 L
.61111 .04053 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .04053 L
.61111 .04053 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .01988 L
.66667 .01988 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .01988 L
.66667 .01988 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .01472 L
.72222 .01472 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.72222 .01472 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02504 L
.77778 .02504 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02504 L
.77778 .02504 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.83333 .01472 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01988 L
.88889 .01988 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01988 L
.88889 .01988 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01988 L
.94444 .01988 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01988 L
.94444 .01988 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00840863 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -12 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(10)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(20)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(30)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(40)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(50)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(60)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(70)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03153 L
.11111 .03153 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03153 L
.11111 .03153 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .03153 L
.22222 .03153 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03153 L
.22222 .03153 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .16607 L
.33333 .16607 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .16607 L
.33333 .16607 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .08198 L
.55556 .08198 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .08198 L
.55556 .08198 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .03994 L
.66667 .03994 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .03994 L
.66667 .03994 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00840863 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -12 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(10)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(20)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(30)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(40)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(50)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(60)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(70)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .01472 L
.22222 .01472 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .01472 L
.22222 .01472 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .07358 L
.33333 .07358 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .07358 L
.33333 .07358 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .22493 L
.55556 .22493 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .22493 L
.55556 .22493 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .02312 L
.66667 .02312 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .02312 L
.66667 .02312 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .03735 L
.22222 .03735 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .11659 L
.33333 .11659 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .11659 L
.33333 .11659 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .39957 L
.55556 .39957 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .39957 L
.55556 .39957 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .03735 L
.66667 .03735 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .03735 L
.66667 .03735 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03735 L
.77778 .03735 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .02603 L
.88889 .02603 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .02603 L
.88889 .02603 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .02603 L
1 .02603 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .02603 L
1 .02603 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00c`3oool2000000@0oooo
0P0000030?ooo`@000003@3oool2000000@0oooo0P0000040?ooo`8000003P3oool2000000@0oooo
0P0000050?ooo`<00000303oool2000000@0oooo0P0000040?ooo`800000@@3oool2000000@0oooo
0P0000030?ooo`@000003@3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<00000303oool2000000@0oooo0P0000040?ooo`800000?`3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002h0oooo0P00
00040?ooo`8000000`3oool4000000d0oooo0P0000040?ooo`800000103oool2000000l0oooo0P00
00040?ooo`8000001@3oool3000000`0oooo0P0000040?ooo`800000103oool2000003d0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000o0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?@3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo000]0?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo1@00000;0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000;0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3o
ool002d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`D0
00002`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo03X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0
oooo00@000000?ooo`3oool000002@3oool200000400oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3o
ool000002@3oool2000003h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool20000
02`0oooo000]0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000T0oooo0P00000m0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000<0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03d0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0[0?ooo`00;@3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`000000303oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03d0oooo0P00
000:0?ooo`8000003P3oool2000000X0oooo0P00000>0?ooo`8000002`3oool2000000d0oooo0P00
000:0?ooo`<00000@03oool2000000X0oooo0P00000>0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003@3oool2000000X0oooo0`00000n0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000?0?ooo`8000002P3oool3000002/0oooo000^
0?ooo`8000002P3oool2000000h0oooo0P00000:0?ooo`8000003`3oool2000000/0oooo0P00000=
0?ooo`8000002P3oool300000?l0ooooo`3ooolF0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00`P3oool2000000<0ooooP@00000M0?ooo`800000103o
oon0000001`0oooo0P0000030?ooohD000005@3oool00240oooo0P0000030?oooh8000006@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000P0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00@000000?oo
o`3oool000000P3ooon1000001`0oooo00@000000?ooo`3oool000000`3ooon0000001/0oooo00@0
00000?ooo`3oool000000P3ooon5000001D0oooo000P0?ooo`040000003oool0oooo00000080oooo
PP00000I0?ooo`040000003oool0oooo00000080oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06@3oool00`00
00000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`0?0000
02T0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00`0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0
003o00`0003o7P00000E0?ooo`00803oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo00/0oooo2000000L0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3o
oolN000000d0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool09`3oool2000001`0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`00
3000o`000`0000000?l0003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0
6@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`00
0?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00`0003o00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0C0?ooo`00803oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo01<0oooo2000000607moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0603oool2000000<0oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000;0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o000?000002X0oooo00<000000?ooo`3o
ool06`3oool2000000@0oooo00<000000?ooo`3oool06@3oool00`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01X0oooo0P0000030?ooo`8000003@3oool@000000d0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000oal000006`3oool2000001D0oooo000Q0?ooo`800000
0`3oool2000001/0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo2000000a0?ooo`030000003oool0oooo01d0oooo0P00000K0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003oool0oooo03D0oooo0P00000S0?ooo`030000003oool0oooo01T0oooo00<00000003o0000o`00
2`00o`000`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0J0?ooo`P000001P1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000;0?l000030000003oool0oooo03H0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0I0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000
o`000`0000000?l0003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`8000006`3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0e0?ooo`8000008`3oool00`000000oooo0?ooo`0I0?ooo`0300000000o`00
0?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0
oooo03D0oooo00<000000?ooo`3oool07`3oool2000001`0oooo00<000000000o`000?l02`000?l0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2
000001D0oooo000V0?ooo`8000008P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01T0oooo3`00000>003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01d0
oooo0P00000K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o000?000003L0
oooo0P00000S0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000
003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo
00<000000?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0D0?ooo`D000000P3oool2000000@0oooo
00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l0
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`800000703oool00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo
0?ooo`0g0?ooo`8000005@3oool002H0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000L0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000:@3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0oooo00<00000
0000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`009P3oool200000280oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000K
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`13
0?ooo`800000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
0P00000X0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo
0?ooo`0d0?ooo`8000008@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool001X0oooo100000030?ooo`8000000`3oool00`000000oooo0?oo
o`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000001`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l00003
0000003oool0oooo04@0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`0300000000o`000?l000`00?l000<00000
003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo0P00000L
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`006P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000001/0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo04<0oooo0P00
000H0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002T0
oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo03D0
oooo00<000000?ooo`3oool04`3oool500000080oooo0P0000030?ooo`030000003oool0oooo01/0
oooo3`00000>0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo0P00000R0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
oooo0?ooo`0e0?ooo`800000503oool2000000@0oooo0P0000030?ooo`030000003oool0oooo01X0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo03D0
oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000:`3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`00703oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000008`3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`P00000>03o
ool00`000000oooo0?ooo`0M0?ooo`8000006`3oool00`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0@`3oool2000002<0oooo00<000000?ooo`3oool09`3o
ool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`02000002X0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo03L0oooo0P00000E0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o0003
00000000o`000?l000/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0E0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000[0?ooo`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01<0oooo000K0?ooo`800000103oool2000000<0oooo0P00000R0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0M0?ooo`8000006`3oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0@`3oool20000
02<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l0
00/00?l000<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00000[0?ooo`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000;
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool0503oool2000000@0oooo0P000003
0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0=`3oool2000001D0oooo000V0?ooo`030000003oool0oooo0240oooo2000000607mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0140oooo100000030?ooo`8000000`3oool2000001/0oooo3`00000=0?l0
00030000003oool0oooo04<0oooo0P00000F0?ooo`@000000`3oool2000000@0oooo00<000000?oo
o`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02P0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`140?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`800000:@3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`800000:@3oool00`000000o`000?l0000;0?l000030000003oool0oooo04<0oooo0P00000G
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2000002P0oooo00<0
0000003o0000o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo03@0oooo0P00
000Q0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0=`3oool2000001D0oooo000V0?ooo`030000003oool0oooo02P0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000Z0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000002T0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o
00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?oo
o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`13
0?ooo`8000005P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l0
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool002H0oooo0P00000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02P0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01D0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo0P00
000Z0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0g0?ooo`8000005@3oool001`0oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`0X
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X
0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo000M0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000:P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01d0oooo0P00
000Y0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0@`3oool2000002<0oooo00<0
00000?ooo`3oool09`3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool001X0oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00
000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000003oool0oooo03`0oooo0P00000O0?ooo`030000003oool0oooo02P0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool09`3oool00`0000000?l0003o000<003o00l00000=`3oool00`000000oooo0?oo
o`0O0?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000?ooo`3oool0=`3oool2000001D0oooo000J0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03d0oooo
00<000000?ooo`3oool07@3oool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo
0?ooo`130?ooo`8000008`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l0
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0C0?ooo`@000000`3oool2000000<0oooo
00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:03oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000o`00
0?l0000;0?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000L0?ooo`8000000`3oool2000000<0oooo
00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo
0P0000040?ooo`8000000`3oool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo
0?ooo`130?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02L0oooo
00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000:P3oool00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0
oooo000V0?ooo`800000:@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
2000000o0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000
o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002/0oooo00<000000000o`000?l030000?l00`000000
003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`02000002T0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`130?ooo`800000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool0oooo0P00000X0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@P3oool2
000001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0:03o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000:P3oool00`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000:@3oool0
0`0000000?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool0503oool2
000000@0oooo0P0000030?ooo`800000:P3oool00`000000003o0000o`0<0000o`03000000000?l0
003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000V0?ooo`800000:@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`130?ooo`8000005P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`00
0?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000
003oool0oooo02P0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000
003oool0oooo01D0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0W0?ooo`030000
0000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0:03o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0M0?ooo`800000:@3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo04<0oooo0P00000S0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000
o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`0300000000
0?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3o
ool002H0oooo0P00000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool0
0`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`800000:@3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo04<0oooo0P00000S0?ooo`030000003oool0oooo
02L0oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o
00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`006P3oool3000000@0
oooo0P0000030?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0X0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`000000
oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`03000000000?l0003o00`0
003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool001X0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02P0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo
04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
02L0oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o
00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`006P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P00000Y0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`130?ooo`8000005@3oool3
00000080oooo0P0000030?ooo`800000:@3oool00`000000o`000?l0000;0?l000030000003oool0
oooo04<0oooo0P00000H0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3oool09`3oool0
0`0000000?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000J0?ooo`<000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002X0oooo00<000000?l0003o0000
2`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool0000002T0oooo00<00000003o0000o`003000o`000`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo0P00000Z0?ooo`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`8000005@3oool001/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02P0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo
04@0oooo00<000000?ooo`3oool04@3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool2
000002T0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`130?ooo`8000005P3oool5
000000050?ooo`000000oooo0?ooo`0000000`3oool2000002P0oooo00<00000003o0000o`003000
o`000`000000oooo0?ooo`120?ooo`8000005P3oool2000000@0oooo0P0000030?ooo`030000003o
ool0oooo02T0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool04`3oool001/0oooo0`0000030?ooo`8000000`3oool2
000002T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo04@0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0:03oool00`000000o`000?l0000;0?l000030000
003oool0oooo04@0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o
00030000003oool0oooo04<0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`800000:@3oool00`000000o`000?l0
000;0?l000030000003oool0oooo04<0oooo0P00000G0?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l0
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`02000002X0oooo00<000000000o`000?l030000?l00`000000
003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`009P3oool00`000000oooo
0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`140?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`8000000`3oool00`000000oooo
0?ooo`0X0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0F0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool09`3oool00`0000000?l0
003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool002H0
oooo0P00000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo0P00000Y0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0@`3oool2000002<0oooo00<000000?ooo`3oool09`3oool00`000000
0?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool04`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l0000;0?l000030000003oool0oooo
04@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l0
00`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`800000103oool20000
00<0oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0g0?ooo`8000005@3oool002H0oooo00<000000?ooo`3oool0:03oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0M0?ooo`800000:@3oool00`000000o`000?l0000;0?l000030000003oool0oooo04<0
oooo0P00000S0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`000000
oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:03oool00`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l0
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02T0oooo
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03P0oooo
00<000000?ooo`3oool04`3oool002H0oooo0P00000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo0P00
00040?ooo`8000000`3oool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo0?oo
o`130?ooo`8000005`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02L0oooo00<0
0000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo0P00
000Z0?ooo`03000000000?l0003o00`0003o3`00000i0?ooo`8000005@3oool001/0oooo0P000004
0?ooo`8000000`3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
02L0oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo
04H0oooo00<000000?ooo`3oool04`3oool001X0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo2000000707moO`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00800000:@3oool00`000000o`000?l0000;0?l000030000003oool0oooo04<0oooo0P00
000I0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P00000X0?ooo`03
00000000o`000?l000`00?l000<000000?ooo`3oool0@P3oool200000240oooo00<000000?ooo`3o
ool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool04`3oool001X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`800000<03oool00`000000Ogmo07moO`0507moO`030000003oool0oooo04<0oooo0P00000D0?oo
o`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01D0oooo0P000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o
000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool07`3oool2000002X0oooo00<0
00000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`8000005@3oool001/0oooo0P000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07mo
O`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo0P00000Y0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool0@`3oool2000001L0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`003000o`000`000000
oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000
003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool001X0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02l0oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0180oooo0`0000030?ooo`8000000`3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0E0?ooo`<000000`3oool20000
00@0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo
04<0oooo00<000000?ooo`3oool07`3oool2000002X0oooo00<000000000o`000?l030000?l00`00
0000oooo0?ooo`150?ooo`8000005@3oool001/0oooo0P0000040?ooo`8000000`3oool200000300
oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0:03oool00`000000o`000?l0000;0?l000030000003oool0oooo04@0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`0
0?l000<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool2000000<0
oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo
07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool2000002T0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`130?ooo`8000008`3oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0F0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`00
0000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507moO`030000003oool0oooo04@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01<0
oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00000Z0?ooo`03000000000?l0003o
00`0003o00<000000?ooo`3oool0A@3oool2000001D0oooo000V0?ooo`030000003oool0oooo02l0
oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0
oooo0P00000Y0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0@`3oool2000002<0
oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo04<0
oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0
oooo04H0oooo00<000000?ooo`3oool04`3oool002H0oooo0P00000`0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
02P0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo
04<0oooo00<000000?ooo`3oool0503oool00`000000oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0
oooo04H0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0;`3oool00`00
0000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool30000
00@0oooo0P0000030?ooo`800000:@3oool00`000000o`000?l0000;0?l000030000003oool0oooo
04<0oooo0P00000F0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`00
00000?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool05@3oool20000
00<0oooo0P0000030?ooo`800000:P3oool00`000000003o0000o`0<0000o`030000003oool0oooo
04D0oooo0P00000E0?ooo`009P3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00D0
Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0D0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`030000
0000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01<0oooo000V0?ooo`800000<03oool00`000000Ogmo07moO`0507moO`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo0P00000Y0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0@`3oool2000001H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`800000:03oool00`0000000?l0003o000<003o00030000003oool0oooo0480oooo0P00000Q
0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01<0oooo000D0?ooo`D000000P3oool2000000@0oooo0P0000030?oo
o`030000003oool0oooo02l0oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0140oooo0`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0:03oool00`000000o`000?l0000;0?l000030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0O0?ooo`800000:P3oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00
000E0?ooo`005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000a0?ooo`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool2000002T0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`130?oo
o`8000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo04<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`005P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0200000300oooo00<0
000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`130?ooo`800000503oool3000000<0oooo0P00
00030?ooo`030000003oool0oooo02P0oooo00<000000?l0003o00002`3o00000`000000oooo0?oo
o`140?ooo`030000003oool0oooo01D0oooo0`0000030?ooo`800000103oool00`000000oooo0?oo
o`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01<0oooo000F0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000340oooo00<0000007moO`1o
Ogl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo0P00000Y0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool0@`3oool2000002<0oooo00<000000?ooo`3o
ool09`3oool00`0000000?l0003o000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3o
ool07`3oool2000002X0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`150?ooo`80
00005@3oool001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000<@3oool00`000000Ogmo07moO`0507moO`030000003oool0
oooo04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo02L0oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0
oooo04H0oooo00<000000?ooo`3oool04`3oool001D0oooo0P0000040?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507moO`030000003oool0oooo
04@0oooo00<000000?ooo`3oool07@3oool2000002T0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`130?ooo`8000008`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l0
00`00?l000<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02T0oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01<0oooo000V0?ooo`800000<03oool00`000000Ogmo07moO`0507moO`030000003oool0oooo04@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0
oooo00<00000003o0000o`003000o`000`000000oooo0?ooo`130?ooo`030000003oool0oooo01l0
oooo0P00000Z0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool2000001D0
oooo000V0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000o`00
0?l0000;0?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0D0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000003o
0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool2000002T0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`130?ooo`800000603oool00`000000oooo0?oo
o`020?ooo`800000103oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000`00?l000<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0
003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`009P3oool200000300oooo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002X0oooo00<000000?l0
003o00002`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000:@3oool00`0000000?l0003o
000<003o00030000003oool0oooo04<0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00800000:P3oool00`000000003o0000o`0<0000o`030000
003oool0oooo04D0oooo0P00000E0?ooo`009P3oool00`000000oooo0?ooo`0_0?ooo`030000001o
Ogl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0C0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000002T0oooo3`0000150?ooo`800000
603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000X0?oo
oa000000A03oool2000001H0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507mo
O`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<0000
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool002H0oooo0P00000`0?ooo`T0
0000AP3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3ooon1000001H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?oooh0000005P3oool3000000<0oooo0P0000030?ooo`800000:P3oool@000004L0oooo
0P00000E0?ooo`009P3ooon2000001<0oooo100000030?ooo`800000VP3oool4000000<0oooo0P00
002U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0C0?ooo`00o`3ooooo0?ooo`h0ooooQ@00000E0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {432.75, 355.813}} -> {-0.331812, \
2.77743, 0.00627702, 0.00627702}, {{42.25, 160.813}, {430.875, 357.625}} -> \
{-0.103665, 646.968, 0.00350274, 1.50757}, {{172.688, 291.25}, {430.875, \
357.625}} -> {-0.678252, 403.395, 0.00355, 0.938189}, {{303.063, 421.625}, \
{430.875, 357.625}} -> {-1.25679, 403.395, 0.00355, 0.938189}, {{433.5, \
552.063}, {430.875, 357.625}} -> {-1.76514, 290.023, 0.00343669, 0.674695}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions3b]\)], "Input"],

Cell[BoxData[
    \({0.3187339028706865`, 0.33430926854924015`, 
      0.3469568285800733`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions3b]]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333333`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions3b]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0016035963471518466`, 
      StandardDeviation \[Rule] 0.04004492910659035`, 
      SampleRange \[Rule] 0.4018311291963378`, 
      MeanDeviation \[Rule] 0.026227952661678534`, 
      MedianDeviation \[Rule] 0.01764189584552367`, 
      QuartileDeviation \[Rule] 0.017579485118164817`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats3b\  = \ 
        Map[DispersionReport, fractions3b]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats3b]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0013131585784993168`\), \(Variance \[Rule] 
              0.0006609638439510382`\), \(Variance \[Rule] 
              0.0024644956597525036`\)},
          {\(StandardDeviation \[Rule] 
              0.03623752997238246`\), \(StandardDeviation \[Rule] 
              0.02570921710109116`\), \(StandardDeviation \[Rule] 
              0.04964368700804266`\)},
          {\(SampleRange \[Rule] 0.2446497212519593`\), \(SampleRange \[Rule] 
              0.15012676950481035`\), \(SampleRange \[Rule] 
              0.3331407621215544`\)},
          {\(MeanDeviation \[Rule] 
              0.024558282651832183`\), \(MeanDeviation \[Rule] 
              0.019388129227884576`\), \(MeanDeviation \[Rule] 
              0.03357130223908317`\)},
          {\(MedianDeviation \[Rule] 
              0.01661471244312518`\), \(MedianDeviation \[Rule] 
              0.015521662684806037`\), \(MedianDeviation \[Rule] 
              0.02265060240963851`\)},
          {\(QuartileDeviation \[Rule] 
              0.017670134025842554`\), \(QuartileDeviation \[Rule] 
              0.015564041570171938`\), \(QuartileDeviation \[Rule] 
              0.022838927622814142`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3; Rosen 1989", "Subsection"],

Cell[CellGroupData[{

Cell["corrected timing data", "Subsubsection"],

Cell[BoxData[{
    \(\(beats4cor\  = \ 
        Drop[RotateLeft[pid52932x05corrected, \ 1]\  - \ 
            pid52932x05corrected, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats4cor\  = \ Drop[beats4cor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure4durs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats4cor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata4\  = \ 
        Transpose[{measure4durs, 
            Partition[beats4cor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions4\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ newdata4]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot4\  = \ 
        Histogram[Flatten[fractions4], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .04867 L
.11111 .04867 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .04867 L
.11111 .04867 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .11659 L
.16667 .11659 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .11659 L
.16667 .11659 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .20714 L
.22222 .20714 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .20714 L
.22222 .20714 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .21846 L
.27778 .21846 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .21846 L
.27778 .21846 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .5354 L
.33333 .5354 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .5354 L
.33333 .5354 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .55804 L
.44444 .55804 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .55804 L
.44444 .55804 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .52408 L
.5 .52408 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .52408 L
.5 .52408 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .32034 L
.55556 .32034 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .32034 L
.55556 .32034 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .21846 L
.61111 .21846 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .21846 L
.61111 .21846 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .17319 L
.66667 .17319 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .17319 L
.66667 .17319 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .10527 L
.72222 .10527 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .10527 L
.72222 .10527 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .04867 L
.77778 .04867 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .04867 L
.77778 .04867 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .02603 L
.83333 .02603 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .02603 L
.83333 .02603 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
003oool0oooo02X0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003o
ool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl?000002`0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0
oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0303oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000=0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0=`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00`0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo00`0oooo4000000>07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo4000000j
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000001`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo04H0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`160?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`170?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moOa000000B03oool2000000<0oooo000A0?ooo`030000003oool0oooo
01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo
4000000>07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2000000D0oooo00<0
00000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo0005
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000002X0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0E03oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0Z
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000002/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000[0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl@000005L0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0Z
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000[0?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1T0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02X0oooo
4000000=07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oo
o`l000003P1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moOa000000IP3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`0000170?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1b0?ooo`<000000`3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`17
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1c0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl?000007H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`<00000A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0800oooo0`00
00030?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`220?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0840oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000004P0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0
oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00050?ooo`<000000P3o
ool2000000D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0880oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00030?ooo`D0000000D0oooo
0000003oool0oooo000000040?ooo`<00000A`3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0800oooo0`0000030?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0880oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00050?ooo`8000000`3o
ool2000000D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0880oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moOa000000Q03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000B03oool@000000h0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001G0?ooo`030000001oOgl0Ogmo00`0Ogmo4000002B0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0:00
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo
07moO`0<07moO`030000003oool0oooo0:00oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`01
0?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`<00000EP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo09h0oooo0`00
00030?ooo`00103oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0X03oool00`000000oooo0?oo
o`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool00@3oool000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1F
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0X03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005L0oooo4000002Q0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0o`3o
ool90?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001
\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {455.063, 313.75}} -> {0.0636924, \
124.923, 0.00169256, 0.332285}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot41\  = 
        Histogram[fractions4[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0202967 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -6 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(5)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(10)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(15)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(20)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(25)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .07561 L
.11111 .07561 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .07561 L
.11111 .07561 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .33946 L
.22222 .33946 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .33946 L
.22222 .33946 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .48154 L
.33333 .48154 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .48154 L
.33333 .48154 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .40035 L
.55556 .40035 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .40035 L
.55556 .40035 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .19739 L
.66667 .19739 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .19739 L
.66667 .19739 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .0959 L
.77778 .0959 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0959 L
.77778 .0959 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o0000o`00
01/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03P0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0g0?ooo`80
00000`3oool00140oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0
oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00006`3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?oooal000007@3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0=`3oool2000000<0
oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l001l00000>@3oool2000000<0oooo000A0?ooo`030000
003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3o
ool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`00303oool00`000000oooo0?ooo`020?ooo`<000006`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0E03oool3000000<0
oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo
000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000703oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
703oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
7`00001G0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`80
00001@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000001/0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3o
ool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00000K0?oo
o`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo01/0oooo00<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000703ooolO000001`0o`0000<000000?l0003o00006`3o00000`00
0000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1c0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000003X0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l001h00000
M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool40000
00<0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`<00000>@3oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0S`3oool3000000<0oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000>P3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oooah000007@3o
00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`@00000
0`3oool2000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000005H0oooo00<000000?l0003o00006`3o
00000`000000oooo0?ooo`2?0?ooo`<000000`3oool000D0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool30000
00@0oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
0P00001G0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T03oool2000000<0oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000
o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K
0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l00003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oooal00000TP3oool2
000000<0oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.161752, 0.00169256, 0.185313}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot42\  = 
        Histogram[fractions4[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0159082 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09426 -6 -4.5 ]
[-0.0125 .09426 0 4.5 ]
[-0.0125 .1738 -12 -4.5 ]
[-0.0125 .1738 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .33288 -12 -4.5 ]
[-0.0125 .33288 0 4.5 ]
[-0.0125 .41242 -12 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .5715 -12 -4.5 ]
[-0.0125 .5715 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09426 m
.00625 .09426 L
s
[(5)] -0.0125 .09426 1 0 Mshowa
0 .1738 m
.00625 .1738 L
s
[(10)] -0.0125 .1738 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(15)] -0.0125 .25334 1 0 Mshowa
0 .33288 m
.00625 .33288 L
s
[(20)] -0.0125 .33288 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(25)] -0.0125 .41242 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(30)] -0.0125 .49196 1 0 Mshowa
0 .5715 m
.00625 .5715 L
s
[(35)] -0.0125 .5715 1 0 Mshowa
.125 Mabswid
0 .03062 m
.00375 .03062 L
s
0 .04653 m
.00375 .04653 L
s
0 .06244 m
.00375 .06244 L
s
0 .07835 m
.00375 .07835 L
s
0 .11016 m
.00375 .11016 L
s
0 .12607 m
.00375 .12607 L
s
0 .14198 m
.00375 .14198 L
s
0 .15789 m
.00375 .15789 L
s
0 .18971 m
.00375 .18971 L
s
0 .20561 m
.00375 .20561 L
s
0 .22152 m
.00375 .22152 L
s
0 .23743 m
.00375 .23743 L
s
0 .26925 m
.00375 .26925 L
s
0 .28515 m
.00375 .28515 L
s
0 .30106 m
.00375 .30106 L
s
0 .31697 m
.00375 .31697 L
s
0 .34879 m
.00375 .34879 L
s
0 .3647 m
.00375 .3647 L
s
0 .3806 m
.00375 .3806 L
s
0 .39651 m
.00375 .39651 L
s
0 .42833 m
.00375 .42833 L
s
0 .44424 m
.00375 .44424 L
s
0 .46014 m
.00375 .46014 L
s
0 .47605 m
.00375 .47605 L
s
0 .50787 m
.00375 .50787 L
s
0 .52378 m
.00375 .52378 L
s
0 .53969 m
.00375 .53969 L
s
0 .55559 m
.00375 .55559 L
s
0 .58741 m
.00375 .58741 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09426 m
1 .09426 L
s
.99375 .1738 m
1 .1738 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .33288 m
1 .33288 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .5715 m
1 .5715 L
s
.125 Mabswid
.99625 .03062 m
1 .03062 L
s
.99625 .04653 m
1 .04653 L
s
.99625 .06244 m
1 .06244 L
s
.99625 .07835 m
1 .07835 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .14198 m
1 .14198 L
s
.99625 .15789 m
1 .15789 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22152 m
1 .22152 L
s
.99625 .23743 m
1 .23743 L
s
.99625 .26925 m
1 .26925 L
s
.99625 .28515 m
1 .28515 L
s
.99625 .30106 m
1 .30106 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .34879 m
1 .34879 L
s
.99625 .3647 m
1 .3647 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .39651 m
1 .39651 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .44424 m
1 .44424 L
s
.99625 .46014 m
1 .46014 L
s
.99625 .47605 m
1 .47605 L
s
.99625 .50787 m
1 .50787 L
s
.99625 .52378 m
1 .52378 L
s
.99625 .53969 m
1 .53969 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .07835 L
.22222 .07835 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .07835 L
.22222 .07835 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .28515 L
.33333 .28515 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .28515 L
.33333 .28515 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .53969 L
.55556 .53969 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .53969 L
.55556 .53969 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .14198 L
.66667 .14198 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .14198 L
.66667 .14198 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .07835 L
.77778 .07835 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .07835 L
.77778 .07835 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6`00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`0300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000K003o00030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`0300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000K003o00030000003oool0
oooo03L0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000K003o00030000003oool0oooo
03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006`00o`000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001/00?l0
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001/00?l000<0
00000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000
003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001/00?l000<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000K003o
00030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool06`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo01/0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001/00?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000001`0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001/00?l000<000000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0
oooo01/0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001/00?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000K003o00030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/0
0?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000703ooolO000001`00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o000300000000o`000?l001/00?l07`00000i0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00090?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K
003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000`0oooo00<000000?oo
o`3oool00P3oool3000003T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1D0?oo
o`<000000`3oool000X0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0`0000040?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0
oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l0
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o
00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o01l00000E`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2000000D0oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000003T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0LP3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000003X0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo00030?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0`00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0`0000030?ooo`001@3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`0300000000
o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo
03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool2000003X0oooo7P00000M003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool20000
00<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0oooo0P0000050?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000
EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
LP3oool3000000<0oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J
003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
00000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000E`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000
o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3o
ool4000000<0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`<00000EP3oool00`0000000?l0003o000K003o000300000000o`00
0?l001X00?l000<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`<00000103oool00`000000
oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J
003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oo
o`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
00000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo0`00001F0?ooo`0300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1b0?ooo`<000000`3oool000H0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/0
0?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000E`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/0
0?l07P00001e0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0
003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?oo
o`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool3000005H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2?0?ooo`<00000
0`3oool000H0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000E`3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
00000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000005L0oooo7`00002B0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0o`3oool90?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
50.7626, 0.00169256, 0.236434}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot43\  = 
        Histogram[fractions4[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0173119 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -6 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -12 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -12 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -12 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(10)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(15)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(20)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(25)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(30)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .11859 L
.22222 .11859 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .11859 L
.22222 .11859 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .4302 L
.33333 .4302 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .4302 L
.33333 .4302 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .36095 L
.55556 .36095 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .36095 L
.55556 .36095 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .27439 L
.66667 .27439 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .27439 L
.66667 .27439 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .06665 L
.77778 .06665 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .06665 L
.77778 .06665 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .03203 L
.88889 .03203 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03203 L
.88889 .03203 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000oah00000703oool2
000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0
003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`004@3oool2
000001`0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000oal00000>@3oool2
000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0E@3oool2000000<0oooo000A
0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<000000?ooo`3o
ool06`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000`0oooo00<000000?ooo`3oool0
0P3oool3000001/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
003oool0oooo05@0oooo0`0000030?ooo`002P3oool2000000D0oooo00<000000?ooo`3oool06`3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0`0000040?ooo`030000003oool0oooo
01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo
05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?oooal0000070000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3o
ool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05D0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool3000003T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`1D0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oo
o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`030000003oool0oooo05D0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1E
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00
000i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000oal00000EP3oool3000000<0oooo00050?ooo`030000003oool0oooo0080oooo0P000005
0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`80
0000103oool3000000@0oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
>P3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o
0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo0003
0?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`<00000>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o7P00001d
0?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3o
ool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0
oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0T03oool20000
00<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3ooolN000001d0003o00<00000
0?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool3000005H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2?0?ooo`<000000`3o
ool000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0EP3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo00040?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o
00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`80
0000E`3oool00`000000003o0000o`0K0000o`030000003oool0oooo0900oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o
01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0
oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`<00000EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo08l0oooo
0`0000030?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T03oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000003o
ool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0
003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000o`000?l06`000?l00`000000oooo0?oo
o`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K
0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?oooal00000TP3oool2000000<0oooo000A0?ooo`030000003oool0
oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00140ooooo`00000=000000<0
oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0636924, \
93.1036, 0.00169256, 0.217263}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot4, \ xplot41, \ xplot42, \ 
            xplot43}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0113193 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12791 -12 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(10)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(20)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(30)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(40)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(50)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .2411 m
1 .2411 L
s
.99375 .35429 m
1 .35429 L
s
.99375 .46749 m
1 .46749 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .03735 m
1 .03735 L
s
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .21846 m
1 .21846 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .39957 m
1 .39957 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .49013 m
1 .49013 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .04867 L
.11111 .04867 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .04867 L
.11111 .04867 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .11659 L
.16667 .11659 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .11659 L
.16667 .11659 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .20714 L
.22222 .20714 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .20714 L
.22222 .20714 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .21846 L
.27778 .21846 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .21846 L
.27778 .21846 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .5354 L
.33333 .5354 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .5354 L
.33333 .5354 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.38889 .60332 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .55804 L
.44444 .55804 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .55804 L
.44444 .55804 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .52408 L
.5 .52408 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .52408 L
.5 .52408 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .32034 L
.55556 .32034 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .32034 L
.55556 .32034 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .21846 L
.61111 .21846 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .21846 L
.61111 .21846 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .17319 L
.66667 .17319 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .17319 L
.66667 .17319 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .10527 L
.72222 .10527 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .10527 L
.72222 .10527 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .04867 L
.77778 .04867 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .04867 L
.77778 .04867 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .02603 L
.83333 .02603 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .02603 L
.83333 .02603 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0202967 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -6 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(5)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(10)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(15)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(20)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(25)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .07561 L
.11111 .07561 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .07561 L
.11111 .07561 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .33946 L
.22222 .33946 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .33946 L
.22222 .33946 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .48154 L
.33333 .48154 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .48154 L
.33333 .48154 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .40035 L
.55556 .40035 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .40035 L
.55556 .40035 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .19739 L
.66667 .19739 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .19739 L
.66667 .19739 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .0959 L
.77778 .0959 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .0959 L
.77778 .0959 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0159082 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09426 -6 -4.5 ]
[-0.0125 .09426 0 4.5 ]
[-0.0125 .1738 -12 -4.5 ]
[-0.0125 .1738 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .33288 -12 -4.5 ]
[-0.0125 .33288 0 4.5 ]
[-0.0125 .41242 -12 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .5715 -12 -4.5 ]
[-0.0125 .5715 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09426 m
.00625 .09426 L
s
[(5)] -0.0125 .09426 1 0 Mshowa
0 .1738 m
.00625 .1738 L
s
[(10)] -0.0125 .1738 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(15)] -0.0125 .25334 1 0 Mshowa
0 .33288 m
.00625 .33288 L
s
[(20)] -0.0125 .33288 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(25)] -0.0125 .41242 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(30)] -0.0125 .49196 1 0 Mshowa
0 .5715 m
.00625 .5715 L
s
[(35)] -0.0125 .5715 1 0 Mshowa
.125 Mabswid
0 .03062 m
.00375 .03062 L
s
0 .04653 m
.00375 .04653 L
s
0 .06244 m
.00375 .06244 L
s
0 .07835 m
.00375 .07835 L
s
0 .11016 m
.00375 .11016 L
s
0 .12607 m
.00375 .12607 L
s
0 .14198 m
.00375 .14198 L
s
0 .15789 m
.00375 .15789 L
s
0 .18971 m
.00375 .18971 L
s
0 .20561 m
.00375 .20561 L
s
0 .22152 m
.00375 .22152 L
s
0 .23743 m
.00375 .23743 L
s
0 .26925 m
.00375 .26925 L
s
0 .28515 m
.00375 .28515 L
s
0 .30106 m
.00375 .30106 L
s
0 .31697 m
.00375 .31697 L
s
0 .34879 m
.00375 .34879 L
s
0 .3647 m
.00375 .3647 L
s
0 .3806 m
.00375 .3806 L
s
0 .39651 m
.00375 .39651 L
s
0 .42833 m
.00375 .42833 L
s
0 .44424 m
.00375 .44424 L
s
0 .46014 m
.00375 .46014 L
s
0 .47605 m
.00375 .47605 L
s
0 .50787 m
.00375 .50787 L
s
0 .52378 m
.00375 .52378 L
s
0 .53969 m
.00375 .53969 L
s
0 .55559 m
.00375 .55559 L
s
0 .58741 m
.00375 .58741 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09426 m
1 .09426 L
s
.99375 .1738 m
1 .1738 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .33288 m
1 .33288 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .5715 m
1 .5715 L
s
.125 Mabswid
.99625 .03062 m
1 .03062 L
s
.99625 .04653 m
1 .04653 L
s
.99625 .06244 m
1 .06244 L
s
.99625 .07835 m
1 .07835 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .14198 m
1 .14198 L
s
.99625 .15789 m
1 .15789 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22152 m
1 .22152 L
s
.99625 .23743 m
1 .23743 L
s
.99625 .26925 m
1 .26925 L
s
.99625 .28515 m
1 .28515 L
s
.99625 .30106 m
1 .30106 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .34879 m
1 .34879 L
s
.99625 .3647 m
1 .3647 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .39651 m
1 .39651 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .44424 m
1 .44424 L
s
.99625 .46014 m
1 .46014 L
s
.99625 .47605 m
1 .47605 L
s
.99625 .50787 m
1 .50787 L
s
.99625 .52378 m
1 .52378 L
s
.99625 .53969 m
1 .53969 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .07835 L
.22222 .07835 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .07835 L
.22222 .07835 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .28515 L
.33333 .28515 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .28515 L
.33333 .28515 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .53969 L
.55556 .53969 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .53969 L
.55556 .53969 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .14198 L
.66667 .14198 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .14198 L
.66667 .14198 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .07835 L
.77778 .07835 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .07835 L
.77778 .07835 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0173119 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10127 -6 -4.5 ]
[-0.0125 .10127 0 4.5 ]
[-0.0125 .18783 -12 -4.5 ]
[-0.0125 .18783 0 4.5 ]
[-0.0125 .27439 -12 -4.5 ]
[-0.0125 .27439 0 4.5 ]
[-0.0125 .36095 -12 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .44751 -12 -4.5 ]
[-0.0125 .44751 0 4.5 ]
[-0.0125 .53407 -12 -4.5 ]
[-0.0125 .53407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10127 m
.00625 .10127 L
s
[(5)] -0.0125 .10127 1 0 Mshowa
0 .18783 m
.00625 .18783 L
s
[(10)] -0.0125 .18783 1 0 Mshowa
0 .27439 m
.00625 .27439 L
s
[(15)] -0.0125 .27439 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(20)] -0.0125 .36095 1 0 Mshowa
0 .44751 m
.00625 .44751 L
s
[(25)] -0.0125 .44751 1 0 Mshowa
0 .53407 m
.00625 .53407 L
s
[(30)] -0.0125 .53407 1 0 Mshowa
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .04934 m
.00375 .04934 L
s
0 .06665 m
.00375 .06665 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .1359 m
.00375 .1359 L
s
0 .15321 m
.00375 .15321 L
s
0 .17052 m
.00375 .17052 L
s
0 .20515 m
.00375 .20515 L
s
0 .22246 m
.00375 .22246 L
s
0 .23977 m
.00375 .23977 L
s
0 .25708 m
.00375 .25708 L
s
0 .29171 m
.00375 .29171 L
s
0 .30902 m
.00375 .30902 L
s
0 .32633 m
.00375 .32633 L
s
0 .34364 m
.00375 .34364 L
s
0 .37826 m
.00375 .37826 L
s
0 .39558 m
.00375 .39558 L
s
0 .41289 m
.00375 .41289 L
s
0 .4302 m
.00375 .4302 L
s
0 .46482 m
.00375 .46482 L
s
0 .48214 m
.00375 .48214 L
s
0 .49945 m
.00375 .49945 L
s
0 .51676 m
.00375 .51676 L
s
0 .55138 m
.00375 .55138 L
s
0 .5687 m
.00375 .5687 L
s
0 .58601 m
.00375 .58601 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10127 m
1 .10127 L
s
.99375 .18783 m
1 .18783 L
s
.99375 .27439 m
1 .27439 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .44751 m
1 .44751 L
s
.99375 .53407 m
1 .53407 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .06665 m
1 .06665 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .15321 m
1 .15321 L
s
.99625 .17052 m
1 .17052 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .23977 m
1 .23977 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .29171 m
1 .29171 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .37826 m
1 .37826 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .41289 m
1 .41289 L
s
.99625 .4302 m
1 .4302 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .51676 m
1 .51676 L
s
.99625 .55138 m
1 .55138 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .58601 m
1 .58601 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .11859 L
.22222 .11859 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .11859 L
.22222 .11859 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .4302 L
.33333 .4302 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .4302 L
.33333 .4302 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .36095 L
.55556 .36095 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .36095 L
.55556 .36095 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .27439 L
.66667 .27439 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .27439 L
.66667 .27439 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .06665 L
.77778 .06665 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .06665 L
.77778 .06665 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .03203 L
.88889 .03203 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03203 L
.88889 .03203 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;03oool002T0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000l0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool002T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002`0oooo000Y0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:`3oool002X0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?@3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000m0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003d0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000:`3oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00703oool2000000@0ooooQ000000J0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`006`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool001/0oooo00@000000?ooo`3oool000000`3ooon5000001P0
oooo00@000000?ooo`3oool000000P3ooon5000001P0oooo00@000000?ooo`3oool000000`3ooon5
000001P0oooo00@000000?ooo`3oool000000P3ooon5000001D0oooo000K0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`T00000503o
ool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo00<000000?l0003o0000
303o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
303o00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0<0?ooo`0300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`003000o`000`0000000?l0003o000;003o00030000003oool0oooo01X0oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0oooo00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo000K0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`000002
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool00`0000000?l0003o
000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o
000<003o000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool2000000d0oooo
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00`0003o
3`00000=0?ooo`8000005@3oool001`0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo0P00
00030?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool06@3oool2000001T0oooo0P00
00040?ooo`030000003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o
000<003o000300000000o`000?l000/00?l000<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0H0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00`0003o00<0
00000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<0
00000000o`000?l030000?l00`000000003o0000o`0<0000o`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0103oool9000000H0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl8000001`0oooo00<000000?ooo`3oool07@3oool00`000000o`000?l0000<
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000<
0?l000030000003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<00000003o0000o`003000o`000`0000000?l0003o000;
003o00030000003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0<
0000o`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?oo
o`3oool0303oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003o0000o`0000`0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000`0o`0000<000000?oo
o`3oool06@3oool2000001l0oooo00<000000?ooo`3oool0303oool00`0000000?l0003o000;003o
000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o
000300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01d0oooo0P00000=0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0<0000o`030000003oool0oooo01T0oooo0P00000E0?oo
o`008P3oool00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
0000303o00000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`002`00o`000`0000000?l0003o000<003o000300000000o`000?l000`00?l000<00000003o0000
o`002`00o`000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`00
0?l030000?l00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000o`000?l0000<0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000<0?l000030000
003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000
0000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000
0000o`000?l000`00?l000<00000003o0000o`003000o`000`0000000?l0003o000;003o00030000
003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool2000000d0oooo00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000oa0000006`3oool2000001D0oooo000R0?ooo`030000003o
ool0oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo0240oooo00<000000?ooo`3oool07@3oool@000000h0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000<0?l000030000003oool0oooo01T0oooo0P00000I0?ooo`800000103o
ool00`000000oooo0?ooo`0<0?ooo`l000003P00o`000`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<00000003o0000o`003000o`0?000001`0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0
oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000<0?l000030000003oool0
oooo01X0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01P0oooo0P0000030?ooo`8000003@3oool00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`0300000000
0?l0003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo000R0?ooo`030000003oool0
oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0
oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000<0?l000030000003oool0
oooo01X0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`3oool2000001/0oooo00<0
0000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<0
0000003o0000o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`03000000000?l0003o00`0003o
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo
000R0?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000003oool0oooo0240oooo00<000000?ooo`3oool0603oool2000000<0oooo0P00
000=0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o000@000001/0oooo0P00
000I0?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<0
0000003o0000o`002`00o`000`0000000?l0003o000<003o000300000000o`000?l000`00?l000<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo008000003@3o
ool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03o
ool2000001D0oooo000R0?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl8
000002<0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00`0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01P0oooo0P0000030?ooo`030000003oool0oooo00`0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3o
ool001D0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`P000001P1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo008000003@3oool00`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0:03oool2000001T0oooo0`000003
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01<0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000001D0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0H0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<0
0000003o0000o`003000o`000`0000000?l0003o000<003o00030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0603oool300000080oooo0P00000=0?oooa0000003@000?l00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?oo
o`0X0?ooo`8000005@3oool001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo0?ooo`800000503oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l0
00<00000003o0000o`003000o`000`0000000?l0003o000<003o00030000003oool0oooo02P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`005`3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0603oool300000080oooo0P00000=0?ooo`030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0X0?ooo`8000007`3oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
0?l0003o000<003o000300000000o`000?l000`00?l000<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0M0?ooo`800000703oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0
003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02P0
oooo0P00000E0?ooo`005`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo0000000E0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000003oool0oooo02P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`00
00000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`0@0000
02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o
00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`005P3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`000000
0?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000001`0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`8000005@3oool00280oooo
00<000000?ooo`3oool04`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo
0P00000=0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`0X0?ooo`8000004P3oool500000080oooo0P0000040?ooo`030000003oool0oooo01X0oooo
00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l0
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo
000R0?ooo`030000003oool0oooo01<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003oool0oooo02T0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`0300000000o`000?l000`0
0?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0
oooo00<000000?ooo`3oool07@3oool2000001`0oooo00<000000000o`000?l02`000?l00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000
oooo0?ooo`0X0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool04`3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo2@00000Z0?ooo`030000003oool0oooo01d0oooo
0P00000=0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`0X0?ooo`800000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool0oooo0P00000K0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`00
00000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool50000
0080oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`000?l00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01<0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0300
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool0
0`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000001d0oooo00<000000000o`000?l02`000?l00`000000003o
0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01<0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0300oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool00`000000
0?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00800000703oool00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo
02P0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0
oooo0P00000=0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`004000000Z0?ooo`8000004`3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C
0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`P000001P1oOgl00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0140oooo1@0000020?ooo`8000000`3oool00`000000oooo0?ooo`0<0?oo
o`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o
000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000001`0oooo00<00000
0000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`8000005@3oool00280oooo00<000000?oo
o`3oool06P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0300oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000003P3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00
o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04P3o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l03000
0?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0
oooo01X0oooo2000000707moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo2000000b0?ooo`030000003oool0
oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo008000003@3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000O0?ooo`030000003o
ool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000
o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`800000703o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`030000003oool0oooo02P0oooo0P00000E0?ooo`005@3oool4
000000<0oooo0P0000040?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000003P3oool00`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`02000000d0oooo00<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0g0?ooo`8000004P3oool500000080oooo0P0000040?ooo`030000003oool0oooo01X0
oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`0
0?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0
oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0
oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000280
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0
oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo00`0
oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool0
0`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`03000000000?l0
003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0
003o00`0003o00<000000?ooo`3oool0:03oool2000001D0oooo000G0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002<0oooo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo
0P00000K0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`005@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`8000003@3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000D0?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo0P00000L0?ooo`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0
003o00<000000?ooo`3oool0:03oool2000001D0oooo000F0?ooo`800000103oool2000000@0oooo
00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l0
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000M0?ooo`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0`0000030?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000L0?ooo`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000oa000000:P3oool2000001D0
oooo000R0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000000d0oooo
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo
0?ooo`0J0?oooa0000003@00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo
0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<0
00000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool2000001`0oooo00<000000000o`000?l02`000?l00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool2000001D0oooo000R
0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000000d0oooo00<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0K
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?oo
o`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000<0oooo00<000000?oo
o`3oool0303oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000003o
0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool06`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo000R0?ooo`03
0000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000003P3oool00`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0
oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`00
0?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`008P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo2000000i0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000d0oooo00<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004P3oool4000000<0oooo0P0000040?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o
00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3o
ool08@3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?oo
o`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01d0oooo0P00000L0?ooo`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo0P00000E0?oo
o`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool2000002X0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o
00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001H0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0B0?ooo`800000103oool300000080oooo0P00000=0?oooa00
00003@3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0=`3oool2000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo0P00000L
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo0P00000E0?ooo`005@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000008P3oool0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool2
000001`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0=`3oool2000001<0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`00
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`800000703oool00`000000003o0000o`0;0000o`0300000000
0?l0003o00`0003o3`00000i0?ooo`8000005@3oool001P0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool0000002<0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?oo
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000
003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`005P3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00
000O0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o
000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P00
00030?ooo`800000703oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0A@3oool2000001D0oooo000R0?ooo`030000003oool0oooo0240oooo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<00000
0000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507mo
O`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool4000000<0oooo0P0000040?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o
00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2000001`0oooo00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?oo
o`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo0P00000L0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o0000303o000?000003T0oooo0P00000B0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?oo
o`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0;0000
o`03000000000?l0003o00`0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?oo
o`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`3oool2000002X0oooo00<00000003o0000o`002`00o`00
0`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool2
000001`0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0
oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool2000001`0oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003oool0oooo04D0oooo0P00000D0?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`00
0`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo
0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l0
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo
00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0A0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0:@3oool00`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0A0?ooo`@000000`3oool2000000<0oooo0P00000L0?ooo`l000003P000?l00`000000
oooo0?ooo`150?ooo`8000005@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool2000000@0oooo
0P0000030?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0C0?ooo`005`3oool300000080oooo0P0000040?ooo`030000003oool0oooo0240oooo
00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool06`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo
00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000
:P3oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`00603o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo02T0
oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0
oooo000E0?ooo`D0000000D0oooo0000003oool0oooo000000030?ooo`8000008P3oool00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool2000001`0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04D0
oooo0P00000O0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000
0?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00000Z0?ooo`03000000000?l0003o
00`0003o00<000000?ooo`3oool0A@3oool2000001D0oooo000E0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0
oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`00
0?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0180oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0
003o00`0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`005P3oool00`00
0000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool2
000001`0oooo3`00000>0?l000030000003oool0oooo04D0oooo0P00000C0?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`00
0?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`800000:P3oool0
0`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`005`3oool20000
00<0oooo0P0000040?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`00
0000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3o
ool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l03000
0?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0
oooo0240oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0
oooo04H0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool0oooo0P00000Z0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`00
3000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
:@3oool00`000000003o0000o`0<0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool07@3oool2000002X0oooo00<000000?l0003o0000303o
00000`000000oooo0?ooo`150?ooo`8000005@3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`000000:`3oool00`0000000?l0003o000;003o000300000000o`000?l000`0
0?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`800000:P3oool00`000000
003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo
0?ooo`0Q0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0A0?ooo`@000000`3oool2000000<0oooo00<000000?ooo`3oool0:@3oool00`000000o`00
0?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`00
00000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo0240
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02T0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo
0140oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l0
00/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0180oooo0P0000040?ooo`8000000`3oool2000002X0oooo00<000000000o`000?l030000?l00`00
0000oooo0?ooo`150?ooo`8000005@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000
Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl900000400
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
0000:P3oool00`000000o`000?l0000<0?l000030000003oool0oooo04D0oooo0P00000O0?ooo`03
0000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o0003
0000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000003o0000o`0<
0000o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?oo
o`3oool08@3oool9000000H0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000003o
0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00800000:P3oool00`000000003o0000o`0<
0000o`030000003oool0oooo04D0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0Y0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`800000:P3oool00`000000o`000?l0000<0?l000030000003oool0oooo04D0oooo0P00000O
0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`0@000003T0oooo00<00000
0?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo
00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo
000R0?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0`00
00020?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000303o00000`000000oooo0?oo
o`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o
000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo0P00000Z0?ooo`03000000000?l0003o00`0
003o00<000000?ooo`3oool0A@3oool2000001D0oooo000R0?ooo`030000003oool0oooo02T0oooo
00<0000007moO`1oOgl0101oOgl8000004P0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0
003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool2000000@0oooo
0P0000030?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01<0oooo000F0?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool0:@3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool07@3oool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?oo
o`150?ooo`8000004P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0003o00`0
003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`005@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`00
0000Ogmo07moO`0407moO`030000003oool0oooo04d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000Z
0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M
0?ooo`800000:P3oool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo0P00000E
0?ooo`00603oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`800000:P3o
ool00`000000Ogmo07moO`0407moO`030000003oool0oooo04d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo
0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000000o`000?l030000?l00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01<0oooo000F0?ooo`8000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo02T0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`00
00<000000?ooo`3oool0A@3oool200000180oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000
oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03000000000?l0003o00`0
003o00<000000?ooo`3oool0A@3oool2000001D0oooo000F0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0
oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140
oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/0
0?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0
oooo00<000000000o`000?l030000?l00`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0
oooo000F0?ooo`<000000`3oool2000000@0oooo00<000000?ooo`3oool0:@3oool8000004l0oooo
00<000000?ooo`3oool07@3oool2000002X0oooo400000170?ooo`8000007`3oool00`000000oooo
0?ooo`0Y0?ooo`l00000B03oool00`000000oooo0?ooo`0M0?ooo`800000:P3oool@000004L0oooo
0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool04`3oool00280ooooQ000000O0?ooohD000007`3ooon4000001l0ooooQ@00000E
0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {90.625, 13.6875}} -> {-0.331812, \
0.0930199, 0.00627702, 0.00627702}, {{42.25, 160.813}, {88.75, 15.5}} -> \
{-0.0843818, 1.48545, 0.00343669, 0.674695}, {{172.688, 291.25}, {88.75, \
15.5}} -> {-0.644723, 0.828424, 0.00343669, 0.376272}, {{303.063, 421.625}, \
{88.75, 15.5}} -> {-1.2048, 1.05696, 0.00343669, 0.480072}, {{433.5, \
552.063}, {88.75, 15.5}} -> {-1.76514, 0.971255, 0.00343669, 0.441146}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions4]\)], "Input"],

Cell[BoxData[
    \({0.3216783612788061`, 0.34124275058595066`, 
      0.33707888813524306`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions4]]\)], "Input"],

Cell[BoxData[
    \(0.33333333333333365`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions4]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.003853142218333984`, 
      StandardDeviation \[Rule] 0.062073683782533674`, 
      SampleRange \[Rule] 0.34330458861122193`, 
      MeanDeviation \[Rule] 0.04919435651463518`, 
      MedianDeviation \[Rule] 0.039372276073770696`, 
      QuartileDeviation \[Rule] 0.038889685485004793`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats4\  = \ 
        Map[DispersionReport, fractions4]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats4]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.00494284981057181`\), \(Variance \[Rule] 
              0.0025941587137552546`\), \(Variance \[Rule] 
              0.0038834608911214644`\)},
          {\(StandardDeviation \[Rule] 
              0.07030540385042824`\), \(StandardDeviation \[Rule] 
              0.050932884404432215`\), \(StandardDeviation \[Rule] 
              0.06231742044662523`\)},
          {\(SampleRange \[Rule] 0.3112166630141685`\), \(SampleRange \[Rule] 
              0.26964212258329906`\), \(SampleRange \[Rule] 
              0.30187530106686256`\)},
          {\(MeanDeviation \[Rule] 
              0.05603693125071239`\), \(MeanDeviation \[Rule] 
              0.039500864157216084`\), \(MeanDeviation \[Rule] 
              0.05082139028832797`\)},
          {\(MedianDeviation \[Rule] 
              0.04222330086377124`\), \(MedianDeviation \[Rule] 
              0.03258424898554191`\), \(MedianDeviation \[Rule] 
              0.04629485336981054`\)},
          {\(QuartileDeviation \[Rule] 
              0.04354054201335955`\), \(QuartileDeviation \[Rule] 
              0.03215045521721105`\), \(QuartileDeviation \[Rule] 
              0.04602947856275447`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["uncorrected average tapping data", "Subsubsection"],

Cell[BoxData[{
    \(\(data4b\  = \ Drop[pid52932x05avg, \ 1];\)\  (*\ 
      remove\ pickup\ note\ *) \), "\[IndentingNewLine]", 
    \(\(beats4bcor\  = \ 
        Drop[RotateLeft[pid52932x05avg, \ 1]\  - \ 
            pid52932x05avg, \ \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(beats4bcor\  = \ Drop[beats4bcor, \ \(-3\)];\) (*\ 
      remove\ last\ measure\ *) \)}], "Input"],

Cell[BoxData[
    \(\(measure4bdurs\  = \ 
        Map[Apply[Plus, \ #] &, \ Partition[beats4bcor, \ 3]];\)\)], "Input"],

Cell[BoxData[{
    \(\(newdata4b\  = \ 
        Transpose[{measure4bdurs, 
            Partition[beats4bcor, \ 3]}];\)\), "\[IndentingNewLine]", 
    \(\(fractions4b\  = \ 
        Transpose[
          Map[{N[\(#[\([2]\)]\)[\([1]\)]/#[\([1]\)]], \ 
                N[\(#[\([2]\)]\)[\([2]\)]/#[\([1]\)]\ ], \[IndentingNewLine]\ \
\ \ \ N[\(#[\([2]\)]\)[\([3]\)]/#[\([1]\)]\ ]} &, \ 
            newdata4b]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot4b\  = \ 
        Histogram[Flatten[fractions4b], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00964924 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11121 -12 -4.5 ]
[-0.0125 .11121 0 4.5 ]
[-0.0125 .2077 -12 -4.5 ]
[-0.0125 .2077 0 4.5 ]
[-0.0125 .30419 -12 -4.5 ]
[-0.0125 .30419 0 4.5 ]
[-0.0125 .40068 -12 -4.5 ]
[-0.0125 .40068 0 4.5 ]
[-0.0125 .49718 -12 -4.5 ]
[-0.0125 .49718 0 4.5 ]
[-0.0125 .59367 -12 -4.5 ]
[-0.0125 .59367 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11121 m
.00625 .11121 L
s
[(10)] -0.0125 .11121 1 0 Mshowa
0 .2077 m
.00625 .2077 L
s
[(20)] -0.0125 .2077 1 0 Mshowa
0 .30419 m
.00625 .30419 L
s
[(30)] -0.0125 .30419 1 0 Mshowa
0 .40068 m
.00625 .40068 L
s
[(40)] -0.0125 .40068 1 0 Mshowa
0 .49718 m
.00625 .49718 L
s
[(50)] -0.0125 .49718 1 0 Mshowa
0 .59367 m
.00625 .59367 L
s
[(60)] -0.0125 .59367 1 0 Mshowa
.125 Mabswid
0 .03401 m
.00375 .03401 L
s
0 .05331 m
.00375 .05331 L
s
0 .07261 m
.00375 .07261 L
s
0 .09191 m
.00375 .09191 L
s
0 .13051 m
.00375 .13051 L
s
0 .1498 m
.00375 .1498 L
s
0 .1691 m
.00375 .1691 L
s
0 .1884 m
.00375 .1884 L
s
0 .227 m
.00375 .227 L
s
0 .2463 m
.00375 .2463 L
s
0 .2656 m
.00375 .2656 L
s
0 .28489 m
.00375 .28489 L
s
0 .32349 m
.00375 .32349 L
s
0 .34279 m
.00375 .34279 L
s
0 .36209 m
.00375 .36209 L
s
0 .38139 m
.00375 .38139 L
s
0 .41998 m
.00375 .41998 L
s
0 .43928 m
.00375 .43928 L
s
0 .45858 m
.00375 .45858 L
s
0 .47788 m
.00375 .47788 L
s
0 .51648 m
.00375 .51648 L
s
0 .53577 m
.00375 .53577 L
s
0 .55507 m
.00375 .55507 L
s
0 .57437 m
.00375 .57437 L
s
0 .61297 m
.00375 .61297 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11121 m
1 .11121 L
s
.99375 .2077 m
1 .2077 L
s
.99375 .30419 m
1 .30419 L
s
.99375 .40068 m
1 .40068 L
s
.99375 .49718 m
1 .49718 L
s
.99375 .59367 m
1 .59367 L
s
.125 Mabswid
.99625 .03401 m
1 .03401 L
s
.99625 .05331 m
1 .05331 L
s
.99625 .07261 m
1 .07261 L
s
.99625 .09191 m
1 .09191 L
s
.99625 .13051 m
1 .13051 L
s
.99625 .1498 m
1 .1498 L
s
.99625 .1691 m
1 .1691 L
s
.99625 .1884 m
1 .1884 L
s
.99625 .227 m
1 .227 L
s
.99625 .2463 m
1 .2463 L
s
.99625 .2656 m
1 .2656 L
s
.99625 .28489 m
1 .28489 L
s
.99625 .32349 m
1 .32349 L
s
.99625 .34279 m
1 .34279 L
s
.99625 .36209 m
1 .36209 L
s
.99625 .38139 m
1 .38139 L
s
.99625 .41998 m
1 .41998 L
s
.99625 .43928 m
1 .43928 L
s
.99625 .45858 m
1 .45858 L
s
.99625 .47788 m
1 .47788 L
s
.99625 .51648 m
1 .51648 L
s
.99625 .53577 m
1 .53577 L
s
.99625 .55507 m
1 .55507 L
s
.99625 .57437 m
1 .57437 L
s
.99625 .61297 m
1 .61297 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .03401 L
.11111 .03401 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .03401 L
.11111 .03401 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .09191 L
.16667 .09191 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .09191 L
.16667 .09191 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .11121 L
.22222 .11121 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .11121 L
.22222 .11121 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .1691 L
.27778 .1691 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .1691 L
.27778 .1691 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .43928 L
.33333 .43928 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .43928 L
.33333 .43928 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .56472 L
.38889 .56472 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .56472 L
.38889 .56472 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .49718 L
.5 .49718 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .49718 L
.5 .49718 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .33314 L
.55556 .33314 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .33314 L
.55556 .33314 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .12086 L
.61111 .12086 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .12086 L
.61111 .12086 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .08226 L
.66667 .08226 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .08226 L
.66667 .08226 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .07261 L
.72222 .07261 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .07261 L
.72222 .07261 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02436 L
.77778 .02436 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02436 L
.77778 .02436 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .04366 L
.83333 .04366 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .04366 L
.83333 .04366 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo4000000=07moO`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
0@3oool000X0oooo0P0000050?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0303o
ool00`000000Ogmo07moO`0;07moO`030000003oool0oooo02X0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
00d0oooo4000000>07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0303oool00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo02T0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?oo
o`0<0?ooo`l00000;03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0AP3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
6`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo04L0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000L0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo400000180?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl0301oOgl@000005P0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool06`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000703oool@000000h0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1T0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0:P3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`03
0000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo02X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo0`00000Z0?oooa0000003@1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`1S0?ooo`<000000`3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl@000006L0oooo00<000000?ooo`3oool00@3oool0
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo
00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000Ogmo
07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07mo
O`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
07moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
>P3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03T0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0i0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0>@3oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000>P3oool?000000h0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo0P0000030?ooo`004@3o
ool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1o
Ogl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo100000030?ooo`8000001@3oool00`00
0000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool30000
04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
0780oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`17
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
0P0000180?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo
0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07mo
O`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00/0Ogmo00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0
oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
00180?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07mo
O`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?oo
o`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool3000004L0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo0780oooo0`0000030?ooo`001P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00/0Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0;07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00/0
Ogmo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo07<0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0;
07moO`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`l00000MP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004P0oooo00<0000007moO`1oOgl0
301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0A`3o
ool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0
oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0A`3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool00140oooo0P0000180?ooo`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
003oool0oooo0840oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`001@3oool300000080
oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00060?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0
Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`000`3oool5000000050?oo
o`000000oooo0?ooo`000000103oool3000004L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`200?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool000000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo
00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`001@3oool2000000<0
oooo0P0000050?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04L0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000B03oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0840oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`170?ooo`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000004P0oooo4000000>07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo
00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000E`3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07mo
O`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0880oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000Ogmo07moO`0<07moO`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`210?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0
Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0
oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`00
0000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00060?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool3000005H0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moOa000000PP3oool3000000<0oooo00040?ooo`8000000`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05H0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool000@0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1o
Ogl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T03oool2
000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<0000007moO`1oOgl0301oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1F0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<0
000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl0301oOgl00`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oooa00
00003P1oOgl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301o
Ogl00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000IP3oool0
0`000000Ogmo07moO`0<07moO`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool3000000@0oooo
0P0000050?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001U0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0S`3oool3000000<0oooo00030?ooo`<000000`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo06D0oooo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U0?ooo`030000001oOgl0Ogmo
00`0Ogmo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool3000000<0
oooo0P0000050?ooo`030000003oool0oooo06D0oooo4000002C0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool2000000<0oooo000A0?ooool000003@000003
0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.340238, 0.00169256, 0.389796}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot4b1\  = 
        Histogram[fractions4b[\([1]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0159082 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09426 -6 -4.5 ]
[-0.0125 .09426 0 4.5 ]
[-0.0125 .1738 -12 -4.5 ]
[-0.0125 .1738 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .33288 -12 -4.5 ]
[-0.0125 .33288 0 4.5 ]
[-0.0125 .41242 -12 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .5715 -12 -4.5 ]
[-0.0125 .5715 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09426 m
.00625 .09426 L
s
[(5)] -0.0125 .09426 1 0 Mshowa
0 .1738 m
.00625 .1738 L
s
[(10)] -0.0125 .1738 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(15)] -0.0125 .25334 1 0 Mshowa
0 .33288 m
.00625 .33288 L
s
[(20)] -0.0125 .33288 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(25)] -0.0125 .41242 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(30)] -0.0125 .49196 1 0 Mshowa
0 .5715 m
.00625 .5715 L
s
[(35)] -0.0125 .5715 1 0 Mshowa
.125 Mabswid
0 .03062 m
.00375 .03062 L
s
0 .04653 m
.00375 .04653 L
s
0 .06244 m
.00375 .06244 L
s
0 .07835 m
.00375 .07835 L
s
0 .11016 m
.00375 .11016 L
s
0 .12607 m
.00375 .12607 L
s
0 .14198 m
.00375 .14198 L
s
0 .15789 m
.00375 .15789 L
s
0 .18971 m
.00375 .18971 L
s
0 .20561 m
.00375 .20561 L
s
0 .22152 m
.00375 .22152 L
s
0 .23743 m
.00375 .23743 L
s
0 .26925 m
.00375 .26925 L
s
0 .28515 m
.00375 .28515 L
s
0 .30106 m
.00375 .30106 L
s
0 .31697 m
.00375 .31697 L
s
0 .34879 m
.00375 .34879 L
s
0 .3647 m
.00375 .3647 L
s
0 .3806 m
.00375 .3806 L
s
0 .39651 m
.00375 .39651 L
s
0 .42833 m
.00375 .42833 L
s
0 .44424 m
.00375 .44424 L
s
0 .46014 m
.00375 .46014 L
s
0 .47605 m
.00375 .47605 L
s
0 .50787 m
.00375 .50787 L
s
0 .52378 m
.00375 .52378 L
s
0 .53969 m
.00375 .53969 L
s
0 .55559 m
.00375 .55559 L
s
0 .58741 m
.00375 .58741 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09426 m
1 .09426 L
s
.99375 .1738 m
1 .1738 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .33288 m
1 .33288 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .5715 m
1 .5715 L
s
.125 Mabswid
.99625 .03062 m
1 .03062 L
s
.99625 .04653 m
1 .04653 L
s
.99625 .06244 m
1 .06244 L
s
.99625 .07835 m
1 .07835 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .14198 m
1 .14198 L
s
.99625 .15789 m
1 .15789 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22152 m
1 .22152 L
s
.99625 .23743 m
1 .23743 L
s
.99625 .26925 m
1 .26925 L
s
.99625 .28515 m
1 .28515 L
s
.99625 .30106 m
1 .30106 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .34879 m
1 .34879 L
s
.99625 .3647 m
1 .3647 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .39651 m
1 .39651 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .44424 m
1 .44424 L
s
.99625 .46014 m
1 .46014 L
s
.99625 .47605 m
1 .47605 L
s
.99625 .50787 m
1 .50787 L
s
.99625 .52378 m
1 .52378 L
s
.99625 .53969 m
1 .53969 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04653 L
.11111 .04653 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04653 L
.11111 .04653 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .18971 L
.22222 .18971 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .18971 L
.22222 .18971 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .47605 L
.33333 .47605 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .47605 L
.33333 .47605 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .30106 L
.55556 .30106 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .30106 L
.55556 .30106 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .07835 L
.66667 .07835 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .07835 L
.66667 .07835 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .03062 L
.77778 .03062 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03062 L
.77778 .03062 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .03062 L
.88889 .03062 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03062 L
.88889 .03062 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000
6`3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000K0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000
003o0000o`0001X0o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00?000000L0?ooo`8000000`3oool0
0140oooo00<000000?l0003o00006`3o00000`000000o`000?l0000K0?l000030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
o`000?l0000K0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo
00<000000?ooo`3oool00@3oool00140oooo7`00000M0?l000030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l0
00030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`1E0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0
oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`030000003o0000o`0001/0o`00
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`00
7`00001G0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000X0oooo0P000005
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool000`0oooo00<000000?ooo`3oool00P3oool3000001/0oooo00<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0
003o00006P3o00000`000000oooo0?ooo`1b0?ooo`<000000`3oool000X0oooo0P0000050?ooo`03
0000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000X0oooo0`0000040?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool0
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0
o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool2000001`0oooo00<000000?l0003o00006`3o00000`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K
0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J
0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool06`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0
003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l00003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
6`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00000L0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o0000
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`000000o`00
0?l0000K0?l000030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`00
0?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o0000
o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`<000006`3oool00`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo0780oooo0`000003
0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0001/0o`0000<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo01/0oooo00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l0
00030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000703ooolO000001`0o`0000<000000?l0003o
00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`00
01X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0
000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
0?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool0
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2000000D0
oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040
oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l00003
0000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00000i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000
003oool0oooo0780oooo0`0000030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`8000001@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o
00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000
o`0001X0o`0000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0`0000040?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0
o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07<0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J
0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o00000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3o
ool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o0000
6P3o00000`000000o`000?l0000K0?l000030000003o0000o`0001X0o`0000<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000o`000?l0000J0?l000030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool0
0`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?l0003o00006P3o0000
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`007P00001e0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0
>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000
003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000i0?ooo`030000
003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`<00000
0`3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`00
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03T0oooo
00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o
00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000
o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`00
0000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140
oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000
oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`00
0?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<0
00000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K
0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?oo
o`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l00003
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`@000000`3o
ool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o
0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3o
ool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo0`00000i0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o0000
0`000000oooo0?ooo`2?0?ooo`<000000`3oool000D0oooo00<000000?ooo`3oool00P3oool20000
00D0oooo00<000000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`00
01/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool00`00
0000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo03T0
oooo00<000000?l0003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940
oooo00<000000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i
0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0
003o00006P3o00000`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o
00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
0000o`0001X0o`0000<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o0000
0`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000j0?ooo`030000003o0000o`0001X0o`0000<000000?l0003o00006`3o00000`00
0000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
o`000?l0000J0?l000030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`030000003o0000o`0001X0o`00
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000?l0003o00006P3o00000`000000o`000?l0
000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000o`000?l0000J0?l000030000003o0000o`0001/0o`0000<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo7P00000M0?l0
00030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000?l0003o0000
6`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03
0000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
1@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000005H0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2?0?ooo`<000000`3oool000H0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000E`3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F
0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000?l0003o
00006`3o00000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003o
ool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo
0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000003o0000o`0001/0
o`0000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
0?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000E`3oool00`000000o`000?l0000K0?l000030000003oool0oooo0900oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo05H0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0`00001F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0
S`3oool3000000<0oooo00060?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`<00000103oool00`000000oooo0?oo
o`1F0?ooo`030000003o0000o`0001/0o`0000<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005L0oooo00<000000?l0003o00006`3o00000`000000oooo0?ooo`2@
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l0
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000o`000?l0000K0?l000030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000o`000?l0000K0?l000030000003oool0oooo0940oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00001G0?oooal00000TP3oool2000000<0oooo000A0?ooo`030000003oool0oooo
0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo
0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0636924, \
50.7626, 0.00169256, 0.236434}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot4b2\  = 
        Histogram[fractions4b[\([2]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0130801 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .06704 L
.22222 .06704 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06704 L
.22222 .06704 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .23708 L
.33333 .23708 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .23708 L
.33333 .23708 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .44636 L
.55556 .44636 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .44636 L
.55556 .44636 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .06704 L
.66667 .06704 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .06704 L
.66667 .06704 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01/0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003o
ool0oooo01/0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000003o
ool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`006`00o`000`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
0?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo
0P00000L0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo
0?ooo`1E0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01/0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o
00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool06`3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`006`00
o`000`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`0000000?l0003o000K003o00030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00000L0?oooal000007000o`000`0000000?l0003o000K003o000300000000o`00
0?l001X00?l07`00001G0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
00000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0
oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0
003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o
0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000
o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`00
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l0
01X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000
0?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo
00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
0000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000
003o0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?oo
o`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o00030000
0000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo0`00000i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00
o`000`0000000?l0003o000J003o00030000003oool0oooo0780oooo0`0000030?ooo`001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`00
00000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X0
0?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0
003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`0000000?l0003o
000J003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J
003o000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o
0000o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03
00000000o`000?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`00
0`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000j0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o000300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00o`000`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`000?l001X00?l000<00000
003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`0000000?l0003o000J003o
000300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000
o`006P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<00000003o0000o`00
6P00o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0
L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<00000003o0000o`006P00
o`000`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`0300000000o`00
0?l001X00?l000<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3ooolN0000
01d00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o
00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00001F0?ooo`0300000000
o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1b0?ooo`<000000`3o
ool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<0
0000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o
0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`030000
0000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000
o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`00
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
0?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l0
00<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o
000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000
o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
00000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000
oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0
003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<0
0000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J
003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
00000000o`000?l001/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`006P00
o`000`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
0?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o000300000000o`000?l001X00?l0
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o
000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo0`00001F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`1b0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`00
6`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o0003
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000003o0000o`00
6P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l0003o000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
01/00?l000<00000003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000E`3oool00`0000000?l0003o000K003o000300000000o`000?l001X0
0?l000<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`0000000?l0003o000J003o00030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o000300000000o`000?l001X00?l000<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<00000
003o0000o`006P00o`000`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`0N000007H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00001G0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T03o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`00
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000
003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000E`3oool00`0000000?l0003o000K003o00030000003oool0oooo0900oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`030000
0000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`00
0?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/0
0?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K
003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0oooo0`0000020?ooo`800000
1@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`001P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000001@3oool000000?oo
o`3oool0000000@0oooo0`00001F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
S`3oool3000000<0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3o
ool0T@3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo000000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o0003
0000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool000D0oooo0P0000030?ooo`800000
1@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1F0?ooo`0300000000o`000?l001/00?l000<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000o`000?l0
01/00?l000<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0
oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2@0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o
000K003o00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o
00030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0EP3oool00`0000000?l0003o000K003o00030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`0000000?l0003o000K003o00030000
003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000
o`000?l001/00?l000<000000?ooo`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0
oooo05H0oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<00000003o0000o`006`00o`000`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0
oooo00<00000003o0000o`006`00o`000`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05H0oooo7`00002C0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
0140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0636924, \
123.225, 0.00169256, 0.287554}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplot4b3\  = 
        Histogram[fractions4b[\([3]\)], \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0163501 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -6 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -12 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -12 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -12 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(10)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(15)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(20)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(25)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(30)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(35)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06377 L
.22222 .06377 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06377 L
.22222 .06377 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .24362 L
.33333 .24362 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .24362 L
.33333 .24362 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .53792 L
.55556 .53792 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .53792 L
.55556 .53792 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .17822 L
.66667 .17822 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .17822 L
.66667 .17822 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .11282 L
.77778 .11282 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .11282 L
.77778 .11282 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .04742 L
.88889 .04742 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .04742 L
.88889 .04742 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000040?oo
o`800000;@3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>03oool002L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000g0?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=@3oool002L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0Z0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003P0oooo000W
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002/0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=`3o
ool002P0oooo0P00000:0?ooo`800000;@3oool2000000X0oooo0P00000]0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000=`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo00090?ooo`040000003oool0oooo000000@0oooo
o`00000=000000<0oooo00090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`010?ooo`002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000L0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool06P3oool2000000<0oooo000A0?ooo`030000003oool0oooo
01/0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000703oool00`000000003o0000o`0K
0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06`000?lN000001`0oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o01/0003o00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`010?ooo`004@3oool2000001`0oooo7`00000L0000o`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01/0003o00<000000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0
oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0
oooo03P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000003o0000o`0K0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0
003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0=`3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J
0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K
0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`01
0?ooo`002P3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?oo
o`002@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?oo
o`3oool00@3oool000`0oooo00<000000?ooo`3oool00P3oool3000003T0oooo00<000000000o`00
0?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0K0000o`030000003oool0oooo03H0oooo0`0000030?ooo`00
2P3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000
00000?l0003o01/0003o00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3o
ool000X0oooo0`0000040?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l0
0`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0K0000o`030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o7`00000i0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0
003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o
0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0?ooo`3oool0E@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000
o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l0
6P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`0300000000
0?l0003o01X0003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0
oooo05D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o
01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<0
00000000o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<0
00000000o`000?l06`000?l00`000000oooo0?ooo`1E0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000003o0000o`0K0000o`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool00@3oool000<0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`0i0?oo
o`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?oo
o`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool3000003T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o7`00001F0?ooo`<000000`3oool000D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000000
o`000?l06P000?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
0@3oool00140oooo0P00000j0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`00
0?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`03000000000?l0003o
01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool2000003X0oooo00<000000000o`000?l06P000?l00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo
000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P000?l00`000000003o0000
o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0003o01X0003o00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000>P3oool00`000000003o0000o`0J0000o`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0>@3oool00`000000003o0000o`0J0000o`030000
00000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03T0oooo00<000000000o`000?l06P00
0?l00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0i0?ooo`03000000000?l0
003o01X0003o00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>@3oool00`00
0000003o0000o`0J0000o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>P3ooolN000001d0
003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo0`00001F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1b0?ooo`<000000`3oool000D0oooo00<000000?ooo`3oool00P3oool20000
00D0oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`00103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo05H0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?oo
o`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool2000005L0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07<0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0
003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo
00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J
0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo100000030?ooo`8000001@3oool0
0`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3
000005H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo0780oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo00030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07<0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0
003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o
0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<0
00000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<00000
0?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000
o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03
000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l0
6P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3o
ool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l0
0`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o
01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`000`3oool4000000<0
oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000
003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0
oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`<00000EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o
00<000000?ooo`3oool0LP3oool3000000<0oooo00050?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05H0oooo00<0
00000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`1F
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`03
0000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
EP3oool00`000000003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000E`3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0L`3oool2000000<0oooo000A0?ooo`030000003oool0oooo
05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o
00<000000000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G
0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000
o`03000000000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`00
0?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`0300000000
0?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`03000000000?l0
003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`00103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`00
0000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo0`00001F0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1b0?ooo`<000000`3oool000H0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<00000
0000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000
o`0J0000o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<00000
0000o`000?l06P000?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03
000000000?l0003o01/0003o00<000000000o`000?l06P000?l00`000000oooo0?ooo`1c0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000
00000?l0003o01X0003o00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000000o`000?l06P00
0?l00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05H0oooo00<000000000o`000?l06`000?l00`000000003o0000o`0J0000o`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o
01/0003o7P00001e0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000
003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0EP3oool00`000000003o0000
o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001G0?ooo`03000000000?l0003o01/0003o00<000000?oo
o`3oool0T03oool2000000<0oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`00
0?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05H0oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05H0oooo00<000000000o`000?l06`00
0?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000E`3oool0
0`000000003o0000o`0K0000o`030000003oool0oooo0900oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0
oooo00<000000000o`000?l06`000?l00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0040
oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo0`00001F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0S`3oool3000000<0
oooo00060?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`03
000000000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0EP3oool00`000000003o0000o`0K0000o`030000003oool0oooo0940oooo00<000000?ooo`3o
ool00@3oool000@0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`1F0?ooo`030000
00000?l0003o01/0003o00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1F0?ooo`03000000000?l0003o01/0003o00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000005L0oooo7`00002B0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00
4@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0636924, \
0.200796, 0.00169256, 0.230044}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplot4b, \ xplot4b1, \ xplot4b2, \ 
            xplot4b3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.00964924 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11121 -12 -4.5 ]
[-0.0125 .11121 0 4.5 ]
[-0.0125 .2077 -12 -4.5 ]
[-0.0125 .2077 0 4.5 ]
[-0.0125 .30419 -12 -4.5 ]
[-0.0125 .30419 0 4.5 ]
[-0.0125 .40068 -12 -4.5 ]
[-0.0125 .40068 0 4.5 ]
[-0.0125 .49718 -12 -4.5 ]
[-0.0125 .49718 0 4.5 ]
[-0.0125 .59367 -12 -4.5 ]
[-0.0125 .59367 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11121 m
.00625 .11121 L
s
[(10)] -0.0125 .11121 1 0 Mshowa
0 .2077 m
.00625 .2077 L
s
[(20)] -0.0125 .2077 1 0 Mshowa
0 .30419 m
.00625 .30419 L
s
[(30)] -0.0125 .30419 1 0 Mshowa
0 .40068 m
.00625 .40068 L
s
[(40)] -0.0125 .40068 1 0 Mshowa
0 .49718 m
.00625 .49718 L
s
[(50)] -0.0125 .49718 1 0 Mshowa
0 .59367 m
.00625 .59367 L
s
[(60)] -0.0125 .59367 1 0 Mshowa
.125 Mabswid
0 .03401 m
.00375 .03401 L
s
0 .05331 m
.00375 .05331 L
s
0 .07261 m
.00375 .07261 L
s
0 .09191 m
.00375 .09191 L
s
0 .13051 m
.00375 .13051 L
s
0 .1498 m
.00375 .1498 L
s
0 .1691 m
.00375 .1691 L
s
0 .1884 m
.00375 .1884 L
s
0 .227 m
.00375 .227 L
s
0 .2463 m
.00375 .2463 L
s
0 .2656 m
.00375 .2656 L
s
0 .28489 m
.00375 .28489 L
s
0 .32349 m
.00375 .32349 L
s
0 .34279 m
.00375 .34279 L
s
0 .36209 m
.00375 .36209 L
s
0 .38139 m
.00375 .38139 L
s
0 .41998 m
.00375 .41998 L
s
0 .43928 m
.00375 .43928 L
s
0 .45858 m
.00375 .45858 L
s
0 .47788 m
.00375 .47788 L
s
0 .51648 m
.00375 .51648 L
s
0 .53577 m
.00375 .53577 L
s
0 .55507 m
.00375 .55507 L
s
0 .57437 m
.00375 .57437 L
s
0 .61297 m
.00375 .61297 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11121 m
1 .11121 L
s
.99375 .2077 m
1 .2077 L
s
.99375 .30419 m
1 .30419 L
s
.99375 .40068 m
1 .40068 L
s
.99375 .49718 m
1 .49718 L
s
.99375 .59367 m
1 .59367 L
s
.125 Mabswid
.99625 .03401 m
1 .03401 L
s
.99625 .05331 m
1 .05331 L
s
.99625 .07261 m
1 .07261 L
s
.99625 .09191 m
1 .09191 L
s
.99625 .13051 m
1 .13051 L
s
.99625 .1498 m
1 .1498 L
s
.99625 .1691 m
1 .1691 L
s
.99625 .1884 m
1 .1884 L
s
.99625 .227 m
1 .227 L
s
.99625 .2463 m
1 .2463 L
s
.99625 .2656 m
1 .2656 L
s
.99625 .28489 m
1 .28489 L
s
.99625 .32349 m
1 .32349 L
s
.99625 .34279 m
1 .34279 L
s
.99625 .36209 m
1 .36209 L
s
.99625 .38139 m
1 .38139 L
s
.99625 .41998 m
1 .41998 L
s
.99625 .43928 m
1 .43928 L
s
.99625 .45858 m
1 .45858 L
s
.99625 .47788 m
1 .47788 L
s
.99625 .51648 m
1 .51648 L
s
.99625 .53577 m
1 .53577 L
s
.99625 .55507 m
1 .55507 L
s
.99625 .57437 m
1 .57437 L
s
.99625 .61297 m
1 .61297 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05556 .01472 L
.05556 .01472 L
0 .01472 L
s
.5 .5 .5 r
.05556 .01472 m
.05556 .03401 L
.11111 .03401 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .03401 L
.11111 .03401 L
.11111 .01472 L
.05556 .01472 L
s
.5 .5 .5 r
.11111 .01472 m
.11111 .09191 L
.16667 .09191 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .09191 L
.16667 .09191 L
.16667 .01472 L
.11111 .01472 L
s
.5 .5 .5 r
.16667 .01472 m
.16667 .11121 L
.22222 .11121 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .11121 L
.22222 .11121 L
.22222 .01472 L
.16667 .01472 L
s
.5 .5 .5 r
.22222 .01472 m
.22222 .1691 L
.27778 .1691 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .1691 L
.27778 .1691 L
.27778 .01472 L
.22222 .01472 L
s
.5 .5 .5 r
.27778 .01472 m
.27778 .43928 L
.33333 .43928 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .43928 L
.33333 .43928 L
.33333 .01472 L
.27778 .01472 L
s
.5 .5 .5 r
.33333 .01472 m
.33333 .56472 L
.38889 .56472 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .56472 L
.38889 .56472 L
.38889 .01472 L
.33333 .01472 L
s
.5 .5 .5 r
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .60332 L
.44444 .60332 L
.44444 .01472 L
.38889 .01472 L
s
.5 .5 .5 r
.44444 .01472 m
.44444 .49718 L
.5 .49718 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .49718 L
.5 .49718 L
.5 .01472 L
.44444 .01472 L
s
.5 .5 .5 r
.5 .01472 m
.5 .33314 L
.55556 .33314 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .33314 L
.55556 .33314 L
.55556 .01472 L
.5 .01472 L
s
.5 .5 .5 r
.55556 .01472 m
.55556 .12086 L
.61111 .12086 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .12086 L
.61111 .12086 L
.61111 .01472 L
.55556 .01472 L
s
.5 .5 .5 r
.61111 .01472 m
.61111 .08226 L
.66667 .08226 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .08226 L
.66667 .08226 L
.66667 .01472 L
.61111 .01472 L
s
.5 .5 .5 r
.66667 .01472 m
.66667 .07261 L
.72222 .07261 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .07261 L
.72222 .07261 L
.72222 .01472 L
.66667 .01472 L
s
.5 .5 .5 r
.72222 .01472 m
.72222 .02436 L
.77778 .02436 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .02436 L
.77778 .02436 L
.77778 .01472 L
.72222 .01472 L
s
.5 .5 .5 r
.77778 .01472 m
.77778 .04366 L
.83333 .04366 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .04366 L
.83333 .04366 L
.83333 .01472 L
.77778 .01472 L
s
.5 .5 .5 r
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .01472 L
.88889 .01472 L
.88889 .01472 L
.83333 .01472 L
s
.5 .5 .5 r
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.94444 .01472 L
.94444 .01472 L
.88889 .01472 L
s
.5 .5 .5 r
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .01472 L
1 .01472 L
1 .01472 L
.94444 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0159082 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09426 -6 -4.5 ]
[-0.0125 .09426 0 4.5 ]
[-0.0125 .1738 -12 -4.5 ]
[-0.0125 .1738 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .33288 -12 -4.5 ]
[-0.0125 .33288 0 4.5 ]
[-0.0125 .41242 -12 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .5715 -12 -4.5 ]
[-0.0125 .5715 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09426 m
.00625 .09426 L
s
[(5)] -0.0125 .09426 1 0 Mshowa
0 .1738 m
.00625 .1738 L
s
[(10)] -0.0125 .1738 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(15)] -0.0125 .25334 1 0 Mshowa
0 .33288 m
.00625 .33288 L
s
[(20)] -0.0125 .33288 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(25)] -0.0125 .41242 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(30)] -0.0125 .49196 1 0 Mshowa
0 .5715 m
.00625 .5715 L
s
[(35)] -0.0125 .5715 1 0 Mshowa
.125 Mabswid
0 .03062 m
.00375 .03062 L
s
0 .04653 m
.00375 .04653 L
s
0 .06244 m
.00375 .06244 L
s
0 .07835 m
.00375 .07835 L
s
0 .11016 m
.00375 .11016 L
s
0 .12607 m
.00375 .12607 L
s
0 .14198 m
.00375 .14198 L
s
0 .15789 m
.00375 .15789 L
s
0 .18971 m
.00375 .18971 L
s
0 .20561 m
.00375 .20561 L
s
0 .22152 m
.00375 .22152 L
s
0 .23743 m
.00375 .23743 L
s
0 .26925 m
.00375 .26925 L
s
0 .28515 m
.00375 .28515 L
s
0 .30106 m
.00375 .30106 L
s
0 .31697 m
.00375 .31697 L
s
0 .34879 m
.00375 .34879 L
s
0 .3647 m
.00375 .3647 L
s
0 .3806 m
.00375 .3806 L
s
0 .39651 m
.00375 .39651 L
s
0 .42833 m
.00375 .42833 L
s
0 .44424 m
.00375 .44424 L
s
0 .46014 m
.00375 .46014 L
s
0 .47605 m
.00375 .47605 L
s
0 .50787 m
.00375 .50787 L
s
0 .52378 m
.00375 .52378 L
s
0 .53969 m
.00375 .53969 L
s
0 .55559 m
.00375 .55559 L
s
0 .58741 m
.00375 .58741 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09426 m
1 .09426 L
s
.99375 .1738 m
1 .1738 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .33288 m
1 .33288 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .5715 m
1 .5715 L
s
.125 Mabswid
.99625 .03062 m
1 .03062 L
s
.99625 .04653 m
1 .04653 L
s
.99625 .06244 m
1 .06244 L
s
.99625 .07835 m
1 .07835 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .14198 m
1 .14198 L
s
.99625 .15789 m
1 .15789 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22152 m
1 .22152 L
s
.99625 .23743 m
1 .23743 L
s
.99625 .26925 m
1 .26925 L
s
.99625 .28515 m
1 .28515 L
s
.99625 .30106 m
1 .30106 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .34879 m
1 .34879 L
s
.99625 .3647 m
1 .3647 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .39651 m
1 .39651 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .44424 m
1 .44424 L
s
.99625 .46014 m
1 .46014 L
s
.99625 .47605 m
1 .47605 L
s
.99625 .50787 m
1 .50787 L
s
.99625 .52378 m
1 .52378 L
s
.99625 .53969 m
1 .53969 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .04653 L
.11111 .04653 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .04653 L
.11111 .04653 L
.11111 .01472 L
0 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .18971 L
.22222 .18971 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .18971 L
.22222 .18971 L
.22222 .01472 L
.11111 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .47605 L
.33333 .47605 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .47605 L
.33333 .47605 L
.33333 .01472 L
.22222 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .30106 L
.55556 .30106 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .30106 L
.55556 .30106 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .07835 L
.66667 .07835 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .07835 L
.66667 .07835 L
.66667 .01472 L
.55556 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .03062 L
.77778 .03062 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .03062 L
.77778 .03062 L
.77778 .01472 L
.66667 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .03062 L
.88889 .03062 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .03062 L
.88889 .03062 L
.88889 .01472 L
.77778 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0130801 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -12 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -12 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -12 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(10)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(20)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(30)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(40)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06704 m
.00375 .06704 L
s
0 .0932 m
.00375 .0932 L
s
0 .11936 m
.00375 .11936 L
s
0 .17168 m
.00375 .17168 L
s
0 .19784 m
.00375 .19784 L
s
0 .224 m
.00375 .224 L
s
0 .25016 m
.00375 .25016 L
s
0 .30248 m
.00375 .30248 L
s
0 .32864 m
.00375 .32864 L
s
0 .3548 m
.00375 .3548 L
s
0 .38096 m
.00375 .38096 L
s
0 .43328 m
.00375 .43328 L
s
0 .45944 m
.00375 .45944 L
s
0 .4856 m
.00375 .4856 L
s
0 .51176 m
.00375 .51176 L
s
0 .56408 m
.00375 .56408 L
s
0 .59024 m
.00375 .59024 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06704 m
1 .06704 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11936 m
1 .11936 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .19784 m
1 .19784 L
s
.99625 .224 m
1 .224 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .30248 m
1 .30248 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .3548 m
1 .3548 L
s
.99625 .38096 m
1 .38096 L
s
.99625 .43328 m
1 .43328 L
s
.99625 .45944 m
1 .45944 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51176 m
1 .51176 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .59024 m
1 .59024 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 1 0 r
.11111 .01472 m
.11111 .06704 L
.22222 .06704 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06704 L
.22222 .06704 L
.22222 .01472 L
.11111 .01472 L
s
0 1 0 r
.22222 .01472 m
.22222 .23708 L
.33333 .23708 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .23708 L
.33333 .23708 L
.33333 .01472 L
.22222 .01472 L
s
0 1 0 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 1 0 r
.44444 .01472 m
.44444 .44636 L
.55556 .44636 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .44636 L
.55556 .44636 L
.55556 .01472 L
.44444 .01472 L
s
0 1 0 r
.55556 .01472 m
.55556 .06704 L
.66667 .06704 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .06704 L
.66667 .06704 L
.66667 .01472 L
.55556 .01472 L
s
0 1 0 r
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .01472 L
.77778 .01472 L
.77778 .01472 L
.66667 .01472 L
s
0 1 0 r
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.88889 .01472 L
.88889 .01472 L
.77778 .01472 L
s
0 1 0 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 2.22222 0.0147151 0.0163501 [
[.11111 -0.0125 -9 -9 ]
[.11111 -0.0125 9 0 ]
[.33333 -0.0125 -9 -9 ]
[.33333 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.77778 -0.0125 -9 -9 ]
[.77778 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09647 -6 -4.5 ]
[-0.0125 .09647 0 4.5 ]
[-0.0125 .17822 -12 -4.5 ]
[-0.0125 .17822 0 4.5 ]
[-0.0125 .25997 -12 -4.5 ]
[-0.0125 .25997 0 4.5 ]
[-0.0125 .34172 -12 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .42347 -12 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .58697 -12 -4.5 ]
[-0.0125 .58697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11111 0 m
.11111 .00625 L
s
[(0.2)] .11111 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0.3)] .33333 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(0.4)] .55556 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(0.5)] .77778 -0.0125 0 1 Mshowa
.125 Mabswid
.15556 0 m
.15556 .00375 L
s
.2 0 m
.2 .00375 L
s
.24444 0 m
.24444 .00375 L
s
.28889 0 m
.28889 .00375 L
s
.37778 0 m
.37778 .00375 L
s
.42222 0 m
.42222 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.51111 0 m
.51111 .00375 L
s
.6 0 m
.6 .00375 L
s
.64444 0 m
.64444 .00375 L
s
.68889 0 m
.68889 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.82222 0 m
.82222 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.91111 0 m
.91111 .00375 L
s
.95556 0 m
.95556 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.02222 0 m
.02222 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09647 m
.00625 .09647 L
s
[(5)] -0.0125 .09647 1 0 Mshowa
0 .17822 m
.00625 .17822 L
s
[(10)] -0.0125 .17822 1 0 Mshowa
0 .25997 m
.00625 .25997 L
s
[(15)] -0.0125 .25997 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(20)] -0.0125 .34172 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(25)] -0.0125 .42347 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(30)] -0.0125 .50522 1 0 Mshowa
0 .58697 m
.00625 .58697 L
s
[(35)] -0.0125 .58697 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .04742 m
.00375 .04742 L
s
0 .06377 m
.00375 .06377 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .12917 m
.00375 .12917 L
s
0 .14552 m
.00375 .14552 L
s
0 .16187 m
.00375 .16187 L
s
0 .19457 m
.00375 .19457 L
s
0 .21092 m
.00375 .21092 L
s
0 .22727 m
.00375 .22727 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .29267 m
.00375 .29267 L
s
0 .30902 m
.00375 .30902 L
s
0 .32537 m
.00375 .32537 L
s
0 .35807 m
.00375 .35807 L
s
0 .37442 m
.00375 .37442 L
s
0 .39077 m
.00375 .39077 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .45617 m
.00375 .45617 L
s
0 .47252 m
.00375 .47252 L
s
0 .48887 m
.00375 .48887 L
s
0 .52157 m
.00375 .52157 L
s
0 .53792 m
.00375 .53792 L
s
0 .55427 m
.00375 .55427 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11111 .61178 m
.11111 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.77778 .61178 m
.77778 .61803 L
s
.125 Mabswid
.15556 .61428 m
.15556 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.24444 .61428 m
.24444 .61803 L
s
.28889 .61428 m
.28889 .61803 L
s
.37778 .61428 m
.37778 .61803 L
s
.42222 .61428 m
.42222 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.51111 .61428 m
.51111 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64444 .61428 m
.64444 .61803 L
s
.68889 .61428 m
.68889 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.82222 .61428 m
.82222 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.91111 .61428 m
.91111 .61803 L
s
.95556 .61428 m
.95556 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.02222 .61428 m
.02222 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09647 m
1 .09647 L
s
.99375 .17822 m
1 .17822 L
s
.99375 .25997 m
1 .25997 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .50522 m
1 .50522 L
s
.99375 .58697 m
1 .58697 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .06377 m
1 .06377 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .12917 m
1 .12917 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .19457 m
1 .19457 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .29267 m
1 .29267 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32537 m
1 .32537 L
s
.99625 .35807 m
1 .35807 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .39077 m
1 .39077 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .48887 m
1 .48887 L
s
.99625 .52157 m
1 .52157 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .55427 m
1 .55427 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.11111 .01472 L
.11111 .01472 L
0 .01472 L
s
0 0 1 r
.11111 .01472 m
.11111 .06377 L
.22222 .06377 L
.22222 .01472 L
F
0 g
.11111 .01472 m
.11111 .06377 L
.22222 .06377 L
.22222 .01472 L
.11111 .01472 L
s
0 0 1 r
.22222 .01472 m
.22222 .24362 L
.33333 .24362 L
.33333 .01472 L
F
0 g
.22222 .01472 m
.22222 .24362 L
.33333 .24362 L
.33333 .01472 L
.22222 .01472 L
s
0 0 1 r
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
F
0 g
.33333 .01472 m
.33333 .60332 L
.44444 .60332 L
.44444 .01472 L
.33333 .01472 L
s
0 0 1 r
.44444 .01472 m
.44444 .53792 L
.55556 .53792 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .53792 L
.55556 .53792 L
.55556 .01472 L
.44444 .01472 L
s
0 0 1 r
.55556 .01472 m
.55556 .17822 L
.66667 .17822 L
.66667 .01472 L
F
0 g
.55556 .01472 m
.55556 .17822 L
.66667 .17822 L
.66667 .01472 L
.55556 .01472 L
s
0 0 1 r
.66667 .01472 m
.66667 .11282 L
.77778 .11282 L
.77778 .01472 L
F
0 g
.66667 .01472 m
.66667 .11282 L
.77778 .11282 L
.77778 .01472 L
.66667 .01472 L
s
0 0 1 r
.77778 .01472 m
.77778 .04742 L
.88889 .04742 L
.88889 .01472 L
F
0 g
.77778 .01472 m
.77778 .04742 L
.88889 .04742 L
.88889 .01472 L
.77778 .01472 L
s
0 0 1 r
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
1 .01472 L
1 .01472 L
.88889 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?P3oool2000000@0oooo
0P0000030?ooo`@000003P3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000;@3oool002T0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000l0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000?03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00/0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`00:@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000P0oooo1@00000<0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:P3oool002T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0
oooo00@000000?ooo`3oool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool2000002d0oooo000Y0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0?03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0;03oool002X0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000?@3oool2000000X0oooo0P00000?0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000m0?ooo`8000002P3oool2000000l0oooo0P00
000:0?ooo`8000003`3oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003d0oooo0P00
000:0?ooo`8000003`3oool2000000X0oooo0P00000?0?ooo`8000002`3oool2000000h0oooo0P00
000:0?ooo`<00000;03oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`007@3oool2000000@0ooooPP00000K0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000@0ooooP`00000F0?ooo`00703oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000<0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo000L
0?ooo`040000003oool0oooo000000<0ooooP`00000I0?ooo`040000003oool0oooo00000080oooo
Q@00000H0?ooo`040000003oool0oooo000000<0ooooQ@00000H0?ooo`040000003oool0oooo0000
00<0ooooQ000000E0?ooo`00703oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo2@00000607moO`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool01000
0000oooo0?ooo`0000020?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0<0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000
o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`003000
o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0;0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0D0?ooo`00703oool010000000oooo0?ooo`0000030?ooo`800000
1@3oool8000000L0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`050?ooo`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`040000
003oool0oooo00000080oooo00<000000?l0003o0000303o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`007P00000=0?ooo`800000603oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o
000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000<003o
00030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00/0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01@0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`0;0?oo
o`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`050?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?oo
o`8000000`3oool00`000000o`000?l0000<0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01L0oooo0P0000040?oo
o`030000003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o
000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000<003o
00030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool2000000@0oooo00<000000?oo
o`3oool02`3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0503oool002<0oooo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool01@3oool8000001@0oooo00<000000?ooo`3o
ool07P3oool@000000h0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`0X0?ooo`80
00007`3oool00`000000oooo0?ooo`0<0?ooo`0300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02`3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`00
0?l02`000?l@000000d0oooo00<000000?ooo`3oool0503oool002<0oooo0P00000<0?ooo`030000
001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0303oool00`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00`0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000
0000o`000?l000/00?l000<00000003o0000o`003000o`000`0000000?l0003o000<003o00030000
003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`030000
00000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`030000
00000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0503oool002<0oooo00<000000?ooo`3oool02`3o
ool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0N0?ooo`8000003@3oool00`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?ooo`3oool0:03oool2000001l0oooo00<000000?ooo`3oool0303o
ool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000003o0000o`002`00
o`000`0000000?l0003o000<003o000300000000o`000?l000`00?l000<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo4000000=0000o`0300000000
0?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`0300000000
0?l0003o00/0003o00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`008`3oool2
000000`0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl8000002<0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool?
000000h00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o01000000:P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l0
0`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0503oool0
02<0oooo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
02P0oooo00<000000?ooo`3oool06@3oool2000000<0oooo0P00000=0?ooo`030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`004000000Z0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l0
00`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo
03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o
00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`03000000000?l0003o
00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01@0oooo000S0?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo2000000Z0?ooo`030000003oool0oooo01P0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l0
00`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?ooo`800000103oool00`00
0000oooo0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`00
0000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo000F0?ooo`D000000P3oool2000000@0
oooo0P00000<0?ooo`T000001P1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02l0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`02000000d0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`03
00000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o0003
0000003oool0oooo03L0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0503oool001P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0I
0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000
003o0000o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo0?ooo`8000006`3o
ool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`00
0?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0D0?ooo`00603oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool0oooo0P00000D0?ooo`P000001P1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool2000000d0oooo00<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`030000
0000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000
003oool0oooo03L0oooo00<000000?ooo`3oool0603oool2000000@0oooo00<000000?ooo`3oool0
6P3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0D0?ooo`00603oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000000L0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0I0?ooo`<000000P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;003o0003
00000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000003o0000o`0;0000o`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`l0
0000703oool00`000000oooo0?ooo`0D0?ooo`00603oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`P00000<@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00`0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0003o000<003o
000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01P0oooo0`0000030?ooo`030000003oool0oooo01X0oooo00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000
o`000?l030000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo000G0?ooo`80
0000103oool2000000@0oooo0P00000K0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool07P3oool2000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`80
00004P3oool500000080oooo0P0000040?ooo`030000003oool0oooo01X0oooo00<00000003o0000
o`003000o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo00<000000000o`00
0?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000000o`00
0?l030000?l00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo000S0?ooo`030000
003oool0oooo01X0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00`0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000703oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o
0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool06P3oool00`000000003o0000o`0;0000o`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000003o0000o`0<0000o`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0503oool002<0oooo0P00000K0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool07P3oool2000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`80
0000503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000K
0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0003o000<
003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0D
0?ooo`008`3oool00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000001`0oooo00<00000003o0000o`003000o`000`0000000?l0003o
000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo01X0oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`D000000P3oool2000000<0oooo0P00000=
0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0=`3oool2000001@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0140oooo1@0000020?ooo`800000103oool00`000000oooo
0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`03000000000?l0003o00`0003o00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0D0?ooo`008`3oool2000001/0oooo2000000607moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000>0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool06P3oool00`0000000?l0003o000<003o000300000000o`000?l000/00?l000<00000003o0000
o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000703oool00`000000003o0000o`0;
0000o`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000003o0000o`0<
0000o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0503oool002<0oooo00<000000?oo
o`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`02000000d0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0g
0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000
003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<00000
0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
0P00000K0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000oa000000:P3oool00`000000oooo0?ooo`0D0?ooo`008`3oool200000280oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00003P3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000
o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3o
ool04`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001H0oooo100000030?oo
o`800000103oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo008000003@3oool@000000d0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo0P00000O
0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001`0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0C0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool06`3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`0000000?l0
003o000<003o000300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001L0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000008P3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0N0?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0g0?ooo`8000007`3oool00`000000oooo
0?ooo`0J0?ooo`0300000000o`000?l000`00?l000<00000003o0000o`002`00o`000`0000000?l0
003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0J0?ooo`03000000000?l0003o00/0003o00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`000000
0?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l00`000000
003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0D0?ooo`005P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo0P00000R0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo01h0oooo0P00000L0?ooo`030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo
03L0oooo0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000003o0000o`003000o`000`00
00000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo00<000000000o`000?l02`000?l00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0D0?ooo`005`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0240
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`0300000000o`000?l000`0
0?l000<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`03000000000?l0003o00/0
003o00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0503oool002<0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0B0?ooo`D000000P3oool2000000<0oooo0P00000L0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03L0oooo
0P00000O0?ooo`030000003oool0oooo01X0oooo4000000=003o000300000000o`000?l000`00?l0
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0oooo
00<000000000o`000?l02`000?l00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`008`3oool200000280oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00007@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3o
ool06P3oool?000000h0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00800000703oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo
0?ooo`0g0?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l0
00<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000:P3oool00`00
0000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0D0?ooo`008`3oool200000280oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0
oooo00<000000?ooo`3oool0403oool4000000<0oooo0P0000040?ooo`030000003oool0oooo02T0
oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`800000:@3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`008`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`80
0000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0g0?ooo`8000004P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o
000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0503oool002<0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0C0?ooo`80
0000103oool300000080oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`800000:P3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000G0?ooo`80
0000103oool2000000@0oooo0P00000R0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01h0oooo0P00000L0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003oool0oooo03L0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000002/0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<
003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0`000003
0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001H0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`0
0?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0
oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0503oool001P0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo0?ooo`8000008P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00@0Ogmo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l0
00`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
02P0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0503oool001T0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000002<0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool07P3oool2000001`0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000l00000>@3oool2000001l0oooo00<00000
0?ooo`3oool0:@3oool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<00000
0000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0503oool001H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0407moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?oo
o`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o
000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool001L0oooo0P000004
0?ooo`800000103oool200000280oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03H0oooo00<000000?ooo`3oool04P3oool4000000<0oooo0P000003
0?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000003o0000o`0;
0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool002<0oooo00<000000?oo
o`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`P00000>03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0A
0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D
0?ooo`008`3oool200000280oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`800000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;
003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0X0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo0240oooo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001d0oooo00<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`00
3000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`800000:@3oool00`000000003o0000o`0<0000o`03
000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`00
8`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool2000001`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003oool0oooo04D0oooo0P00000O0?ooo`030000003oool0oooo02T0oooo00<00000003o
0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01@0oooo000S0?ooo`8000008P3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`04
07moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P000003
0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000003o
0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool002<0oooo00<0
00000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool07P3oool2000001`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003oool0oooo04D0oooo0P00000O0?ooo`030000003oool0oooo02T0oooo00<0
0000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<0
00000?ooo`3oool04P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0503oool002<0oooo0P00000R0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000
003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0:03oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`00603oool300000080oooo0P0000040?oo
o`030000003oool0oooo0240oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo01h0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`150?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?oo
o`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?oo
o`006@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000008`3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo03d0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool0
0`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l0
0`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool0
01H0oooo1@0000001@3oool000000?ooo`3oool0000000<0oooo0P00000R0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`@000000`3oool2
000000<0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000oooo0?ooo`150?ooo`8000004`3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo02T0oooo00<00000003o0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0
oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0
003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo01@0oooo000F0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<00000003o
0000o`002`00o`000`0000000?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?oo
o`3oool04@3oool4000000<0oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<000000000
o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0503oool001L0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?oo
o`8000008P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo03d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000703oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool20000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000:P3o
ool00`0000000?l0003o000;003o000300000000o`000?l000`00?l000<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l0
2`000?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000H0?ooo`8000000`3o
ool2000000@0oooo00<000000?ooo`3oool08@3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0407moO`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`8000000`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000002/0oooo00<00000003o0000o`002`00o`000`000000
0?l0003o000<003o00030000003oool0oooo03L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`800000:@3oool00`000000003o0000o`0<0000
o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?oo
o`008`3oool00`000000oooo0?ooo`0Q0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool2000001`0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003oool0oooo04D0oooo0P00000B0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<0
0000003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`000000003o0000
o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0D0?ooo`008`3oool200000280oooo2000000607moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01<0oooo0P000004
0?ooo`<000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<00000
003o0000o`003000o`000`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0
00000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0503oool002<0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo01h0oooo0P00000L0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000007`3oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<00000003o0000o`003000o`000`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`0X
0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01@0oooo000S0?ooo`800000:@3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`0@000003T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000000
o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000S0?ooo`03
0000003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0N0?ooo`80
0000703oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o0003
0000003oool0oooo04H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`03
000000000?l0003o00`0003o00<000000000o`000?l02`000?l00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01@0oooo000S0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
503oool001L0oooo0P0000040?ooo`800000103oool2000002T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l03000
0?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503o
ool001H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`800000
103oool2000000<0oooo0P00000L0?ooo`l000003P3o00000`000000oooo0?ooo`150?ooo`800000
7`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l0
30000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
503oool001T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000002T0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`P00000?`3oool00`000000
oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`00
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000000o`000?l02`000?l0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo000G0?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000Z0?ooo`030000003o
0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0oooo00<000000?ooo`3oool0:@3o
ool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0:03oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0D0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0E0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool00`000000o`000?l0000<
0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000002T0oooo
00<000000000o`000?l030000?l00`000000003o0000o`0;0000o`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0503oool001L0oooo0`0000030?ooo`800000103oool2000002T0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<000000?ooo`3oool0A@3oool2000001l0
oooo00<000000?ooo`3oool0:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0
oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`000000:P3oool00`000000003o0000o`0<0000o`03000000000?l0003o00/0003o00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`008`3oool00`000000oooo0?ooo`0X0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`140?oo
o`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003o0000o`0000`0o`0000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo0?ooo`160?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo02P0oooo00<000000000o`000?l030000?l00`000000003o0000
o`0;0000o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool002<0oooo0P00000Y
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo01h0oooo0P00000Z0?ooo`030000003o0000o`0000`0o`0000<00000
0?ooo`3oool0A@3oool2000001@0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`0Y
0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0:03oool00`000000003o0000o`0<
0000o`03000000000?l0003o00/0003o00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D
0?ooo`008`3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?oo
o`3oool04`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000:`3o
ool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o3`00000i0?ooo`030000003o
ool0oooo01@0oooo000S0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo04@0oooo00<000000?ooo`3oool07P3oool2
000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000004P3oool5
000000050?ooo`000000oooo0?ooo`0000000`3oool2000002X0oooo00<00000003o0000o`002`00
o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03o
ool00`000000003o0000o`0<0000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503o
ool002<0oooo0P00000Y0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01@1oOgl0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:@3oool0
0`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0D0?ooo`008`3oool00`000000oooo0?ooo`0X0?ooo`P000001`1o
Ogl00`000000oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool2000002X0oooo00<000000?l0003o0000303o00000`000000oooo0?ooo`150?ooo`8000004`3o
ool00`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
:@3oool00`0000000?l0003o000;003o00030000003oool0oooo04H0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0D0?ooo`008`3oool200000300oooo00<0000007moO`1oOgl01@1o
Ogl00`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000?l0003o
0000303o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0180oooo0P0000030?ooo`80
0000103oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000000o`00
0?l030000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo000F0?ooo`<00000
103oool2000000@0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507moO`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00800000:P3oool00`000000o`000?l0000<0?l000030000003oool0oooo04D0oooo
0P00000O0?ooo`030000003oool0oooo02T0oooo00<00000003o0000o`002`00o`000`000000oooo
0?ooo`160?ooo`030000003oool0oooo0180oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0D0?ooo`005P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0507moO`030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`3oool0:@3oool00`000000o`000?l0000<0?l000030000003oool0oooo04H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/00?l000<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0003o00`0003o00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`005P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0P00000`0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00P3oool2000002X0oooo00<000000?l0003o0000303o00000`000000
oooo0?ooo`150?ooo`8000007`3oool00`000000oooo0?ooo`0Y0?ooo`0300000000o`000?l000/0
0?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0P00000Y0?ooo`03000000000?l0003o00`0003o00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`005P3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0_0?ooo`T00000AP3oool00`000000oooo0?ooo`0C0?oo
o`800000103oool300000080oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000<0?l0
00030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?oo
o`0300000000o`000?l000/00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?oo
o`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`03000000000?l0
003o00`0003o00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`005`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool000000?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01h0oooo0P00000Z0?oooa000000A`3oool2000001l0oooo00<00000
0?ooo`3oool0:@3oool?000004P0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool@000004L0oooo00<0
00000?ooo`3oool0503oool001L0oooo0`0000030?ooo`800000103ooon200000200oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo0P000004
0?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo0035
0?ooohD000007`3ooon400000200ooooP`00000F0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {261.688, 184.75}} -> {-0.331812, \
1.43522, 0.00627702, 0.00627702}, {{42.25, 160.813}, {259.813, 186.563}} -> \
{-0.0920452, 173.898, 0.00349437, 0.804754}, {{172.688, 291.25}, {259.813, \
186.563}} -> {-0.644723, 103.71, 0.00343669, 0.480072}, {{303.063, 421.625}, \
{259.813, 186.563}} -> {-1.2048, 126.133, 0.00343669, 0.58387}, {{433.5, \
552.063}, {259.813, 186.563}} -> {-1.77699, 101.476, 0.00345575, 0.469687}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Mean, \ fractions4b]\)], "Input"],

Cell[BoxData[
    \({0.31285999008204834`, 0.33354640748009046`, 
      0.35359360243786087`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Flatten[fractions4b]]\)], "Input"],

Cell[BoxData[
    \(0.333333333333333`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[Flatten[fractions4b]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0030330173723411404`, 
      StandardDeviation \[Rule] 0.055072836973785365`, 
      SampleRange \[Rule] 0.33704753507964624`, 
      MeanDeviation \[Rule] 0.04151696951709953`, 
      MedianDeviation \[Rule] 0.032734146038776946`, 
      QuartileDeviation \[Rule] 0.03316656842950311`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(stats4b\  = \ 
        Map[DispersionReport, fractions4b]\ \  // \ 
          N;\)\), "\[IndentingNewLine]", 
    \(TableForm[Transpose[stats4b]]\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Variance \[Rule] 0.0032267365180448484`\), \(Variance \[Rule] 
              0.0017225193193191716`\), \(Variance \[Rule] 
              0.0033714513856614023`\)},
          {\(StandardDeviation \[Rule] 
              0.05680437058928519`\), \(StandardDeviation \[Rule] 
              0.04150324468423128`\), \(StandardDeviation \[Rule] 
              0.058064200551298406`\)},
          {\(SampleRange \[Rule] 
              0.31794965126928587`\), \(SampleRange \[Rule] 
              0.1999911633455574`\), \(SampleRange \[Rule] 
              0.287131293073838`\)},
          {\(MeanDeviation \[Rule] 
              0.042396796739497346`\), \(MeanDeviation \[Rule] 
              0.032505462696882426`\), \(MeanDeviation \[Rule] 
              0.0452183499823731`\)},
          {\(MedianDeviation \[Rule] 
              0.031690140845070436`\), \(MedianDeviation \[Rule] 
              0.02745172961419512`\), \(MedianDeviation \[Rule] 
              0.03343317037788568`\)},
          {\(QuartileDeviation \[Rule] 
              0.03184562204132621`\), \(QuartileDeviation \[Rule] 
              0.02659201838743039`\), \(QuartileDeviation \[Rule] 
              0.03340144318655283`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All pieces", "Subsection"],

Cell[CellGroupData[{

Cell["Manually Corrected Data", "Subsubsection"],

Cell[BoxData[
    \(\(allbeatdurs\  = \ 
        Flatten[{fractions1, \ fractions2, \ fractions3, \ 
            fractions4}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[allbeatdurs]\)], "Input"],

Cell[BoxData[
    \(0.3333333333333334`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[
      Flatten[{fractions1, \ fractions2, \ fractions3, \ 
          fractions4}]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0036367879131805514`, 
      StandardDeviation \[Rule] 0.06030578673046685`, 
      SampleRange \[Rule] 0.5027541311967951`, 
      MeanDeviation \[Rule] 0.0463485407857312`, 
      MedianDeviation \[Rule] 0.03705242659013114`, 
      QuartileDeviation \[Rule] 0.0375575945080652`}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(allbeat1dur\  = \ 
        Flatten[{fractions1[\([1]\)], \ fractions2[\([1]\)], \ 
            fractions3[\([1]\)], \ 
            fractions4[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(allbeat2dur\  = \ 
        Flatten[{fractions1[\([2]\)], \ fractions2[\([2]\)], \ 
            fractions3[\([2]\)], \ 
            fractions4[\([2]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(allbeat3dur\  = \ 
        Flatten[{fractions1[\([3]\)], \ fractions2[\([3]\)], \ 
            fractions3[\([3]\)], \ fractions4[\([3]\)]}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[allbeat1dur]\), "\[IndentingNewLine]", 
    \(Mean[allbeat2dur]\), "\[IndentingNewLine]", 
    \(Mean[allbeat3dur]\)}], "Input"],

Cell[BoxData[
    \(0.326869538585412`\)], "Output"],

Cell[BoxData[
    \(0.33178505969345545`\)], "Output"],

Cell[BoxData[
    \(0.34134540172113226`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DispersionReport[allbeat1dur]\), "\[IndentingNewLine]", 
    \(DispersionReport[allbeat2dur]\), "\[IndentingNewLine]", 
    \(DispersionReport[allbeat3dur]\)}], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.004278665203254914`, 
      StandardDeviation \[Rule] 0.0654115066578879`, 
      SampleRange \[Rule] 0.4189192880229435`, 
      MeanDeviation \[Rule] 0.05023805797154918`, 
      MedianDeviation \[Rule] 0.039411579609817504`, 
      QuartileDeviation \[Rule] 0.039522390321677064`}\)], "Output"],

Cell[BoxData[
    \({Variance \[Rule] 0.002632449802244562`, 
      StandardDeviation \[Rule] 0.05130740494552966`, 
      SampleRange \[Rule] 0.3322256787330317`, 
      MeanDeviation \[Rule] 0.03968788958594557`, 
      MedianDeviation \[Rule] 0.030938088512241058`, 
      QuartileDeviation \[Rule] 0.03022620808770829`}\)], "Output"],

Cell[BoxData[
    \({Variance \[Rule] 0.003907658039477204`, 
      StandardDeviation \[Rule] 0.06251126330092205`, 
      SampleRange \[Rule] 0.4759147672279179`, 
      MeanDeviation \[Rule] 0.04851491570531092`, 
      MedianDeviation \[Rule] 0.04068424777442545`, 
      QuartileDeviation \[Rule] 0.04101738907864769`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotall\  = \ 
        Histogram[Flatten[allbeatdurs], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.372093 2.32558 0.0147151 0.00606808 [
[.09302 -0.0125 -9 -9 ]
[.09302 -0.0125 9 0 ]
[.32558 -0.0125 -9 -9 ]
[.32558 -0.0125 9 0 ]
[.55814 -0.0125 -9 -9 ]
[.55814 -0.0125 9 0 ]
[.7907 -0.0125 -9 -9 ]
[.7907 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13608 -12 -4.5 ]
[-0.0125 .13608 0 4.5 ]
[-0.0125 .25744 -12 -4.5 ]
[-0.0125 .25744 0 4.5 ]
[-0.0125 .3788 -12 -4.5 ]
[-0.0125 .3788 0 4.5 ]
[-0.0125 .50016 -12 -4.5 ]
[-0.0125 .50016 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09302 0 m
.09302 .00625 L
s
[(0.2)] .09302 -0.0125 0 1 Mshowa
.32558 0 m
.32558 .00625 L
s
[(0.3)] .32558 -0.0125 0 1 Mshowa
.55814 0 m
.55814 .00625 L
s
[(0.4)] .55814 -0.0125 0 1 Mshowa
.7907 0 m
.7907 .00625 L
s
[(0.5)] .7907 -0.0125 0 1 Mshowa
.125 Mabswid
.13953 0 m
.13953 .00375 L
s
.18605 0 m
.18605 .00375 L
s
.23256 0 m
.23256 .00375 L
s
.27907 0 m
.27907 .00375 L
s
.37209 0 m
.37209 .00375 L
s
.4186 0 m
.4186 .00375 L
s
.46512 0 m
.46512 .00375 L
s
.51163 0 m
.51163 .00375 L
s
.60465 0 m
.60465 .00375 L
s
.65116 0 m
.65116 .00375 L
s
.69767 0 m
.69767 .00375 L
s
.74419 0 m
.74419 .00375 L
s
.04651 0 m
.04651 .00375 L
s
.83721 0 m
.83721 .00375 L
s
.88372 0 m
.88372 .00375 L
s
.93023 0 m
.93023 .00375 L
s
.97674 0 m
.97674 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13608 m
.00625 .13608 L
s
[(20)] -0.0125 .13608 1 0 Mshowa
0 .25744 m
.00625 .25744 L
s
[(40)] -0.0125 .25744 1 0 Mshowa
0 .3788 m
.00625 .3788 L
s
[(60)] -0.0125 .3788 1 0 Mshowa
0 .50016 m
.00625 .50016 L
s
[(80)] -0.0125 .50016 1 0 Mshowa
.125 Mabswid
0 .04506 m
.00375 .04506 L
s
0 .0754 m
.00375 .0754 L
s
0 .10574 m
.00375 .10574 L
s
0 .16642 m
.00375 .16642 L
s
0 .19676 m
.00375 .19676 L
s
0 .2271 m
.00375 .2271 L
s
0 .28778 m
.00375 .28778 L
s
0 .31812 m
.00375 .31812 L
s
0 .34846 m
.00375 .34846 L
s
0 .40914 m
.00375 .40914 L
s
0 .43948 m
.00375 .43948 L
s
0 .46982 m
.00375 .46982 L
s
0 .5305 m
.00375 .5305 L
s
0 .56084 m
.00375 .56084 L
s
0 .59118 m
.00375 .59118 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09302 .61178 m
.09302 .61803 L
s
.32558 .61178 m
.32558 .61803 L
s
.55814 .61178 m
.55814 .61803 L
s
.7907 .61178 m
.7907 .61803 L
s
.125 Mabswid
.13953 .61428 m
.13953 .61803 L
s
.18605 .61428 m
.18605 .61803 L
s
.23256 .61428 m
.23256 .61803 L
s
.27907 .61428 m
.27907 .61803 L
s
.37209 .61428 m
.37209 .61803 L
s
.4186 .61428 m
.4186 .61803 L
s
.46512 .61428 m
.46512 .61803 L
s
.51163 .61428 m
.51163 .61803 L
s
.60465 .61428 m
.60465 .61803 L
s
.65116 .61428 m
.65116 .61803 L
s
.69767 .61428 m
.69767 .61803 L
s
.74419 .61428 m
.74419 .61803 L
s
.04651 .61428 m
.04651 .61803 L
s
.83721 .61428 m
.83721 .61803 L
s
.88372 .61428 m
.88372 .61803 L
s
.93023 .61428 m
.93023 .61803 L
s
.97674 .61428 m
.97674 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13608 m
1 .13608 L
s
.99375 .25744 m
1 .25744 L
s
.99375 .3788 m
1 .3788 L
s
.99375 .50016 m
1 .50016 L
s
.125 Mabswid
.99625 .04506 m
1 .04506 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .10574 m
1 .10574 L
s
.99625 .16642 m
1 .16642 L
s
.99625 .19676 m
1 .19676 L
s
.99625 .2271 m
1 .2271 L
s
.99625 .28778 m
1 .28778 L
s
.99625 .31812 m
1 .31812 L
s
.99625 .34846 m
1 .34846 L
s
.99625 .40914 m
1 .40914 L
s
.99625 .43948 m
1 .43948 L
s
.99625 .46982 m
1 .46982 L
s
.99625 .5305 m
1 .5305 L
s
.99625 .56084 m
1 .56084 L
s
.99625 .59118 m
1 .59118 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02078 L
.02326 .02078 L
.02326 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02078 L
.02326 .02078 L
.02326 .01472 L
0 .01472 L
s
.5 .5 .5 r
.02326 .01472 m
.02326 .02685 L
.04651 .02685 L
.04651 .01472 L
F
0 g
.02326 .01472 m
.02326 .02685 L
.04651 .02685 L
.04651 .01472 L
.02326 .01472 L
s
.5 .5 .5 r
.04651 .01472 m
.04651 .03292 L
.06977 .03292 L
.06977 .01472 L
F
0 g
.04651 .01472 m
.04651 .03292 L
.06977 .03292 L
.06977 .01472 L
.04651 .01472 L
s
.5 .5 .5 r
.06977 .01472 m
.06977 .03292 L
.09302 .03292 L
.09302 .01472 L
F
0 g
.06977 .01472 m
.06977 .03292 L
.09302 .03292 L
.09302 .01472 L
.06977 .01472 L
s
.5 .5 .5 r
.09302 .01472 m
.09302 .06326 L
.11628 .06326 L
.11628 .01472 L
F
0 g
.09302 .01472 m
.09302 .06326 L
.11628 .06326 L
.11628 .01472 L
.09302 .01472 L
s
.5 .5 .5 r
.11628 .01472 m
.11628 .09967 L
.13953 .09967 L
.13953 .01472 L
F
0 g
.11628 .01472 m
.11628 .09967 L
.13953 .09967 L
.13953 .01472 L
.11628 .01472 L
s
.5 .5 .5 r
.13953 .01472 m
.13953 .0936 L
.16279 .0936 L
.16279 .01472 L
F
0 g
.13953 .01472 m
.13953 .0936 L
.16279 .0936 L
.16279 .01472 L
.13953 .01472 L
s
.5 .5 .5 r
.16279 .01472 m
.16279 .12394 L
.18605 .12394 L
.18605 .01472 L
F
0 g
.16279 .01472 m
.16279 .12394 L
.18605 .12394 L
.18605 .01472 L
.16279 .01472 L
s
.5 .5 .5 r
.18605 .01472 m
.18605 .20889 L
.2093 .20889 L
.2093 .01472 L
F
0 g
.18605 .01472 m
.18605 .20889 L
.2093 .20889 L
.2093 .01472 L
.18605 .01472 L
s
.5 .5 .5 r
.2093 .01472 m
.2093 .19676 L
.23256 .19676 L
.23256 .01472 L
F
0 g
.2093 .01472 m
.2093 .19676 L
.23256 .19676 L
.23256 .01472 L
.2093 .01472 L
s
.5 .5 .5 r
.23256 .01472 m
.23256 .25137 L
.25581 .25137 L
.25581 .01472 L
F
0 g
.23256 .01472 m
.23256 .25137 L
.25581 .25137 L
.25581 .01472 L
.23256 .01472 L
s
.5 .5 .5 r
.25581 .01472 m
.25581 .33632 L
.27907 .33632 L
.27907 .01472 L
F
0 g
.25581 .01472 m
.25581 .33632 L
.27907 .33632 L
.27907 .01472 L
.25581 .01472 L
s
.5 .5 .5 r
.27907 .01472 m
.27907 .42734 L
.30233 .42734 L
.30233 .01472 L
F
0 g
.27907 .01472 m
.27907 .42734 L
.30233 .42734 L
.30233 .01472 L
.27907 .01472 L
s
.5 .5 .5 r
.30233 .01472 m
.30233 .49409 L
.32558 .49409 L
.32558 .01472 L
F
0 g
.30233 .01472 m
.30233 .49409 L
.32558 .49409 L
.32558 .01472 L
.30233 .01472 L
s
.5 .5 .5 r
.32558 .01472 m
.32558 .57905 L
.34884 .57905 L
.34884 .01472 L
F
0 g
.32558 .01472 m
.32558 .57905 L
.34884 .57905 L
.34884 .01472 L
.32558 .01472 L
s
.5 .5 .5 r
.34884 .01472 m
.34884 .57298 L
.37209 .57298 L
.37209 .01472 L
F
0 g
.34884 .01472 m
.34884 .57298 L
.37209 .57298 L
.37209 .01472 L
.34884 .01472 L
s
.5 .5 .5 r
.37209 .01472 m
.37209 .56691 L
.39535 .56691 L
.39535 .01472 L
F
0 g
.37209 .01472 m
.37209 .56691 L
.39535 .56691 L
.39535 .01472 L
.37209 .01472 L
s
.5 .5 .5 r
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
F
0 g
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
.39535 .01472 L
s
.5 .5 .5 r
.4186 .01472 m
.4186 .48803 L
.44186 .48803 L
.44186 .01472 L
F
0 g
.4186 .01472 m
.4186 .48803 L
.44186 .48803 L
.44186 .01472 L
.4186 .01472 L
s
.5 .5 .5 r
.44186 .01472 m
.44186 .51837 L
.46512 .51837 L
.46512 .01472 L
F
0 g
.44186 .01472 m
.44186 .51837 L
.46512 .51837 L
.46512 .01472 L
.44186 .01472 L
s
.5 .5 .5 r
.46512 .01472 m
.46512 .397 L
.48837 .397 L
.48837 .01472 L
F
0 g
.46512 .01472 m
.46512 .397 L
.48837 .397 L
.48837 .01472 L
.46512 .01472 L
s
.5 .5 .5 r
.48837 .01472 m
.48837 .397 L
.51163 .397 L
.51163 .01472 L
F
0 g
.48837 .01472 m
.48837 .397 L
.51163 .397 L
.51163 .01472 L
.48837 .01472 L
s
.5 .5 .5 r
.51163 .01472 m
.51163 .39094 L
.53488 .39094 L
.53488 .01472 L
F
0 g
.51163 .01472 m
.51163 .39094 L
.53488 .39094 L
.53488 .01472 L
.51163 .01472 L
s
.5 .5 .5 r
.53488 .01472 m
.53488 .33026 L
.55814 .33026 L
.55814 .01472 L
F
0 g
.53488 .01472 m
.53488 .33026 L
.55814 .33026 L
.55814 .01472 L
.53488 .01472 L
s
.5 .5 .5 r
.55814 .01472 m
.55814 .19676 L
.5814 .19676 L
.5814 .01472 L
F
0 g
.55814 .01472 m
.55814 .19676 L
.5814 .19676 L
.5814 .01472 L
.55814 .01472 L
s
.5 .5 .5 r
.5814 .01472 m
.5814 .14821 L
.60465 .14821 L
.60465 .01472 L
F
0 g
.5814 .01472 m
.5814 .14821 L
.60465 .14821 L
.60465 .01472 L
.5814 .01472 L
s
.5 .5 .5 r
.60465 .01472 m
.60465 .13001 L
.62791 .13001 L
.62791 .01472 L
F
0 g
.60465 .01472 m
.60465 .13001 L
.62791 .13001 L
.62791 .01472 L
.60465 .01472 L
s
.5 .5 .5 r
.62791 .01472 m
.62791 .12394 L
.65116 .12394 L
.65116 .01472 L
F
0 g
.62791 .01472 m
.62791 .12394 L
.65116 .12394 L
.65116 .01472 L
.62791 .01472 L
s
.5 .5 .5 r
.65116 .01472 m
.65116 .0936 L
.67442 .0936 L
.67442 .01472 L
F
0 g
.65116 .01472 m
.65116 .0936 L
.67442 .0936 L
.67442 .01472 L
.65116 .01472 L
s
.5 .5 .5 r
.67442 .01472 m
.67442 .0754 L
.69767 .0754 L
.69767 .01472 L
F
0 g
.67442 .01472 m
.67442 .0754 L
.69767 .0754 L
.69767 .01472 L
.67442 .01472 L
s
.5 .5 .5 r
.69767 .01472 m
.69767 .04506 L
.72093 .04506 L
.72093 .01472 L
F
0 g
.69767 .01472 m
.69767 .04506 L
.72093 .04506 L
.72093 .01472 L
.69767 .01472 L
s
.5 .5 .5 r
.72093 .01472 m
.72093 .04506 L
.74419 .04506 L
.74419 .01472 L
F
0 g
.72093 .01472 m
.72093 .04506 L
.74419 .04506 L
.74419 .01472 L
.72093 .01472 L
s
.5 .5 .5 r
.74419 .01472 m
.74419 .0754 L
.76744 .0754 L
.76744 .01472 L
F
0 g
.74419 .01472 m
.74419 .0754 L
.76744 .0754 L
.76744 .01472 L
.74419 .01472 L
s
.5 .5 .5 r
.76744 .01472 m
.76744 .02078 L
.7907 .02078 L
.7907 .01472 L
F
0 g
.76744 .01472 m
.76744 .02078 L
.7907 .02078 L
.7907 .01472 L
.76744 .01472 L
s
.5 .5 .5 r
.7907 .01472 m
.7907 .01472 L
.81395 .01472 L
.81395 .01472 L
F
0 g
.7907 .01472 m
.7907 .01472 L
.81395 .01472 L
.81395 .01472 L
.7907 .01472 L
s
.5 .5 .5 r
.81395 .01472 m
.81395 .03292 L
.83721 .03292 L
.83721 .01472 L
F
0 g
.81395 .01472 m
.81395 .03292 L
.83721 .03292 L
.83721 .01472 L
.81395 .01472 L
s
.5 .5 .5 r
.83721 .01472 m
.83721 .02685 L
.86047 .02685 L
.86047 .01472 L
F
0 g
.83721 .01472 m
.83721 .02685 L
.86047 .02685 L
.86047 .01472 L
.83721 .01472 L
s
.5 .5 .5 r
.86047 .01472 m
.86047 .02078 L
.88372 .02078 L
.88372 .01472 L
F
0 g
.86047 .01472 m
.86047 .02078 L
.88372 .02078 L
.88372 .01472 L
.86047 .01472 L
s
.5 .5 .5 r
.88372 .01472 m
.88372 .02078 L
.90698 .02078 L
.90698 .01472 L
F
0 g
.88372 .01472 m
.88372 .02078 L
.90698 .02078 L
.90698 .01472 L
.88372 .01472 L
s
.5 .5 .5 r
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
F
0 g
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
.90698 .01472 L
s
.5 .5 .5 r
.93023 .01472 m
.93023 .02685 L
.95349 .02685 L
.95349 .01472 L
F
0 g
.93023 .01472 m
.93023 .02685 L
.95349 .02685 L
.95349 .01472 L
.93023 .01472 L
s
.5 .5 .5 r
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
F
0 g
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
.95349 .01472 L
s
.5 .5 .5 r
.97674 .01472 m
.97674 .02078 L
1 .02078 L
1 .01472 L
F
0 g
.97674 .01472 m
.97674 .02078 L
1 .02078 L
1 .01472 L
.97674 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;`3oool2000000@0oooo0P0000040?oo
o`800000<03oool2000000@0oooo0P0000050?ooo`<00000;P3oool2000000@0oooo0P0000040?oo
o`800000=@3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0_0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000d0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0
oooo000000P0oooo1@00000]0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
<P3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0]0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002@3oool2000003D0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000^0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=03o
ool002<0oooo0P00000:0?ooo`800000<03oool2000000X0oooo0P00000`0?ooo`8000002`3oool2
000002l0oooo0P00000:0?ooo`<00000=03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`L00000
1@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo3@0000050?ooo`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0103oool7000000<0oooo00090?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000003o
ool0oooo00@0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo00T0oooo00<0000007moO`1oOgl00`1o
Ogl800000140oooo1`00000<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00X0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0:0?ooo`d000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
00T0oooo1`00000[0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01H0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000001L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`h000001@1oOgl00`000000oooo0?ooo`0j0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool05P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo03/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool05P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool02P3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo03/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3o
ool7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0307moO`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0703oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo00X0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000001d0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo1`00000<0?ooo`L00000?03oool2000000<0oooo000A0?ooo`030000003oool0oooo01`0oooo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0L0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo05@0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0703oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo01`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0L0?ooo`030000001oOgl0Ogmo00@0Ogmo1`00000507moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl7000005H0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0703oool8000000D0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0Y0?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000Z0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo05T0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0Y0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
05X0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0:@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02T0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0Y0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo05X0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0:@3oool7000000D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo1`00001L0?ooo`030000003oool0oooo0040oooo00030?oo
o`@000000`3oool2000000D0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo0600oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02l0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo2000001R0?oo
o`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool3000002l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0I@3oool3000000<0oooo00050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0;`3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0040oooo00040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo1`00001Y0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02l0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo06d0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo06d0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000`0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1/0?oo
o`8000000`3oool00140oooo00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;`3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo02l0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo06d0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`010?ooo`004@3oool200000300oooo00<0
000007moO`1oOgl00`1oOgl7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl7000006h0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0_0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0_0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool00`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0_0?ooo`L00000
1@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0k0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003`0
oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0780
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0k0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00@3oool000D0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`0k0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0040oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0k0?ooo`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0040oooo00030?ooo`D0000000D0oooo0000003oool0oooo000000040?ooo`<00000
@P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0740oooo0`0000030?ooo`000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0@P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00@3oool000@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0480oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0040oooo00050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0
@P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0@P3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
07<0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0@P3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0@P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00@3oool00140oooo0P0000130?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0LP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0480oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0480oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0480oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0480oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0480oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0480oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo0480oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000@`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0780oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`120?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`120?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`12
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`L00000M@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`120?oo
o`L000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`180?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000190?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1h0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`180?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04P0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`180?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0040oooo00030?oo
o`<00000103oool2000000D0oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`010?oo
o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo0`0000180?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1g0?ooo`<000000`3oool000<0oooo0`000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`010?ooo`00103oool3000000<0oooo0P000005
0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl7000007/0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo07l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo3P0000210?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`010?ooo`004@3oool2
000004T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo08/0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`180?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04P0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo08`0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`180?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04P0oooo1`000005
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo08`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0CP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo08`0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0CP3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001?0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0R`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo04h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04h0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04h0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04h0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo04h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04h0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000C`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`1>0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1>0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1>0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1>0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl70000
00D0Ogmo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo04h0oooo1`00000507moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0040
oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo08`0oooo00<000000?ooo`3oool00@3oool000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`<00000E03oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`2:0?ooo`<000000`3oool000@0oooo0P0000030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo08`0oooo00<000000?ooo`3oool00@3o
ool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1D0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo08`0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0E03oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05@0
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`L00000SP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1D0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0V03oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005D0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2G
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo09P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0E03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo09P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0E03o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo09P0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo09P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0E03oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo09P0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0E03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo09P0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001E0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0U`3oool2000000<0oooo000A0?ooo`030000003oool0oooo05@0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo05@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`L000001@1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05@0oooo00<0000007moO`1oOgl00`1oOgl8000000D0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05@0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0:0?ooo`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1D0?ooo`L00000303oool00`000000Ogmo07moO`0307moO`030000
003oool0oooo09P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0I`3o
ool00`000000Ogmo07moO`0307moO`030000003oool0oooo09P0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0I`3oool00`000000Ogmo07moO`0307moO`030000003oool0
oooo09P0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001X0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0U`3oool2000000<0oooo000A0?ooo`030000003oool0oooo06L0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo06L0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo06L0oooo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo06L0oooo1`00002J0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000A0?ooool000003@0000030?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0775284, \
0.541034, 0.00161733, 0.61984}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb1\  = 
        Histogram[allbeat1dur, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00964924 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11121 -12 -4.5 ]
[-0.0125 .11121 0 4.5 ]
[-0.0125 .2077 -12 -4.5 ]
[-0.0125 .2077 0 4.5 ]
[-0.0125 .30419 -12 -4.5 ]
[-0.0125 .30419 0 4.5 ]
[-0.0125 .40068 -12 -4.5 ]
[-0.0125 .40068 0 4.5 ]
[-0.0125 .49718 -12 -4.5 ]
[-0.0125 .49718 0 4.5 ]
[-0.0125 .59367 -12 -4.5 ]
[-0.0125 .59367 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11121 m
.00625 .11121 L
s
[(10)] -0.0125 .11121 1 0 Mshowa
0 .2077 m
.00625 .2077 L
s
[(20)] -0.0125 .2077 1 0 Mshowa
0 .30419 m
.00625 .30419 L
s
[(30)] -0.0125 .30419 1 0 Mshowa
0 .40068 m
.00625 .40068 L
s
[(40)] -0.0125 .40068 1 0 Mshowa
0 .49718 m
.00625 .49718 L
s
[(50)] -0.0125 .49718 1 0 Mshowa
0 .59367 m
.00625 .59367 L
s
[(60)] -0.0125 .59367 1 0 Mshowa
.125 Mabswid
0 .03401 m
.00375 .03401 L
s
0 .05331 m
.00375 .05331 L
s
0 .07261 m
.00375 .07261 L
s
0 .09191 m
.00375 .09191 L
s
0 .13051 m
.00375 .13051 L
s
0 .1498 m
.00375 .1498 L
s
0 .1691 m
.00375 .1691 L
s
0 .1884 m
.00375 .1884 L
s
0 .227 m
.00375 .227 L
s
0 .2463 m
.00375 .2463 L
s
0 .2656 m
.00375 .2656 L
s
0 .28489 m
.00375 .28489 L
s
0 .32349 m
.00375 .32349 L
s
0 .34279 m
.00375 .34279 L
s
0 .36209 m
.00375 .36209 L
s
0 .38139 m
.00375 .38139 L
s
0 .41998 m
.00375 .41998 L
s
0 .43928 m
.00375 .43928 L
s
0 .45858 m
.00375 .45858 L
s
0 .47788 m
.00375 .47788 L
s
0 .51648 m
.00375 .51648 L
s
0 .53577 m
.00375 .53577 L
s
0 .55507 m
.00375 .55507 L
s
0 .57437 m
.00375 .57437 L
s
0 .61297 m
.00375 .61297 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11121 m
1 .11121 L
s
.99375 .2077 m
1 .2077 L
s
.99375 .30419 m
1 .30419 L
s
.99375 .40068 m
1 .40068 L
s
.99375 .49718 m
1 .49718 L
s
.99375 .59367 m
1 .59367 L
s
.125 Mabswid
.99625 .03401 m
1 .03401 L
s
.99625 .05331 m
1 .05331 L
s
.99625 .07261 m
1 .07261 L
s
.99625 .09191 m
1 .09191 L
s
.99625 .13051 m
1 .13051 L
s
.99625 .1498 m
1 .1498 L
s
.99625 .1691 m
1 .1691 L
s
.99625 .1884 m
1 .1884 L
s
.99625 .227 m
1 .227 L
s
.99625 .2463 m
1 .2463 L
s
.99625 .2656 m
1 .2656 L
s
.99625 .28489 m
1 .28489 L
s
.99625 .32349 m
1 .32349 L
s
.99625 .34279 m
1 .34279 L
s
.99625 .36209 m
1 .36209 L
s
.99625 .38139 m
1 .38139 L
s
.99625 .41998 m
1 .41998 L
s
.99625 .43928 m
1 .43928 L
s
.99625 .45858 m
1 .45858 L
s
.99625 .47788 m
1 .47788 L
s
.99625 .51648 m
1 .51648 L
s
.99625 .53577 m
1 .53577 L
s
.99625 .55507 m
1 .55507 L
s
.99625 .57437 m
1 .57437 L
s
.99625 .61297 m
1 .61297 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03401 L
.04545 .03401 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03401 L
.04545 .03401 L
.04545 .01472 L
0 .01472 L
s
1 0 0 r
.04545 .01472 m
.04545 .06296 L
.09091 .06296 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .06296 L
.09091 .06296 L
.09091 .01472 L
.04545 .01472 L
s
1 0 0 r
.09091 .01472 m
.09091 .13051 L
.13636 .13051 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .13051 L
.13636 .13051 L
.13636 .01472 L
.09091 .01472 L
s
1 0 0 r
.13636 .01472 m
.13636 .1884 L
.18182 .1884 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .1884 L
.18182 .1884 L
.18182 .01472 L
.13636 .01472 L
s
1 0 0 r
.18182 .01472 m
.18182 .27524 L
.22727 .27524 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .27524 L
.22727 .27524 L
.22727 .01472 L
.18182 .01472 L
s
1 0 0 r
.22727 .01472 m
.22727 .28489 L
.27273 .28489 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .28489 L
.27273 .28489 L
.27273 .01472 L
.22727 .01472 L
s
1 0 0 r
.27273 .01472 m
.27273 .46823 L
.31818 .46823 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .46823 L
.31818 .46823 L
.31818 .01472 L
.27273 .01472 L
s
1 0 0 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
1 0 0 r
.36364 .01472 m
.36364 .55507 L
.40909 .55507 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .55507 L
.40909 .55507 L
.40909 .01472 L
.36364 .01472 L
s
1 0 0 r
.40909 .01472 m
.40909 .53577 L
.45455 .53577 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .53577 L
.45455 .53577 L
.45455 .01472 L
.40909 .01472 L
s
1 0 0 r
.45455 .01472 m
.45455 .33314 L
.5 .33314 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .33314 L
.5 .33314 L
.5 .01472 L
.45455 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .37174 L
.54545 .37174 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .37174 L
.54545 .37174 L
.54545 .01472 L
.5 .01472 L
s
1 0 0 r
.54545 .01472 m
.54545 .14016 L
.59091 .14016 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .14016 L
.59091 .14016 L
.59091 .01472 L
.54545 .01472 L
s
1 0 0 r
.59091 .01472 m
.59091 .13051 L
.63636 .13051 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .13051 L
.63636 .13051 L
.63636 .01472 L
.59091 .01472 L
s
1 0 0 r
.63636 .01472 m
.63636 .09191 L
.68182 .09191 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .09191 L
.68182 .09191 L
.68182 .01472 L
.63636 .01472 L
s
1 0 0 r
.68182 .01472 m
.68182 .05331 L
.72727 .05331 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .05331 L
.72727 .05331 L
.72727 .01472 L
.68182 .01472 L
s
1 0 0 r
.72727 .01472 m
.72727 .05331 L
.77273 .05331 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .05331 L
.77273 .05331 L
.77273 .01472 L
.72727 .01472 L
s
1 0 0 r
.77273 .01472 m
.77273 .03401 L
.81818 .03401 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .03401 L
.81818 .03401 L
.81818 .01472 L
.77273 .01472 L
s
1 0 0 r
.81818 .01472 m
.81818 .02436 L
.86364 .02436 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02436 L
.86364 .02436 L
.86364 .01472 L
.81818 .01472 L
s
1 0 0 r
.86364 .01472 m
.86364 .02436 L
.90909 .02436 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .02436 L
.90909 .02436 L
.90909 .01472 L
.86364 .01472 L
s
1 0 0 r
.90909 .01472 m
.90909 .02436 L
.95455 .02436 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02436 L
.95455 .02436 L
.95455 .01472 L
.90909 .01472 L
s
1 0 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o000V000000/0oooo00<000000?ooo`3oool0
0@3oool000X0oooo0P0000050?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`010?ooo`004@3oool>0000
00/0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`003@00000_0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool02P3oool00`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003oool0oooo03X0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool02P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo03X0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003oool0oooo03X0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool02P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo03X0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00000;0?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o000I000003/0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00X0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003oool0oooo0580oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool02P3oool=000000/0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
01L0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1A0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool05P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo0580
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool05P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo0580oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo0P00000G0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00d00000D`3oool2000000<0oooo000A0?ooo`030000003oool0oooo01H0oooo00<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003oool0oooo05h0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo00030?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool05P3oool00`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`01
0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3
000001H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0G03oool3000000<0oooo00050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0
oooo05h0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003oool0oooo05h0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool05P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040
oooo000A0?ooo`8000005`3oool=000000/0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`003@00001O0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool08P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo06X0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool00`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o000=000006`0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0280oooo00<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000002<0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo0280oooo00<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool00`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0280
oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000002<0oooo
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo0280oooo00<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R
0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool08P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0280oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000002<0oooo3@00000;0?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o
00000`000000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`000`3oool40000
00<0oooo0P0000050?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
02h0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
07H0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`<00000;P3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0M03oool3000000<0oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo02h0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo02h0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000_0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1e0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
02h0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo
07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000002l0oooo00<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l000090?l000030000003oool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo02h0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000_0?ooo`030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1e0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0;P3oool00`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`0^0?ooo`d000002`3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000>`3oool=000000/0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003oool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`16
0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002P3o00000`000000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo0`0000160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo07@0oooo0`0000030?ooo`001P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003oool0
oooo07H0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000A`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`003P00000;0?l0
00030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o
00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000
A`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<000000?l0003o00002@3o
00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000
o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool02P3oool00`00
0000o`000?l000090?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo00X0
oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000A`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo
00<000000?l0003o00002@3o00000`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo00X0oooo00<0
00000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`0:
0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool02P3oool=000007P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P0000170?ooo`030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
SP3oool2000000<0oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00050?ooo`<000000P3oool2000000D0
oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0
oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00030?ooo`D0000000D0oooo0000003oool0
oooo000000040?ooo`<00000AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08d0
oooo0`0000030?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo
08l0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00050?ooo`8000000`3oool2000000D0
oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
00170?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0SP3oool2000000<0oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000A`3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003oool0oooo08h0oooo0P0000030?ooo`004@3oool0
0`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004L0oooo00<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0AP3oool=000000/0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000D`3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0DP3oool0
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0040oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool30000
0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0S@3oool3000000<0oooo00040?ooo`8000000`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0040oooo00040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0DP3oool00`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005<0oooo00<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0SP3oool2000000<0oooo000A0?ooo`030000003oool0oooo0580oooo00<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3o
ool00140oooo0P00001C0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o000=
00000900oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000D`3oool00`000000o`000?l00009
0?l000d00000W03oool2000000<0oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0
003o00002@3o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo0580oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000D`3oool00`000000o`000?l000090?l000030000003oool0
oooo0:H0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`00
00T0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`010?ooo`000`3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0580oooo
00<000000?l0003o00002@3o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0040oooo
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo0`00001B0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0Y@3oool30000
00<0oooo00030?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0580oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
0040oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`010?ooo`00103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo0580
oooo3@00002Y0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0?l0oooo
2@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000000/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`004@3ooooo
000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0756102, \
83.6897, 0.00165494, 0.389796}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb2\  = 
        Histogram[allbeat2dur, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00784805 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -12 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -12 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -12 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -12 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(10)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(20)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(30)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(40)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(50)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(60)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(70)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03041 m
.00375 .03041 L
s
0 .04611 m
.00375 .04611 L
s
0 .0618 m
.00375 .0618 L
s
0 .0775 m
.00375 .0775 L
s
0 .10889 m
.00375 .10889 L
s
0 .12459 m
.00375 .12459 L
s
0 .14028 m
.00375 .14028 L
s
0 .15598 m
.00375 .15598 L
s
0 .18737 m
.00375 .18737 L
s
0 .20307 m
.00375 .20307 L
s
0 .21876 m
.00375 .21876 L
s
0 .23446 m
.00375 .23446 L
s
0 .26585 m
.00375 .26585 L
s
0 .28155 m
.00375 .28155 L
s
0 .29724 m
.00375 .29724 L
s
0 .31294 m
.00375 .31294 L
s
0 .34433 m
.00375 .34433 L
s
0 .36003 m
.00375 .36003 L
s
0 .37573 m
.00375 .37573 L
s
0 .39142 m
.00375 .39142 L
s
0 .42281 m
.00375 .42281 L
s
0 .43851 m
.00375 .43851 L
s
0 .45421 m
.00375 .45421 L
s
0 .4699 m
.00375 .4699 L
s
0 .50129 m
.00375 .50129 L
s
0 .51699 m
.00375 .51699 L
s
0 .53269 m
.00375 .53269 L
s
0 .54838 m
.00375 .54838 L
s
0 .57977 m
.00375 .57977 L
s
0 .59547 m
.00375 .59547 L
s
0 .61117 m
.00375 .61117 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03041 m
1 .03041 L
s
.99625 .04611 m
1 .04611 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0775 m
1 .0775 L
s
.99625 .10889 m
1 .10889 L
s
.99625 .12459 m
1 .12459 L
s
.99625 .14028 m
1 .14028 L
s
.99625 .15598 m
1 .15598 L
s
.99625 .18737 m
1 .18737 L
s
.99625 .20307 m
1 .20307 L
s
.99625 .21876 m
1 .21876 L
s
.99625 .23446 m
1 .23446 L
s
.99625 .26585 m
1 .26585 L
s
.99625 .28155 m
1 .28155 L
s
.99625 .29724 m
1 .29724 L
s
.99625 .31294 m
1 .31294 L
s
.99625 .34433 m
1 .34433 L
s
.99625 .36003 m
1 .36003 L
s
.99625 .37573 m
1 .37573 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .42281 m
1 .42281 L
s
.99625 .43851 m
1 .43851 L
s
.99625 .45421 m
1 .45421 L
s
.99625 .4699 m
1 .4699 L
s
.99625 .50129 m
1 .50129 L
s
.99625 .51699 m
1 .51699 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .54838 m
1 .54838 L
s
.99625 .57977 m
1 .57977 L
s
.99625 .59547 m
1 .59547 L
s
.99625 .61117 m
1 .61117 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
0 1 0 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
0 1 0 r
.09091 .01472 m
.09091 .04611 L
.13636 .04611 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .04611 L
.13636 .04611 L
.13636 .01472 L
.09091 .01472 L
s
0 1 0 r
.13636 .01472 m
.13636 .05396 L
.18182 .05396 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .05396 L
.18182 .05396 L
.18182 .01472 L
.13636 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .13244 L
.22727 .13244 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .13244 L
.22727 .13244 L
.22727 .01472 L
.18182 .01472 L
s
0 1 0 r
.22727 .01472 m
.22727 .28155 L
.27273 .28155 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .28155 L
.27273 .28155 L
.27273 .01472 L
.22727 .01472 L
s
0 1 0 r
.27273 .01472 m
.27273 .44636 L
.31818 .44636 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .44636 L
.31818 .44636 L
.31818 .01472 L
.27273 .01472 L
s
0 1 0 r
.31818 .01472 m
.31818 .58762 L
.36364 .58762 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .58762 L
.36364 .58762 L
.36364 .01472 L
.31818 .01472 L
s
0 1 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 1 0 r
.40909 .01472 m
.40909 .50129 L
.45455 .50129 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .50129 L
.45455 .50129 L
.45455 .01472 L
.40909 .01472 L
s
0 1 0 r
.45455 .01472 m
.45455 .32864 L
.5 .32864 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .32864 L
.5 .32864 L
.5 .01472 L
.45455 .01472 L
s
0 1 0 r
.5 .01472 m
.5 .18737 L
.54545 .18737 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .18737 L
.54545 .18737 L
.54545 .01472 L
.5 .01472 L
s
0 1 0 r
.54545 .01472 m
.54545 .15598 L
.59091 .15598 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .15598 L
.59091 .15598 L
.59091 .01472 L
.54545 .01472 L
s
0 1 0 r
.59091 .01472 m
.59091 .10104 L
.63636 .10104 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .10104 L
.63636 .10104 L
.63636 .01472 L
.59091 .01472 L
s
0 1 0 r
.63636 .01472 m
.63636 .06965 L
.68182 .06965 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .06965 L
.68182 .06965 L
.68182 .01472 L
.63636 .01472 L
s
0 1 0 r
.68182 .01472 m
.68182 .03826 L
.72727 .03826 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .03826 L
.72727 .03826 L
.72727 .01472 L
.68182 .01472 L
s
0 1 0 r
.72727 .01472 m
.72727 .03041 L
.77273 .03041 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .03041 L
.77273 .03041 L
.77273 .01472 L
.72727 .01472 L
s
0 1 0 r
.77273 .01472 m
.77273 .02256 L
.81818 .02256 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02256 L
.81818 .02256 L
.81818 .01472 L
.77273 .01472 L
s
0 1 0 r
.81818 .01472 m
.81818 .02256 L
.86364 .02256 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02256 L
.86364 .02256 L
.86364 .01472 L
.81818 .01472 L
s
0 1 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 1 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
0 1 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o00030000003oool0oooo0280oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o01T00000
903oool00`000000oooo0?ooo`010?ooo`002P3oool2000000D0oooo00<000000?ooo`3oool05P3o
ool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0040oooo000A0?ooo`8000005`3oool0
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l03@00000k0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool05P3oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0F0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l03@0000180?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo01H0oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`8000005`3oool=000000/00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo0540oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo0580oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool=000000/00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo0P00000_0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1A0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l03@00001D0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000;`3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo05d0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P000005
0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000;P3oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o00030000003oool0oooo05`0oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o00d00000H03oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000002l0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0J@3oool2000000<0oooo000A0?ooo`030000
003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000;`3oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1Y0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo02h0oooo3@00000;003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>`3oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0J@3oool2000000<0oooo000A0?oo
o`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
00030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo0040oooo000A0?ooo`800000>`3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00d00000J`3o
ool2000000<0oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0>P3oool00`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o00030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03X0
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040
oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool3000003X0
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1d0?ooo`<000000`3oool000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo07H0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo07H0oooo00<000000?ooo`3o
ool00@3oool00140oooo0P00000k0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00d00000M`3oool2000000<0oooo000A0?ooo`030000003o
ool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000>`3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00000k0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0840oooo0P0000030?oo
o`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000003/0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0P@3oool2
000000<0oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03X0
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X0
0?l000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000003X0oooo00<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0P03oool3000000<0oooo00060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3o
ool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03X0oooo00<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003/0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0
P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0
oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>`3oool=000000/0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`160?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo0P0000170?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3o
ool00140oooo0P0000170?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`00
0`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0AP3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`010?ooo`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo04H0
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool000<0oooo
1@0000001@3oool000000?ooo`3oool0000000@0oooo0`0000160?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l03P0000220?ooo`<000000`3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool000000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`001@3oool2000000<0
oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000A`3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08h0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004L0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0
oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140
oooo0P0000170?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0SP3oool2000000<0
oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000A`3oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
00030000003oool0oooo08h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
1P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`0000160?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S@3oool3000000<0oooo00040?ooo`800000
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04H0oooo00<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04H0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`800000A`3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0
oooo08h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004L0oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool=000000/00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000D`3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2>0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo
08l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001C0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08h0
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo
00<000000?ooo`3oool00@3oool000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?oo
o`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo0`00001B0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08d0
oooo0`0000030?ooo`000`3oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00103oool3000000<0oooo
0P0000050?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005<0oooo00<00000003o0000o`002@00o`000`0000000?l0003o
0009003o00d00000T03oool2000000<0oooo000A0?ooo`030000003oool0oooo0580oooo00<00000
003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001C0?ooo`0300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2J0?ooo`8000000`3o
ool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo09/0
oooo00<000000?ooo`3oool00@3oool00140oooo0P00001C0?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`000000oooo0?ooo`2J0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<000000?oo
o`3oool00@3oool00140oooo0P00001C0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`2J0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`020?ooo`8000001@3o
ool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo00050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo00<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<0
00000?ooo`3oool00@3oool000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo0`00001B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`2I0?ooo`<000000`3oool000H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool000<0oooo100000030?ooo`8000001@3o
ool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000D`3oool0
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0VP3oool2
000000<0oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0DP3oool=000000/00?l000<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`0300000000o`000?l000T00?l0
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005l0oooo00<0
0000003o0000o`002@00o`000`000000oooo0?ooo`2J0?ooo`8000000`3oool00140oooo00<00000
0?ooo`3oool0GP3oool00`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool00`0000000?l0003o0009003o
00030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0GP3oool=000009d0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0040oooo000A0?ooo`8000002`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool2000000<0oooo000A
0?ooool000003@0000030?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0756102, \
205.376, 0.00165494, 0.479258}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb3\  = 
        Histogram[allbeat3dur, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.0101483 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -12 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(10)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(20)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(30)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(40)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(50)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02486 L
.04545 .02486 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02486 L
.04545 .02486 L
.04545 .01472 L
0 .01472 L
s
0 0 1 r
.04545 .01472 m
.04545 .02486 L
.09091 .02486 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02486 L
.09091 .02486 L
.09091 .01472 L
.04545 .01472 L
s
0 0 1 r
.09091 .01472 m
.09091 .07561 L
.13636 .07561 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .07561 L
.13636 .07561 L
.13636 .01472 L
.09091 .01472 L
s
0 0 1 r
.13636 .01472 m
.13636 .0959 L
.18182 .0959 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .0959 L
.18182 .0959 L
.18182 .01472 L
.13636 .01472 L
s
0 0 1 r
.18182 .01472 m
.18182 .21768 L
.22727 .21768 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .21768 L
.22727 .21768 L
.22727 .01472 L
.18182 .01472 L
s
0 0 1 r
.22727 .01472 m
.22727 .31917 L
.27273 .31917 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .31917 L
.27273 .31917 L
.27273 .01472 L
.22727 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .46124 L
.31818 .46124 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .46124 L
.31818 .46124 L
.31818 .01472 L
.27273 .01472 L
s
0 0 1 r
.31818 .01472 m
.31818 .53228 L
.36364 .53228 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .53228 L
.36364 .53228 L
.36364 .01472 L
.31818 .01472 L
s
0 0 1 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 0 1 r
.40909 .01472 m
.40909 .46124 L
.45455 .46124 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .46124 L
.45455 .46124 L
.45455 .01472 L
.40909 .01472 L
s
0 0 1 r
.45455 .01472 m
.45455 .56273 L
.5 .56273 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .56273 L
.5 .56273 L
.5 .01472 L
.45455 .01472 L
s
0 0 1 r
.5 .01472 m
.5 .57287 L
.54545 .57287 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .57287 L
.54545 .57287 L
.54545 .01472 L
.5 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .22783 L
.59091 .22783 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .22783 L
.59091 .22783 L
.59091 .01472 L
.54545 .01472 L
s
0 0 1 r
.59091 .01472 m
.59091 .15679 L
.63636 .15679 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .15679 L
.63636 .15679 L
.63636 .01472 L
.59091 .01472 L
s
0 0 1 r
.63636 .01472 m
.63636 .0959 L
.68182 .0959 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .0959 L
.68182 .0959 L
.68182 .01472 L
.63636 .01472 L
s
0 0 1 r
.68182 .01472 m
.68182 .04516 L
.72727 .04516 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04516 L
.72727 .04516 L
.72727 .01472 L
.68182 .01472 L
s
0 0 1 r
.72727 .01472 m
.72727 .06546 L
.77273 .06546 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .06546 L
.77273 .06546 L
.77273 .01472 L
.72727 .01472 L
s
0 0 1 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
0 0 1 r
.81818 .01472 m
.81818 .02486 L
.86364 .02486 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02486 L
.86364 .02486 L
.86364 .01472 L
.81818 .01472 L
s
0 0 1 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 0 1 r
.90909 .01472 m
.90909 .02486 L
.95455 .02486 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02486 L
.95455 .02486 L
.95455 .01472 L
.90909 .01472 L
s
0 0 1 r
.95455 .01472 m
.95455 .03501 L
1 .03501 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .03501 L
1 .03501 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0
2P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`090000o`030000
003oool0oooo00X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
003oool0oooo0040oooo000:0?ooo`8000001@3ooolJ000000/0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`030000003oool0oooo00T0oooo3@00000<0?ooo`d000002`00
0?l00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0
oooo02h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`010?ooo`004@3oool20000
01L0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0;P3oool=000000<0oooo000A0?ooo`030000003oool0oooo01H0
oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0F0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`030000003oool0oooo03X0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool05P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`d000002`000?l00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo01H0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0F0?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`090000
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000G0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`090000o`03
0000003oool0oooo03T0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`090000o`030000
003oool0oooo03X0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`030000003oool0oooo00T0oooo3@00000l0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo01H0oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
01H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0040oooo000A0?ooo`8000005`3oool=000000/0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`030000003oool0oooo0540oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0R0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`030000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool08P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo0280oooo00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo0580oooo00<000000?oo
o`3oool00@3oool00140oooo0P00000S0?ooo`d000002`000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l=000005<0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`010?ooo`000`3oool500000080oooo0P0000050?ooo`030000003oool0oooo
02h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0040oooo00050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000;P3oool00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo
05`0oooo0`0000030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`010?ooo`001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo
000A0?ooo`800000;`3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo05d0oooo0P00
00030?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool2000002l0oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o3@00001O0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo06X0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000;`3oool00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1Y
0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000;`3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1Y0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0;P3oool00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0
oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool000<0oooo1000
00030?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00
000^0?ooo`d000002`000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo06P0oooo0`00
00030?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0>P3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l00`000000003o0000o`090000o`d00000K03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool2000003/0oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0>P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo0P00000k0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0M@3oool2000000<0oooo000A0?ooo`030000
003oool0oooo03X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03X0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>`3oool00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`030000003oool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`0j0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000003/0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`00
0?l02@000?l00`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0
>P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool0
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0j0?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>P3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00000j
0?ooo`d000002`000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0M03oool3000000<0oooo00060?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`010?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000170?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
0000003oool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000A`3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000A`3oool00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1e0?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo
07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004L0oooo00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000D0oooo0`0000020?ooo`80
00001@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool00@3oool000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`00
0`3oool5000000050?ooo`000000oooo0?ooo`000000103oool3000004H0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0M03oool3000000<0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool000@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?oo
o`001@3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo0P0000170?ooo`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0
oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0
oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A
0?ooo`800000A`3oool=000000/0003o00<000000000o`000?l02@000?l=000000`0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool02@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`030000003oool0oooo00T0oooo00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`0300000000
0?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000005<0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0
oooo00T0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0
oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o
00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`090?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo00T0oooo00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00@3oool00140oooo0P00001C0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`1e0?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool02@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0040oooo00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0DP3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool02@3o
ool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`001P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001B0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1d0?ooo`<00000
0`3oool000@0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
2@3oool00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`00103o
ool3000000<0oooo0P0000050?ooo`030000003oool0oooo0580oooo3@00000;0000o`030000003o
ool0oooo00T0oooo00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool0
0`000000003o0000o`090000o`030000003oool0oooo00T0oooo00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00001O0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`00
0000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0M@3oool20000
00<0oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000
oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo
00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o
00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?oo
o`090?ooo`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?oo
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0040oooo000A0?ooo`800000G`3oool00`000000003o0000o`090000o`03
0000003oool0oooo00T0oooo3P00000;0000o`030000003oool0oooo07D0oooo0P0000030?ooo`00
4@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0
5P3oool00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000o`090000o`030000003o
ool0oooo01H0oooo3@00001h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000G`3oool00`000000
003o0000o`090000o`030000003oool0oooo09X0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N
0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03
000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool2000005l0oooo3@00002L0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0o`3o
ool90?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00@3oool00140ooooo`00000=000000<0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0756102, \
0.323506, 0.00165494, 0.370627}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplotall, \ xplotallb1, \ xplotallb2, \ 
            xplotallb3}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.372093 2.32558 0.0147151 0.00606808 [
[.09302 -0.0125 -9 -9 ]
[.09302 -0.0125 9 0 ]
[.32558 -0.0125 -9 -9 ]
[.32558 -0.0125 9 0 ]
[.55814 -0.0125 -9 -9 ]
[.55814 -0.0125 9 0 ]
[.7907 -0.0125 -9 -9 ]
[.7907 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13608 -12 -4.5 ]
[-0.0125 .13608 0 4.5 ]
[-0.0125 .25744 -12 -4.5 ]
[-0.0125 .25744 0 4.5 ]
[-0.0125 .3788 -12 -4.5 ]
[-0.0125 .3788 0 4.5 ]
[-0.0125 .50016 -12 -4.5 ]
[-0.0125 .50016 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09302 0 m
.09302 .00625 L
s
[(0.2)] .09302 -0.0125 0 1 Mshowa
.32558 0 m
.32558 .00625 L
s
[(0.3)] .32558 -0.0125 0 1 Mshowa
.55814 0 m
.55814 .00625 L
s
[(0.4)] .55814 -0.0125 0 1 Mshowa
.7907 0 m
.7907 .00625 L
s
[(0.5)] .7907 -0.0125 0 1 Mshowa
.125 Mabswid
.13953 0 m
.13953 .00375 L
s
.18605 0 m
.18605 .00375 L
s
.23256 0 m
.23256 .00375 L
s
.27907 0 m
.27907 .00375 L
s
.37209 0 m
.37209 .00375 L
s
.4186 0 m
.4186 .00375 L
s
.46512 0 m
.46512 .00375 L
s
.51163 0 m
.51163 .00375 L
s
.60465 0 m
.60465 .00375 L
s
.65116 0 m
.65116 .00375 L
s
.69767 0 m
.69767 .00375 L
s
.74419 0 m
.74419 .00375 L
s
.04651 0 m
.04651 .00375 L
s
.83721 0 m
.83721 .00375 L
s
.88372 0 m
.88372 .00375 L
s
.93023 0 m
.93023 .00375 L
s
.97674 0 m
.97674 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13608 m
.00625 .13608 L
s
[(20)] -0.0125 .13608 1 0 Mshowa
0 .25744 m
.00625 .25744 L
s
[(40)] -0.0125 .25744 1 0 Mshowa
0 .3788 m
.00625 .3788 L
s
[(60)] -0.0125 .3788 1 0 Mshowa
0 .50016 m
.00625 .50016 L
s
[(80)] -0.0125 .50016 1 0 Mshowa
.125 Mabswid
0 .04506 m
.00375 .04506 L
s
0 .0754 m
.00375 .0754 L
s
0 .10574 m
.00375 .10574 L
s
0 .16642 m
.00375 .16642 L
s
0 .19676 m
.00375 .19676 L
s
0 .2271 m
.00375 .2271 L
s
0 .28778 m
.00375 .28778 L
s
0 .31812 m
.00375 .31812 L
s
0 .34846 m
.00375 .34846 L
s
0 .40914 m
.00375 .40914 L
s
0 .43948 m
.00375 .43948 L
s
0 .46982 m
.00375 .46982 L
s
0 .5305 m
.00375 .5305 L
s
0 .56084 m
.00375 .56084 L
s
0 .59118 m
.00375 .59118 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09302 .61178 m
.09302 .61803 L
s
.32558 .61178 m
.32558 .61803 L
s
.55814 .61178 m
.55814 .61803 L
s
.7907 .61178 m
.7907 .61803 L
s
.125 Mabswid
.13953 .61428 m
.13953 .61803 L
s
.18605 .61428 m
.18605 .61803 L
s
.23256 .61428 m
.23256 .61803 L
s
.27907 .61428 m
.27907 .61803 L
s
.37209 .61428 m
.37209 .61803 L
s
.4186 .61428 m
.4186 .61803 L
s
.46512 .61428 m
.46512 .61803 L
s
.51163 .61428 m
.51163 .61803 L
s
.60465 .61428 m
.60465 .61803 L
s
.65116 .61428 m
.65116 .61803 L
s
.69767 .61428 m
.69767 .61803 L
s
.74419 .61428 m
.74419 .61803 L
s
.04651 .61428 m
.04651 .61803 L
s
.83721 .61428 m
.83721 .61803 L
s
.88372 .61428 m
.88372 .61803 L
s
.93023 .61428 m
.93023 .61803 L
s
.97674 .61428 m
.97674 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13608 m
1 .13608 L
s
.99375 .25744 m
1 .25744 L
s
.99375 .3788 m
1 .3788 L
s
.99375 .50016 m
1 .50016 L
s
.125 Mabswid
.99625 .04506 m
1 .04506 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .10574 m
1 .10574 L
s
.99625 .16642 m
1 .16642 L
s
.99625 .19676 m
1 .19676 L
s
.99625 .2271 m
1 .2271 L
s
.99625 .28778 m
1 .28778 L
s
.99625 .31812 m
1 .31812 L
s
.99625 .34846 m
1 .34846 L
s
.99625 .40914 m
1 .40914 L
s
.99625 .43948 m
1 .43948 L
s
.99625 .46982 m
1 .46982 L
s
.99625 .5305 m
1 .5305 L
s
.99625 .56084 m
1 .56084 L
s
.99625 .59118 m
1 .59118 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02078 L
.02326 .02078 L
.02326 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02078 L
.02326 .02078 L
.02326 .01472 L
0 .01472 L
s
.5 .5 .5 r
.02326 .01472 m
.02326 .02685 L
.04651 .02685 L
.04651 .01472 L
F
0 g
.02326 .01472 m
.02326 .02685 L
.04651 .02685 L
.04651 .01472 L
.02326 .01472 L
s
.5 .5 .5 r
.04651 .01472 m
.04651 .03292 L
.06977 .03292 L
.06977 .01472 L
F
0 g
.04651 .01472 m
.04651 .03292 L
.06977 .03292 L
.06977 .01472 L
.04651 .01472 L
s
.5 .5 .5 r
.06977 .01472 m
.06977 .03292 L
.09302 .03292 L
.09302 .01472 L
F
0 g
.06977 .01472 m
.06977 .03292 L
.09302 .03292 L
.09302 .01472 L
.06977 .01472 L
s
.5 .5 .5 r
.09302 .01472 m
.09302 .06326 L
.11628 .06326 L
.11628 .01472 L
F
0 g
.09302 .01472 m
.09302 .06326 L
.11628 .06326 L
.11628 .01472 L
.09302 .01472 L
s
.5 .5 .5 r
.11628 .01472 m
.11628 .09967 L
.13953 .09967 L
.13953 .01472 L
F
0 g
.11628 .01472 m
.11628 .09967 L
.13953 .09967 L
.13953 .01472 L
.11628 .01472 L
s
.5 .5 .5 r
.13953 .01472 m
.13953 .0936 L
.16279 .0936 L
.16279 .01472 L
F
0 g
.13953 .01472 m
.13953 .0936 L
.16279 .0936 L
.16279 .01472 L
.13953 .01472 L
s
.5 .5 .5 r
.16279 .01472 m
.16279 .12394 L
.18605 .12394 L
.18605 .01472 L
F
0 g
.16279 .01472 m
.16279 .12394 L
.18605 .12394 L
.18605 .01472 L
.16279 .01472 L
s
.5 .5 .5 r
.18605 .01472 m
.18605 .20889 L
.2093 .20889 L
.2093 .01472 L
F
0 g
.18605 .01472 m
.18605 .20889 L
.2093 .20889 L
.2093 .01472 L
.18605 .01472 L
s
.5 .5 .5 r
.2093 .01472 m
.2093 .19676 L
.23256 .19676 L
.23256 .01472 L
F
0 g
.2093 .01472 m
.2093 .19676 L
.23256 .19676 L
.23256 .01472 L
.2093 .01472 L
s
.5 .5 .5 r
.23256 .01472 m
.23256 .25137 L
.25581 .25137 L
.25581 .01472 L
F
0 g
.23256 .01472 m
.23256 .25137 L
.25581 .25137 L
.25581 .01472 L
.23256 .01472 L
s
.5 .5 .5 r
.25581 .01472 m
.25581 .33632 L
.27907 .33632 L
.27907 .01472 L
F
0 g
.25581 .01472 m
.25581 .33632 L
.27907 .33632 L
.27907 .01472 L
.25581 .01472 L
s
.5 .5 .5 r
.27907 .01472 m
.27907 .42734 L
.30233 .42734 L
.30233 .01472 L
F
0 g
.27907 .01472 m
.27907 .42734 L
.30233 .42734 L
.30233 .01472 L
.27907 .01472 L
s
.5 .5 .5 r
.30233 .01472 m
.30233 .49409 L
.32558 .49409 L
.32558 .01472 L
F
0 g
.30233 .01472 m
.30233 .49409 L
.32558 .49409 L
.32558 .01472 L
.30233 .01472 L
s
.5 .5 .5 r
.32558 .01472 m
.32558 .57905 L
.34884 .57905 L
.34884 .01472 L
F
0 g
.32558 .01472 m
.32558 .57905 L
.34884 .57905 L
.34884 .01472 L
.32558 .01472 L
s
.5 .5 .5 r
.34884 .01472 m
.34884 .57298 L
.37209 .57298 L
.37209 .01472 L
F
0 g
.34884 .01472 m
.34884 .57298 L
.37209 .57298 L
.37209 .01472 L
.34884 .01472 L
s
.5 .5 .5 r
.37209 .01472 m
.37209 .56691 L
.39535 .56691 L
.39535 .01472 L
F
0 g
.37209 .01472 m
.37209 .56691 L
.39535 .56691 L
.39535 .01472 L
.37209 .01472 L
s
.5 .5 .5 r
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
F
0 g
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
.39535 .01472 L
s
.5 .5 .5 r
.4186 .01472 m
.4186 .48803 L
.44186 .48803 L
.44186 .01472 L
F
0 g
.4186 .01472 m
.4186 .48803 L
.44186 .48803 L
.44186 .01472 L
.4186 .01472 L
s
.5 .5 .5 r
.44186 .01472 m
.44186 .51837 L
.46512 .51837 L
.46512 .01472 L
F
0 g
.44186 .01472 m
.44186 .51837 L
.46512 .51837 L
.46512 .01472 L
.44186 .01472 L
s
.5 .5 .5 r
.46512 .01472 m
.46512 .397 L
.48837 .397 L
.48837 .01472 L
F
0 g
.46512 .01472 m
.46512 .397 L
.48837 .397 L
.48837 .01472 L
.46512 .01472 L
s
.5 .5 .5 r
.48837 .01472 m
.48837 .397 L
.51163 .397 L
.51163 .01472 L
F
0 g
.48837 .01472 m
.48837 .397 L
.51163 .397 L
.51163 .01472 L
.48837 .01472 L
s
.5 .5 .5 r
.51163 .01472 m
.51163 .39094 L
.53488 .39094 L
.53488 .01472 L
F
0 g
.51163 .01472 m
.51163 .39094 L
.53488 .39094 L
.53488 .01472 L
.51163 .01472 L
s
.5 .5 .5 r
.53488 .01472 m
.53488 .33026 L
.55814 .33026 L
.55814 .01472 L
F
0 g
.53488 .01472 m
.53488 .33026 L
.55814 .33026 L
.55814 .01472 L
.53488 .01472 L
s
.5 .5 .5 r
.55814 .01472 m
.55814 .19676 L
.5814 .19676 L
.5814 .01472 L
F
0 g
.55814 .01472 m
.55814 .19676 L
.5814 .19676 L
.5814 .01472 L
.55814 .01472 L
s
.5 .5 .5 r
.5814 .01472 m
.5814 .14821 L
.60465 .14821 L
.60465 .01472 L
F
0 g
.5814 .01472 m
.5814 .14821 L
.60465 .14821 L
.60465 .01472 L
.5814 .01472 L
s
.5 .5 .5 r
.60465 .01472 m
.60465 .13001 L
.62791 .13001 L
.62791 .01472 L
F
0 g
.60465 .01472 m
.60465 .13001 L
.62791 .13001 L
.62791 .01472 L
.60465 .01472 L
s
.5 .5 .5 r
.62791 .01472 m
.62791 .12394 L
.65116 .12394 L
.65116 .01472 L
F
0 g
.62791 .01472 m
.62791 .12394 L
.65116 .12394 L
.65116 .01472 L
.62791 .01472 L
s
.5 .5 .5 r
.65116 .01472 m
.65116 .0936 L
.67442 .0936 L
.67442 .01472 L
F
0 g
.65116 .01472 m
.65116 .0936 L
.67442 .0936 L
.67442 .01472 L
.65116 .01472 L
s
.5 .5 .5 r
.67442 .01472 m
.67442 .0754 L
.69767 .0754 L
.69767 .01472 L
F
0 g
.67442 .01472 m
.67442 .0754 L
.69767 .0754 L
.69767 .01472 L
.67442 .01472 L
s
.5 .5 .5 r
.69767 .01472 m
.69767 .04506 L
.72093 .04506 L
.72093 .01472 L
F
0 g
.69767 .01472 m
.69767 .04506 L
.72093 .04506 L
.72093 .01472 L
.69767 .01472 L
s
.5 .5 .5 r
.72093 .01472 m
.72093 .04506 L
.74419 .04506 L
.74419 .01472 L
F
0 g
.72093 .01472 m
.72093 .04506 L
.74419 .04506 L
.74419 .01472 L
.72093 .01472 L
s
.5 .5 .5 r
.74419 .01472 m
.74419 .0754 L
.76744 .0754 L
.76744 .01472 L
F
0 g
.74419 .01472 m
.74419 .0754 L
.76744 .0754 L
.76744 .01472 L
.74419 .01472 L
s
.5 .5 .5 r
.76744 .01472 m
.76744 .02078 L
.7907 .02078 L
.7907 .01472 L
F
0 g
.76744 .01472 m
.76744 .02078 L
.7907 .02078 L
.7907 .01472 L
.76744 .01472 L
s
.5 .5 .5 r
.7907 .01472 m
.7907 .01472 L
.81395 .01472 L
.81395 .01472 L
F
0 g
.7907 .01472 m
.7907 .01472 L
.81395 .01472 L
.81395 .01472 L
.7907 .01472 L
s
.5 .5 .5 r
.81395 .01472 m
.81395 .03292 L
.83721 .03292 L
.83721 .01472 L
F
0 g
.81395 .01472 m
.81395 .03292 L
.83721 .03292 L
.83721 .01472 L
.81395 .01472 L
s
.5 .5 .5 r
.83721 .01472 m
.83721 .02685 L
.86047 .02685 L
.86047 .01472 L
F
0 g
.83721 .01472 m
.83721 .02685 L
.86047 .02685 L
.86047 .01472 L
.83721 .01472 L
s
.5 .5 .5 r
.86047 .01472 m
.86047 .02078 L
.88372 .02078 L
.88372 .01472 L
F
0 g
.86047 .01472 m
.86047 .02078 L
.88372 .02078 L
.88372 .01472 L
.86047 .01472 L
s
.5 .5 .5 r
.88372 .01472 m
.88372 .02078 L
.90698 .02078 L
.90698 .01472 L
F
0 g
.88372 .01472 m
.88372 .02078 L
.90698 .02078 L
.90698 .01472 L
.88372 .01472 L
s
.5 .5 .5 r
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
F
0 g
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
.90698 .01472 L
s
.5 .5 .5 r
.93023 .01472 m
.93023 .02685 L
.95349 .02685 L
.95349 .01472 L
F
0 g
.93023 .01472 m
.93023 .02685 L
.95349 .02685 L
.95349 .01472 L
.93023 .01472 L
s
.5 .5 .5 r
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
F
0 g
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
.95349 .01472 L
s
.5 .5 .5 r
.97674 .01472 m
.97674 .02078 L
1 .02078 L
1 .01472 L
F
0 g
.97674 .01472 m
.97674 .02078 L
1 .02078 L
1 .01472 L
.97674 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00964924 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11121 -12 -4.5 ]
[-0.0125 .11121 0 4.5 ]
[-0.0125 .2077 -12 -4.5 ]
[-0.0125 .2077 0 4.5 ]
[-0.0125 .30419 -12 -4.5 ]
[-0.0125 .30419 0 4.5 ]
[-0.0125 .40068 -12 -4.5 ]
[-0.0125 .40068 0 4.5 ]
[-0.0125 .49718 -12 -4.5 ]
[-0.0125 .49718 0 4.5 ]
[-0.0125 .59367 -12 -4.5 ]
[-0.0125 .59367 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11121 m
.00625 .11121 L
s
[(10)] -0.0125 .11121 1 0 Mshowa
0 .2077 m
.00625 .2077 L
s
[(20)] -0.0125 .2077 1 0 Mshowa
0 .30419 m
.00625 .30419 L
s
[(30)] -0.0125 .30419 1 0 Mshowa
0 .40068 m
.00625 .40068 L
s
[(40)] -0.0125 .40068 1 0 Mshowa
0 .49718 m
.00625 .49718 L
s
[(50)] -0.0125 .49718 1 0 Mshowa
0 .59367 m
.00625 .59367 L
s
[(60)] -0.0125 .59367 1 0 Mshowa
.125 Mabswid
0 .03401 m
.00375 .03401 L
s
0 .05331 m
.00375 .05331 L
s
0 .07261 m
.00375 .07261 L
s
0 .09191 m
.00375 .09191 L
s
0 .13051 m
.00375 .13051 L
s
0 .1498 m
.00375 .1498 L
s
0 .1691 m
.00375 .1691 L
s
0 .1884 m
.00375 .1884 L
s
0 .227 m
.00375 .227 L
s
0 .2463 m
.00375 .2463 L
s
0 .2656 m
.00375 .2656 L
s
0 .28489 m
.00375 .28489 L
s
0 .32349 m
.00375 .32349 L
s
0 .34279 m
.00375 .34279 L
s
0 .36209 m
.00375 .36209 L
s
0 .38139 m
.00375 .38139 L
s
0 .41998 m
.00375 .41998 L
s
0 .43928 m
.00375 .43928 L
s
0 .45858 m
.00375 .45858 L
s
0 .47788 m
.00375 .47788 L
s
0 .51648 m
.00375 .51648 L
s
0 .53577 m
.00375 .53577 L
s
0 .55507 m
.00375 .55507 L
s
0 .57437 m
.00375 .57437 L
s
0 .61297 m
.00375 .61297 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11121 m
1 .11121 L
s
.99375 .2077 m
1 .2077 L
s
.99375 .30419 m
1 .30419 L
s
.99375 .40068 m
1 .40068 L
s
.99375 .49718 m
1 .49718 L
s
.99375 .59367 m
1 .59367 L
s
.125 Mabswid
.99625 .03401 m
1 .03401 L
s
.99625 .05331 m
1 .05331 L
s
.99625 .07261 m
1 .07261 L
s
.99625 .09191 m
1 .09191 L
s
.99625 .13051 m
1 .13051 L
s
.99625 .1498 m
1 .1498 L
s
.99625 .1691 m
1 .1691 L
s
.99625 .1884 m
1 .1884 L
s
.99625 .227 m
1 .227 L
s
.99625 .2463 m
1 .2463 L
s
.99625 .2656 m
1 .2656 L
s
.99625 .28489 m
1 .28489 L
s
.99625 .32349 m
1 .32349 L
s
.99625 .34279 m
1 .34279 L
s
.99625 .36209 m
1 .36209 L
s
.99625 .38139 m
1 .38139 L
s
.99625 .41998 m
1 .41998 L
s
.99625 .43928 m
1 .43928 L
s
.99625 .45858 m
1 .45858 L
s
.99625 .47788 m
1 .47788 L
s
.99625 .51648 m
1 .51648 L
s
.99625 .53577 m
1 .53577 L
s
.99625 .55507 m
1 .55507 L
s
.99625 .57437 m
1 .57437 L
s
.99625 .61297 m
1 .61297 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03401 L
.04545 .03401 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03401 L
.04545 .03401 L
.04545 .01472 L
0 .01472 L
s
1 0 0 r
.04545 .01472 m
.04545 .06296 L
.09091 .06296 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .06296 L
.09091 .06296 L
.09091 .01472 L
.04545 .01472 L
s
1 0 0 r
.09091 .01472 m
.09091 .13051 L
.13636 .13051 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .13051 L
.13636 .13051 L
.13636 .01472 L
.09091 .01472 L
s
1 0 0 r
.13636 .01472 m
.13636 .1884 L
.18182 .1884 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .1884 L
.18182 .1884 L
.18182 .01472 L
.13636 .01472 L
s
1 0 0 r
.18182 .01472 m
.18182 .27524 L
.22727 .27524 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .27524 L
.22727 .27524 L
.22727 .01472 L
.18182 .01472 L
s
1 0 0 r
.22727 .01472 m
.22727 .28489 L
.27273 .28489 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .28489 L
.27273 .28489 L
.27273 .01472 L
.22727 .01472 L
s
1 0 0 r
.27273 .01472 m
.27273 .46823 L
.31818 .46823 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .46823 L
.31818 .46823 L
.31818 .01472 L
.27273 .01472 L
s
1 0 0 r
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .60332 L
.36364 .60332 L
.36364 .01472 L
.31818 .01472 L
s
1 0 0 r
.36364 .01472 m
.36364 .55507 L
.40909 .55507 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .55507 L
.40909 .55507 L
.40909 .01472 L
.36364 .01472 L
s
1 0 0 r
.40909 .01472 m
.40909 .53577 L
.45455 .53577 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .53577 L
.45455 .53577 L
.45455 .01472 L
.40909 .01472 L
s
1 0 0 r
.45455 .01472 m
.45455 .33314 L
.5 .33314 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .33314 L
.5 .33314 L
.5 .01472 L
.45455 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .37174 L
.54545 .37174 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .37174 L
.54545 .37174 L
.54545 .01472 L
.5 .01472 L
s
1 0 0 r
.54545 .01472 m
.54545 .14016 L
.59091 .14016 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .14016 L
.59091 .14016 L
.59091 .01472 L
.54545 .01472 L
s
1 0 0 r
.59091 .01472 m
.59091 .13051 L
.63636 .13051 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .13051 L
.63636 .13051 L
.63636 .01472 L
.59091 .01472 L
s
1 0 0 r
.63636 .01472 m
.63636 .09191 L
.68182 .09191 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .09191 L
.68182 .09191 L
.68182 .01472 L
.63636 .01472 L
s
1 0 0 r
.68182 .01472 m
.68182 .05331 L
.72727 .05331 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .05331 L
.72727 .05331 L
.72727 .01472 L
.68182 .01472 L
s
1 0 0 r
.72727 .01472 m
.72727 .05331 L
.77273 .05331 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .05331 L
.77273 .05331 L
.77273 .01472 L
.72727 .01472 L
s
1 0 0 r
.77273 .01472 m
.77273 .03401 L
.81818 .03401 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .03401 L
.81818 .03401 L
.81818 .01472 L
.77273 .01472 L
s
1 0 0 r
.81818 .01472 m
.81818 .02436 L
.86364 .02436 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02436 L
.86364 .02436 L
.86364 .01472 L
.81818 .01472 L
s
1 0 0 r
.86364 .01472 m
.86364 .02436 L
.90909 .02436 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .02436 L
.90909 .02436 L
.90909 .01472 L
.86364 .01472 L
s
1 0 0 r
.90909 .01472 m
.90909 .02436 L
.95455 .02436 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02436 L
.95455 .02436 L
.95455 .01472 L
.90909 .01472 L
s
1 0 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00784805 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0932 -12 -4.5 ]
[-0.0125 .0932 0 4.5 ]
[-0.0125 .17168 -12 -4.5 ]
[-0.0125 .17168 0 4.5 ]
[-0.0125 .25016 -12 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .32864 -12 -4.5 ]
[-0.0125 .32864 0 4.5 ]
[-0.0125 .40712 -12 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .56408 -12 -4.5 ]
[-0.0125 .56408 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .0932 m
.00625 .0932 L
s
[(10)] -0.0125 .0932 1 0 Mshowa
0 .17168 m
.00625 .17168 L
s
[(20)] -0.0125 .17168 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(30)] -0.0125 .25016 1 0 Mshowa
0 .32864 m
.00625 .32864 L
s
[(40)] -0.0125 .32864 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(50)] -0.0125 .40712 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(60)] -0.0125 .4856 1 0 Mshowa
0 .56408 m
.00625 .56408 L
s
[(70)] -0.0125 .56408 1 0 Mshowa
.125 Mabswid
0 .03041 m
.00375 .03041 L
s
0 .04611 m
.00375 .04611 L
s
0 .0618 m
.00375 .0618 L
s
0 .0775 m
.00375 .0775 L
s
0 .10889 m
.00375 .10889 L
s
0 .12459 m
.00375 .12459 L
s
0 .14028 m
.00375 .14028 L
s
0 .15598 m
.00375 .15598 L
s
0 .18737 m
.00375 .18737 L
s
0 .20307 m
.00375 .20307 L
s
0 .21876 m
.00375 .21876 L
s
0 .23446 m
.00375 .23446 L
s
0 .26585 m
.00375 .26585 L
s
0 .28155 m
.00375 .28155 L
s
0 .29724 m
.00375 .29724 L
s
0 .31294 m
.00375 .31294 L
s
0 .34433 m
.00375 .34433 L
s
0 .36003 m
.00375 .36003 L
s
0 .37573 m
.00375 .37573 L
s
0 .39142 m
.00375 .39142 L
s
0 .42281 m
.00375 .42281 L
s
0 .43851 m
.00375 .43851 L
s
0 .45421 m
.00375 .45421 L
s
0 .4699 m
.00375 .4699 L
s
0 .50129 m
.00375 .50129 L
s
0 .51699 m
.00375 .51699 L
s
0 .53269 m
.00375 .53269 L
s
0 .54838 m
.00375 .54838 L
s
0 .57977 m
.00375 .57977 L
s
0 .59547 m
.00375 .59547 L
s
0 .61117 m
.00375 .61117 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0932 m
1 .0932 L
s
.99375 .17168 m
1 .17168 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .32864 m
1 .32864 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .56408 m
1 .56408 L
s
.125 Mabswid
.99625 .03041 m
1 .03041 L
s
.99625 .04611 m
1 .04611 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0775 m
1 .0775 L
s
.99625 .10889 m
1 .10889 L
s
.99625 .12459 m
1 .12459 L
s
.99625 .14028 m
1 .14028 L
s
.99625 .15598 m
1 .15598 L
s
.99625 .18737 m
1 .18737 L
s
.99625 .20307 m
1 .20307 L
s
.99625 .21876 m
1 .21876 L
s
.99625 .23446 m
1 .23446 L
s
.99625 .26585 m
1 .26585 L
s
.99625 .28155 m
1 .28155 L
s
.99625 .29724 m
1 .29724 L
s
.99625 .31294 m
1 .31294 L
s
.99625 .34433 m
1 .34433 L
s
.99625 .36003 m
1 .36003 L
s
.99625 .37573 m
1 .37573 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .42281 m
1 .42281 L
s
.99625 .43851 m
1 .43851 L
s
.99625 .45421 m
1 .45421 L
s
.99625 .4699 m
1 .4699 L
s
.99625 .50129 m
1 .50129 L
s
.99625 .51699 m
1 .51699 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .54838 m
1 .54838 L
s
.99625 .57977 m
1 .57977 L
s
.99625 .59547 m
1 .59547 L
s
.99625 .61117 m
1 .61117 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
0 1 0 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
0 1 0 r
.09091 .01472 m
.09091 .04611 L
.13636 .04611 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .04611 L
.13636 .04611 L
.13636 .01472 L
.09091 .01472 L
s
0 1 0 r
.13636 .01472 m
.13636 .05396 L
.18182 .05396 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .05396 L
.18182 .05396 L
.18182 .01472 L
.13636 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .13244 L
.22727 .13244 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .13244 L
.22727 .13244 L
.22727 .01472 L
.18182 .01472 L
s
0 1 0 r
.22727 .01472 m
.22727 .28155 L
.27273 .28155 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .28155 L
.27273 .28155 L
.27273 .01472 L
.22727 .01472 L
s
0 1 0 r
.27273 .01472 m
.27273 .44636 L
.31818 .44636 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .44636 L
.31818 .44636 L
.31818 .01472 L
.27273 .01472 L
s
0 1 0 r
.31818 .01472 m
.31818 .58762 L
.36364 .58762 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .58762 L
.36364 .58762 L
.36364 .01472 L
.31818 .01472 L
s
0 1 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 1 0 r
.40909 .01472 m
.40909 .50129 L
.45455 .50129 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .50129 L
.45455 .50129 L
.45455 .01472 L
.40909 .01472 L
s
0 1 0 r
.45455 .01472 m
.45455 .32864 L
.5 .32864 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .32864 L
.5 .32864 L
.5 .01472 L
.45455 .01472 L
s
0 1 0 r
.5 .01472 m
.5 .18737 L
.54545 .18737 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .18737 L
.54545 .18737 L
.54545 .01472 L
.5 .01472 L
s
0 1 0 r
.54545 .01472 m
.54545 .15598 L
.59091 .15598 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .15598 L
.59091 .15598 L
.59091 .01472 L
.54545 .01472 L
s
0 1 0 r
.59091 .01472 m
.59091 .10104 L
.63636 .10104 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .10104 L
.63636 .10104 L
.63636 .01472 L
.59091 .01472 L
s
0 1 0 r
.63636 .01472 m
.63636 .06965 L
.68182 .06965 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .06965 L
.68182 .06965 L
.68182 .01472 L
.63636 .01472 L
s
0 1 0 r
.68182 .01472 m
.68182 .03826 L
.72727 .03826 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .03826 L
.72727 .03826 L
.72727 .01472 L
.68182 .01472 L
s
0 1 0 r
.72727 .01472 m
.72727 .03041 L
.77273 .03041 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .03041 L
.77273 .03041 L
.77273 .01472 L
.72727 .01472 L
s
0 1 0 r
.77273 .01472 m
.77273 .02256 L
.81818 .02256 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02256 L
.81818 .02256 L
.81818 .01472 L
.77273 .01472 L
s
0 1 0 r
.81818 .01472 m
.81818 .02256 L
.86364 .02256 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02256 L
.86364 .02256 L
.86364 .01472 L
.81818 .01472 L
s
0 1 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 1 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
0 1 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.0101483 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1162 -12 -4.5 ]
[-0.0125 .1162 0 4.5 ]
[-0.0125 .21768 -12 -4.5 ]
[-0.0125 .21768 0 4.5 ]
[-0.0125 .31917 -12 -4.5 ]
[-0.0125 .31917 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .52213 -12 -4.5 ]
[-0.0125 .52213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1162 m
.00625 .1162 L
s
[(10)] -0.0125 .1162 1 0 Mshowa
0 .21768 m
.00625 .21768 L
s
[(20)] -0.0125 .21768 1 0 Mshowa
0 .31917 m
.00625 .31917 L
s
[(30)] -0.0125 .31917 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(40)] -0.0125 .42065 1 0 Mshowa
0 .52213 m
.00625 .52213 L
s
[(50)] -0.0125 .52213 1 0 Mshowa
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1162 m
1 .1162 L
s
.99375 .21768 m
1 .21768 L
s
.99375 .31917 m
1 .31917 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .52213 m
1 .52213 L
s
.125 Mabswid
.99625 .03501 m
1 .03501 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .0959 m
1 .0959 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15679 m
1 .15679 L
s
.99625 .17709 m
1 .17709 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .23798 m
1 .23798 L
s
.99625 .25828 m
1 .25828 L
s
.99625 .27857 m
1 .27857 L
s
.99625 .29887 m
1 .29887 L
s
.99625 .33946 m
1 .33946 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .38006 m
1 .38006 L
s
.99625 .40035 m
1 .40035 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .48154 m
1 .48154 L
s
.99625 .50184 m
1 .50184 L
s
.99625 .54243 m
1 .54243 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .58302 m
1 .58302 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .02486 L
.04545 .02486 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02486 L
.04545 .02486 L
.04545 .01472 L
0 .01472 L
s
0 0 1 r
.04545 .01472 m
.04545 .02486 L
.09091 .02486 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02486 L
.09091 .02486 L
.09091 .01472 L
.04545 .01472 L
s
0 0 1 r
.09091 .01472 m
.09091 .07561 L
.13636 .07561 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .07561 L
.13636 .07561 L
.13636 .01472 L
.09091 .01472 L
s
0 0 1 r
.13636 .01472 m
.13636 .0959 L
.18182 .0959 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .0959 L
.18182 .0959 L
.18182 .01472 L
.13636 .01472 L
s
0 0 1 r
.18182 .01472 m
.18182 .21768 L
.22727 .21768 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .21768 L
.22727 .21768 L
.22727 .01472 L
.18182 .01472 L
s
0 0 1 r
.22727 .01472 m
.22727 .31917 L
.27273 .31917 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .31917 L
.27273 .31917 L
.27273 .01472 L
.22727 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .46124 L
.31818 .46124 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .46124 L
.31818 .46124 L
.31818 .01472 L
.27273 .01472 L
s
0 0 1 r
.31818 .01472 m
.31818 .53228 L
.36364 .53228 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .53228 L
.36364 .53228 L
.36364 .01472 L
.31818 .01472 L
s
0 0 1 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 0 1 r
.40909 .01472 m
.40909 .46124 L
.45455 .46124 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .46124 L
.45455 .46124 L
.45455 .01472 L
.40909 .01472 L
s
0 0 1 r
.45455 .01472 m
.45455 .56273 L
.5 .56273 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .56273 L
.5 .56273 L
.5 .01472 L
.45455 .01472 L
s
0 0 1 r
.5 .01472 m
.5 .57287 L
.54545 .57287 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .57287 L
.54545 .57287 L
.54545 .01472 L
.5 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .22783 L
.59091 .22783 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .22783 L
.59091 .22783 L
.59091 .01472 L
.54545 .01472 L
s
0 0 1 r
.59091 .01472 m
.59091 .15679 L
.63636 .15679 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .15679 L
.63636 .15679 L
.63636 .01472 L
.59091 .01472 L
s
0 0 1 r
.63636 .01472 m
.63636 .0959 L
.68182 .0959 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .0959 L
.68182 .0959 L
.68182 .01472 L
.63636 .01472 L
s
0 0 1 r
.68182 .01472 m
.68182 .04516 L
.72727 .04516 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04516 L
.72727 .04516 L
.72727 .01472 L
.68182 .01472 L
s
0 0 1 r
.72727 .01472 m
.72727 .06546 L
.77273 .06546 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .06546 L
.77273 .06546 L
.77273 .01472 L
.72727 .01472 L
s
0 0 1 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
0 0 1 r
.81818 .01472 m
.81818 .02486 L
.86364 .02486 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02486 L
.86364 .02486 L
.86364 .01472 L
.81818 .01472 L
s
0 0 1 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 0 1 r
.90909 .01472 m
.90909 .02486 L
.95455 .02486 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02486 L
.95455 .02486 L
.95455 .01472 L
.90909 .01472 L
s
0 0 1 r
.95455 .01472 m
.95455 .03501 L
1 .03501 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .03501 L
1 .03501 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`009`3oool2000000@0oooo
0P0000030?ooo`@00000403oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003`3oool2000000@0oooo0P0000040?ooo`800000>P3oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`8000003`3oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?@3oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?03oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;@3oool002H0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000h0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0;0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000>`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`009P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo1@00000>0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<
0?ooo`040000003oool0oooo000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>03o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:P3oool002H0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000l0
oooo00@000000?ooo`3oool000002@3oool2000003T0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3o
ool000002@3oool2000003`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002d0oooo000V0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000?0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03/0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0j0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0;03oool002L0oooo0P00
000:0?ooo`8000004@3oool2000000X0oooo0P00000@0?ooo`8000002`3oool200000100oooo0P00
000:0?ooo`<00000>@3oool2000000X0oooo0P00000@0?ooo`8000002P3oool2000000l0oooo0P00
000;0?ooo`8000003P3oool2000000X0oooo0`00000l0?ooo`8000002P3oool200000100oooo0P00
000:0?ooo`800000403oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003/0oooo0P00
000:0?ooo`800000403oool2000000X0oooo0P00000@0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000;03oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`00703oool2000000@0ooooQ000000K0?ooo`8000000`3o
oon3000001X0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`006`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001X0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool001/0oooo00@000000?ooo`3oool000000`3ooon4000001X0oooo00@00000
0?ooo`3oool000000P3ooon3000001T0oooo00@000000?ooo`3oool000000`3ooon5000001P0oooo
00@000000?ooo`3oool000000P3ooon5000001D0oooo000K0?ooo`040000003oool0oooo000000<0
oooo1000000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000000<0Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`050000001oOgl0
Ogmo07moO`0000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00<0000007moO`1oOgl0100000020?ooo`040000001oOgl0Ogmo00000080Ogmo1`0000020?oo
o`040000001oOgl0Ogmo00000080oooo1000000J0?ooo`040000003oool0oooo00000080oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`004`00
00050?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`090?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0002003o00d000004@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080
oooo3@0000050000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`030?ooo`L000001@3oool7000000D0003o00<000000?ooo`3oool04`3oool001/0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`050000001oOgl0Ogmo07moO`0000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
00<0Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00<000000?ooo`3oool00`3oool7000000P0oooo100000050?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool000000P3oool7000000D0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`001`00000F0?ooo`80
00006@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00H000007@3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool04`3oool001`0oooo0P0000040?oo
o`030000003oool0oooo00T0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo000000<0Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`050000001oOgl0Ogmo07moO`0000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000007@3oool00`000000oooo0?ooo`0I0?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`000080o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?oo
o`800000103oool00`000000oooo0?ooo`090?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l01`00000R0?oo
o`030000003oool0oooo01P0oooo0P0000030?ooo`8000002P3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0E0?oo
o`L000005@3oool00280oooo00<000000?ooo`3oool02@3oool010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000`1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00D0000007mo
O`1oOgl0Ogmo0000000207moO`040000001oOgl0Ogmo00000080Ogmo1`00000207moO`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00T0oooo1`000005003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`L000001@000?l00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01<0oooo000R0?ooo`030000003oool0oooo00T0oooo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000000<0Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`050000001o
Ogl0Ogmo07moO`0000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo00<0
oooo00@0000007moO`1oOgl000007@3oool00`000000oooo0?ooo`0N0?ooo`800000103oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`003000000L0?ooo`800000803oool00`00
0000oooo0?ooo`0?0?ooo`L000001@00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
02H0oooo00<000000?ooo`3oool07@3oool2000000X0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool06P3oool20000
01D0oooo000R0?ooo`030000003oool0oooo00T0oooo1000000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000`1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo0000000207mo
O`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool00`3oool010000000Ogmo07moO`00
000M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool7000000D0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo02H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool00`3oool00`000000003o0000o`030000o`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0303oool010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo0000000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000`1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000000D0oooo00@0000007moO`1o
Ogl000007@3oool00`000000oooo0?ooo`0N0?ooo`8000002P3oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003oool0oooo02D0oooo0P00000P0?ooo`030000003oool0oooo01D0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`07000002P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool7000001d0oooo00<000000?oo
o`3oool04`3oool00280oooo00<000000?ooo`3oool0303oool010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo0000000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000`1oOgl01000
0000Ogmo07moO`00000207moO`@000001@3oool4000001d0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0A0?ooo`D000000P3oool2000000@0oooo00<000000?ooo`3oool05@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo02`0oooo00<000000?ooo`3oool07@3oool2
000000X0oooo1`0000050000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0V0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0303oool01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo
0000000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000`1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo00`0oooo
00<0000007moO`1oOgl01000000207moO`040000001oOgl0Ogmo000000<0Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`050000001o
Ogl0Ogmo07moO`0000000P1oOgl4000002T0oooo00<000000?ooo`3oool04P3oool500000080oooo
0P0000030?ooo`8000002P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o0007000002L0oooo0P00000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`3oool2000001H0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo00`0
oooo100000020?ooo`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo00000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000`1oOgl010000000Ogmo07moO`00000/0?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000/0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000001L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l01`00000^0?ooo`030000003oool0oooo0140oooo1@0000020?ooo`80
00000`3oool200000100oooo1`0000050000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`L00000:03oool2000001D0oooo000R0?ooo`030000
003oool0oooo0180oooo00@0000007moO`1oOgl000000P1oOgl01@000000Ogmo07moO`1oOgl00000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000307moO`040000001oOgl0Ogmo000002`0oooo00<000000?ooo`3oool0503oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000:0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
02/0oooo0P00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000G0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo
0?ooo`0B0?ooo`040000001oOgl0Ogmo00000080Ogmo00D0000007moO`1oOgl0Ogmo0000000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0`1oOgl010000000Ogmo07moO`00000/0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000/0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0B0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool05@3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo008000005P3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02`0oooo0P00000E0?ooo`005@3oool4000000<0oooo0P0000040?ooo`030000003oool0
oooo0180oooo1000000207moO`050000001oOgl0Ogmo07moO`0000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000000<0Ogmo1000000/0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000/0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01D0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000G0?ooo`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool010000000
Ogmo07moO`00000307moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl5000002l0oooo00<000000?ooo`3oool04`3oool2000000@0oooo
0P0000030?ooo`8000002P3oool7000000D0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`001`00000]0?ooo`800000803oool00`000000oooo
0?ooo`0E0?ooo`L000001@00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000005`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo02d0oooo00<000000?oo
o`3oool04`3oool001H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`8000005P3oool010000000Ogmo07moO`00000307moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000003@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`80
00000`3oool2000001H0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0/0?ooo`80
00005@3oool001L0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000005`3oool010000000Ogmo07moO`00000307moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00<0000007moO`1oOgl01000000c0?ooo`030000003oool0oooo01h0oooo
0P00000@0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo03L0oooo0P00000P0?ooo`030000003oool0oooo01/0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`005@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool010000000
Ogmo07moO`00000307moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl00000=P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo0380oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`005P3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo01D0oooo00@0000007moO`1oOgl000000`1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000003H0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03P0oooo00<00000
0?ooo`3oool04@3oool4000000<0oooo0P0000040?ooo`030000003oool0oooo01/0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`07000003@0oooo00<000000?ooo`3oool07@3oool2000001H0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o1`00000^
0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool05@3oool010000000Ogmo07moO`000003
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
0000=P3oool00`000000oooo0?ooo`0N0?ooo`800000403oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0g0?ooo`80
00004`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03<0oooo00<000000?oo
o`3oool04`3oool00280oooo00<000000?ooo`3oool05@3oool010000000Ogmo07moO`00000307mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
=P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool2000001`0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01d0oooo0P00000F0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo0380oooo0P00000E0?ooo`00
8P3oool00`000000oooo0?ooo`0E0?ooo`040000001oOgl0Ogmo000000<0Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000f0?ooo`030000003o
ool0oooo01h0oooo0P00000@0?ooo`L000001@3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo03L0oooo0P00000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000001d0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo01D0oooo00@0000007moO`1oOgl0
00000`1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo000003H0oooo00<000000?ooo`3oool04P3oool4000000<0oooo0P0000030?ooo`030000003o
ool0oooo01D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo03P0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`07000003X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool04`3oool00280oooo00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`0500000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01000000f0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01D0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
03P0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`8000005P3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0b0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool05@3oool4000000<0
oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`8000005P3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0=`3oool200000200oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0140oooo100000030?ooo`8000000`3oool00`000000oooo0?oo
o`0E0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo03<0oooo00<000000?ooo`3oool04`3oool00280oooo00<00000
0?ooo`3oool0703oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000005`3oool00`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo03<0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool0703oool01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo0P00000F0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0g0?ooo`800000803oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03h0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo0P00000F0?ooo`L000001@000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
0380oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0L0?ooo`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool05@3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o1`00000e0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003o
ool0oooo01`0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0B0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool06`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`800000703oool00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo03P0oooo0P00000E0?ooo`005`3oool300000080oooo0P0000040?ooo`030000003oool0oooo
01`0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01h0oooo0P00000F0?ooo`030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<0
00000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`0g0?ooo`8000004`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`0K0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0C0?ooo`00603oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000007P3oool400000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000L0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`005@3o
ool5000000050?ooo`000000oooo0?ooo`0000000`3oool200000200oooo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl00000>@3oool00`000000oooo0?ooo`0N0?ooo`8000005P3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0=`3oool20000
01H0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000001d0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`800000703oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo03P0oooo0P00000E0?ooo`005@3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool07`3oool010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000i0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03h0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool07`3oool010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000i0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool05@3oool7000000D0o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0B0?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool04`3oool001L0oooo0P0000030?ooo`800000
103oool00`000000oooo0?ooo`0O0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
03T0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`800000703oool70000
00D0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo
03L0oooo0P00000P0?ooo`030000003oool0oooo01/0oooo1`000005003o000300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`800000703oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo03P0oooo0P00000E0?ooo`008P3oool00`000000
oooo0?ooo`0O0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000003T0oooo00<00000
0?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool08@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo
000R0?ooo`030000003oool0oooo01l0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
0000>@3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0200000280oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0=`3oool200000200oooo00<000000?oo
o`3oool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`800000703oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03P0oooo0P00000E0?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo000003T0oooo00<000000?ooo`3oool05@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002<0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo03h0oooo00<000000?ooo`3oool0
4P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo01/0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003o
ool0oooo01l0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000>@3oool00`000000
oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool3
00000080oooo0P0000040?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o00030000003oool0oooo03h0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
6`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool07`3oool010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000i0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3oool200000280
oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=`3oool2000001H0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000002<0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o00030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P00000L0?ooo`L000001@000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001D0oooo000R
0?ooo`030000003oool0oooo01l0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo1000000i0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000o`000?l000030?l000030000003o
0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000L000001@3o
00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo1@0000001@3oool000000?oo
o`3oool0000000<0oooo0P00000R0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l01`0000100?ooo`030000
003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000S0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3o
ool07`3oool400000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`030000003oool0oooo03X0oooo00<000000?ooo`3oool07P3oool200000280
oooo00<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`030?ooo`030000003o0000o`0000<0
o`0000<000000?ooo`3oool0=`3oool2000001<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0240oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0R0?ooo`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000l0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo00<0oooo00<000000?l0003o00000`3o00000`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`140?ooo`030000003oool0oooo0180oooo0P0000040?ooo`8000000`3oool200000280
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000?ooo`3oool0>03oool2000001D0oooo000R0?ooo`030000003oool0oooo0280oooo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo000003`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool00`3oool00`000000o`000?l000030?l00003
0000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool2000000<0oooo0P0000040?ooo`03
0000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo0280oooo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000003`0
oooo00<000000?ooo`3oool07P3oool200000280oooo00<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`030?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0=`3oool200000200
oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0
oooo00<000000?ooo`3oool07@3oool200000280oooo00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001D0
oooo000E0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool08P3oool010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
0000?03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo00<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`030?ooo`L00000>P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01<0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0R0?ooo`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000l0?ooo`030000003oool0
oooo01h0oooo0P00000R0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0@`3oool2
00000200oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0
oooo04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0
oooo03T0oooo00<000000?ooo`3oool04`3oool001D0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`8000008`3oool010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000?03oool00`000000oooo
0?ooo`0D0?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3oool08@3oool00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0M0?ooo`8000008P3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`0h0?ooo`8000005@3oool001D0oooo0`00
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08P3oool010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo1000000l0?ooo`030000
003oool0oooo01D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000S0?oo
o`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0R0?ooo`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo1`00000o0?ooo`030000003oool0oooo0180oooo1@0000001@3oool000000?ooo`3oool00000
0080oooo0P00000R0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0@`3oool20000
01@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l0
00<00?l000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0240oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`005P3oool3000000<0
oooo0P0000040?ooo`030000003oool0oooo0280oooo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl00`000000oooo0?ooo`130?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0240oooo00<000000?l0
003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo0`00
00020?ooo`8000000`3oool200000280oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001D0oooo000R
0?ooo`030000003oool0oooo0280oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`8000008P3oool00`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo04<0oooo0P00000F0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo
0P00000R0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000008`3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo0280
oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`130?ooo`030000
003oool0oooo01@0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0B0?ooo`800000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo0140oooo1@0000001@3oool0
00000?ooo`3oool000000080oooo0P00000R0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03P0oooo0P00000E0?oo
o`008P3oool00`000000oooo0?ooo`0R0?ooo`@000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?oo
o`130?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000o`000?l0
00030?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08@3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02D0
oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl00000A@3oool00`000000oooo0?ooo`0N0?ooo`800000
8P3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo04<0oooo0P00000D0?ooo`<00000
0`3oool2000000@0oooo00<000000?ooo`3oool08@3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02D0oooo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl00000A@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo00<0
00000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<0
00000?l0003o00000`3o00000`000000oooo0?ooo`140?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<0
00000?ooo`3oool04`3oool2000000<0oooo0P0000030?ooo`8000008P3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0h0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool09@3oool010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`0000150?ooo`030000003oool0oooo01h0oooo0P00000R0?ooo`030000003o0000o`00
00<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?ooo`3oool0@`3oool200000200oooo00<000000?ooo`3oool08@3oool70000
00D00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo
03T0oooo00<000000?ooo`3oool04`3oool00280oooo00<000000?ooo`3oool09@3oool010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`0000150?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
8@3oool00`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo04@0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
4`3oool00280oooo00<000000?ooo`3oool09@3oool010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000015
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool7000000@0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo04@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<00000
0?ooo`3oool07@3oool200000280oooo1`0000050000o`03000000000?l0003o00<0003o1`000005
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001D0oooo000R0?oo
o`030000003oool0oooo02D0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000A@3oool00`000000
oooo0?ooo`0C0?ooo`800000103oool2000000<0oooo0P00000X0?ooo`030000003o0000o`000080
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo04<0
oooo0P00000C0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`000000
0?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000
oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0U0?ooo`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo000004D0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000o`000?l000020?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M
0?ooo`800000:03oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool00`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0>03oool2000001D0oooo000F0?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool09@3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<0
000007moO`1oOgl01000000207moO`030000003oool0oooo04<0oooo00<000000?ooo`3oool05@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00800000:03oool00`000000o`00
0?l000020?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`130?ooo`8000004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo0P00000X0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000E0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0U0?ooo`@000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080oooo00@0000007moO`1oOgl0
0000A@3oool00`000000oooo0?ooo`0C0?ooo`8000000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02L0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0A0?oo
o`<000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02L0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool04`3oool001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`800000:@3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@000000?ooo`3oool000000P1oOgl00`000000oooo0?ooo`130?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02L0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000
o`000?l000<00?l000<00000003o0000o`000`00o`07000004H0oooo00<000000?ooo`3oool07@3o
ool2000002P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo03P0oooo0P00000E0?ooo`005P3oool2000000<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0X0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000oooo0?ooo`00000207moO`030000003oool0oooo04<0oooo00<000000?oo
o`3oool04`3oool3000000<0oooo0P0000030?ooo`800000:03oool00`000000o`000?l000020?l0
00030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`130?oo
o`800000503oool3000000<0oooo0P0000040?ooo`030000003oool0oooo02L0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04X0oooo00<000000?oo
o`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo02L0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?oo
o`3oool04`3oool001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02P0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`030000003oool0oooo00@00000A@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02L0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
003oool0oooo04X0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?oo
o`005P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo02P0oooo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool07P3oool2000002P0oooo00<000000?l0003o00000P3o00000`000000o`000?l00003
0?l000L00000A@3oool200000200oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0D
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P00000X0?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0h0?ooo`8000005@3o
ool00280oooo00<000000?ooo`3oool0:03oool010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02L0oooo00<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003oool0oooo04X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo0180oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool09`3oool7000000D0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`00
8P3oool00`000000oooo0?ooo`0X0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool09`3oool00`000000o`000?l000020?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02L0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04X0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000^
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>03oool2000001D0oooo000R0?oo
o`030000003oool0oooo02P0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`030000003oool0oooo04T0oooo00<000000?ooo`3oool07P3oool2000002P0oooo00<0
00000?l0003o00000P3o0007000004/0oooo0P00000E0?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo04X0oooo00<000000?ooo`3oool04P3oool3000000<0oooo0P00
00030?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo02P0oooo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo04T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`030000003o0000o`000080o`00
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000002T0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo04X0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0]0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool00`3oool00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`190?ooo`030000003oool0
oooo01h0oooo0P00000X0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0C`3oool2
000001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000
:03oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0M0?ooo`800000;P3oool00`000000003o0000o`030000o`030000
003oool0oooo00<0oooo1`0000050000o`030000003oool0oooo03P0oooo0P00000E0?ooo`008P3o
ool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo00L000000P1oOgl00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0180oooo0`0000040?ooo`8000000`3oool00`000000oooo0?oo
o`0W0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0D0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000003o0000o`030000o`03
0000003oool0oooo00T0oooo1`00000k0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000
003oool0oooo02P0oooo100000050?ooo`040000001oOgl0Ogmo000004/0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool09`3oool00`000000o`000?l000020?l000030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool09`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02d0oooo
00<000000000o`000?l00`000?l00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01<0oooo
000R0?ooo`030000003oool0oooo0340oooo00@0000007moO`1oOgl00000B`3oool00`000000oooo
0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool20000
02P0oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`1?0?ooo`8000004`3oool40000
00<0oooo0P0000040?ooo`030000003oool0oooo02L0oooo1`000005003o00030000003oool0oooo
04X0oooo00<000000?ooo`3oool07@3oool2000002h0oooo00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`1:0?ooo`8000005@3oool00280oooo00<000000?ooo`3oool0<@3oool010000000
Ogmo07moO`00001;0?ooo`030000003oool0oooo0180oooo0`0000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool09`3oool600000580oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo
0340oooo1000001;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool200000200oooo00<000000?ooo`3oool0;@3oool7
000004`0oooo00<000000?ooo`3oool07@3oool2000002h0oooo1`00001<0?ooo`8000005@3oool0
0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01<0oooo0`0000030?ooo`8000000`3ooon300000200oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo000R0?oooh@00000``3ooon4000001l0
ooooQ@00000E0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0ooooZ03oool00001\
\>"],
  ImageRangeCache->{{{26.375, 568}, {261.688, 184.75}} -> {-0.331812, \
1.43522, 0.00627702, 0.00627702}, {{42.25, 160.813}, {259.813, 186.563}} -> \
{-0.0639646, 271.888, 0.00328395, 1.25857}, {{172.688, 291.25}, {259.813, \
186.563}} -> {-0.633751, 173.898, 0.00341671, 0.804754}, {{303.063, 421.625}, \
{259.813, 186.563}} -> {-1.16469, 210.222, 0.00336031, 0.973118}, {{433.5, \
552.063}, {259.813, 186.563}} -> {-1.71257, 162.573, 0.00336031, 0.752548}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Raw Tapping Data", "Subsubsection"],

Cell[BoxData[
    \(\(allbeatdurstap\  = \ 
        Flatten[{fractions1b, \ fractions2b, \ fractions3b, \ 
            fractions4b}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[allbeatdurstap]\)], "Input"],

Cell[BoxData[
    \(0.33333333333333304`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DispersionReport[
      Flatten[{fractions1b, \ fractions2b, \ fractions3b, \ 
          fractions4b}]]\)], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0023773266094253317`, 
      StandardDeviation \[Rule] 0.048757836389911026`, 
      SampleRange \[Rule] 0.4772384977237145`, 
      MeanDeviation \[Rule] 0.03562167257537691`, 
      MedianDeviation \[Rule] 0.027083337468721214`, 
      QuartileDeviation \[Rule] 0.02689281453413514`}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(allbeat1durt\  = \ 
        Flatten[{fractions1b[\([1]\)], \ fractions2b[\([1]\)], \ 
            fractions3b[\([1]\)], \ 
            fractions4b[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(allbeat2durt\  = \ 
        Flatten[{fractions1b[\([2]\)], \ fractions2b[\([2]\)], \ 
            fractions3b[\([2]\)], \ 
            fractions4b[\([2]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(allbeat3durt\  = \ 
        Flatten[{fractions1b[\([3]\)], \ fractions2b[\([3]\)], \ 
            fractions3b[\([3]\)], \ fractions4b[\([3]\)]}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[allbeat1durt]\), "\[IndentingNewLine]", 
    \(Mean[allbeat2durt]\), "\[IndentingNewLine]", 
    \(Mean[allbeat3durt]\)}], "Input"],

Cell[BoxData[
    \(0.3298864661108947`\)], "Output"],

Cell[BoxData[
    \(0.324718902842784`\)], "Output"],

Cell[BoxData[
    \(0.3453946310463212`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DispersionReport[allbeat1durt]\), "\[IndentingNewLine]", 
    \(DispersionReport[allbeat2durt]\), "\[IndentingNewLine]", 
    \(DispersionReport[allbeat3durt]\)}], "Input"],

Cell[BoxData[
    \({Variance \[Rule] 0.0026567094030658933`, 
      StandardDeviation \[Rule] 0.051543276991921`, 
      SampleRange \[Rule] 0.339381868375906`, 
      MeanDeviation \[Rule] 0.038717475406868006`, 
      MedianDeviation \[Rule] 0.029567937565002866`, 
      QuartileDeviation \[Rule] 0.029623840485834912`}\)], "Output"],

Cell[BoxData[
    \({Variance \[Rule] 0.0013912713157277665`, 
      StandardDeviation \[Rule] 0.0372997495397458`, 
      SampleRange \[Rule] 0.26428017929262376`, 
      MeanDeviation \[Rule] 0.028897279986291734`, 
      MedianDeviation \[Rule] 0.023587665685177478`, 
      QuartileDeviation \[Rule] 0.023091415385686265`}\)], "Output"],

Cell[BoxData[
    \({Variance \[Rule] 0.0028630276149445477`, 
      StandardDeviation \[Rule] 0.053507266935852255`, 
      SampleRange \[Rule] 0.44717543541259774`, 
      MeanDeviation \[Rule] 0.03834647557299045`, 
      MedianDeviation \[Rule] 0.027066265258447658`, 
      QuartileDeviation \[Rule] 0.026857154392062876`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(jj\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotalltap\  = \ 
        Histogram[Flatten[allbeatdurstap], \ Frame \[Rule] True, \ 
          HistogramRange \[Rule] {0.16, \ 0.58}, \ 
          BarStyle \[Rule] {RGBColor[0.5, 0.5, 0.5]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.372093 2.32558 0.0147151 0.0041451 [
[.09302 -0.0125 -9 -9 ]
[.09302 -0.0125 9 0 ]
[.32558 -0.0125 -9 -9 ]
[.32558 -0.0125 9 0 ]
[.55814 -0.0125 -9 -9 ]
[.55814 -0.0125 9 0 ]
[.7907 -0.0125 -9 -9 ]
[.7907 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09762 -12 -4.5 ]
[-0.0125 .09762 0 4.5 ]
[-0.0125 .18052 -12 -4.5 ]
[-0.0125 .18052 0 4.5 ]
[-0.0125 .26342 -12 -4.5 ]
[-0.0125 .26342 0 4.5 ]
[-0.0125 .34632 -12 -4.5 ]
[-0.0125 .34632 0 4.5 ]
[-0.0125 .42922 -18 -4.5 ]
[-0.0125 .42922 0 4.5 ]
[-0.0125 .51213 -18 -4.5 ]
[-0.0125 .51213 0 4.5 ]
[-0.0125 .59503 -18 -4.5 ]
[-0.0125 .59503 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09302 0 m
.09302 .00625 L
s
[(0.2)] .09302 -0.0125 0 1 Mshowa
.32558 0 m
.32558 .00625 L
s
[(0.3)] .32558 -0.0125 0 1 Mshowa
.55814 0 m
.55814 .00625 L
s
[(0.4)] .55814 -0.0125 0 1 Mshowa
.7907 0 m
.7907 .00625 L
s
[(0.5)] .7907 -0.0125 0 1 Mshowa
.125 Mabswid
.13953 0 m
.13953 .00375 L
s
.18605 0 m
.18605 .00375 L
s
.23256 0 m
.23256 .00375 L
s
.27907 0 m
.27907 .00375 L
s
.37209 0 m
.37209 .00375 L
s
.4186 0 m
.4186 .00375 L
s
.46512 0 m
.46512 .00375 L
s
.51163 0 m
.51163 .00375 L
s
.60465 0 m
.60465 .00375 L
s
.65116 0 m
.65116 .00375 L
s
.69767 0 m
.69767 .00375 L
s
.74419 0 m
.74419 .00375 L
s
.04651 0 m
.04651 .00375 L
s
.83721 0 m
.83721 .00375 L
s
.88372 0 m
.88372 .00375 L
s
.93023 0 m
.93023 .00375 L
s
.97674 0 m
.97674 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09762 m
.00625 .09762 L
s
[(20)] -0.0125 .09762 1 0 Mshowa
0 .18052 m
.00625 .18052 L
s
[(40)] -0.0125 .18052 1 0 Mshowa
0 .26342 m
.00625 .26342 L
s
[(60)] -0.0125 .26342 1 0 Mshowa
0 .34632 m
.00625 .34632 L
s
[(80)] -0.0125 .34632 1 0 Mshowa
0 .42922 m
.00625 .42922 L
s
[(100)] -0.0125 .42922 1 0 Mshowa
0 .51213 m
.00625 .51213 L
s
[(120)] -0.0125 .51213 1 0 Mshowa
0 .59503 m
.00625 .59503 L
s
[(140)] -0.0125 .59503 1 0 Mshowa
.125 Mabswid
0 .03544 m
.00375 .03544 L
s
0 .05617 m
.00375 .05617 L
s
0 .07689 m
.00375 .07689 L
s
0 .11834 m
.00375 .11834 L
s
0 .13907 m
.00375 .13907 L
s
0 .15979 m
.00375 .15979 L
s
0 .20124 m
.00375 .20124 L
s
0 .22197 m
.00375 .22197 L
s
0 .2427 m
.00375 .2427 L
s
0 .28415 m
.00375 .28415 L
s
0 .30487 m
.00375 .30487 L
s
0 .3256 m
.00375 .3256 L
s
0 .36705 m
.00375 .36705 L
s
0 .38777 m
.00375 .38777 L
s
0 .4085 m
.00375 .4085 L
s
0 .44995 m
.00375 .44995 L
s
0 .47068 m
.00375 .47068 L
s
0 .4914 m
.00375 .4914 L
s
0 .53285 m
.00375 .53285 L
s
0 .55358 m
.00375 .55358 L
s
0 .5743 m
.00375 .5743 L
s
0 .61575 m
.00375 .61575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09302 .61178 m
.09302 .61803 L
s
.32558 .61178 m
.32558 .61803 L
s
.55814 .61178 m
.55814 .61803 L
s
.7907 .61178 m
.7907 .61803 L
s
.125 Mabswid
.13953 .61428 m
.13953 .61803 L
s
.18605 .61428 m
.18605 .61803 L
s
.23256 .61428 m
.23256 .61803 L
s
.27907 .61428 m
.27907 .61803 L
s
.37209 .61428 m
.37209 .61803 L
s
.4186 .61428 m
.4186 .61803 L
s
.46512 .61428 m
.46512 .61803 L
s
.51163 .61428 m
.51163 .61803 L
s
.60465 .61428 m
.60465 .61803 L
s
.65116 .61428 m
.65116 .61803 L
s
.69767 .61428 m
.69767 .61803 L
s
.74419 .61428 m
.74419 .61803 L
s
.04651 .61428 m
.04651 .61803 L
s
.83721 .61428 m
.83721 .61803 L
s
.88372 .61428 m
.88372 .61803 L
s
.93023 .61428 m
.93023 .61803 L
s
.97674 .61428 m
.97674 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09762 m
1 .09762 L
s
.99375 .18052 m
1 .18052 L
s
.99375 .26342 m
1 .26342 L
s
.99375 .34632 m
1 .34632 L
s
.99375 .42922 m
1 .42922 L
s
.99375 .51213 m
1 .51213 L
s
.99375 .59503 m
1 .59503 L
s
.125 Mabswid
.99625 .03544 m
1 .03544 L
s
.99625 .05617 m
1 .05617 L
s
.99625 .07689 m
1 .07689 L
s
.99625 .11834 m
1 .11834 L
s
.99625 .13907 m
1 .13907 L
s
.99625 .15979 m
1 .15979 L
s
.99625 .20124 m
1 .20124 L
s
.99625 .22197 m
1 .22197 L
s
.99625 .2427 m
1 .2427 L
s
.99625 .28415 m
1 .28415 L
s
.99625 .30487 m
1 .30487 L
s
.99625 .3256 m
1 .3256 L
s
.99625 .36705 m
1 .36705 L
s
.99625 .38777 m
1 .38777 L
s
.99625 .4085 m
1 .4085 L
s
.99625 .44995 m
1 .44995 L
s
.99625 .47068 m
1 .47068 L
s
.99625 .4914 m
1 .4914 L
s
.99625 .53285 m
1 .53285 L
s
.99625 .55358 m
1 .55358 L
s
.99625 .5743 m
1 .5743 L
s
.99625 .61575 m
1 .61575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02301 L
.02326 .02301 L
.02326 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02301 L
.02326 .02301 L
.02326 .01472 L
0 .01472 L
s
.5 .5 .5 r
.02326 .01472 m
.02326 .01886 L
.04651 .01886 L
.04651 .01472 L
F
0 g
.02326 .01472 m
.02326 .01886 L
.04651 .01886 L
.04651 .01472 L
.02326 .01472 L
s
.5 .5 .5 r
.04651 .01472 m
.04651 .02301 L
.06977 .02301 L
.06977 .01472 L
F
0 g
.04651 .01472 m
.04651 .02301 L
.06977 .02301 L
.06977 .01472 L
.04651 .01472 L
s
.5 .5 .5 r
.06977 .01472 m
.06977 .02715 L
.09302 .02715 L
.09302 .01472 L
F
0 g
.06977 .01472 m
.06977 .02715 L
.09302 .02715 L
.09302 .01472 L
.06977 .01472 L
s
.5 .5 .5 r
.09302 .01472 m
.09302 .03959 L
.11628 .03959 L
.11628 .01472 L
F
0 g
.09302 .01472 m
.09302 .03959 L
.11628 .03959 L
.11628 .01472 L
.09302 .01472 L
s
.5 .5 .5 r
.11628 .01472 m
.11628 .01886 L
.13953 .01886 L
.13953 .01472 L
F
0 g
.11628 .01472 m
.11628 .01886 L
.13953 .01886 L
.13953 .01472 L
.11628 .01472 L
s
.5 .5 .5 r
.13953 .01472 m
.13953 .03959 L
.16279 .03959 L
.16279 .01472 L
F
0 g
.13953 .01472 m
.13953 .03959 L
.16279 .03959 L
.16279 .01472 L
.13953 .01472 L
s
.5 .5 .5 r
.16279 .01472 m
.16279 .07275 L
.18605 .07275 L
.18605 .01472 L
F
0 g
.16279 .01472 m
.16279 .07275 L
.18605 .07275 L
.18605 .01472 L
.16279 .01472 L
s
.5 .5 .5 r
.18605 .01472 m
.18605 .08104 L
.2093 .08104 L
.2093 .01472 L
F
0 g
.18605 .01472 m
.18605 .08104 L
.2093 .08104 L
.2093 .01472 L
.18605 .01472 L
s
.5 .5 .5 r
.2093 .01472 m
.2093 .09762 L
.23256 .09762 L
.23256 .01472 L
F
0 g
.2093 .01472 m
.2093 .09762 L
.23256 .09762 L
.23256 .01472 L
.2093 .01472 L
s
.5 .5 .5 r
.23256 .01472 m
.23256 .13907 L
.25581 .13907 L
.25581 .01472 L
F
0 g
.23256 .01472 m
.23256 .13907 L
.25581 .13907 L
.25581 .01472 L
.23256 .01472 L
s
.5 .5 .5 r
.25581 .01472 m
.25581 .17223 L
.27907 .17223 L
.27907 .01472 L
F
0 g
.25581 .01472 m
.25581 .17223 L
.27907 .17223 L
.27907 .01472 L
.25581 .01472 L
s
.5 .5 .5 r
.27907 .01472 m
.27907 .25099 L
.30233 .25099 L
.30233 .01472 L
F
0 g
.27907 .01472 m
.27907 .25099 L
.30233 .25099 L
.30233 .01472 L
.27907 .01472 L
s
.5 .5 .5 r
.30233 .01472 m
.30233 .31316 L
.32558 .31316 L
.32558 .01472 L
F
0 g
.30233 .01472 m
.30233 .31316 L
.32558 .31316 L
.32558 .01472 L
.30233 .01472 L
s
.5 .5 .5 r
.32558 .01472 m
.32558 .38777 L
.34884 .38777 L
.34884 .01472 L
F
0 g
.32558 .01472 m
.32558 .38777 L
.34884 .38777 L
.34884 .01472 L
.32558 .01472 L
s
.5 .5 .5 r
.34884 .01472 m
.34884 .54114 L
.37209 .54114 L
.37209 .01472 L
F
0 g
.34884 .01472 m
.34884 .54114 L
.37209 .54114 L
.37209 .01472 L
.34884 .01472 L
s
.5 .5 .5 r
.37209 .01472 m
.37209 .52871 L
.39535 .52871 L
.39535 .01472 L
F
0 g
.37209 .01472 m
.37209 .52871 L
.39535 .52871 L
.39535 .01472 L
.37209 .01472 L
s
.5 .5 .5 r
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
F
0 g
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
.39535 .01472 L
s
.5 .5 .5 r
.4186 .01472 m
.4186 .52456 L
.44186 .52456 L
.44186 .01472 L
F
0 g
.4186 .01472 m
.4186 .52456 L
.44186 .52456 L
.44186 .01472 L
.4186 .01472 L
s
.5 .5 .5 r
.44186 .01472 m
.44186 .42922 L
.46512 .42922 L
.46512 .01472 L
F
0 g
.44186 .01472 m
.44186 .42922 L
.46512 .42922 L
.46512 .01472 L
.44186 .01472 L
s
.5 .5 .5 r
.46512 .01472 m
.46512 .35876 L
.48837 .35876 L
.48837 .01472 L
F
0 g
.46512 .01472 m
.46512 .35876 L
.48837 .35876 L
.48837 .01472 L
.46512 .01472 L
s
.5 .5 .5 r
.48837 .01472 m
.48837 .2427 L
.51163 .2427 L
.51163 .01472 L
F
0 g
.48837 .01472 m
.48837 .2427 L
.51163 .2427 L
.51163 .01472 L
.48837 .01472 L
s
.5 .5 .5 r
.51163 .01472 m
.51163 .15979 L
.53488 .15979 L
.53488 .01472 L
F
0 g
.51163 .01472 m
.51163 .15979 L
.53488 .15979 L
.53488 .01472 L
.51163 .01472 L
s
.5 .5 .5 r
.53488 .01472 m
.53488 .18881 L
.55814 .18881 L
.55814 .01472 L
F
0 g
.53488 .01472 m
.53488 .18881 L
.55814 .18881 L
.55814 .01472 L
.53488 .01472 L
s
.5 .5 .5 r
.55814 .01472 m
.55814 .12249 L
.5814 .12249 L
.5814 .01472 L
F
0 g
.55814 .01472 m
.55814 .12249 L
.5814 .12249 L
.5814 .01472 L
.55814 .01472 L
s
.5 .5 .5 r
.5814 .01472 m
.5814 .06446 L
.60465 .06446 L
.60465 .01472 L
F
0 g
.5814 .01472 m
.5814 .06446 L
.60465 .06446 L
.60465 .01472 L
.5814 .01472 L
s
.5 .5 .5 r
.60465 .01472 m
.60465 .06446 L
.62791 .06446 L
.62791 .01472 L
F
0 g
.60465 .01472 m
.60465 .06446 L
.62791 .06446 L
.62791 .01472 L
.60465 .01472 L
s
.5 .5 .5 r
.62791 .01472 m
.62791 .06446 L
.65116 .06446 L
.65116 .01472 L
F
0 g
.62791 .01472 m
.62791 .06446 L
.65116 .06446 L
.65116 .01472 L
.62791 .01472 L
s
.5 .5 .5 r
.65116 .01472 m
.65116 .06446 L
.67442 .06446 L
.67442 .01472 L
F
0 g
.65116 .01472 m
.65116 .06446 L
.67442 .06446 L
.67442 .01472 L
.65116 .01472 L
s
.5 .5 .5 r
.67442 .01472 m
.67442 .03959 L
.69767 .03959 L
.69767 .01472 L
F
0 g
.67442 .01472 m
.67442 .03959 L
.69767 .03959 L
.69767 .01472 L
.67442 .01472 L
s
.5 .5 .5 r
.69767 .01472 m
.69767 .02715 L
.72093 .02715 L
.72093 .01472 L
F
0 g
.69767 .01472 m
.69767 .02715 L
.72093 .02715 L
.72093 .01472 L
.69767 .01472 L
s
.5 .5 .5 r
.72093 .01472 m
.72093 .02715 L
.74419 .02715 L
.74419 .01472 L
F
0 g
.72093 .01472 m
.72093 .02715 L
.74419 .02715 L
.74419 .01472 L
.72093 .01472 L
s
.5 .5 .5 r
.74419 .01472 m
.74419 .01886 L
.76744 .01886 L
.76744 .01472 L
F
0 g
.74419 .01472 m
.74419 .01886 L
.76744 .01886 L
.76744 .01472 L
.74419 .01472 L
s
.5 .5 .5 r
.76744 .01472 m
.76744 .01886 L
.7907 .01886 L
.7907 .01472 L
F
0 g
.76744 .01472 m
.76744 .01886 L
.7907 .01886 L
.7907 .01472 L
.76744 .01472 L
s
.5 .5 .5 r
.7907 .01472 m
.7907 .01886 L
.81395 .01886 L
.81395 .01472 L
F
0 g
.7907 .01472 m
.7907 .01886 L
.81395 .01886 L
.81395 .01472 L
.7907 .01472 L
s
.5 .5 .5 r
.81395 .01472 m
.81395 .01886 L
.83721 .01886 L
.83721 .01472 L
F
0 g
.81395 .01472 m
.81395 .01886 L
.83721 .01886 L
.83721 .01472 L
.81395 .01472 L
s
.5 .5 .5 r
.83721 .01472 m
.83721 .01886 L
.86047 .01886 L
.86047 .01472 L
F
0 g
.83721 .01472 m
.83721 .01886 L
.86047 .01886 L
.86047 .01472 L
.83721 .01472 L
s
.5 .5 .5 r
.86047 .01472 m
.86047 .01472 L
.88372 .01472 L
.88372 .01472 L
F
0 g
.86047 .01472 m
.86047 .01472 L
.88372 .01472 L
.88372 .01472 L
.86047 .01472 L
s
.5 .5 .5 r
.88372 .01472 m
.88372 .01886 L
.90698 .01886 L
.90698 .01472 L
F
0 g
.88372 .01472 m
.88372 .01886 L
.90698 .01886 L
.90698 .01472 L
.88372 .01472 L
s
.5 .5 .5 r
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
F
0 g
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
.90698 .01472 L
s
.5 .5 .5 r
.93023 .01472 m
.93023 .02301 L
.95349 .02301 L
.95349 .01472 L
F
0 g
.93023 .01472 m
.93023 .02301 L
.95349 .02301 L
.95349 .01472 L
.93023 .01472 L
s
.5 .5 .5 r
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
F
0 g
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
.95349 .01472 L
s
.5 .5 .5 r
.97674 .01472 m
.97674 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.97674 .01472 m
.97674 .01472 L
1 .01472 L
1 .01472 L
.97674 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`009`3oool2000000@0oooo0P0000030?ooo`@00000;P3oool2000000@0oooo0P0000040?oo
o`800000<03oool2000000@0oooo0P0000050?ooo`<00000;P3oool2000000@0oooo0P0000040?oo
o`800000<P3oool002H0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0^0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000a0?ooo`009P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0
oooo000000P0oooo1@00000]0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
;`3oool002H0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002@3oool200000380oooo000V
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000^0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0<@3o
ool002L0oooo0P00000:0?ooo`800000;`3oool2000000X0oooo0P00000`0?ooo`8000002`3oool2
000002l0oooo0P00000:0?ooo`<00000<@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo000E0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo0@0000010?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0d0?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`003@3oool010000000oooo0?oo
o`0000040?ooool000003000000000d0oooo00@000000?ooo`3oool00000103oool00`000000Ogmo
07moO`0307moO`L000001@1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo800000050?ooo`P000001@3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo00T0oooo0@0000010?ooo`003@3oool010000000oooo0?oo
o`0000040?ooo`L000001@3oool7000000H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0_0?ooo`L000002`3oool100000040oooo000>0?ooo`8000001@3oool00`000000oooo0?oo
o`0?0?ooo`P000001@1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`d00000@`3oool100000040oooo000E
0?ooo`030000003oool0oooo01H0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo04d0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0F0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1=0?oo
o`4000000@3oool001D0oooo0P00000G0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool00`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`1<0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
5P3oool7000000D0oooo1`00000507moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`L00000C`3oool100000040oooo000E0?ooo`030000003o
ool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1C0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo05<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0X0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0D`3oool100000040oooo000E0?ooo`800000:@3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0580oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`0X0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0D`3oool100000040oooo
000E0?ooo`030000003oool0oooo02P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo6P00001E0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0:03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`1/0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0:03oool7000000D0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1/0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0;P3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0K03oool100000040oooo000E0?ooo`800000
;`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
J`3oool200000040oooo000E0?ooo`030000003oool0oooo02h0oooo1`00000607moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo06`0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0d0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0K03oool100000040oooo00070?ooo`@000000`3oool20000
00D0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
06`0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0=03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo
06`0oooo0@0000010?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo0P00000e0?ooo`P000001@1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0J`3oool200000040oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0K03oool100000040oooo00070?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo06`0oooo0@000001
0?ooo`00203oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03/0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0K03oool100000040oooo000E0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0K03oool100000040oooo000E0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
K03oool100000040oooo000E0?ooo`800000?03oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1[0?ooo`8000000@3o
ool001D0oooo00<000000?ooo`3oool0>`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo1`00001^0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0>`3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0LP3oool10000
0040oooo000E0?ooo`030000003oool0oooo03/0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0780oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`0k0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`1b0?ooo`4000000@3oool001D0oooo0P00000l0?ooo`L000001@1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`1a0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0@@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo0780oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`110?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0LP3oool100000040oooo000E0?ooo`03
0000003oool0oooo0440oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1b0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0@@3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo0780oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`110?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<000000?ooo`3oool0LP3oool100000040oooo000E0?ooo`800000@P3oool0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo1`00000507moO`030000003oool0
oooo0740oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`110?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo
00<0Ogmo00<000000?ooo`3oool0LP3oool100000040oooo000E0?ooo`030000003oool0oooo0440
oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo00<0
oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1b0?ooo`4000000@3oool000T0oooo
0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`110?ooo`L000001@1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0LP3oool100000040oooo
000:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`170?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
07moO`0307moO`030000003oool0oooo0780oooo0@0000010?ooo`001`3oool5000000050?ooo`00
0000oooo0?ooo`000000103oool2000004P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0L@3oool200000040oooo
00070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`170?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool00`3oool00`000000
Ogmo07moO`0307moO`030000003oool0oooo0780oooo0@0000010?ooo`00203oool00`000000oooo
000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo00<0oooo1`00001d0?ooo`4000000@3oool000T0oooo
0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`170?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0OP3oool100000040oooo000E0?ooo`030000003oool0oooo04L0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1n0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0A`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo07h0oooo0@000001
0?ooo`005@3oool2000004P0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1m0?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`03
0000003oool0oooo07h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0OP3oool100000040oooo000E0?ooo`030000003o
ool0oooo04L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`1n0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo07h0oooo0@0000010?ooo`005@3oool2000004P0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`1m0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo07h0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`170?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0OP3oool100000040oooo
000E0?ooo`030000003oool0oooo04L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`1n0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo07h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0OP3oool100000040oooo000E0?ooo`80
0000B03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl7000007l0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo08@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`L000001@1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?ooo`001`3oool3
000000@0oooo0P0000050?ooo`030000003oool0oooo04d0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?ooo`001`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0C@3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0Q03o
ool100000040oooo00070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool2000004h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
003oool0oooo08<0oooo0P0000010?ooo`001`3oool3000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1=0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000oooo0?ooo`240?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04d0oooo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?ooo`00203o
ool3000000<0oooo0P0000050?ooo`030000003oool0oooo04d0oooo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1=0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`240?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0C@3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0Q03oool10000
0040oooo000E0?ooo`800000CP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0
Ogmo00<000000?ooo`3oool0P`3oool200000040oooo000E0?ooo`030000003oool0oooo04d0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`240?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0C@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0Q03oool100000040oooo000E0?ooo`030000003oool0oooo04d0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?oo
o`005@3oool2000004h0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo08<0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`240?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0C@3oool7000000D0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0Q03o
ool100000040oooo000E0?ooo`030000003oool0oooo05<0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`240?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0D`3oool00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0Q03oool100000040
oooo000E0?ooo`800000E03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08<0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
00000?ooo`3oool0Q03oool100000040oooo000E0?ooo`030000003oool0oooo05<0oooo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`240?ooo`4000000@3oool000P0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0Q03oool100000040oooo00070?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0Q03oool100000040oooo00070?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool2000005@0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`230?ooo`8000000@3oool000P0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0D`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo0@00
00010?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0D`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo08@0oooo
0@0000010?ooo`00203oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05<0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo2000
00260?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0D`3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2;
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0D`3oool00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2;0?oo
o`4000000@3oool001D0oooo0P00001D0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo08X0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`1C0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`005@3oool2000005@0
oooo1`00000607moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0RP3oool200000040
oooo000E0?ooo`030000003oool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2;0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0F@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0R`3oool100000040oooo000E0?oo
o`030000003oool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307mo
O`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo08/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1I0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2;0?ooo`40
00000@3oool001D0oooo0P00001J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`2:0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0F@3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0R`3o
ool100000040oooo000E0?ooo`030000003oool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo08/0oooo0@0000010?ooo`0000<0oooo0000
000000000`0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0F@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0R`3oool10000
0040oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0R`3oool100000040oooo00030?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo0P00001J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo1`00002<0?ooo`8000000@3o
ool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0T@3oool100000040oooo00030?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0F@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0940oooo0@0000010?ooo`00
0P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1I0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0T@3oool100000040oooo000E0?ooo`030000003o
ool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2A0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0F@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo0940oooo0@0000010?ooo`005@3oool2000005X0oooo00<0000007moO`1oOgl0101oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`2@0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0F@3oool00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0307moO`030000003oool0oooo0940oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0T@3oool100000040oooo
000E0?ooo`030000003oool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07mo
O`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2A0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0F@3oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000003oool0oooo0940oooo0@0000010?ooo`005@3oool2000005X0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`2@0?ooo`8000000@3oool001D0oooo00<000000?ooo`3o
ool0F@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0940oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
T@3oool100000040oooo000E0?ooo`030000003oool0oooo05T0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`2A0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0F@3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0307moO`030000003oool0oooo0940oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0T@3oool10000
0040oooo000E0?ooo`800000FP3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0900
oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0T@3oool100000040oooo000E0?ooo`030000003oool0oooo05T0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2A0?ooo`4000000@3oool000030?ooo`000000
000000<0000000<0oooo0000000000000P0000030?ooo`8000001@3oool00`000000oooo0?ooo`1I
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0T@3oool100000040oooo00030?oo
o`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2A0?ooo`4000000@3o
ool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo0P00001J0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0T03o
ool200000040oooo00030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool00`000000Ogmo07mo
O`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0307moO`030000003oool0oooo0940oooo0@0000010?ooo`000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05T0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2A0?ooo`400000
0@3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0F@3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1o
Ogl7000009<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0
Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo09L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1I0?ooo`030000001oOgl0Ogmo
00@0Ogmo1`00000507moO`030000003oool0oooo09L0oooo0@0000010?ooo`005@3oool2000005X0
oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0UP3oool200000040oooo000E0?ooo`030000003oool0oooo05T0oooo
00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0U`3oool100000040oooo000E0?ooo`030000003oool0oooo05T0oooo2000
00050?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0U`3oool100000040oooo000E
0?ooo`030000003oool0oooo06H0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2G
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0IP3oool00`000000Ogmo07moO`0307mo
O`030000003oool0oooo09L0oooo0@0000010?ooo`005@3oool2000006L0oooo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`2F0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
IP3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo09L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`1V0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0U`3o
ool100000040oooo000E0?ooo`030000003oool0oooo06H0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`2G0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0IP3oool00`00
0000Ogmo07moO`0307moO`030000003oool0oooo09L0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1V0?ooo`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0U`3oool100000040
oooo000E0?ooo`800000I`3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo09H0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`1V0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0U`3oool100000040oooo000E0?ooo`030000003oool0oooo06H0oooo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`2G0?ooo`4000000@3oool000030?ooo`0000000000
00<000000`3oool300000080oooo0P0000050?ooo`030000003oool0oooo06H0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`2G0?ooo`4000000@3oool000<0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0IP3oool00`000000Ogmo07moO`0307moO`030000003oool0oooo09L0oooo0@0000010?oo
o`000`3oool010000000oooo0?ooo`3oool5000000050?ooo`000000oooo0?ooo`000000103oool2
000006L0oooo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2F0?ooo`8000000@3oool0
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0U`3oool100000040oooo00030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06H0oooo1`00
002I0?ooo`4000000@3oool00080oooo0P0000050?ooo`8000000`3oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool100000040oooo000E0?ooool00000
2`0000010?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {440.75, 299.438}} -> {0.0720046, \
325.474, 0.00162096, 0.909428}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb1t\  = 
        Histogram[allbeat1durt, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[1, 0, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00692475 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15321 -12 -4.5 ]
[-0.0125 .15321 0 4.5 ]
[-0.0125 .29171 -12 -4.5 ]
[-0.0125 .29171 0 4.5 ]
[-0.0125 .4302 -12 -4.5 ]
[-0.0125 .4302 0 4.5 ]
[-0.0125 .5687 -12 -4.5 ]
[-0.0125 .5687 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15321 m
.00625 .15321 L
s
[(20)] -0.0125 .15321 1 0 Mshowa
0 .29171 m
.00625 .29171 L
s
[(40)] -0.0125 .29171 1 0 Mshowa
0 .4302 m
.00625 .4302 L
s
[(60)] -0.0125 .4302 1 0 Mshowa
0 .5687 m
.00625 .5687 L
s
[(80)] -0.0125 .5687 1 0 Mshowa
.125 Mabswid
0 .04934 m
.00375 .04934 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .18783 m
.00375 .18783 L
s
0 .22246 m
.00375 .22246 L
s
0 .25708 m
.00375 .25708 L
s
0 .32633 m
.00375 .32633 L
s
0 .36095 m
.00375 .36095 L
s
0 .39558 m
.00375 .39558 L
s
0 .46482 m
.00375 .46482 L
s
0 .49945 m
.00375 .49945 L
s
0 .53407 m
.00375 .53407 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15321 m
1 .15321 L
s
.99375 .29171 m
1 .29171 L
s
.99375 .4302 m
1 .4302 L
s
.99375 .5687 m
1 .5687 L
s
.125 Mabswid
.99625 .04934 m
1 .04934 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .18783 m
1 .18783 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .36095 m
1 .36095 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .53407 m
1 .53407 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02856 L
.04545 .02856 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02856 L
.04545 .02856 L
.04545 .01472 L
0 .01472 L
s
1 0 0 r
.04545 .01472 m
.04545 .04241 L
.09091 .04241 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .04241 L
.09091 .04241 L
.09091 .01472 L
.04545 .01472 L
s
1 0 0 r
.09091 .01472 m
.09091 .04934 L
.13636 .04934 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .04934 L
.13636 .04934 L
.13636 .01472 L
.09091 .01472 L
s
1 0 0 r
.13636 .01472 m
.13636 .09781 L
.18182 .09781 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .09781 L
.18182 .09781 L
.18182 .01472 L
.13636 .01472 L
s
1 0 0 r
.18182 .01472 m
.18182 .09781 L
.22727 .09781 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .09781 L
.22727 .09781 L
.22727 .01472 L
.18182 .01472 L
s
1 0 0 r
.22727 .01472 m
.22727 .18091 L
.27273 .18091 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .18091 L
.27273 .18091 L
.27273 .01472 L
.22727 .01472 L
s
1 0 0 r
.27273 .01472 m
.27273 .33325 L
.31818 .33325 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .33325 L
.31818 .33325 L
.31818 .01472 L
.27273 .01472 L
s
1 0 0 r
.31818 .01472 m
.31818 .47175 L
.36364 .47175 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .47175 L
.36364 .47175 L
.36364 .01472 L
.31818 .01472 L
s
1 0 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
1 0 0 r
.40909 .01472 m
.40909 .4579 L
.45455 .4579 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .4579 L
.45455 .4579 L
.45455 .01472 L
.40909 .01472 L
s
1 0 0 r
.45455 .01472 m
.45455 .3471 L
.5 .3471 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .3471 L
.5 .3471 L
.5 .01472 L
.45455 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .18091 L
.54545 .18091 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .18091 L
.54545 .18091 L
.54545 .01472 L
.5 .01472 L
s
1 0 0 r
.54545 .01472 m
.54545 .12551 L
.59091 .12551 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .12551 L
.59091 .12551 L
.59091 .01472 L
.54545 .01472 L
s
1 0 0 r
.59091 .01472 m
.59091 .07704 L
.63636 .07704 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .07704 L
.63636 .07704 L
.63636 .01472 L
.59091 .01472 L
s
1 0 0 r
.63636 .01472 m
.63636 .07704 L
.68182 .07704 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .07704 L
.68182 .07704 L
.68182 .01472 L
.63636 .01472 L
s
1 0 0 r
.68182 .01472 m
.68182 .02164 L
.72727 .02164 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .02164 L
.72727 .02164 L
.72727 .01472 L
.68182 .01472 L
s
1 0 0 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
1 0 0 r
.77273 .01472 m
.77273 .02164 L
.81818 .02164 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02164 L
.81818 .02164 L
.81818 .01472 L
.77273 .01472 L
s
1 0 0 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
1 0 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
1 0 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
1 0 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
2@3oool00`000000o`000?l000090?l000030000003oool0oooo02h0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o000=000000/0oooo3@00000`0?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool>000000/0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00X0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0
oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo00X0oooo3@00000;0?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo0580oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool05P3oool00`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo0P00000G
0?ooo`d000002`3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?ooo`3oool0D@3oool2000000<0oooo000A0?ooo`030000003oool0oooo0280oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
8P3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo0280oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003oool0oooo0580oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool08P3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0280oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o000I000005@0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool00`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
000S0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0J@3oool2000000<0oooo000A
0?ooo`030000003oool0oooo0280oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0280oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0280oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0280oooo6@00000;0?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo03X0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0
oooo06X0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000>`3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002P3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?ooo`3oool0J@3oool2000000<0oooo000A0?ooo`030000003oool0oooo03X0oooo00<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo06X0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000o`000?l00009
0?l000d00000K03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`000`3oool40000
00<0oooo0P0000050?ooo`030000003oool0oooo03X0oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j0?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000j0?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00T0o`0000<000000?ooo`3oool0M03oool3000000<0oooo00050?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j
0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03X0oooo00<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo03X0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo03X0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo3@00000;0?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000X0o`003@00001h0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo
0880oooo00<000000?ooo`3oool00@3oool00140oooo0P0000170?ooo`030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo
00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000A`3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04H0
oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0880oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool2
000004L0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0
oooo0840oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l0000:0?l000030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`00
00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l0000:0?l000030000003oool0oooo0880oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00050?ooo`<00000
0P3oool2000000D0oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`001P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`010?ooo`000`3oool5000000050?ooo`000000oooo0?ooo`000000
103oool3000004H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo0800oooo0`0000030?ooo`000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`00
103oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000
003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:0?l000030000
003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0AP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`160?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`800000A`3oool00`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0P@3oool2000000<0oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l0000:
0?l000030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0AP3oool=000000/0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000o`000?l000090?l000h00000Q03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o0000
0`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000003o0000o`00
00T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`010?ooo`004@3oool2000005<0oooo00<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0SP3oool2000000<0oooo
000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<00000
0?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l0
00030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000
003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3o
ool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o
00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000
o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000o`000?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140
oooo0P00001C0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000
o`000?l000090?l000030000003oool0oooo08h0oooo0P0000030?ooo`004@3oool00`000000oooo
0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`00
0?l000090?l000030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<0
00000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0
003o00002@3o00000`000000o`000?l000090?l000030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o0000
2@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`010?ooo`000`3oool3000000@0oooo0P0000050?ooo`030000003o
ool0oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o
0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool300000580oooo00<000000?l0003o
00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3o
ool0S@3oool3000000<0oooo00030?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0580oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l00003
0000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0DP3oool00`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o
00002@3o00000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo00040?ooo`<00000
0`3oool2000000D0oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l000090?l000030000
003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000?l0003o00002@3o
00000`000000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000
o`0000T0o`0000<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003oool0
oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`00
0000o`000?l000090?l000030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580
oooo00<000000?l0003o00002@3o00000`000000o`000?l000090?l000030000003o0000o`0000T0
o`0000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1B0?ooo`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o000=00000940oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000o`000?l0
00090?l000030000003o0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`010?ooo`004@3oool2000005<0oooo00<000000?l0003o00002@3o00000`000000o`000?l00009
0?l000030000003oool0oooo09X0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?oo
o`030000003o0000o`0000T0o`0000<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo3@00000;0?l00003
0000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
GP3oool00`000000o`000?l000090?l000030000003oool0oooo09/0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000o`000?l000090?l000030000003o
ool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool0
0`000000o`000?l000090?l000030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0GP3oool00`000000o`000?l000090?l000030000003oool0oooo
09/0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000
o`000?l000090?l000030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0GP3oool00`000000o`000?l000090?l000030000003oool0oooo09/0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00001O0?ooo`030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0VP3oool2000000<0oooo000A0?ooo`030000003oool0oooo05h0oooo00<00000
0?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o
00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o
00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o00000`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0
oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040
oooo000A0?ooo`800000G`3oool00`000000o`000?l000090?l000030000003oool0oooo09X0oooo
0P0000030?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000T0o`0000<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N
0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000T0o`0000<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03
0000003o0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000T0o`0000<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000003o
0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o0000
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`030000003o
0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001N0?ooo`030000
003o0000o`0000T0o`0000<000000?ooo`3oool0V@3oool3000000<0oooo00040?ooo`8000000`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05h0oooo00<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`03
0000003o0000o`0000T0o`0000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05h0oooo00<000000?l0003o0000
2@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o0000
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o00000`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo
00<000000?l0003o00002@3o00000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00002@3o00000`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000G`3oool=000009`0oooo0P000003
0?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d00000
0`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {155, 13.6875}} -> {0.0756102, \
0.474102, 0.00165494, 0.543159}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb2t\  = 
        Histogram[allbeat2durt, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00632907 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1413 -12 -4.5 ]
[-0.0125 .1413 0 4.5 ]
[-0.0125 .26788 -12 -4.5 ]
[-0.0125 .26788 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .52104 -12 -4.5 ]
[-0.0125 .52104 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1413 m
.00625 .1413 L
s
[(20)] -0.0125 .1413 1 0 Mshowa
0 .26788 m
.00625 .26788 L
s
[(40)] -0.0125 .26788 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(60)] -0.0125 .39446 1 0 Mshowa
0 .52104 m
.00625 .52104 L
s
[(80)] -0.0125 .52104 1 0 Mshowa
.125 Mabswid
0 .04636 m
.00375 .04636 L
s
0 .07801 m
.00375 .07801 L
s
0 .10965 m
.00375 .10965 L
s
0 .17294 m
.00375 .17294 L
s
0 .20459 m
.00375 .20459 L
s
0 .23623 m
.00375 .23623 L
s
0 .29952 m
.00375 .29952 L
s
0 .33117 m
.00375 .33117 L
s
0 .36281 m
.00375 .36281 L
s
0 .4261 m
.00375 .4261 L
s
0 .45775 m
.00375 .45775 L
s
0 .4894 m
.00375 .4894 L
s
0 .55269 m
.00375 .55269 L
s
0 .58433 m
.00375 .58433 L
s
0 .61598 m
.00375 .61598 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1413 m
1 .1413 L
s
.99375 .26788 m
1 .26788 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .52104 m
1 .52104 L
s
.125 Mabswid
.99625 .04636 m
1 .04636 L
s
.99625 .07801 m
1 .07801 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .17294 m
1 .17294 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .23623 m
1 .23623 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .33117 m
1 .33117 L
s
.99625 .36281 m
1 .36281 L
s
.99625 .4261 m
1 .4261 L
s
.99625 .45775 m
1 .45775 L
s
.99625 .4894 m
1 .4894 L
s
.99625 .55269 m
1 .55269 L
s
.99625 .58433 m
1 .58433 L
s
.99625 .61598 m
1 .61598 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02104 L
.04545 .02104 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02104 L
.04545 .02104 L
.04545 .01472 L
0 .01472 L
s
0 1 0 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
0 1 0 r
.09091 .01472 m
.09091 .02104 L
.13636 .02104 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02104 L
.13636 .02104 L
.13636 .01472 L
.09091 .01472 L
s
0 1 0 r
.13636 .01472 m
.13636 .04003 L
.18182 .04003 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .04003 L
.18182 .04003 L
.18182 .01472 L
.13636 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .05902 L
.22727 .05902 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .05902 L
.22727 .05902 L
.22727 .01472 L
.18182 .01472 L
s
0 1 0 r
.22727 .01472 m
.22727 .22357 L
.27273 .22357 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .22357 L
.27273 .22357 L
.27273 .01472 L
.22727 .01472 L
s
0 1 0 r
.27273 .01472 m
.27273 .35649 L
.31818 .35649 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .35649 L
.31818 .35649 L
.31818 .01472 L
.27273 .01472 L
s
0 1 0 r
.31818 .01472 m
.31818 .578 L
.36364 .578 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .578 L
.36364 .578 L
.36364 .01472 L
.31818 .01472 L
s
0 1 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 1 0 r
.40909 .01472 m
.40909 .54003 L
.45455 .54003 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .54003 L
.45455 .54003 L
.45455 .01472 L
.40909 .01472 L
s
0 1 0 r
.45455 .01472 m
.45455 .22357 L
.5 .22357 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .22357 L
.5 .22357 L
.5 .01472 L
.45455 .01472 L
s
0 1 0 r
.5 .01472 m
.5 .12864 L
.54545 .12864 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .12864 L
.54545 .12864 L
.54545 .01472 L
.5 .01472 L
s
0 1 0 r
.54545 .01472 m
.54545 .06535 L
.59091 .06535 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .06535 L
.59091 .06535 L
.59091 .01472 L
.54545 .01472 L
s
0 1 0 r
.59091 .01472 m
.59091 .0337 L
.63636 .0337 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0337 L
.63636 .0337 L
.63636 .01472 L
.59091 .01472 L
s
0 1 0 r
.63636 .01472 m
.63636 .02104 L
.68182 .02104 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .02104 L
.68182 .02104 L
.68182 .01472 L
.63636 .01472 L
s
0 1 0 r
.68182 .01472 m
.68182 .01472 L
.72727 .01472 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .01472 L
.72727 .01472 L
.72727 .01472 L
.68182 .01472 L
s
0 1 0 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
0 1 0 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
0 1 0 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
0 1 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 1 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
0 1 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`h000002`3oool=000000/00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`0=000005@0oooo00<000000?ooo`3oool00@3oool000T0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000:0?ooo`8000001@3o
ool00`000000oooo0?ooo`0R0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo0280oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0
oooo05h0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool08P3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00d00000H03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0R0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`d000002`00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000002l0oooo00<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0J@3oool2000000<0oooo000A
0?ooo`030000003oool0oooo02h0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo06X0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo3@00000;003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l03@00001/0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000X00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000>`3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo07D0oooo0P0000030?ooo`004@3oool00`000000oooo0?oo
o`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o000300000000o`000?l000T00?l000<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
03/0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00X00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`1e0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo07H0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0
003o0009003o00030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`0000000?l0003o0009003o00030000003oool0oooo07H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`0000000?l0003o0009
003o00030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`0=000007P0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00030?ooo`@00000
0`3oool2000000D0oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000
003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool0
0@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`<00000
>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2P00o`000`000000oooo0?ooo`200?ooo`<000000`3oool000D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo
0?ooo`220?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`800000>`3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`210?ooo`800000
0`3oool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000X00?l000<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o000:003o00030000003oool0oooo
0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0>P3oool00`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002P00o`000`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000X00?l0
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?oo
o`800000>`3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002P00o`000`000000oooo0?ooo`210?ooo`8000000`3oool00140oooo00<000000?ooo`3o
ool0>P3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo03X0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000X00?l000<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0j0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o000:003o00030000003oool0oooo0880oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0>P3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002P00o`000`000000oooo0?ooo`220?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo03X0oooo3@00000;003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00h00000Q03oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool2000004L0oooo00<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140oooo00<000000?oo
o`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003o
ool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool0
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool0
00D0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`001P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000<0
oooo1@0000001@3oool000000?ooo`3oool0000000@0oooo0`0000160?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0S@3oool3000000<0oooo00030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00103oool00`00
0000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0AP3oool0
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool0
00D0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l0
00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l0
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`160?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?oo
o`004@3oool2000004L0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2>0?ooo`80
00000`3oool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0
oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
00000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P0000170?ooo`0300000000o`000?l000T00?l000<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0SP3oool2000000<0oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo04H0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo04H0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
04H0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo04H0oooo3@00000;003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`010?ooo`004@3oool2000005<0oooo00<00000003o0000o`002@00o`000`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0SP3oool2000000<0oooo000A
0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003o
ool0oooo08l0oooo00<000000?ooo`3oool00@3oool000<0oooo0`0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001B0?ooo`030000
0000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
003oool0oooo08d0oooo0`0000030?ooo`000`3oool3000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool0
0@3oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00103o
ool3000000<0oooo0P0000050?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0
oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`00
00000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580
oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0
003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
001C0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o
0009003o00030000003oool0oooo08h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009
003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000
o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`00
0`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo
08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000
0?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000D`3oool00`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo
0?ooo`2>0?ooo`8000000`3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o
0009003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000
003o0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<00000003o0000
o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000
0000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0040oooo000A0?ooo`800000D`3oool00`0000000?l0003o0009003o000300000000o`000?l0
00T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2>0?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<0
0000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`00
2@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001B0?oo
o`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o
00030000003oool0oooo08d0oooo0`0000030?ooo`00103oool2000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T00?l000<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009
003o000300000000o`000?l000T00?l000<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`01
0?ooo`00103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0580oooo00<00000003o
0000o`002@00o`000`0000000?l0003o0009003o000300000000o`000?l000T00?l000<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03
00000000o`000?l000T00?l000<00000003o0000o`002@00o`000`0000000?l0003o0009003o0003
0000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l03@00002A0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00
o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`00
0?l000T00?l000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05<0oooo00<00000003o0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo
09X0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`0300000000o`000?l000T0
0?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o0000o`002@00o`000`0000000?l0
003o0009003o00030000003oool0oooo09/0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0DP3oool00`0000000?l0003o0009003o000300000000o`000?l000T00?l000<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B
0?ooo`0300000000o`000?l000T00?l000<00000003o0000o`002@00o`000`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<00000003o
0000o`002@00o`000`0000000?l0003o0009003o00030000003oool0oooo09/0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`0000000?l0003o0009003o0003
00000000o`000?l000T00?l000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1B0?ooo`d000002`00o`000`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<00000003o0000o`002@00
o`000`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000G`3oool0
0`0000000?l0003o0009003o00030000003oool0oooo09X0oooo0P0000030?ooo`004@3oool00`00
0000oooo0?ooo`1N0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0V`3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`0300000000o`000?l000T0
0?l000<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1N0?ooo`0300000000o`000?l000T00?l000<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`0300000000o`000?l000T00?l000<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N
0?ooo`d00000W@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`010?ooo`004@3ooooo000000d000000`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {326.063, 184.75}} -> {0.0756102, \
127.592, 0.00165494, 0.59428}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(xplotallb3t\  = 
        Histogram[allbeat3durt, \ 
          Frame \[Rule] True, \ \ HistogramRange \[Rule] {0.16, \ 0.58}, 
          BarStyle \[Rule] {RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00676556 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15003 -12 -4.5 ]
[-0.0125 .15003 0 4.5 ]
[-0.0125 .28534 -12 -4.5 ]
[-0.0125 .28534 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .55596 -12 -4.5 ]
[-0.0125 .55596 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15003 m
.00625 .15003 L
s
[(20)] -0.0125 .15003 1 0 Mshowa
0 .28534 m
.00625 .28534 L
s
[(40)] -0.0125 .28534 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(60)] -0.0125 .42065 1 0 Mshowa
0 .55596 m
.00625 .55596 L
s
[(80)] -0.0125 .55596 1 0 Mshowa
.125 Mabswid
0 .04854 m
.00375 .04854 L
s
0 .08237 m
.00375 .08237 L
s
0 .1162 m
.00375 .1162 L
s
0 .18385 m
.00375 .18385 L
s
0 .21768 m
.00375 .21768 L
s
0 .25151 m
.00375 .25151 L
s
0 .31917 m
.00375 .31917 L
s
0 .35299 m
.00375 .35299 L
s
0 .38682 m
.00375 .38682 L
s
0 .45448 m
.00375 .45448 L
s
0 .4883 m
.00375 .4883 L
s
0 .52213 m
.00375 .52213 L
s
0 .58979 m
.00375 .58979 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15003 m
1 .15003 L
s
.99375 .28534 m
1 .28534 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .55596 m
1 .55596 L
s
.125 Mabswid
.99625 .04854 m
1 .04854 L
s
.99625 .08237 m
1 .08237 L
s
.99625 .1162 m
1 .1162 L
s
.99625 .18385 m
1 .18385 L
s
.99625 .21768 m
1 .21768 L
s
.99625 .25151 m
1 .25151 L
s
.99625 .31917 m
1 .31917 L
s
.99625 .35299 m
1 .35299 L
s
.99625 .38682 m
1 .38682 L
s
.99625 .45448 m
1 .45448 L
s
.99625 .4883 m
1 .4883 L
s
.99625 .52213 m
1 .52213 L
s
.99625 .58979 m
1 .58979 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
0 0 1 r
.04545 .01472 m
.04545 .02148 L
.09091 .02148 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02148 L
.09091 .02148 L
.09091 .01472 L
.04545 .01472 L
s
0 0 1 r
.09091 .01472 m
.09091 .02148 L
.13636 .02148 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02148 L
.13636 .02148 L
.13636 .01472 L
.09091 .01472 L
s
0 0 1 r
.13636 .01472 m
.13636 .04178 L
.18182 .04178 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .04178 L
.18182 .04178 L
.18182 .01472 L
.13636 .01472 L
s
0 0 1 r
.18182 .01472 m
.18182 .12973 L
.22727 .12973 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .12973 L
.22727 .12973 L
.22727 .01472 L
.18182 .01472 L
s
0 0 1 r
.22727 .01472 m
.22727 .08237 L
.27273 .08237 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .08237 L
.27273 .08237 L
.27273 .01472 L
.22727 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .21092 L
.31818 .21092 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .21092 L
.31818 .21092 L
.31818 .01472 L
.27273 .01472 L
s
0 0 1 r
.31818 .01472 m
.31818 .44095 L
.36364 .44095 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .44095 L
.36364 .44095 L
.36364 .01472 L
.31818 .01472 L
s
0 0 1 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 0 1 r
.40909 .01472 m
.40909 .53566 L
.45455 .53566 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .53566 L
.45455 .53566 L
.45455 .01472 L
.40909 .01472 L
s
0 0 1 r
.45455 .01472 m
.45455 .40035 L
.5 .40035 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .40035 L
.5 .40035 L
.5 .01472 L
.45455 .01472 L
s
0 0 1 r
.5 .01472 m
.5 .25151 L
.54545 .25151 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .25151 L
.54545 .25151 L
.54545 .01472 L
.5 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .10943 L
.59091 .10943 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .10943 L
.59091 .10943 L
.59091 .01472 L
.54545 .01472 L
s
0 0 1 r
.59091 .01472 m
.59091 .0959 L
.63636 .0959 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0959 L
.63636 .0959 L
.63636 .01472 L
.59091 .01472 L
s
0 0 1 r
.63636 .01472 m
.63636 .06884 L
.68182 .06884 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .06884 L
.68182 .06884 L
.68182 .01472 L
.63636 .01472 L
s
0 0 1 r
.68182 .01472 m
.68182 .04854 L
.72727 .04854 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04854 L
.72727 .04854 L
.72727 .01472 L
.68182 .01472 L
s
0 0 1 r
.72727 .01472 m
.72727 .02825 L
.77273 .02825 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .02825 L
.77273 .02825 L
.77273 .01472 L
.72727 .01472 L
s
0 0 1 r
.77273 .01472 m
.77273 .02148 L
.81818 .02148 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02148 L
.81818 .02148 L
.81818 .01472 L
.77273 .01472 L
s
0 0 1 r
.81818 .01472 m
.81818 .02148 L
.86364 .02148 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02148 L
.86364 .02148 L
.86364 .01472 L
.81818 .01472 L
s
0 0 1 r
.86364 .01472 m
.86364 .02148 L
.90909 .02148 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .02148 L
.90909 .02148 L
.90909 .01472 L
.86364 .01472 L
s
0 0 1 r
.90909 .01472 m
.90909 .02825 L
.95455 .02825 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02825 L
.95455 .02825 L
.95455 .01472 L
.90909 .01472 L
s
0 0 1 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000030?ooo`@00000;@3oool2000000@0oooo0P0000040?oo
o`800000;`3oool2000000@0oooo0P0000050?ooo`<00000;03oool2000000@0oooo0P0000040?oo
o`800000>P3oool00280oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000i0?ooo`008P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000000P0oooo1@00000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
=`3oool00280oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000002`0oooo00@000000?ooo`3oool000002@3oool2000003X0oooo000R
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000;03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000/0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3o
ool002<0oooo0P00000:0?ooo`800000;P3oool2000000X0oooo0P00000_0?ooo`8000002`3oool2
000002d0oooo0P00000:0?ooo`<00000>@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000A0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool000X0oooo0P0000050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`010?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`010?ooo`002@3oool010000000oooo0?ooo`0000040?ooool000003@0000030?ooo`002@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@3oool000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0:0?oooaT00000
2`000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000obH000002`000?l00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0040oooo000:0?ooo`8000001@3oool00`000000oooo0?ooo`0R0?ooo`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o3@00000T0?ooo`d000002`3oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`0R0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0R0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`d000002`000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool00@3oool00140oooo0P00000_0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l=000004L0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`0^0?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo0580oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo02h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l=000005@0oooo00<000000?ooo`3oool00@3oool0
0140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo
05h0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0;P3oool00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`030000003oool0oooo05h0oooo00<000000?ooo`3oool00@3oool00140oooo
00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo05h0oooo
00<000000?ooo`3oool00@3oool00140oooo0P00000_0?ooo`03000000000?l0003o00T0003o3@00
000;0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0G@3oool2000000<0oooo000A
0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`09
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000000
o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o3@00001P0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000
003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`090?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool02@3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0;P3oool00`000000003o0000o`090000o`030000003oool0
oooo00T0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo0040oooo000A0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`00
0000oooo0?ooo`090?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`d00000K03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`0^0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool02@3oool00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000;`3oool00`000000003o
0000o`090000o`030000003oool0oooo00T0oooo00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0M@3oool2000000<0oooo
000A0?ooo`030000003oool0oooo02h0oooo00<000000000o`000?l02@000?l00`000000oooo0?oo
o`090?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0;P3oool00`000000003o0000o`090000o`030000003oool0oooo00T0oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`0^0?oo
o`d000002`3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0040oooo00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0AP3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`160?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0
oooo07H0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`<00000AP3oool00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1d0?ooo`<000000`3oool0
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0AP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo00030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`160?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000
o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`160?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`030000
003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3o
ool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
04L0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0M@3oool2000000<0oooo000A0?ooo`030000003oool0oooo04H0
oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o
0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo04H0oooo00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`160?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0AP3oool00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo04H0oooo3@00000;0000o`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000
00000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@00
0?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000D`3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l0
0`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0M@3oool2
000000<0oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`00
0000003o0000o`090000o`030000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000000o`000?l02@000?l00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02P000?l00`000000003o0000o`090000o`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000000
o`000?l02@000?l00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000003o0000o`090000o`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`010?ooo`004@3oool2000005<0oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P00
0?l=000007L0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`00
0000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`00
0000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0
003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo
0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`01
0?ooo`001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo0580oooo00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00060?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1B0?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`000`3oool5000000050?ooo`000000oooo0?ooo`000000103oool300000580oooo00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`200?ooo`<000000`3oool000<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo00040?oo
o`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1B
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`01
0?ooo`001@3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo0580oooo00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l0
2@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo
0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000D`3oool00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo0840
oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?oo
o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000
00000?l0003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`03000000000?l0003o00X0003o00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05<0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`210?ooo`8000000`3oool00140
oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo0880
oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o
0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o
0000o`0:0000o`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:
0000o`030000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?oo
o`3oool0DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`0:0000o`030000003oool0oooo0880oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`03
0000003oool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0
DP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000003o0000o`0:0000o`030000003oool0oooo0880oooo00<000000?ooo`3oool0
0@3oool00140oooo00<000000?ooo`3oool0DP3oool00`000000003o0000o`090000o`0300000000
0?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`0:0000o`030000003o
ool0oooo0880oooo00<000000?ooo`3oool00@3oool00140oooo0P00001C0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0
003o00X0003o00<000000?ooo`3oool0P@3oool2000000<0oooo000A0?ooo`030000003oool0oooo
0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0040oooo000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000
003o0000o`090000o`03000000000?l0003o00T0003o00<000000000o`000?l02P000?l00`000000
oooo0?ooo`220?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo0580oooo
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o
00<000000000o`000?l02P000?l00`000000oooo0?ooo`220?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000
o`090000o`03000000000?l0003o00T0003o3P0000240?ooo`030000003oool0oooo0040oooo000A
0?ooo`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1B0?ooo`03
000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`090000o`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo0`00001B0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08d0oooo0`000003
0?ooo`000`3oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1B
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000003o0000o`09
0000o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool000@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo00<00000
0000o`000?l02@000?l00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00103oool3000000<0oooo0P0000050?oo
o`030000003oool0oooo0580oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`03000000000?l0003o00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?oo
o`004@3oool00`000000oooo0?ooo`1B0?ooo`03000000000?l0003o00T0003o00<000000000o`00
0?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool00@3oool00140oooo00<000000?ooo`3oool0DP3oool=000000/0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool0
0`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o
00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0040oooo000A0?ooo`800000G`3oool00`000000003o0000o`090000o`03000000000?l0003o00T0
003o00<000000?ooo`3oool0SP3oool2000000<0oooo000A0?ooo`030000003oool0oooo05h0oooo
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000
o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<00000
0000o`000?l02@000?l00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?oo
o`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3o
ool0GP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000
00000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@00
0?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3o
ool00140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000o`090000o`03000000000?l0
003o00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool20000
05l0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo
08h0oooo0P0000030?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0
003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040
oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000003o
0000o`090000o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo00<0
00000?ooo`3oool0GP3oool00`000000003o0000o`090000o`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N
0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000
o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000o`090000o`03
000000000?l0003o00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`00
4@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool00@3oool00140oooo0P00001O0?ooo`03000000000?l0
003o00T0003o00<000000000o`000?l02@000?l00`000000oooo0?ooo`2>0?ooo`8000000`3oool0
0140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000o`090000o`03000000000?l0003o
00T0003o00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000000o`000?l02@000?l00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo
00<000000000o`000?l02@000?l00`000000003o0000o`090000o`030000003oool0oooo08l0oooo
00<000000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0GP3oool00`000000003o0000
o`090000o`d00000T@3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N
0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`010?ooo`000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo0`00001N0?ooo`03000000000?l0003o00T0003o00<00000
0?ooo`3oool0V@3oool3000000<0oooo00040?ooo`8000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0040oooo00030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`00103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000
o`000?l02@000?l00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`03
0000003oool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l0
2@000?l00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003o
ool0oooo05h0oooo00<000000000o`000?l02@000?l00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0040oooo000A0?ooo`030000003oool0oooo05h0oooo00<000000000o`000?l02@000?l0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000G`3oool00`00
0000003o0000o`090000o`030000003oool0oooo09X0oooo0P0000030?ooo`004@3oool00`000000
oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`03000000000?l0003o00T0003o
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000oooo0?oo
o`1N0?ooo`03000000000?l0003o00T0003o00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`010?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`d00000W@3oool00`000000oooo0?ooo`01
0?ooo`004@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool00@3oool00140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`004@3ooooo000000d00000
0`3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 255.75}, {497.125, 355.813}} -> {0.0756102, \
238.236, 0.00165494, 0.555939}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xplotalltap, \ xplotallb1t, \ xplotallb2t, \ 
            xplotallb3t}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .14373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00342212 0.238095 [
[ 0 0 0 0 ]
[ 1 .14373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .14373 L
0 .14373 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00342212 0.245293 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.372093 2.32558 0.0147151 0.0041451 [
[.09302 -0.0125 -9 -9 ]
[.09302 -0.0125 9 0 ]
[.32558 -0.0125 -9 -9 ]
[.32558 -0.0125 9 0 ]
[.55814 -0.0125 -9 -9 ]
[.55814 -0.0125 9 0 ]
[.7907 -0.0125 -9 -9 ]
[.7907 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09762 -12 -4.5 ]
[-0.0125 .09762 0 4.5 ]
[-0.0125 .18052 -12 -4.5 ]
[-0.0125 .18052 0 4.5 ]
[-0.0125 .26342 -12 -4.5 ]
[-0.0125 .26342 0 4.5 ]
[-0.0125 .34632 -12 -4.5 ]
[-0.0125 .34632 0 4.5 ]
[-0.0125 .42922 -18 -4.5 ]
[-0.0125 .42922 0 4.5 ]
[-0.0125 .51213 -18 -4.5 ]
[-0.0125 .51213 0 4.5 ]
[-0.0125 .59503 -18 -4.5 ]
[-0.0125 .59503 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09302 0 m
.09302 .00625 L
s
[(0.2)] .09302 -0.0125 0 1 Mshowa
.32558 0 m
.32558 .00625 L
s
[(0.3)] .32558 -0.0125 0 1 Mshowa
.55814 0 m
.55814 .00625 L
s
[(0.4)] .55814 -0.0125 0 1 Mshowa
.7907 0 m
.7907 .00625 L
s
[(0.5)] .7907 -0.0125 0 1 Mshowa
.125 Mabswid
.13953 0 m
.13953 .00375 L
s
.18605 0 m
.18605 .00375 L
s
.23256 0 m
.23256 .00375 L
s
.27907 0 m
.27907 .00375 L
s
.37209 0 m
.37209 .00375 L
s
.4186 0 m
.4186 .00375 L
s
.46512 0 m
.46512 .00375 L
s
.51163 0 m
.51163 .00375 L
s
.60465 0 m
.60465 .00375 L
s
.65116 0 m
.65116 .00375 L
s
.69767 0 m
.69767 .00375 L
s
.74419 0 m
.74419 .00375 L
s
.04651 0 m
.04651 .00375 L
s
.83721 0 m
.83721 .00375 L
s
.88372 0 m
.88372 .00375 L
s
.93023 0 m
.93023 .00375 L
s
.97674 0 m
.97674 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09762 m
.00625 .09762 L
s
[(20)] -0.0125 .09762 1 0 Mshowa
0 .18052 m
.00625 .18052 L
s
[(40)] -0.0125 .18052 1 0 Mshowa
0 .26342 m
.00625 .26342 L
s
[(60)] -0.0125 .26342 1 0 Mshowa
0 .34632 m
.00625 .34632 L
s
[(80)] -0.0125 .34632 1 0 Mshowa
0 .42922 m
.00625 .42922 L
s
[(100)] -0.0125 .42922 1 0 Mshowa
0 .51213 m
.00625 .51213 L
s
[(120)] -0.0125 .51213 1 0 Mshowa
0 .59503 m
.00625 .59503 L
s
[(140)] -0.0125 .59503 1 0 Mshowa
.125 Mabswid
0 .03544 m
.00375 .03544 L
s
0 .05617 m
.00375 .05617 L
s
0 .07689 m
.00375 .07689 L
s
0 .11834 m
.00375 .11834 L
s
0 .13907 m
.00375 .13907 L
s
0 .15979 m
.00375 .15979 L
s
0 .20124 m
.00375 .20124 L
s
0 .22197 m
.00375 .22197 L
s
0 .2427 m
.00375 .2427 L
s
0 .28415 m
.00375 .28415 L
s
0 .30487 m
.00375 .30487 L
s
0 .3256 m
.00375 .3256 L
s
0 .36705 m
.00375 .36705 L
s
0 .38777 m
.00375 .38777 L
s
0 .4085 m
.00375 .4085 L
s
0 .44995 m
.00375 .44995 L
s
0 .47068 m
.00375 .47068 L
s
0 .4914 m
.00375 .4914 L
s
0 .53285 m
.00375 .53285 L
s
0 .55358 m
.00375 .55358 L
s
0 .5743 m
.00375 .5743 L
s
0 .61575 m
.00375 .61575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09302 .61178 m
.09302 .61803 L
s
.32558 .61178 m
.32558 .61803 L
s
.55814 .61178 m
.55814 .61803 L
s
.7907 .61178 m
.7907 .61803 L
s
.125 Mabswid
.13953 .61428 m
.13953 .61803 L
s
.18605 .61428 m
.18605 .61803 L
s
.23256 .61428 m
.23256 .61803 L
s
.27907 .61428 m
.27907 .61803 L
s
.37209 .61428 m
.37209 .61803 L
s
.4186 .61428 m
.4186 .61803 L
s
.46512 .61428 m
.46512 .61803 L
s
.51163 .61428 m
.51163 .61803 L
s
.60465 .61428 m
.60465 .61803 L
s
.65116 .61428 m
.65116 .61803 L
s
.69767 .61428 m
.69767 .61803 L
s
.74419 .61428 m
.74419 .61803 L
s
.04651 .61428 m
.04651 .61803 L
s
.83721 .61428 m
.83721 .61803 L
s
.88372 .61428 m
.88372 .61803 L
s
.93023 .61428 m
.93023 .61803 L
s
.97674 .61428 m
.97674 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09762 m
1 .09762 L
s
.99375 .18052 m
1 .18052 L
s
.99375 .26342 m
1 .26342 L
s
.99375 .34632 m
1 .34632 L
s
.99375 .42922 m
1 .42922 L
s
.99375 .51213 m
1 .51213 L
s
.99375 .59503 m
1 .59503 L
s
.125 Mabswid
.99625 .03544 m
1 .03544 L
s
.99625 .05617 m
1 .05617 L
s
.99625 .07689 m
1 .07689 L
s
.99625 .11834 m
1 .11834 L
s
.99625 .13907 m
1 .13907 L
s
.99625 .15979 m
1 .15979 L
s
.99625 .20124 m
1 .20124 L
s
.99625 .22197 m
1 .22197 L
s
.99625 .2427 m
1 .2427 L
s
.99625 .28415 m
1 .28415 L
s
.99625 .30487 m
1 .30487 L
s
.99625 .3256 m
1 .3256 L
s
.99625 .36705 m
1 .36705 L
s
.99625 .38777 m
1 .38777 L
s
.99625 .4085 m
1 .4085 L
s
.99625 .44995 m
1 .44995 L
s
.99625 .47068 m
1 .47068 L
s
.99625 .4914 m
1 .4914 L
s
.99625 .53285 m
1 .53285 L
s
.99625 .55358 m
1 .55358 L
s
.99625 .5743 m
1 .5743 L
s
.99625 .61575 m
1 .61575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 .5 .5 r
0 .01472 m
0 .02301 L
.02326 .02301 L
.02326 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02301 L
.02326 .02301 L
.02326 .01472 L
0 .01472 L
s
.5 .5 .5 r
.02326 .01472 m
.02326 .01886 L
.04651 .01886 L
.04651 .01472 L
F
0 g
.02326 .01472 m
.02326 .01886 L
.04651 .01886 L
.04651 .01472 L
.02326 .01472 L
s
.5 .5 .5 r
.04651 .01472 m
.04651 .02301 L
.06977 .02301 L
.06977 .01472 L
F
0 g
.04651 .01472 m
.04651 .02301 L
.06977 .02301 L
.06977 .01472 L
.04651 .01472 L
s
.5 .5 .5 r
.06977 .01472 m
.06977 .02715 L
.09302 .02715 L
.09302 .01472 L
F
0 g
.06977 .01472 m
.06977 .02715 L
.09302 .02715 L
.09302 .01472 L
.06977 .01472 L
s
.5 .5 .5 r
.09302 .01472 m
.09302 .03959 L
.11628 .03959 L
.11628 .01472 L
F
0 g
.09302 .01472 m
.09302 .03959 L
.11628 .03959 L
.11628 .01472 L
.09302 .01472 L
s
.5 .5 .5 r
.11628 .01472 m
.11628 .01886 L
.13953 .01886 L
.13953 .01472 L
F
0 g
.11628 .01472 m
.11628 .01886 L
.13953 .01886 L
.13953 .01472 L
.11628 .01472 L
s
.5 .5 .5 r
.13953 .01472 m
.13953 .03959 L
.16279 .03959 L
.16279 .01472 L
F
0 g
.13953 .01472 m
.13953 .03959 L
.16279 .03959 L
.16279 .01472 L
.13953 .01472 L
s
.5 .5 .5 r
.16279 .01472 m
.16279 .07275 L
.18605 .07275 L
.18605 .01472 L
F
0 g
.16279 .01472 m
.16279 .07275 L
.18605 .07275 L
.18605 .01472 L
.16279 .01472 L
s
.5 .5 .5 r
.18605 .01472 m
.18605 .08104 L
.2093 .08104 L
.2093 .01472 L
F
0 g
.18605 .01472 m
.18605 .08104 L
.2093 .08104 L
.2093 .01472 L
.18605 .01472 L
s
.5 .5 .5 r
.2093 .01472 m
.2093 .09762 L
.23256 .09762 L
.23256 .01472 L
F
0 g
.2093 .01472 m
.2093 .09762 L
.23256 .09762 L
.23256 .01472 L
.2093 .01472 L
s
.5 .5 .5 r
.23256 .01472 m
.23256 .13907 L
.25581 .13907 L
.25581 .01472 L
F
0 g
.23256 .01472 m
.23256 .13907 L
.25581 .13907 L
.25581 .01472 L
.23256 .01472 L
s
.5 .5 .5 r
.25581 .01472 m
.25581 .17223 L
.27907 .17223 L
.27907 .01472 L
F
0 g
.25581 .01472 m
.25581 .17223 L
.27907 .17223 L
.27907 .01472 L
.25581 .01472 L
s
.5 .5 .5 r
.27907 .01472 m
.27907 .25099 L
.30233 .25099 L
.30233 .01472 L
F
0 g
.27907 .01472 m
.27907 .25099 L
.30233 .25099 L
.30233 .01472 L
.27907 .01472 L
s
.5 .5 .5 r
.30233 .01472 m
.30233 .31316 L
.32558 .31316 L
.32558 .01472 L
F
0 g
.30233 .01472 m
.30233 .31316 L
.32558 .31316 L
.32558 .01472 L
.30233 .01472 L
s
.5 .5 .5 r
.32558 .01472 m
.32558 .38777 L
.34884 .38777 L
.34884 .01472 L
F
0 g
.32558 .01472 m
.32558 .38777 L
.34884 .38777 L
.34884 .01472 L
.32558 .01472 L
s
.5 .5 .5 r
.34884 .01472 m
.34884 .54114 L
.37209 .54114 L
.37209 .01472 L
F
0 g
.34884 .01472 m
.34884 .54114 L
.37209 .54114 L
.37209 .01472 L
.34884 .01472 L
s
.5 .5 .5 r
.37209 .01472 m
.37209 .52871 L
.39535 .52871 L
.39535 .01472 L
F
0 g
.37209 .01472 m
.37209 .52871 L
.39535 .52871 L
.39535 .01472 L
.37209 .01472 L
s
.5 .5 .5 r
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
F
0 g
.39535 .01472 m
.39535 .60332 L
.4186 .60332 L
.4186 .01472 L
.39535 .01472 L
s
.5 .5 .5 r
.4186 .01472 m
.4186 .52456 L
.44186 .52456 L
.44186 .01472 L
F
0 g
.4186 .01472 m
.4186 .52456 L
.44186 .52456 L
.44186 .01472 L
.4186 .01472 L
s
.5 .5 .5 r
.44186 .01472 m
.44186 .42922 L
.46512 .42922 L
.46512 .01472 L
F
0 g
.44186 .01472 m
.44186 .42922 L
.46512 .42922 L
.46512 .01472 L
.44186 .01472 L
s
.5 .5 .5 r
.46512 .01472 m
.46512 .35876 L
.48837 .35876 L
.48837 .01472 L
F
0 g
.46512 .01472 m
.46512 .35876 L
.48837 .35876 L
.48837 .01472 L
.46512 .01472 L
s
.5 .5 .5 r
.48837 .01472 m
.48837 .2427 L
.51163 .2427 L
.51163 .01472 L
F
0 g
.48837 .01472 m
.48837 .2427 L
.51163 .2427 L
.51163 .01472 L
.48837 .01472 L
s
.5 .5 .5 r
.51163 .01472 m
.51163 .15979 L
.53488 .15979 L
.53488 .01472 L
F
0 g
.51163 .01472 m
.51163 .15979 L
.53488 .15979 L
.53488 .01472 L
.51163 .01472 L
s
.5 .5 .5 r
.53488 .01472 m
.53488 .18881 L
.55814 .18881 L
.55814 .01472 L
F
0 g
.53488 .01472 m
.53488 .18881 L
.55814 .18881 L
.55814 .01472 L
.53488 .01472 L
s
.5 .5 .5 r
.55814 .01472 m
.55814 .12249 L
.5814 .12249 L
.5814 .01472 L
F
0 g
.55814 .01472 m
.55814 .12249 L
.5814 .12249 L
.5814 .01472 L
.55814 .01472 L
s
.5 .5 .5 r
.5814 .01472 m
.5814 .06446 L
.60465 .06446 L
.60465 .01472 L
F
0 g
.5814 .01472 m
.5814 .06446 L
.60465 .06446 L
.60465 .01472 L
.5814 .01472 L
s
.5 .5 .5 r
.60465 .01472 m
.60465 .06446 L
.62791 .06446 L
.62791 .01472 L
F
0 g
.60465 .01472 m
.60465 .06446 L
.62791 .06446 L
.62791 .01472 L
.60465 .01472 L
s
.5 .5 .5 r
.62791 .01472 m
.62791 .06446 L
.65116 .06446 L
.65116 .01472 L
F
0 g
.62791 .01472 m
.62791 .06446 L
.65116 .06446 L
.65116 .01472 L
.62791 .01472 L
s
.5 .5 .5 r
.65116 .01472 m
.65116 .06446 L
.67442 .06446 L
.67442 .01472 L
F
0 g
.65116 .01472 m
.65116 .06446 L
.67442 .06446 L
.67442 .01472 L
.65116 .01472 L
s
.5 .5 .5 r
.67442 .01472 m
.67442 .03959 L
.69767 .03959 L
.69767 .01472 L
F
0 g
.67442 .01472 m
.67442 .03959 L
.69767 .03959 L
.69767 .01472 L
.67442 .01472 L
s
.5 .5 .5 r
.69767 .01472 m
.69767 .02715 L
.72093 .02715 L
.72093 .01472 L
F
0 g
.69767 .01472 m
.69767 .02715 L
.72093 .02715 L
.72093 .01472 L
.69767 .01472 L
s
.5 .5 .5 r
.72093 .01472 m
.72093 .02715 L
.74419 .02715 L
.74419 .01472 L
F
0 g
.72093 .01472 m
.72093 .02715 L
.74419 .02715 L
.74419 .01472 L
.72093 .01472 L
s
.5 .5 .5 r
.74419 .01472 m
.74419 .01886 L
.76744 .01886 L
.76744 .01472 L
F
0 g
.74419 .01472 m
.74419 .01886 L
.76744 .01886 L
.76744 .01472 L
.74419 .01472 L
s
.5 .5 .5 r
.76744 .01472 m
.76744 .01886 L
.7907 .01886 L
.7907 .01472 L
F
0 g
.76744 .01472 m
.76744 .01886 L
.7907 .01886 L
.7907 .01472 L
.76744 .01472 L
s
.5 .5 .5 r
.7907 .01472 m
.7907 .01886 L
.81395 .01886 L
.81395 .01472 L
F
0 g
.7907 .01472 m
.7907 .01886 L
.81395 .01886 L
.81395 .01472 L
.7907 .01472 L
s
.5 .5 .5 r
.81395 .01472 m
.81395 .01886 L
.83721 .01886 L
.83721 .01472 L
F
0 g
.81395 .01472 m
.81395 .01886 L
.83721 .01886 L
.83721 .01472 L
.81395 .01472 L
s
.5 .5 .5 r
.83721 .01472 m
.83721 .01886 L
.86047 .01886 L
.86047 .01472 L
F
0 g
.83721 .01472 m
.83721 .01886 L
.86047 .01886 L
.86047 .01472 L
.83721 .01472 L
s
.5 .5 .5 r
.86047 .01472 m
.86047 .01472 L
.88372 .01472 L
.88372 .01472 L
F
0 g
.86047 .01472 m
.86047 .01472 L
.88372 .01472 L
.88372 .01472 L
.86047 .01472 L
s
.5 .5 .5 r
.88372 .01472 m
.88372 .01886 L
.90698 .01886 L
.90698 .01472 L
F
0 g
.88372 .01472 m
.88372 .01886 L
.90698 .01886 L
.90698 .01472 L
.88372 .01472 L
s
.5 .5 .5 r
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
F
0 g
.90698 .01472 m
.90698 .01472 L
.93023 .01472 L
.93023 .01472 L
.90698 .01472 L
s
.5 .5 .5 r
.93023 .01472 m
.93023 .02301 L
.95349 .02301 L
.95349 .01472 L
F
0 g
.93023 .01472 m
.93023 .02301 L
.95349 .02301 L
.95349 .01472 L
.93023 .01472 L
s
.5 .5 .5 r
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
F
0 g
.95349 .01472 m
.95349 .01472 L
.97674 .01472 L
.97674 .01472 L
.95349 .01472 L
s
.5 .5 .5 r
.97674 .01472 m
.97674 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.97674 .01472 m
.97674 .01472 L
1 .01472 L
1 .01472 L
.97674 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00342212 0.488926 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00692475 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15321 -12 -4.5 ]
[-0.0125 .15321 0 4.5 ]
[-0.0125 .29171 -12 -4.5 ]
[-0.0125 .29171 0 4.5 ]
[-0.0125 .4302 -12 -4.5 ]
[-0.0125 .4302 0 4.5 ]
[-0.0125 .5687 -12 -4.5 ]
[-0.0125 .5687 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15321 m
.00625 .15321 L
s
[(20)] -0.0125 .15321 1 0 Mshowa
0 .29171 m
.00625 .29171 L
s
[(40)] -0.0125 .29171 1 0 Mshowa
0 .4302 m
.00625 .4302 L
s
[(60)] -0.0125 .4302 1 0 Mshowa
0 .5687 m
.00625 .5687 L
s
[(80)] -0.0125 .5687 1 0 Mshowa
.125 Mabswid
0 .04934 m
.00375 .04934 L
s
0 .08396 m
.00375 .08396 L
s
0 .11859 m
.00375 .11859 L
s
0 .18783 m
.00375 .18783 L
s
0 .22246 m
.00375 .22246 L
s
0 .25708 m
.00375 .25708 L
s
0 .32633 m
.00375 .32633 L
s
0 .36095 m
.00375 .36095 L
s
0 .39558 m
.00375 .39558 L
s
0 .46482 m
.00375 .46482 L
s
0 .49945 m
.00375 .49945 L
s
0 .53407 m
.00375 .53407 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15321 m
1 .15321 L
s
.99375 .29171 m
1 .29171 L
s
.99375 .4302 m
1 .4302 L
s
.99375 .5687 m
1 .5687 L
s
.125 Mabswid
.99625 .04934 m
1 .04934 L
s
.99625 .08396 m
1 .08396 L
s
.99625 .11859 m
1 .11859 L
s
.99625 .18783 m
1 .18783 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .25708 m
1 .25708 L
s
.99625 .32633 m
1 .32633 L
s
.99625 .36095 m
1 .36095 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .46482 m
1 .46482 L
s
.99625 .49945 m
1 .49945 L
s
.99625 .53407 m
1 .53407 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02856 L
.04545 .02856 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02856 L
.04545 .02856 L
.04545 .01472 L
0 .01472 L
s
1 0 0 r
.04545 .01472 m
.04545 .04241 L
.09091 .04241 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .04241 L
.09091 .04241 L
.09091 .01472 L
.04545 .01472 L
s
1 0 0 r
.09091 .01472 m
.09091 .04934 L
.13636 .04934 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .04934 L
.13636 .04934 L
.13636 .01472 L
.09091 .01472 L
s
1 0 0 r
.13636 .01472 m
.13636 .09781 L
.18182 .09781 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .09781 L
.18182 .09781 L
.18182 .01472 L
.13636 .01472 L
s
1 0 0 r
.18182 .01472 m
.18182 .09781 L
.22727 .09781 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .09781 L
.22727 .09781 L
.22727 .01472 L
.18182 .01472 L
s
1 0 0 r
.22727 .01472 m
.22727 .18091 L
.27273 .18091 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .18091 L
.27273 .18091 L
.27273 .01472 L
.22727 .01472 L
s
1 0 0 r
.27273 .01472 m
.27273 .33325 L
.31818 .33325 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .33325 L
.31818 .33325 L
.31818 .01472 L
.27273 .01472 L
s
1 0 0 r
.31818 .01472 m
.31818 .47175 L
.36364 .47175 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .47175 L
.36364 .47175 L
.36364 .01472 L
.31818 .01472 L
s
1 0 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
1 0 0 r
.40909 .01472 m
.40909 .4579 L
.45455 .4579 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .4579 L
.45455 .4579 L
.45455 .01472 L
.40909 .01472 L
s
1 0 0 r
.45455 .01472 m
.45455 .3471 L
.5 .3471 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .3471 L
.5 .3471 L
.5 .01472 L
.45455 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .18091 L
.54545 .18091 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .18091 L
.54545 .18091 L
.54545 .01472 L
.5 .01472 L
s
1 0 0 r
.54545 .01472 m
.54545 .12551 L
.59091 .12551 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .12551 L
.59091 .12551 L
.59091 .01472 L
.54545 .01472 L
s
1 0 0 r
.59091 .01472 m
.59091 .07704 L
.63636 .07704 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .07704 L
.63636 .07704 L
.63636 .01472 L
.59091 .01472 L
s
1 0 0 r
.63636 .01472 m
.63636 .07704 L
.68182 .07704 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .07704 L
.68182 .07704 L
.68182 .01472 L
.63636 .01472 L
s
1 0 0 r
.68182 .01472 m
.68182 .02164 L
.72727 .02164 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .02164 L
.72727 .02164 L
.72727 .01472 L
.68182 .01472 L
s
1 0 0 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
1 0 0 r
.77273 .01472 m
.77273 .02164 L
.81818 .02164 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02164 L
.81818 .02164 L
.81818 .01472 L
.77273 .01472 L
s
1 0 0 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
1 0 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
1 0 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
1 0 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00342212 0.732558 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00632907 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1413 -12 -4.5 ]
[-0.0125 .1413 0 4.5 ]
[-0.0125 .26788 -12 -4.5 ]
[-0.0125 .26788 0 4.5 ]
[-0.0125 .39446 -12 -4.5 ]
[-0.0125 .39446 0 4.5 ]
[-0.0125 .52104 -12 -4.5 ]
[-0.0125 .52104 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1413 m
.00625 .1413 L
s
[(20)] -0.0125 .1413 1 0 Mshowa
0 .26788 m
.00625 .26788 L
s
[(40)] -0.0125 .26788 1 0 Mshowa
0 .39446 m
.00625 .39446 L
s
[(60)] -0.0125 .39446 1 0 Mshowa
0 .52104 m
.00625 .52104 L
s
[(80)] -0.0125 .52104 1 0 Mshowa
.125 Mabswid
0 .04636 m
.00375 .04636 L
s
0 .07801 m
.00375 .07801 L
s
0 .10965 m
.00375 .10965 L
s
0 .17294 m
.00375 .17294 L
s
0 .20459 m
.00375 .20459 L
s
0 .23623 m
.00375 .23623 L
s
0 .29952 m
.00375 .29952 L
s
0 .33117 m
.00375 .33117 L
s
0 .36281 m
.00375 .36281 L
s
0 .4261 m
.00375 .4261 L
s
0 .45775 m
.00375 .45775 L
s
0 .4894 m
.00375 .4894 L
s
0 .55269 m
.00375 .55269 L
s
0 .58433 m
.00375 .58433 L
s
0 .61598 m
.00375 .61598 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1413 m
1 .1413 L
s
.99375 .26788 m
1 .26788 L
s
.99375 .39446 m
1 .39446 L
s
.99375 .52104 m
1 .52104 L
s
.125 Mabswid
.99625 .04636 m
1 .04636 L
s
.99625 .07801 m
1 .07801 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .17294 m
1 .17294 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .23623 m
1 .23623 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .33117 m
1 .33117 L
s
.99625 .36281 m
1 .36281 L
s
.99625 .4261 m
1 .4261 L
s
.99625 .45775 m
1 .45775 L
s
.99625 .4894 m
1 .4894 L
s
.99625 .55269 m
1 .55269 L
s
.99625 .58433 m
1 .58433 L
s
.99625 .61598 m
1 .61598 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
0 .01472 m
0 .02104 L
.04545 .02104 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02104 L
.04545 .02104 L
.04545 .01472 L
0 .01472 L
s
0 1 0 r
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .01472 L
.09091 .01472 L
.09091 .01472 L
.04545 .01472 L
s
0 1 0 r
.09091 .01472 m
.09091 .02104 L
.13636 .02104 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02104 L
.13636 .02104 L
.13636 .01472 L
.09091 .01472 L
s
0 1 0 r
.13636 .01472 m
.13636 .04003 L
.18182 .04003 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .04003 L
.18182 .04003 L
.18182 .01472 L
.13636 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .05902 L
.22727 .05902 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .05902 L
.22727 .05902 L
.22727 .01472 L
.18182 .01472 L
s
0 1 0 r
.22727 .01472 m
.22727 .22357 L
.27273 .22357 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .22357 L
.27273 .22357 L
.27273 .01472 L
.22727 .01472 L
s
0 1 0 r
.27273 .01472 m
.27273 .35649 L
.31818 .35649 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .35649 L
.31818 .35649 L
.31818 .01472 L
.27273 .01472 L
s
0 1 0 r
.31818 .01472 m
.31818 .578 L
.36364 .578 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .578 L
.36364 .578 L
.36364 .01472 L
.31818 .01472 L
s
0 1 0 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 1 0 r
.40909 .01472 m
.40909 .54003 L
.45455 .54003 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .54003 L
.45455 .54003 L
.45455 .01472 L
.40909 .01472 L
s
0 1 0 r
.45455 .01472 m
.45455 .22357 L
.5 .22357 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .22357 L
.5 .22357 L
.5 .01472 L
.45455 .01472 L
s
0 1 0 r
.5 .01472 m
.5 .12864 L
.54545 .12864 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .12864 L
.54545 .12864 L
.54545 .01472 L
.5 .01472 L
s
0 1 0 r
.54545 .01472 m
.54545 .06535 L
.59091 .06535 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .06535 L
.59091 .06535 L
.59091 .01472 L
.54545 .01472 L
s
0 1 0 r
.59091 .01472 m
.59091 .0337 L
.63636 .0337 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0337 L
.63636 .0337 L
.63636 .01472 L
.59091 .01472 L
s
0 1 0 r
.63636 .01472 m
.63636 .02104 L
.68182 .02104 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .02104 L
.68182 .02104 L
.68182 .01472 L
.63636 .01472 L
s
0 1 0 r
.68182 .01472 m
.68182 .01472 L
.72727 .01472 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .01472 L
.72727 .01472 L
.72727 .01472 L
.68182 .01472 L
s
0 1 0 r
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .01472 L
.77273 .01472 L
.77273 .01472 L
.72727 .01472 L
s
0 1 0 r
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .01472 L
.81818 .01472 L
.81818 .01472 L
.77273 .01472 L
s
0 1 0 r
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .01472 L
.86364 .01472 L
.86364 .01472 L
.81818 .01472 L
s
0 1 0 r
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .01472 L
.90909 .01472 L
.90909 .01472 L
.86364 .01472 L
s
0 1 0 r
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .01472 L
.95455 .01472 L
.95455 .01472 L
.90909 .01472 L
s
0 1 0 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00342212 0.97619 0.140307 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.363636 2.27273 0.0147151 0.00676556 [
[.09091 -0.0125 -9 -9 ]
[.09091 -0.0125 9 0 ]
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15003 -12 -4.5 ]
[-0.0125 .15003 0 4.5 ]
[-0.0125 .28534 -12 -4.5 ]
[-0.0125 .28534 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .55596 -12 -4.5 ]
[-0.0125 .55596 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
[(0.2)] .09091 -0.0125 0 1 Mshowa
.31818 0 m
.31818 .00625 L
s
[(0.3)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(0.4)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(0.5)] .77273 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15003 m
.00625 .15003 L
s
[(20)] -0.0125 .15003 1 0 Mshowa
0 .28534 m
.00625 .28534 L
s
[(40)] -0.0125 .28534 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(60)] -0.0125 .42065 1 0 Mshowa
0 .55596 m
.00625 .55596 L
s
[(80)] -0.0125 .55596 1 0 Mshowa
.125 Mabswid
0 .04854 m
.00375 .04854 L
s
0 .08237 m
.00375 .08237 L
s
0 .1162 m
.00375 .1162 L
s
0 .18385 m
.00375 .18385 L
s
0 .21768 m
.00375 .21768 L
s
0 .25151 m
.00375 .25151 L
s
0 .31917 m
.00375 .31917 L
s
0 .35299 m
.00375 .35299 L
s
0 .38682 m
.00375 .38682 L
s
0 .45448 m
.00375 .45448 L
s
0 .4883 m
.00375 .4883 L
s
0 .52213 m
.00375 .52213 L
s
0 .58979 m
.00375 .58979 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09091 .61178 m
.09091 .61803 L
s
.31818 .61178 m
.31818 .61803 L
s
.54545 .61178 m
.54545 .61803 L
s
.77273 .61178 m
.77273 .61803 L
s
.125 Mabswid
.13636 .61428 m
.13636 .61803 L
s
.18182 .61428 m
.18182 .61803 L
s
.22727 .61428 m
.22727 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.36364 .61428 m
.36364 .61803 L
s
.40909 .61428 m
.40909 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.59091 .61428 m
.59091 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.68182 .61428 m
.68182 .61803 L
s
.72727 .61428 m
.72727 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.86364 .61428 m
.86364 .61803 L
s
.90909 .61428 m
.90909 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.04545 .61428 m
.04545 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15003 m
1 .15003 L
s
.99375 .28534 m
1 .28534 L
s
.99375 .42065 m
1 .42065 L
s
.99375 .55596 m
1 .55596 L
s
.125 Mabswid
.99625 .04854 m
1 .04854 L
s
.99625 .08237 m
1 .08237 L
s
.99625 .1162 m
1 .1162 L
s
.99625 .18385 m
1 .18385 L
s
.99625 .21768 m
1 .21768 L
s
.99625 .25151 m
1 .25151 L
s
.99625 .31917 m
1 .31917 L
s
.99625 .35299 m
1 .35299 L
s
.99625 .38682 m
1 .38682 L
s
.99625 .45448 m
1 .45448 L
s
.99625 .4883 m
1 .4883 L
s
.99625 .52213 m
1 .52213 L
s
.99625 .58979 m
1 .58979 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.04545 .01472 L
.04545 .01472 L
0 .01472 L
s
0 0 1 r
.04545 .01472 m
.04545 .02148 L
.09091 .02148 L
.09091 .01472 L
F
0 g
.04545 .01472 m
.04545 .02148 L
.09091 .02148 L
.09091 .01472 L
.04545 .01472 L
s
0 0 1 r
.09091 .01472 m
.09091 .02148 L
.13636 .02148 L
.13636 .01472 L
F
0 g
.09091 .01472 m
.09091 .02148 L
.13636 .02148 L
.13636 .01472 L
.09091 .01472 L
s
0 0 1 r
.13636 .01472 m
.13636 .04178 L
.18182 .04178 L
.18182 .01472 L
F
0 g
.13636 .01472 m
.13636 .04178 L
.18182 .04178 L
.18182 .01472 L
.13636 .01472 L
s
0 0 1 r
.18182 .01472 m
.18182 .12973 L
.22727 .12973 L
.22727 .01472 L
F
0 g
.18182 .01472 m
.18182 .12973 L
.22727 .12973 L
.22727 .01472 L
.18182 .01472 L
s
0 0 1 r
.22727 .01472 m
.22727 .08237 L
.27273 .08237 L
.27273 .01472 L
F
0 g
.22727 .01472 m
.22727 .08237 L
.27273 .08237 L
.27273 .01472 L
.22727 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .21092 L
.31818 .21092 L
.31818 .01472 L
F
0 g
.27273 .01472 m
.27273 .21092 L
.31818 .21092 L
.31818 .01472 L
.27273 .01472 L
s
0 0 1 r
.31818 .01472 m
.31818 .44095 L
.36364 .44095 L
.36364 .01472 L
F
0 g
.31818 .01472 m
.31818 .44095 L
.36364 .44095 L
.36364 .01472 L
.31818 .01472 L
s
0 0 1 r
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
F
0 g
.36364 .01472 m
.36364 .60332 L
.40909 .60332 L
.40909 .01472 L
.36364 .01472 L
s
0 0 1 r
.40909 .01472 m
.40909 .53566 L
.45455 .53566 L
.45455 .01472 L
F
0 g
.40909 .01472 m
.40909 .53566 L
.45455 .53566 L
.45455 .01472 L
.40909 .01472 L
s
0 0 1 r
.45455 .01472 m
.45455 .40035 L
.5 .40035 L
.5 .01472 L
F
0 g
.45455 .01472 m
.45455 .40035 L
.5 .40035 L
.5 .01472 L
.45455 .01472 L
s
0 0 1 r
.5 .01472 m
.5 .25151 L
.54545 .25151 L
.54545 .01472 L
F
0 g
.5 .01472 m
.5 .25151 L
.54545 .25151 L
.54545 .01472 L
.5 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .10943 L
.59091 .10943 L
.59091 .01472 L
F
0 g
.54545 .01472 m
.54545 .10943 L
.59091 .10943 L
.59091 .01472 L
.54545 .01472 L
s
0 0 1 r
.59091 .01472 m
.59091 .0959 L
.63636 .0959 L
.63636 .01472 L
F
0 g
.59091 .01472 m
.59091 .0959 L
.63636 .0959 L
.63636 .01472 L
.59091 .01472 L
s
0 0 1 r
.63636 .01472 m
.63636 .06884 L
.68182 .06884 L
.68182 .01472 L
F
0 g
.63636 .01472 m
.63636 .06884 L
.68182 .06884 L
.68182 .01472 L
.63636 .01472 L
s
0 0 1 r
.68182 .01472 m
.68182 .04854 L
.72727 .04854 L
.72727 .01472 L
F
0 g
.68182 .01472 m
.68182 .04854 L
.72727 .04854 L
.72727 .01472 L
.68182 .01472 L
s
0 0 1 r
.72727 .01472 m
.72727 .02825 L
.77273 .02825 L
.77273 .01472 L
F
0 g
.72727 .01472 m
.72727 .02825 L
.77273 .02825 L
.77273 .01472 L
.72727 .01472 L
s
0 0 1 r
.77273 .01472 m
.77273 .02148 L
.81818 .02148 L
.81818 .01472 L
F
0 g
.77273 .01472 m
.77273 .02148 L
.81818 .02148 L
.81818 .01472 L
.77273 .01472 L
s
0 0 1 r
.81818 .01472 m
.81818 .02148 L
.86364 .02148 L
.86364 .01472 L
F
0 g
.81818 .01472 m
.81818 .02148 L
.86364 .02148 L
.86364 .01472 L
.81818 .01472 L
s
0 0 1 r
.86364 .01472 m
.86364 .02148 L
.90909 .02148 L
.90909 .01472 L
F
0 g
.86364 .01472 m
.86364 .02148 L
.90909 .02148 L
.90909 .01472 L
.86364 .01472 L
s
0 0 1 r
.90909 .01472 m
.90909 .02825 L
.95455 .02825 L
.95455 .01472 L
F
0 g
.90909 .01472 m
.90909 .02825 L
.95455 .02825 L
.95455 .01472 L
.90909 .01472 L
s
0 0 1 r
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95455 .01472 m
.95455 .01472 L
1 .01472 L
1 .01472 L
.95455 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{678.313, 97.4375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:V0000HB000`400?l00000o`00003oo`3ooooo
0?ooojP0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00:`3oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000=`3oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000?03oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`800000?03oool2000000@0oooo
0P0000030?ooo`@000003`3oool2000000@0oooo0P0000040?ooo`800000403oool2000000@0oooo
0P0000050?ooo`<000003P3oool2000000@0oooo0P0000040?ooo`800000;@3oool002X0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000e0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000>P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`00:P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000000P0oooo1@00000=0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0>03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000000P0oooo1@00000<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0>03o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo1@00000=0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0:P3oool002X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000002@3oool2000003H0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000002@3oool2000003/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000d0oooo00@000000?ooo`3oool000002@3oool20000
03/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool2000002d0oooo000Z0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0000000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0=@3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03X0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0j0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0;03oool002/0oooo0P00
000:0?ooo`800000403oool2000000X0oooo0P00000@0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000=P3oool2000000X0oooo0P00000@0?ooo`8000002P3oool200000100oooo0P00
000;0?ooo`8000003`3oool2000000X0oooo0`00000k0?ooo`8000002P3oool200000100oooo0P00
000:0?ooo`800000403oool2000000/0oooo0P00000>0?ooo`8000002P3oool3000003/0oooo0P00
000:0?ooo`800000403oool2000000X0oooo0P00000@0?ooo`8000002`3oool2000000l0oooo0P00
000:0?ooo`<00000;03oool00?l0ooooo`3ooonX0?ooo`00o`3ooooo0?ooojP0oooo003o0?ooool0
ooooZ03oool00?l0ooooo`3ooonX0?ooo`008@3oool2000000<0ooooPP00000H0?ooo`8000000`3o
oon5000001T0oooo0P0000040?oooh@000006P3oool2000000<0ooooQ@00000E0?ooo`00803oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001L0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000P0?oo
o`040000003oool0oooo00000080ooooPP00000G0?ooo`040000003oool0oooo00000080ooooQ@00
000H0?ooo`040000003oool0oooo000000<0ooooQ@00000H0?ooo`040000003oool0oooo00000080
ooooQ@00000E0?ooo`00803oool010000000oooo0?ooo`0000020?ooo`@000000P3oool400000080
Ogmo00@0000007moO`1oOgl000000P3oool010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`030000003oool0oooo01D0oooo100000050?ooo`030000
003oool0oooo01D0oooo00@000000?ooo`3oool000000P3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o0007000000D0oooo1`00000G0?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool7000000D0oooo1`000005003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o
000300000000o`000?l000<00?l01`00000X0?ooo`030000003oool0oooo01L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`d000001@000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000oa<000001@000?l00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000P0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool400000080Ogmo00@00000
0?ooo`3oool000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00<0000007moO`1oOgl01`00000P0?ooo`030000
003oool0oooo01D0oooo00@000000?ooo`3oool000000P3oool7000000D0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0?0?ooo`0300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l01`00000^0?oo
o`030000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?
0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o1`00000A0?ooo`L000001@3oool00`000000oooo0?ooo`0C
0?ooo`008@3oool2000000<0oooo0P00000:0?ooo`@000000P3oool400000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000Ogmo07moO`040000
02H0oooo00<000000?ooo`3oool05P3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0?0?ooo`L000001@00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0H0?ooo`8000000`3oool00`000000oooo0?ooo`0?0?ooo`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`0B0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool00`3oool7000000D0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0M0?ooo`800000403oool7000000D0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l70000
0280oooo0P00000E0?ooo`009P3oool2000001<0oooo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo
02L0oooo00<000000?ooo`3oool06`3oool2000000X0oooo1`0000050?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0V0?ooo`8000007`3oool00`00
0000oooo0?ooo`0E0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo0380oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo0180
oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo3@00000Y0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool03`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool05@3oool7000000D00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0B0?ooo`@000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo00<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`07000003@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?oo
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o1`00000Y0?ooo`030000003oool0oooo01<0oooo000V0?ooo`80
00005P3oool400000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03`3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000d00000:@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04`3oool001X0oooo100000030?ooo`8000000`3oool0
0`000000oooo0?ooo`0H0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01/0
oooo0P00000@0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0<P3oool2000001l0
oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03P0
oooo00<000000?ooo`3oool07@3oool2000001H0oooo00<000000000o`000?l00`000?l7000000D0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0/0?ooo`8000005@3oool001X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01P0
oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`030000003oool0oooo03<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0?0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000003o0000
o`030000o`030000003oool0oooo00<0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`030000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool001/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`8000006@3oool400000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0b0?ooo`80
00007@3oool00`000000oooo0?ooo`0?0?ooo`d000001@3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01D0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`030?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o1`00000_0?ooo`030000003oool0oooo01<0oooo000L0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000M0?ooo`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000=@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<000000000o`000?l00`000?l00`000000oooo
0?ooo`030?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`L00000=@3oool00`000000oooo0?ooo`0C0?ooo`006P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo0P00000L0?ooo`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000=@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0K0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0M0?ooo`8000005P3oool00`000000003o0000o`030000o`030000003oool0oooo00<0oooo00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000?ooo`3oool0>03oool2000001D0oooo000K0?ooo`800000103oool2000000<0oooo00<00000
0?ooo`3oool06`3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`@00000
=@3oool00`000000oooo0?ooo`0K0?ooo`800000703oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?ooo`3oool0<P3oool2000001l0oooo00<000000?ooo`3oool0
6`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo03P0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0E0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0
0`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo01/0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000L00000=@3oool00`000000oooo0?ooo`0@0?ooo`@000000`3oool2000000@0
oooo00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`07000003X0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0E0?ooo`L000001@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`800000703oool400000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0?0?ooo`@000000`3oool2000000<0oooo00<000000?ooo`3o
ool06`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0140oooo100000030?oo
o`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool07P3oool010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07mo
O`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000h0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01/0oooo00<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`800000703oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0240oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`0N0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
03P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo0P00000L0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0>03oool2
000001@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
7@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`8000008P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0h0?ooo`80
00005@3oool001`0oooo0`0000020?ooo`8000000`3oool2000001l0oooo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000001oOgl0Ogmo00@00000
0P1oOgl00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000001d0oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`00000S0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool04`3oool001d0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000P0?ooo`@000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080oooo00@0000007mo
O`1oOgl00000>03oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo
00<000000?ooo`3oool06`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0240oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o
00<0003o00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`006P3oool500000005
0?ooo`000000oooo0?ooo`0000000P3oool200000280oooo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000003oool0oooo00000080Ogmo00<00000
0?ooo`3oool0=@3oool200000180oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0K
0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool08@3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01<0oooo000J0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`040000001oOgl0Ogmo00000080Ogmo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`04000003P0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`L000001@3o00000`000000o`000?l0
00030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000L00000>`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0M0?ooo`8000008P3oool00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?oo
o`0h0?ooo`8000005@3oool001/0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0240oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`030000003oool0oooo03`0oooo00<000000?ooo`3oool06`3o
ool200000280oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
ool0oooo03h0oooo0P00000O0?ooo`030000003oool0oooo01/0oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0C0?ooo`00703oool2000000<0oooo0P0000030?ooo`8000008P3oool0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03l0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo03h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool08@3oool010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003oool0oooo03l0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0K0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Q0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool08@3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000
001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0240oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003oool0oooo03l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`L0
00001@000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool04`3oool002H0oooo0P00000R0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01/0oooo
0P00000R0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`0n0?ooo`8000007`3oool00`000000oooo0?ooo`0K0?ooo`L000001@00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`0700000400oooo
00<000000?ooo`3oool07@3oool2000002P0oooo00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o
0000o`030000o`030000003oool0oooo03P0oooo0P00000E0?ooo`009P3oool00`000000oooo0?oo
o`0Q0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3o
ool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00
o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00
o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3o
ool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`00
0?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool200000280oooo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl00`000000Ogmo07moO`04000003h0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000J0?ooo`<00000103oool2000000<0
oooo00<000000?ooo`3oool08@3oool400000080Ogmo00@0000007moO`1oOgl000000P1oOgl01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
@@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo03l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000003o0000o`030000o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
4`3oool001X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02@0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool00`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`00
0?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0B0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3oool08@3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool2000002P0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l7000003X0oooo0P00000E0?ooo`006P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo0P00000U0?ooo`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001o
Ogl0Ogmo00000080Ogmo00<000000?ooo`3oool0?P3oool2000001d0oooo0P00000R0?ooo`030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`0n0?ooo`800000
5@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000008`3oool00`00
00000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`00
00000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0C0?ooo`006P3oool3000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0T0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0403oool5000000050?ooo`000000oooo0?ooo`0000000`3oool200000280oooo00<00000003o
0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool09`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0oooo00<000000?oo
o`3oool04`3oool001/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02@0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00
000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0140oooo0`0000020?ooo`8000000`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo00<00000003o0000o`000`00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo0`0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0C0?ooo`006`3oool3000000<0oooo0P0000030?ooo`8000009@3oool01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000
0P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002<0oooo00<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo03l0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002T0
oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo02@0oooo00@0000007moO`1oOgl000000P1oOgl010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1o
Ogl00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00l0oooo1@0000001@3oool000000?oo
o`3oool000000080oooo0P00000R0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`0n0?ooo`800000503oool2000000<0oooo0P0000040?ooo`030000
003oool0oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000
003oool0oooo0140oooo1@0000001@3oool000000?ooo`3oool000000080oooo0P00000X0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0?P3oool2000001D0oooo000V0?ooo`800000
9@3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool08@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo0140
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02L0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0
003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo02@0oooo1000000207moO`040000001oOgl0Ogmo
00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0403oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0240oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02L0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo02L0oooo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl00000@@3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool2000000<0oooo
00<000000?ooo`3oool08@3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo
0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool2000002P0oooo00@0
000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo0000
0080Ogmo00@0000007moO`1oOgl00000@@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0240oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000
o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0
oooo03l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000o`00
0?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`00
0?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`800000:03oool0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`030000003oool0oooo03h0oooo0P00000E0?ooo`006`3oool20000
00@0oooo0P0000030?ooo`030000003oool0oooo02L0oooo00@0000007moO`1oOgl000000P1oOgl0
10000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl0
0000@@3oool00`000000oooo0?ooo`0K0?ooo`8000008P3oool00`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003
0000003o0000o`0000<0o`0000<000000?ooo`3oool0?P3oool2000001l0oooo00<000000?ooo`3o
ool08@3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0C0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo
07moO`0000110?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool7000000D0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240
oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<0
0?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool09`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0
003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0
oooo00<000000?ooo`3oool04`3oool001X0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`800000:03oool010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`0000100?ooo`80
00007@3oool00`000000oooo0?ooo`0W0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000
o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool09`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool04`3oool001/0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool09`3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl400000440oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0W0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000L00000@@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo00<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo0P00
000X0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0?P3oool2000001D0oooo000J
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000002P0oooo
00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo
00000080Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0K0?ooo`800000:03oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`140?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`L000001@00o`00
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000000o`000?l00`000?l0
0`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0oooo000K0?ooo`800000103oool20000
00<0oooo00<000000?ooo`3oool09`3oool010000000Ogmo07moO`00000207moO`040000001oOgl0
Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`120?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool09`3oool00`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`150?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0003003o00030000
0000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000003o0000o`030000o`030000
00000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000
003oool0oooo03l0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool09`3o
ool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1o
Ogl000000P1oOgl00`000000oooo0?ooo`120?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool09`3oool00`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0
003o00000`3o00000`000000oooo0?ooo`150?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool09`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool09`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000
o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo03l0oooo00<000000?oo
o`3oool04`3oool002H0oooo0P00000X0?ooo`@000000P1oOgl010000000Ogmo07moO`00000207mo
O`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo02L0oooo00<000000?l0003o00000`3o00000`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0@
0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`14
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000003o0000o`03
0000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`03
0000o`030000003oool0oooo03l0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0:P3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0
000007moO`1oOgl00000A03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02L0oooo
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`00
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l0
00<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo
04@0oooo00<000000?ooo`3oool07@3oool2000002P0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`00
0000oooo0?ooo`0n0?ooo`8000005@3oool002H0oooo00<000000?ooo`3oool0:P3oool010000000
Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl00000A03o
ool00`000000oooo0?ooo`0K0?ooo`800000:03oool00`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`140?ooo`8000004P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00000X0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`03
000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`00
503oool500000080oooo0P0000040?ooo`8000000`3oool2000002/0oooo00@0000007moO`1oOgl0
00000P1oOgl010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo000004@0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`030000003o0000o`0000<0o`0000<00000
0?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0403oool3000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0W0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o
0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool3000000@0oooo0P00
00030?ooo`030000003oool0oooo02L0oooo00<000000000o`000?l00`000?l00`000000003o0000
o`030000o`03000000000?l0003o00<0003o1`0000110?ooo`030000003oool0oooo01<0oooo000F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002`0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`040000001oOgl0Ogmo000004@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0W0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00030?l000030000003oool0oooo04D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool09`3oool00`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo
0?ooo`140?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02L0oooo00<000000000o`000?l00`000?l00`00
0000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0C0?ooo`005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`02000002/0oooo00@0000007moO`1oOgl000000P1o
Ogl010000000Ogmo07moO`00000207moO`@00000@`3oool200000140oooo0`0000040?ooo`800000
0`3oool00`000000oooo0?ooo`0W0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo04D0oooo00<000000?ooo`3oool0
4@3oool3000000<0oooo0P0000040?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool2000002P0oooo00<000000000o`000?l00`000?l00`000000003o0000o`030000
o`03000000000?l0003o00<0003o00<000000?ooo`3oool0A03oool2000001D0oooo000F0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000002`0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000o`000?l00003
0?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0140oooo0`0000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool09`3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo000F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002`0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`000002
07moO`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo0P00000X0?ooo`030000003o0000o`0000<0o`00
00<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003oool0oooo04@0oooo
0P00000O0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0W0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000
003o0000o`030000o`030000003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool001D0oooo
0P0000040?ooo`800000103oool2000000<0oooo0P00000[0?ooo`040000001oOgl0Ogmo00000080
Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00l0oooo0`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool0
0`000000o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000oooo0?ooo`150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool0
0`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o0000o`000`00o`00
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo0`0000030?ooo`8000000`3oool0
0`000000oooo0?ooo`0W0?ooo`L000001@000?l00`000000003o0000o`030000o`030000003oool0
oooo04D0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0:P3oool01000
0000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0W0?ooo`030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003oool0oooo04D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`00
0`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l0
0`000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo02X0oooo00@0000007moO`1oOgl000000P1oOgl010000000Ogmo07moO`00000207moO`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0403oool3000000<0oooo0P0000030?ooo`03
0000003oool0oooo02L0oooo00<000000?l0003o00000`3o00000`000000o`000?l000030?l000L0
0000A`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<00000003o0000
o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0M0?ooo`800000;P3oool00`000000003o0000o`030000o`03
000000000?l0003o00<0003o00<000000?ooo`3oool0A03oool2000001D0oooo000V0?ooo`800000
:`3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0K0?ooo`800000:03oool00`000000o`000?l000030?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0BP3oool2000001l0oooo00<000000?oo
o`3oool09`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000003o
0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;@3oool00`000000003o0000o`030000o`03000000000?l0003o00<0003o00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`0Z0?ooo`04
0000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool09`3oool7000000D0o`0000<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o000300000000o`000?l000<00?l000<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02d0oooo00<00000
0000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool04`3oool002H0oooo0P00000[0?ooo`040000001oOgl0Ogmo00000080Ogmo00@00000
07moO`1oOgl000000P1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0;@3oool00`000000o`000?l000030?l000030000003oool0oooo04/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<0
0000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o00<0003o00<0
00000000o`000?l00`000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo000D
0?ooo`D0000000<0oooo0000000000000P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0Z
0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007moO`1oOgl000000P1oOgl00`000000oooo
0?ooo`150?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;@3oool00`000000o`00
0?l000030?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool2000002h0oooo
00<000000000o`000?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo04@0oooo
0P00000E0?ooo`005P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0Z0?ooo`040000001oOgl0Ogmo00000080Ogmo00@0000007mo
O`1oOgl000000P1oOgl00`000000oooo0?ooo`150?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0;@3oool00`000000o`000?l000030?l000030000003oool0oooo04/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o00<0003o00<00000
0000o`000?l00`000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo000F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`800000:`3oool010000000Ogmo07moO`00000207moO`040000001oOgl0Ogmo00000080Ogmo
00<000000?ooo`3oool0A03oool2000001d0oooo0P00000^0?ooo`030000003o0000o`0000<0o`00
00<000000?ooo`3oool0BP3oool2000001<0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`0W0?ooo`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0]0?ooo`03000000000?l0003o00<0003o00<000000000o`000?l00`000?l00`000000oooo
0?ooo`150?ooo`030000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002`0oooo00@0000007moO`1o
Ogl000000P1oOgl010000000Ogmo07moO`00000207moO`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`0300000000o`000?l000<00?l0
00<00000003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o00<0003o
00<000000000o`000?l00`000?l00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo
000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000002`0oooo00<0000007moO`1oOgl01000000207moO`@00000A`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000?l0003o00000`3o00000`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`800000:03oool00`0000000?l0003o0003003o000300000000
o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`140?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;@3oool00`000000003o0000o`030000o`0300000000
0?l0003o00<0003o00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0C0?ooo`005@3oool2
000000@0oooo0P0000040?ooo`8000000`3oool2000002/0oooo00@0000007moO`1oOgl000000P3o
ool010000000Ogmo07moO`00001:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
;@3oool00`000000o`000?l000030?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool0
4@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0W0?ooo`03
00000000o`000?l000<00?l000<00000003o0000o`000`00o`000`0000000?l0003o0003003o0003
0000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool2000002h0oooo00<000000000o`00
0?l00`000?l00`000000003o0000o`030000o`030000003oool0oooo04@0oooo0P00000E0?ooo`00
9P3oool00`000000oooo0?ooo`0Z0?ooo`@000000P3oool010000000Ogmo07moO`00001:0?ooo`03
0000003oool0oooo01/0oooo0P00000^0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0BP3oool200000180oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0003o0003
003o000300000000o`000?l000<00?l000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00`000?l7000004L0oooo00<00000
0?ooo`3oool04`3oool002H0oooo0P00000a0?ooo`040000001oOgl0Ogmo000004X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool09`3oool00`0000000?l0003o0003003o000300000000o`000?l000<00?l01`000016
0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0]
0?ooo`03000000000?l0003o00<0003o00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`0`0?ooo`040000001oOgl0Ogmo000004X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003o0000o`0000<0o`0000<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<00000
003o0000o`000`00o`000`0000000?l0003o0003003o00030000003oool0oooo04X0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0;@3oool00`000000003o0000o`030000o`030000003oool0oooo04/0oooo
00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0<03oool010000000Ogmo07mo
O`00001:0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`8000000`3oool00`000000oooo
0?ooo`0]0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<00000003o0000o`000`00o`000`0000000?l0
003o0003003o00030000003oool0oooo04X0oooo00<000000?ooo`3oool04@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P00000^0?ooo`03000000000?l0003o
00<0003o00<000000?ooo`3oool0BP3oool2000001D0oooo000V0?ooo`800000<@3oool010000000
Ogmo07moO`00001:0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<000000?l0003o00000`3o
00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3o
ool00`0000000?l0003o0003003o000300000000o`000?l000<00?l000<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo01<0oooo000D0?ooo`D000000`3oool300000080oooo0P0000030?ooo`030000003o
ool0oooo0300oooo00@0000007moO`1oOgl00000BP3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000002h0oooo00<000000?l0
003o00000`3o00000`000000oooo0?ooo`1:0?ooo`8000007`3oool00`000000oooo0?ooo`0W0?oo
o`0300000000o`000?l000<00?l000<00000003o0000o`000`00o`000`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00`000?l00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo01<0oooo000F0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000b0?ooo`040000001oOgl0Ogmo000004X0
oooo00<000000?ooo`3oool0403oool2000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo1`000005003o00030000003oool0oooo
04X0oooo00<000000?ooo`3oool04P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo
02d0oooo00<000000000o`000?l00`000?l00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
01<0oooo000F0?ooo`040000003oool0oooo0?ooo`D0000000D0oooo0000003oool0oooo00000002
0?ooo`800000<@3oool010000000Ogmo07moO`0000190?ooo`8000004@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000
o`000?l000030?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0]0?ooo`0300000000o`000?l000<00?l000<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo02d0oooo00<000000000o`000?l00`000?l00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo01<0oooo000F0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000380oooo1000001:
0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`0]
0?ooo`030000003o0000o`0000<0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02d0oooo00<00000003o0000o`000`00o`000`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo01d0oooo0P00000^0?ooo`03000000000?l0003o00<0003o00<00000
0?ooo`3oool0BP3oool2000001D0oooo000F0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000007@3oool2000002h0oooo1`00
001<0?ooo`8000007`3oool00`000000oooo0?ooo`0]0?ooo`L00000C03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02d0oooo1`00001=0?ooo`030000003oool0oooo01<0oooo000E
0?ooo`8000001@3oool2000000<0oooo0P0000030?oooh8000007@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00<D0ooooQ@00000O0?oo
oh@000007`3ooon5000001D0oooo003o0?ooool0ooooZ03oool00?l0ooooo`3ooonX0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 568}, {90.625, 13.6875}} -> {-0.331812, \
0.0930199, 0.00627702, 0.00627702}, {{42.25, 160.813}, {88.75, 15.5}} -> \
{-0.082391, 4.24957, 0.00334706, 1.87785}, {{172.688, 291.25}, {88.75, 15.5}} -> \
{-0.617061, 2.42814, 0.00336031, 1.10287}, {{303.063, 421.625}, {88.75, \
15.5}} -> {-1.16469, 2.65667, 0.00336031, 1.20667}, {{433.5, 552.063}, \
{88.75, 15.5}} -> {-1.71257, 2.48528, 0.00336031, 1.12882}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Looking at the relative metric fractions of each beat in sequence\
\>", "Section"],

Cell[BoxData[
    \(ShowMetricCycles[list_]\  := \ 
      Module[{dplot11, \ dplot12, \ 
          dplot13}, \ \ Block[{$DisplayFunction\  = \ 
              Identity}, \[IndentingNewLine]dplot11\  = \ 
            ListPlot[list[\([1]\)], \ PlotJoined \[Rule] True, 
              Frame \[Rule] True, \ PlotStyle \[Rule] RGBColor[1, 0, 0], \ 
              Axes \[Rule] False]; \[IndentingNewLine]dplot12\  = \ 
            ListPlot[list[\([2]\)], \ PlotJoined \[Rule] True, \ 
              Frame \[Rule] True, \ PlotStyle \[Rule] RGBColor[0, 1, 0], \ 
              Axes \[Rule] False]; \[IndentingNewLine]dplot13\  = \ 
            ListPlot[list[\([3]\)], \ PlotJoined \[Rule] True, \ 
              Frame \[Rule] True, \ PlotStyle \[Rule] RGBColor[0, 0, 1], \ 
              Axes \[Rule] 
                False];\[IndentingNewLine]]; \[IndentingNewLine]Show[
          dplot11, \ dplot12, \ dplot13, \ 
          AspectRatio \[Rule] 1/4]\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2 performed by Chiu 1999", "Subsection"],

Cell[CellGroupData[{

Cell["Manually Corrected Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0080032 -0.122946 0.650989 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18387 -0.0125 -6 -9 ]
[.18387 -0.0125 6 0 ]
[.34394 -0.0125 -6 -9 ]
[.34394 -0.0125 6 0 ]
[.504 -0.0125 -6 -9 ]
[.504 -0.0125 6 0 ]
[.66407 -0.0125 -6 -9 ]
[.66407 -0.0125 6 0 ]
[.82413 -0.0125 -9 -9 ]
[.82413 -0.0125 9 0 ]
[.98419 -0.0125 -9 -9 ]
[.98419 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00725 -18 -4.5 ]
[-0.0125 .00725 0 4.5 ]
[-0.0125 .0398 -24 -4.5 ]
[-0.0125 .0398 0 4.5 ]
[-0.0125 .07235 -18 -4.5 ]
[-0.0125 .07235 0 4.5 ]
[-0.0125 .1049 -24 -4.5 ]
[-0.0125 .1049 0 4.5 ]
[-0.0125 .13745 -18 -4.5 ]
[-0.0125 .13745 0 4.5 ]
[-0.0125 .17 -24 -4.5 ]
[-0.0125 .17 0 4.5 ]
[-0.0125 .20255 -18 -4.5 ]
[-0.0125 .20255 0 4.5 ]
[-0.0125 .2351 -24 -4.5 ]
[-0.0125 .2351 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18387 0 m
.18387 .00625 L
s
[(20)] .18387 -0.0125 0 1 Mshowa
.34394 0 m
.34394 .00625 L
s
[(40)] .34394 -0.0125 0 1 Mshowa
.504 0 m
.504 .00625 L
s
[(60)] .504 -0.0125 0 1 Mshowa
.66407 0 m
.66407 .00625 L
s
[(80)] .66407 -0.0125 0 1 Mshowa
.82413 0 m
.82413 .00625 L
s
[(100)] .82413 -0.0125 0 1 Mshowa
.98419 0 m
.98419 .00625 L
s
[(120)] .98419 -0.0125 0 1 Mshowa
.125 Mabswid
.06383 0 m
.06383 .00375 L
s
.10384 0 m
.10384 .00375 L
s
.14386 0 m
.14386 .00375 L
s
.22389 0 m
.22389 .00375 L
s
.26391 0 m
.26391 .00375 L
s
.30392 0 m
.30392 .00375 L
s
.38395 0 m
.38395 .00375 L
s
.42397 0 m
.42397 .00375 L
s
.46399 0 m
.46399 .00375 L
s
.54402 0 m
.54402 .00375 L
s
.58403 0 m
.58403 .00375 L
s
.62405 0 m
.62405 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.7441 0 m
.7441 .00375 L
s
.78411 0 m
.78411 .00375 L
s
.86415 0 m
.86415 .00375 L
s
.90416 0 m
.90416 .00375 L
s
.94418 0 m
.94418 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00725 m
.00625 .00725 L
s
[(0.2)] -0.0125 .00725 1 0 Mshowa
0 .0398 m
.00625 .0398 L
s
[(0.25)] -0.0125 .0398 1 0 Mshowa
0 .07235 m
.00625 .07235 L
s
[(0.3)] -0.0125 .07235 1 0 Mshowa
0 .1049 m
.00625 .1049 L
s
[(0.35)] -0.0125 .1049 1 0 Mshowa
0 .13745 m
.00625 .13745 L
s
[(0.4)] -0.0125 .13745 1 0 Mshowa
0 .17 m
.00625 .17 L
s
[(0.45)] -0.0125 .17 1 0 Mshowa
0 .20255 m
.00625 .20255 L
s
[(0.5)] -0.0125 .20255 1 0 Mshowa
0 .2351 m
.00625 .2351 L
s
[(0.55)] -0.0125 .2351 1 0 Mshowa
.125 Mabswid
0 .01376 m
.00375 .01376 L
s
0 .02027 m
.00375 .02027 L
s
0 .02678 m
.00375 .02678 L
s
0 .03329 m
.00375 .03329 L
s
0 .04631 m
.00375 .04631 L
s
0 .05282 m
.00375 .05282 L
s
0 .05933 m
.00375 .05933 L
s
0 .06584 m
.00375 .06584 L
s
0 .07886 m
.00375 .07886 L
s
0 .08537 m
.00375 .08537 L
s
0 .09188 m
.00375 .09188 L
s
0 .09839 m
.00375 .09839 L
s
0 .11141 m
.00375 .11141 L
s
0 .11792 m
.00375 .11792 L
s
0 .12443 m
.00375 .12443 L
s
0 .13094 m
.00375 .13094 L
s
0 .14396 m
.00375 .14396 L
s
0 .15047 m
.00375 .15047 L
s
0 .15698 m
.00375 .15698 L
s
0 .16349 m
.00375 .16349 L
s
0 .17651 m
.00375 .17651 L
s
0 .18302 m
.00375 .18302 L
s
0 .18953 m
.00375 .18953 L
s
0 .19604 m
.00375 .19604 L
s
0 .20906 m
.00375 .20906 L
s
0 .21557 m
.00375 .21557 L
s
0 .22208 m
.00375 .22208 L
s
0 .22859 m
.00375 .22859 L
s
0 .00074 m
.00375 .00074 L
s
0 .24161 m
.00375 .24161 L
s
0 .24812 m
.00375 .24812 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.18387 .24375 m
.18387 .25 L
s
.34394 .24375 m
.34394 .25 L
s
.504 .24375 m
.504 .25 L
s
.66407 .24375 m
.66407 .25 L
s
.82413 .24375 m
.82413 .25 L
s
.98419 .24375 m
.98419 .25 L
s
.125 Mabswid
.06383 .24625 m
.06383 .25 L
s
.10384 .24625 m
.10384 .25 L
s
.14386 .24625 m
.14386 .25 L
s
.22389 .24625 m
.22389 .25 L
s
.26391 .24625 m
.26391 .25 L
s
.30392 .24625 m
.30392 .25 L
s
.38395 .24625 m
.38395 .25 L
s
.42397 .24625 m
.42397 .25 L
s
.46399 .24625 m
.46399 .25 L
s
.54402 .24625 m
.54402 .25 L
s
.58403 .24625 m
.58403 .25 L
s
.62405 .24625 m
.62405 .25 L
s
.70408 .24625 m
.70408 .25 L
s
.7441 .24625 m
.7441 .25 L
s
.78411 .24625 m
.78411 .25 L
s
.86415 .24625 m
.86415 .25 L
s
.90416 .24625 m
.90416 .25 L
s
.94418 .24625 m
.94418 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .00725 m
1 .00725 L
s
.99375 .0398 m
1 .0398 L
s
.99375 .07235 m
1 .07235 L
s
.99375 .1049 m
1 .1049 L
s
.99375 .13745 m
1 .13745 L
s
.99375 .17 m
1 .17 L
s
.99375 .20255 m
1 .20255 L
s
.99375 .2351 m
1 .2351 L
s
.125 Mabswid
.99625 .01376 m
1 .01376 L
s
.99625 .02027 m
1 .02027 L
s
.99625 .02678 m
1 .02678 L
s
.99625 .03329 m
1 .03329 L
s
.99625 .04631 m
1 .04631 L
s
.99625 .05282 m
1 .05282 L
s
.99625 .05933 m
1 .05933 L
s
.99625 .06584 m
1 .06584 L
s
.99625 .07886 m
1 .07886 L
s
.99625 .08537 m
1 .08537 L
s
.99625 .09188 m
1 .09188 L
s
.99625 .09839 m
1 .09839 L
s
.99625 .11141 m
1 .11141 L
s
.99625 .11792 m
1 .11792 L
s
.99625 .12443 m
1 .12443 L
s
.99625 .13094 m
1 .13094 L
s
.99625 .14396 m
1 .14396 L
s
.99625 .15047 m
1 .15047 L
s
.99625 .15698 m
1 .15698 L
s
.99625 .16349 m
1 .16349 L
s
.99625 .17651 m
1 .17651 L
s
.99625 .18302 m
1 .18302 L
s
.99625 .18953 m
1 .18953 L
s
.99625 .19604 m
1 .19604 L
s
.99625 .20906 m
1 .20906 L
s
.99625 .21557 m
1 .21557 L
s
.99625 .22208 m
1 .22208 L
s
.99625 .22859 m
1 .22859 L
s
.99625 .00074 m
1 .00074 L
s
.99625 .24161 m
1 .24161 L
s
.99625 .24812 m
1 .24812 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03181 .13002 m
.03982 .0884 L
.04782 .15512 L
.05582 .09526 L
.06383 .16271 L
.07183 .08207 L
.07983 .0929 L
.08784 .0146 L
.09584 .11186 L
.10384 .07841 L
.11184 .1444 L
.11985 .09535 L
.12785 .1298 L
.13585 .03915 L
.14386 .10026 L
.15186 .04618 L
.15986 .12857 L
.16787 .08901 L
.17587 .13982 L
.18387 .10615 L
.19188 .15296 L
.19988 .06273 L
.20788 .10291 L
.21589 .0496 L
.22389 .13511 L
.23189 .10363 L
.2399 .1531 L
.2479 .08849 L
.2559 .12995 L
.26391 .0517 L
.27191 .21291 L
.27991 .05612 L
.28792 .09641 L
.29592 .10024 L
.30392 .10133 L
.31192 .11057 L
.31993 .13653 L
.32793 .11519 L
.33593 .10703 L
.34394 .10581 L
.35194 .12666 L
.35994 .09609 L
.36795 .13864 L
.37595 .0764 L
.38395 .12681 L
.39196 .03973 L
.39996 .15747 L
.40796 .06272 L
.41597 .12391 L
.42397 .09125 L
Mistroke
.43197 .13621 L
.43998 .09012 L
.44798 .13281 L
.45598 .13773 L
.46399 .10694 L
.47199 .08454 L
.47999 .14484 L
.488 .08058 L
.496 .12704 L
.504 .07524 L
.512 .13022 L
.52001 .04988 L
.52801 .11566 L
.53601 .10643 L
.54402 .14795 L
.55202 .08216 L
.56002 .08106 L
.56803 .14291 L
.57603 .09127 L
.58403 .13054 L
.59204 .0971 L
.60004 .09776 L
.60804 .1476 L
.61605 .08141 L
.62405 .07854 L
.63205 .07783 L
.64006 .14988 L
.64806 .07996 L
.65606 .0828 L
.66407 .10497 L
.67207 .12798 L
.68007 .10617 L
.68808 .0776 L
.69608 .13735 L
.70408 .08535 L
.71208 .08972 L
.72009 .08465 L
.72809 .10753 L
.73609 .13623 L
.7441 .08984 L
.7521 .09439 L
.7601 .11217 L
.76811 .13395 L
.77611 .10249 L
.78411 .07752 L
.79212 .05778 L
.80012 .16678 L
.80812 .10462 L
.81613 .09371 L
.82413 .12392 L
Mistroke
.83213 .06074 L
.84014 .1159 L
.84814 .08268 L
.85614 .00595 L
.86415 .09901 L
.87215 .13523 L
.88015 .19454 L
.88816 .06977 L
.89616 .18312 L
.90416 .0389 L
.91216 .08275 L
.92017 .08034 L
.92817 .1307 L
.93617 .08302 L
.94418 .1323 L
.95218 .07906 L
.96018 .19066 L
.96819 .04684 L
.97619 .18648 L
Mfstroke
0 1 0 r
.03181 .09416 m
.03982 .0609 L
.04782 .07254 L
.05582 .0513 L
.06383 .05371 L
.07183 .09602 L
.07983 .11409 L
.08784 .0902 L
.09584 .10777 L
.10384 .07918 L
.11184 .09165 L
.11985 .05036 L
.12785 .09152 L
.13585 .1099 L
.14386 .10064 L
.15186 .1144 L
.15986 .0866 L
.16787 .06693 L
.17587 .08458 L
.18387 .0541 L
.19188 .05541 L
.19988 .10311 L
.20788 .10009 L
.21589 .09179 L
.22389 .0609 L
.23189 .06751 L
.2399 .07803 L
.2479 .0656 L
.2559 .0769 L
.26391 .10973 L
.27191 .04168 L
.27991 .11625 L
.28792 .04915 L
.29592 .07054 L
.30392 .04711 L
.31192 .0728 L
.31993 .06184 L
.32793 .08327 L
.33593 .058 L
.34394 .05412 L
.35194 .09105 L
.35994 .06346 L
.36795 .07812 L
.37595 .06606 L
.38395 .08691 L
.39196 .10778 L
.39996 .07524 L
.40796 .12452 L
.41597 .03465 L
.42397 .0546 L
Mistroke
.43197 .04571 L
.43998 .06103 L
.44798 .06162 L
.45598 .07239 L
.46399 .05119 L
.47199 .05603 L
.47999 .07816 L
.488 .06835 L
.496 .09922 L
.504 .05585 L
.512 .09241 L
.52001 .10439 L
.52801 .10558 L
.53601 .09546 L
.54402 .07701 L
.55202 .10802 L
.56002 .10003 L
.56803 .05321 L
.57603 .09023 L
.58403 .06583 L
.59204 .08957 L
.60004 .05327 L
.60804 .06803 L
.61605 .08093 L
.62405 .08993 L
.63205 .08391 L
.64006 .05463 L
.64806 .07897 L
.65606 .06161 L
.66407 .08941 L
.67207 .11953 L
.68007 .10433 L
.68808 .0986 L
.69608 .06348 L
.70408 .08692 L
.71208 .10109 L
.72009 .08773 L
.72809 .07187 L
.73609 .08537 L
.7441 .08194 L
.7521 .09543 L
.7601 .08197 L
.76811 .08187 L
.77611 .07202 L
.78411 .07581 L
.79212 .11295 L
.80012 .0759 L
.80812 .09623 L
.81613 .10818 L
.82413 .08612 L
Mistroke
.83213 .09266 L
.84014 .07866 L
.84814 .1111 L
.85614 .03215 L
.86415 .09816 L
.87215 .03526 L
.88015 .05068 L
.88816 .06546 L
.89616 .04248 L
.90416 .08741 L
.91216 .08853 L
.92017 .1153 L
.92817 .07316 L
.93617 .07825 L
.94418 .10472 L
.95218 .06859 L
.96018 .04607 L
.96819 .08273 L
.97619 .04513 L
Mfstroke
0 0 1 r
.03181 .05797 m
.03982 .13285 L
.04782 .05449 L
.05582 .13559 L
.06383 .06574 L
.07183 .10405 L
.07983 .07516 L
.08784 .17735 L
.09584 .06252 L
.10384 .12456 L
.11184 .0461 L
.11985 .13643 L
.12785 .06083 L
.13585 .1331 L
.14386 .08125 L
.15186 .12157 L
.15986 .06698 L
.16787 .12621 L
.17587 .05775 L
.18387 .12191 L
.19188 .07378 L
.19988 .11632 L
.20788 .07915 L
.21589 .14076 L
.22389 .08614 L
.23189 .11102 L
.2399 .05102 L
.2479 .12806 L
.2559 .0753 L
.26391 .12072 L
.27191 .02756 L
.27991 .10978 L
.28792 .13658 L
.29592 .11138 L
.30392 .13372 L
.31192 .09879 L
.31993 .08378 L
.32793 .08369 L
.33593 .11712 L
.34394 .12222 L
.35194 .06444 L
.35994 .1226 L
.36795 .06538 L
.37595 .13969 L
.38395 .06843 L
.39196 .13465 L
.39996 .04944 L
.40796 .09491 L
.41597 .12359 L
.42397 .1363 L
Mistroke
.43197 .10023 L
.43998 .131 L
.44798 .08772 L
.45598 .07203 L
.46399 .12402 L
.47199 .14158 L
.47999 .05915 L
.488 .13322 L
.496 .0559 L
.504 .15106 L
.512 .05953 L
.52001 .12788 L
.52801 .06091 L
.53601 .08026 L
.54402 .05719 L
.55202 .09197 L
.56002 .10106 L
.56803 .08604 L
.57603 .10065 L
.58403 .08578 L
.59204 .09549 L
.60004 .13112 L
.60804 .06652 L
.61605 .11981 L
.62405 .11369 L
.63205 .12041 L
.64006 .07764 L
.64806 .12323 L
.65606 .13774 L
.66407 .08777 L
.67207 .03464 L
.68007 .07166 L
.68808 .10595 L
.69608 .08132 L
.70408 .10989 L
.71208 .09134 L
.72009 .10977 L
.72809 .10275 L
.73609 .06055 L
.7441 .11038 L
.7521 .09233 L
.7601 .08801 L
.76811 .06633 L
.77611 .10764 L
.78411 .12883 L
.79212 .11142 L
.80012 .03948 L
.80812 .0813 L
.81613 .08026 L
.82413 .07212 L
Mistroke
.83213 .12875 L
.84014 .0876 L
.84814 .08837 L
.85614 .24405 L
.86415 .08498 L
.87215 .11167 L
.88015 .03694 L
.88816 .14693 L
.89616 .05655 L
.90416 .15584 L
.91216 .11087 L
.92017 .08651 L
.92817 .07829 L
.93617 .12088 L
.94418 .04513 L
.95218 .13451 L
.96018 .04542 L
.96819 .15258 L
.97619 .05054 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00DP3oool200000940oooo100000030?ooo`800000T03oool30000
0080oooo0P00002=0?ooo`<00000103oool2000008l0oooo0P0000040?ooo`800000R`3oool50000
0080oooo0P0000040?ooo`800000R03oool5000000030?ooo`0000000000008000000`3oool20000
0280oooo001A0?ooo`040000003oool0oooo00000900oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00002@0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0RP3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000008d0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00002<0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo00000240oooo001A0?ooo`040000003oool0oooo0000
0940oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00002=0?ooo`D0000000D0oooo
0000003oool0oooo0000002<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000S@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000008`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00008@3oool00540oooo00@000000?ooo`3oool00000TP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0R`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000008`0oooo0`0000030?ooo`040000003oool0oooo000008h0oooo0P0000030?ooo`040000
003oool0oooo000008`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`00D@3oool010000000oooo0?ooo`00
002@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000SP3oool00`000000
oooo000000020?ooo`040000003oool0oooo000008d0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00002=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
S03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01l0oooo001B0?ooo`800000TP3oool2000000@0oooo0P00002@
0?ooo`8000000`3oool2000008h0oooo0`0000030?ooo`800000S`3oool2000000@0oooo0P00002<
0?ooo`800000103oool2000000@0oooo0P0000290?ooo`800000103oool2000000@0oooo0P00000R
0?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00
o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo
0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0
ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3o
ool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?oo
o`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3o
oooo0?ooool0ooooo`3oool90?ooo`00?03ooooo00000?l00000o`00002c000001T0oooo000l0?oo
o`D000004P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`080?ooo`D000006@3oool003`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05`3o
ool00240oooo0P0000040?ooo`8000000`3oool4000000`0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0
oooo07H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`00803oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo1`00003o0?ooool0ooooo`3ooolS
0?ooo`030?l0003oool0oooo07l0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9`3oool0
0`3o0000oooo0?ooo`250?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolW0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool05`3oool00240oooo0P00000:
0?ooo`8000003@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`030?l0003oool0
oooo08D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo9`3oool00`3o0000oooo0?ooo`250?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0o`000?ooo`3o0000QP3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool500000?l0ooooo`3ooooo0?ooob@0oooo00<0o`000?ooo`3o0000
PP3oool5000001T0oooo000l0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3o
oooo0?ooom80oooo00<0o`000?ooo`3o0000QP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0ooooo`3ooooB0?ooo`030?l0003oool0
o`0008H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`3o0?ooool0oooodP3oool00`3o0000oooo0?l000260?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3ooooo0?ooom80
oooo00<0o`000?ooo`3o0000QP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo0?l0ooooo`3ooooB0?ooo`030?l0003oool0o`0008H0oooo
00<000000?ooo`3oool05`3oool003`0oooo1@00001>0?ooo`030?l0003oool0oooo0?l0ooooo`3o
oooB0?ooo`030?l0003oool0o`000880oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`1?
0?ooo`030?l0003oool0o`000?l0ooooo`3ooooC0?ooo`030?l0003oool0o`0008H0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?l0003o0?oo
ool0ooood`3oool00`3o0000oooo0?l000260?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo04l0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooom80oooo00@0o`000?ooo`3o
ool0o`00QP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1?0?ooo`03
0?l0003oool0o`000?l0ooooo`3ooooB0?ooo`050?l0003oool0oooo0?ooo`3o0000Q@3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0o`000?l0
ooooo`3ooooB0?ooo`050?l0003oool0oooo0?ooo`3o0000Q@3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool5000004d0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooom80oooo00D0o`000?ooo`3o
ool0oooo0?l000210?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0C`3oool00`3o0000
oooo0?l0002/0?ooo`030000o`3oool0oooo0?l0ooooo`3ooolS0?ooo`050?l0003oool0oooo0?oo
o`3o0000Q@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1?0?ooo`03
0?l0003oool0o`000:`0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooob<0oooo00D0o`000?ooo`3o
ool0oooo0?l000250?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3o0000[03oool00`000?l0oooo0?ooo`3o0?ooool0oooo8`3oool01@3o0000
oooo0?ooo`3oool0o`0008D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0?l0002/0?ooo`030000o`3oool0oooo0?l0ooooo`3ooolS0?ooo`05
0?l0003oool0oooo0?ooo`3o0000Q@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`1>0?ooo`040?l0003oool0oooo0?l00:`0oooo00<0003o0?ooo`3oool0o`3ooooo0?oo
ob<0oooo00D0o`000?ooo`00o`00oooo0?l000250?ooo`030000003oool0oooo01L0oooo000l0?oo
o`D00000C03oool0103o0000oooo0?ooo`3o002/0?ooo`030000o`3oool0oooo0?l0ooooo`3ooolS
0?ooo`050?l0003oool00?l00?ooo`3o0000P@3oool5000001T0oooo000l0?ooo`030000003oool0
oooo04h0oooo00D0o`000?ooo`3oool0oooo0?l0002Z0?ooo`030000o`3oool0003o0?l0ooooo`3o
oolS0?ooo`060?l0003oool0oooo003o003oool0o`00Q@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`1>0?ooo`050?l0003oool0oooo0?ooo`3o0000ZP3oool00`000?l0
oooo0000o`250?ooo`03003o003oool0oooo0>l0oooo00<0003o0?ooo`3oool0Y`3oool01P3o0000
oooo0?ooo`00o`00oooo0?l000`0oooo00<00?l00?ooo`3oool0MP3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`1>0?ooo`050?l0003oool0oooo0?ooo`3o0000ZP3oool0
0`000?l0oooo0000o`250?ooo`03003o003oool0oooo0>l0oooo00<0003o0?ooo`3oool0Y`3oool0
0`3o0000oooo0?ooo`02003o00030?ooo`3o0000oooo00X0oooo0P00o`1g0?ooo`030000003oool0
oooo01L0oooo000K0?ooo`800000103oool2000000<0oooo100000030?ooo`8000003@3oool00`00
0000oooo0?ooo`1>0?ooo`050?l0003oool0oooo0?ooo`3o0000ZP3oool00`000?l0oooo0000o`25
0?ooo`800?l0l03oool00`000?l0oooo0?ooo`2W0?ooo`030?l0003oool0oooo00800?l000<0oooo
0?l0003oool02P3oool2003o00H0oooo00<0003o0?ooo`3oool0KP3oool00`000000oooo0?ooo`0G
0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000303oool00`000000oooo0?ooo`1>0?ooo`050?l0003oool0oooo0?ooo`3o0000
ZP3oool00`000?l0oooo0000o`250?ooo`800?l0l03oool20000ojP0oooo00L0o`000?ooo`00o`00
oooo003o003oool0o`0000/0oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`1^0?oo
o`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`L00000BP3oool01@3o0000oooo0?ooo`3oool0
o`0002X0oooo00<0o`000?ooo`3oool0O@3oool00`000?l0oooo0000o`1_0?ooo`030?l0003oool0
oooo01<0oooo00<00?l00?ooo`00o`00kP3oool00`000?l0oooo0000o`1f0?ooo`030000o`3oool0
oooo02l0oooo00L0o`000?ooo`00o`00oooo003o003oool0o`0000/0oooo00<00?l00?ooo`00o`00
1@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0540oooo1`00000I0?ooo`006P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000
003oool0oooo04h0oooo00D0o`000?ooo`3oool0oooo0?l0000Z0?ooo`030?l0003oool0oooo07d0
oooo00<0003o0?ooo`000?l0K`3oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool00?l00>h0
oooo00<0003o0?ooo`000?l0MP3oool00`000?l0oooo0?ooo`0_0?ooo`070?l0003oool00?l00?oo
o`00o`00oooo0?l0000:0?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo05L0oooo00<000000?ooo`3oool05`3oool001X0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0CP3oool01@3o0000oooo0?ooo`3oool0o`0002X0oooo00<0o`000?ooo`3o
ool0O@3oool00`000?l00?l00000o`1_0?ooo`030?l0003oool0oooo0180oooo00D00?l00?ooo`3o
ool0oooo003o003]0?ooo`030000o`3oool0003o07H0oooo00<0003o0?ooo`3oool0;`3oool01`3o
0000oooo003o003oool00?l00?ooo`3o00002P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`1G0?ooo`030000003oool0oooo01L0oooo
000K0?ooo`8000002P3oool2000000@0oooo0`00000<0?ooo`030000003oool0oooo04h0oooo00D0
o`000?ooo`3oool0oooo0?l0000Z0?ooo`030?l0003oool0oooo07d0oooo00<0003o003o00000?l0
K`3oool00`3o0000oooo0?ooo`0B0?ooo`05003o003oool0oooo0?ooo`00o`00k@3oool00`000?l0
oooo0000o`1f0?ooo`80003o<03oool01`3o0000oooo003o003oool00?l00?ooo`3o00002P3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080003o3P3oool00`00o`00oooo0?ooo`05
0?ooo`80o`00F03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1=0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0:03oool20?l007h0oooo00<0003o003o
00000?l0K`3oool00`3o0000oooo0?ooo`0B0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool0jP3oool010000?l0oooo0?ooo`000?me0?ooo`80003o<03oool01`3o0000oooo003o003o
ool00?l00?ooo`3o00002P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080003o
3P3oool00`00o`00oooo0?ooo`050?ooo`80o`00F03oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0:03o
ool20?l007h0oooo00<0003o003o00000?l0K`3oool00`3o0000oooo0?ooo`0B0?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool0jP3oool010000?l0oooo0?ooo`000?md0?ooo`030000
o`3oool0003o02l0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00o`000?ooo`090?ooo`03
003o003oool0oooo00<0oooo00@00?l00?ooo`000?l0003o3@3oool2003o00L0oooo0P3o000S0?oo
o`030000o`3oool0oooo01/0oooo00<00?l00?ooo`3oool0503oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`1=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0C0?ooo`80o`003P3oool00`3o0000oooo0?ooo`1/0?ooo`05
0000o`00o`000?l00?ooo`000?l0K@3oool20?l001@0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`090?ooo`03003o003oool0oooo0=d0oooo00D0003o0?ooo`3oool0oooo0000o`1d
0?ooo`030000o`3oool0003o02l0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00o`000?oo
o`090?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`000?l0oooo0000o`0<0?ooo`03003o
003oool00?l000H0oooo0P3o000S0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000B`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo06`0oooo00D0003o003o0000o`00oooo
0000o`0K0?ooo`03003o003oool0oooo04l0oooo0P3o000D0?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool01`3oool2003o0=l0oooo00D0003o0?ooo`3oool0oooo0000o`1d0?ooo`03
0000o`3oool0003o02l0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00o`000?ooo`090?oo
o`03003o003oool0oooo00@0oooo00@00?l00000o`3oool0003o303oool00`00o`00oooo003o0006
0?ooo`80o`008`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0@0?ooo`D000006@3oool003`0oooo00<000000?oo
o`3oool0C@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo06`0oooo00D0003o003o
003oool00?l00000o`0K0?ooo`03003o003oool0oooo04l0oooo00<0o`000?ooo`3o00004`3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool00?l0gP3o
ool01@000?l0oooo0?ooo`3oool0003o07@0oooo00@0003o0?ooo`3oool0003o;P3oool0103o0000
oooo0?ooo`00o`020?ooo`03003o003oool0o`0000T0oooo00<00?l00?ooo`3oool0103oool01000
o`00003o0?ooo`000?l;0?ooo`04003o003oool0oooo003o00H0oooo0P3o000S0?ooo`030000o`3o
ool0oooo00/0oooo00<00?l00000o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`03003o003o
ool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0C@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo06`0oooo00D0003o003o003oool00?l00000
o`0<0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`00o`00D03oool00`3o0000oooo0?l0
00050?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`040?ooo`05003o003oool0oooo0?ooo`00o`00gP3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0740oooo00@0003o0?ooo`3oool0003o;P3oool0103o0000oooo0?ooo`00o`020?oo
o`03003o003oool0o`0000P0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0000o`0;0?oo
o`04003o003oool0oooo003o00D0oooo00@0o`000?ooo`3oool0o`008P3oool00`000?l0oooo0?oo
o`0;0?ooo`03003o00000?l00?l000H0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0E0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04d0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<00?l0
0?ooo`3oool02`3oool00`3o0000oooo0?l0000=0?ooo`80o`00>`3oool00`3o0000oooo0?ooo`0`
0?ooo`050000o`00o`00oooo003o00000?l0303oool00`00o`00oooo0?ooo`0;0?ooo`03003o003o
ool00?l00500oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo04d0oooo00<0o`000?ooo`3oool0R`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0740oooo00@0003o0?ooo`3oool0003o;P3oool00`3o0000oooo003o00030?ooo`03003o
003oool0o`0000P0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0000o`0:0?ooo`05003o
003oool0oooo0?ooo`00o`001@3oool0103o0000oooo0?ooo`3o000R0?ooo`030000o`3oool0oooo
00/0oooo00<00?l00000o`00o`001P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
01D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0<P3oool2003o01T0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`80003o1P3oool00`00o`00
oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000`0oooo0P3o000k0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool06@3oool01@000?l00?l00?ooo`00o`00003o00`0oooo0P00o`0<
0?ooo`03003o003oool00?l00500oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`0;
0?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`03003o003o
ool0oooo01T0oooo00<00?l00?ooo`3oool0<@3oool00`3o0000oooo0?ooo`2;0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0L@3oool010000?l0oooo0?ooo`000?l^0?ooo`030?l0
003oool00?l000<0oooo00<00?l00?ooo`3o0000203oool00`00o`00oooo0?ooo`060?ooo`030000
o`00o`00003o00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`040?l0
003oool0oooo0?l00240oooo00<0003o0?ooo`000?l02`3oool01000o`00oooo0000o`00o`060?oo
o`030?l0003oool0oooo00<0oooo00<00?l00000o`3oool05@3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0b0?ooo`04003o003oool00?l0003o01L0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`80003o1P3oool00`00o`00oooo0?ooo`0;0?oo
o`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o0000>P3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool01@000?l00?l00?ooo`00
o`00003o00`0oooo0P00o`0;0?ooo`04003o003oool0oooo003o0500oooo00<0o`000?ooo`3o0000
1@3oool20000o``0oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`00o`080?ooo`03
003o003oool0oooo01P0oooo0`00o`0a0?ooo`030?l0003oool0oooo08X0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1a0?ooo`040000o`3oool0oooo0000obh0oooo00<0o`000?oo
o`00o`000`3oool00`00o`00oooo0?l000080?ooo`03003o003oool0oooo00D0oooo00@0003o0?oo
o`00o`00003o2P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00@0o`00
0?ooo`3oool0o`008@3oool00`000?l0oooo0000o`0;0?ooo`04003o00000?l0003o003o00H0oooo
00<0o`000?ooo`3oool00`3oool00`00o`00003o0?ooo`0E0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`D00000;`3oool00`00o`00oooo0?ooo`020?ooo`<00?l0503oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo003o
000<0?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o0000>P3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool01@000?l00?l0
0?ooo`00o`00003o00/0oooo00<00?l00?ooo`00o`002`3oool01@00o`00oooo0?ooo`3oool00?l0
04l0oooo00<0o`000?ooo`3o00001@3oool20000o``0oooo00<00?l00?ooo`3oool01P3oool2003o
00T0oooo00<00?l00?ooo`3oool05`3oool01@00o`00oooo0?ooo`3oool00?l00300oooo00<0o`00
0?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo03h0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1a0?ooo`050000o`3oool0oooo0?ooo`000?l0;@3o
ool00`3o0000oooo003o00040?ooo`03003o003o0000oooo00L0oooo00<00?l00?ooo`3oool01@3o
ool010000?l0oooo0?ooo`000?l90?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0P3oool0103o0000oooo0?ooo`3o000Q0?ooo`030000o`3oool0003o00/0oooo00D00?l00000o`3o
ool0003o003o00050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`000?l04P3oool50000
01T0oooo000l0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`050?ooo`800?l04@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo003o000<0?ooo`040?l0003oool0oooo0?l0
00`0oooo00<0o`000?ooo`3o0000703oool4003o01T0oooo0P3o000F0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`00o`00003o00/0oooo00@00?l0
0?ooo`3oool00?l02@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0240oooo00<0
0?l00?ooo`3oool0:@3oool00`3o0000oooo0?l000050?ooo`80003o2`3oool00`00o`00oooo0?oo
o`070?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo02d0oooo0P3o000/0?ooo`03003o003oool0oooo01/0oooo00<0
0?l00?ooo`3oool08`3oool00`00o`00oooo0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0L03oool01@000?l0oooo0?ooo`3oool0003o02d0oooo00<0o`000?ooo`00o`00
103oool00`00o`00o`000?ooo`070?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0
003o2@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00@0o`000?ooo`3o
ool0o`008@3oool00`000?l0oooo0000o`0:0?ooo`06003o003oool0003o0?ooo`000?l00?l01@3o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool0003o01H0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0
oooo00H0oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo003o000<0?ooo`040?l0003oool0
oooo0?l000`0oooo00<0o`000?ooo`3o0000703oool01000o`00oooo0?ooo`3oool4003o01D0oooo
0P3o000E0?ooo`80003o5@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo003o0000
0?l02`3oool01000o`00oooo0?ooo`00o`090?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool07`3oool3003o02/0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`0;0?oo
o`03003o003oool0oooo01<0oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`040?oo
o`800?l0;@3oool20?l002`0oooo00<00?l00?ooo`3oool06`3oool2003o02@0oooo00<00?l00?oo
o`3oool0603oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06l0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool00?l000@0oooo00<00?l00?l0
003oool01`3oool00`00o`00oooo0?ooo`050?ooo`050000o`3oool0oooo0000o`00o`00203oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0
000P0?ooo`030000o`3oool0003o00X0oooo00H00?l00?ooo`000?l0oooo0000o`00o`050?ooo`03
0?l0003oool0oooo0080oooo00<00?l00?ooo`000?l05P3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0000o`040?ooo`03003o003oool00?l000`0oooo00@0o`000?ooo`3oool0
o`002`3oool0103o0000oooo0?ooo`3o000K0?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool04`3oool00`3o0000oooo0?l0000D0?ooo`80003o5@3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo003o00000?l0103oool00`3o0000oooo0?ooo`040?ooo`04003o003oool0
oooo003o00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0L0?ooo`800?l00P3o
ool00`00o`00oooo0?ooo`0X0?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`000?l0
2`3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo01@0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0D0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0
2`3oool00`3o0000oooo0?l0000[0?ooo`03003o003oool00?l001/0oooo00<00?l00?ooo`00o`00
8`3oool00`00o`00oooo003o000I0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
K`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02X0oooo00@0o`000?ooo`3oool0
0?l0103oool00`00o`00o`000?ooo`070?ooo`03003o003oool0oooo00D0oooo00D0003o0?ooo`3o
ool0003o003o00070?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`00o`00103oool01@3o
0000oooo0?ooo`3oool0o`000200oooo00<0003o0?ooo`000?l02P3oool01P00o`00oooo0000o`3o
ool0003o003o00@0oooo0P3o00040?ooo`03003o003oool0003o01H0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo00P0oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo003o000<0?ooo`040?l0003o
ool0oooo0?l000/0oooo00@0o`000?ooo`3oool0o`00503oool00`000?l0oooo0?ooo`040?ooo`03
003o003oool0oooo00D0oooo00<00?l00?ooo`3oool04`3oool00`3o0000oooo0?l0000D0?ooo`03
0000o`3oool0003o01@0oooo00<0o`000?ooo`3oool00P3oool01`000?l00?l00?ooo`3oool00?l0
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`00o`001`3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01X0oooo0P00o`050?ooo`03003o003o
ool0oooo02L0oooo00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0000o`0;0?ooo`03003o
003oool0oooo01@0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`0;0?ooo`030?l0
003oool0o`0001D0oooo00<0003o0?ooo`3oool04`3oool00`00o`00oooo003o000K0?ooo`04003o
003oool0oooo003o0280oooo00<00?l00?ooo`00o`006@3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo06X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo02X0oooo00@0o`000?ooo`3oool00?l0103oool00`00o`00o`000?ooo`070?oo
o`03003o003oool0oooo00D0oooo00H0003o0?ooo`3oool0003o0?ooo`00o`060?ooo`03003o003o
ool0oooo0080oooo00@0003o0?ooo`3oool00?l00`3oool01@3o0000oooo0?ooo`3oool0o`000200
oooo00<0003o0?ooo`000?l02@3oool02000o`00oooo0?ooo`000?l0oooo0000o`3oool00?l00`3o
ool00`3o0000oooo0?l000030?ooo`03003o003oool0003o01H0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0080oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0000o`040?ooo`04003o003oool0
oooo003o00/0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`040?l0003oool0oooo0?l001@0
oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0180
oooo00<0o`000?ooo`3o0000503oool00`000?l0oooo0000o`0C0?ooo`80o`00103oool00`000?l0
0?l00?ooo`020?ooo`03003o00000?l0oooo0080oooo00<0o`000?ooo`3oool0103oool01@00o`00
oooo0?ooo`3oool00?l000L0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0H0?oo
o`800?l01`3oool00`00o`00oooo0?ooo`0W0?ooo`040?l0003oool0oooo0?l000@0oooo00@0003o
0?ooo`3oool0003o2P3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo0180oooo00<0
0?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0
0?l00?ooo`3oool02`3oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo01<0oooo00<0
0?l00?ooo`00o`006`3oool01000o`00oooo0?ooo`00o`0R0?ooo`03003o003oool00?l001P0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1Y0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Y0?ooo`040?l0003oool0oooo003o00@0
oooo00<00?l00?ooo`3o00001P3oool00`00o`00oooo0?ooo`060?ooo`060000o`3oool0oooo0000
o`3oool00?l01P3oool00`00o`00oooo0?ooo`020?ooo`040000o`3oool0oooo003o00<0oooo00D0
o`000?ooo`3oool0oooo0?l0000P0?ooo`030000o`3oool0003o00T0oooo00P00?l00?ooo`3oool0
003o0?ooo`000?l0oooo003o00<0oooo00<0o`000?ooo`3o00000P3oool00`00o`00oooo0000o`0G
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D000006@3oool00`000?l0oooo0?ooo`0<0?oo
o`80003o0`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00h0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0003o00<0oooo00D00?l00?oo
o`3oool0oooo003o000:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool0
103o0000oooo0?ooo`3o000D0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0o`0001@0oooo00<0003o0?ooo`000?l04`3o
ool20?l000@0oooo00<0003o003o003oool00P3oool00`00o`00003o0?ooo`020?ooo`80o`001@3o
ool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`0H0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool09`3oool0103o0000oooo
0?ooo`3o00040?ooo`040000o`3oool0oooo0000o`X0oooo00<00?l00?ooo`3oool05@3oool00`00
o`00oooo0?ooo`0B0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`00o`001P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0o`0001@0oooo0P000?lE0?ooo`03003o003oool00?l0
01/0oooo00D00?l00?ooo`3oool0oooo003o000Q0?ooo`04003o003oool0oooo003o01L0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1X0?ooo`80o`00103oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo02T0oooo00@0o`000?ooo`3oool00?l0103oool00`00o`00oooo
0?l000060?ooo`03003o003oool0oooo00H0oooo00@0003o0?ooo`3oool0003o0P3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00@0003o0?ooo`3oool00?l00`3oool01@3o
0000oooo0?ooo`3oool0o`000200oooo00<0003o0?ooo`000?l02@3oool02000o`00oooo0?ooo`00
0?l0oooo0000o`3oool00?l00`3oool00`3o0000oooo0?l000020?ooo`03003o003oool0003o01<0
oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00D0oooo
00<00?l00?ooo`3oool0103oool00`000?l0oooo0000o`020?ooo`03003o003oool0oooo00T0oooo
00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00h0oooo
00@0003o0?ooo`3oool0003o0`3oool01@00o`00oooo0?ooo`3oool00?l000D0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00@0o`000?oo
o`3oool0o`00503oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo00<00?l0
0?ooo`3oool04@3oool0103o0000oooo0?ooo`3o00050?ooo`03003o003oool0oooo00`0oooo00<0
003o0?ooo`000?l04`3oool20?l000@0oooo00<0003o003o003oool00P3oool00`00o`00003o0?oo
o`020?ooo`80o`001@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3oool09`3oool0103o0000oooo0?ooo`3o00040?ooo`040000o`3oool0oooo0000o`X0
oooo00<00?l00?ooo`3oool05P3oool4003o00l0oooo00<00?l00?ooo`3oool02P3oool00`00o`00
oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo003o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o00001P3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0003o01@0oooo00<00?l00?ooo`00o`006P3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo01h0oooo00D00?l00?ooo`3oool0oooo003o000G0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`0a0?oo
o`80o`00103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo003o00050?ooo`03003o003oool0o`0000H0oooo00<00?l00?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`030?ooo`040000o`3oool0oooo003o00<0oooo00D0o`000?ooo`3oool0oooo
0?l0000P0?ooo`030000o`3oool0003o00T0oooo00P00?l00?ooo`3oool0003o0?ooo`000?l0oooo
003o00<0oooo00<0o`000?ooo`3o00000P3oool00`00o`00oooo0000o`0G0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01@3oool2003o
00D0oooo00D0003o0?ooo`000?l0oooo003o000<0?ooo`03003o003oool0oooo00h0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0000o`<0oooo00D0
0?l00?ooo`3oool0oooo003o00050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l001@0oooo0P000?l40?ooo`03
003o003oool0oooo00L0oooo00<00?l00?ooo`3oool04@3oool0103o0000oooo0?ooo`3o00050?oo
o`800?l03@3oool00`000?l0oooo0000o`0C0?ooo`80o`00103oool00`000?l00?l00?ooo`020?oo
o`03003o00000?l0oooo0080oooo0P3o00040?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<00?l00?oo
o`3oool02`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo02L0oooo00@0o`000?oo
o`3oool0o`00103oool010000?l0oooo0?ooo`000?l:0?ooo`03003o003oool0oooo01X0oooo1@00
o`0:0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0;0?ooo`80003o1@3oool00`00o`00oooo003o00060?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0003o01@0oooo00@0
0?l00?ooo`3oool00?l06@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01d0oooo
00D00?l00?ooo`3oool0oooo003o000<0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo0300oooo00<0o`000?ooo`3o
0000103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool03P3oool00`3o0000oooo003o00060?ooo`03003o003o0000oooo00D0oooo00<00?l00?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo003o0080oooo00<00?l00?oo
o`3oool0103oool010000?l0oooo0?ooo`00o`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0703oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00T00?l00?ooo`3oool0oooo
0000o`3oool0003o0?ooo`00o`000`3oool00`3o0000oooo0?l000020?ooo`03003o003oool0003o
01L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool06`3oool00`000?l0
oooo0?ooo`040?ooo`03003o003oool00?l000D0oooo00D0003o0?ooo`000?l0oooo003o000<0?oo
o`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
003o00`0oooo00@0003o0?ooo`3oool0003o0`3oool01@00o`00oooo0?ooo`3oool00?l000D0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo
00D0o`000?ooo`3oool0oooo0?l0000C0?ooo`030000o`3oool0003o00@0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3o
ool0o`001@3oool00`00o`00oooo003o000;0?ooo`040000o`3oool0oooo0000oa<0oooo00<0o`00
0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`03003o00000?l0oooo0080oooo0P3o0004
0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`06
0?ooo`03003o003oool0oooo00L0oooo0P00o`0=0?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?ooo`3oool09P3oool0103o0000oooo0?ooo`3o00040?ooo`040000o`3oool0oooo0000o`D0oooo
00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0O0?ooo`03003o003oool0oooo00L0oooo
00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo
0P000?l50?ooo`03003o003oool00?l000H0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo
0?ooo`3o00050?ooo`80003o2`3oool010000?l0oooo0?ooo`000?lC0?ooo`05003o003oool0oooo
0?ooo`00o`006@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01d0oooo00D00?l0
0?ooo`3oool0oooo003o000;0?ooo`800?l02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo03@0oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?l000040?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool00?l000H0oooo00<00?l00?l0003oool01@3oool00`00o`00oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00@0003o0?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`030?ooo`030000
o`3oool0003o0080oooo00@00?l00?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`0L0?ooo`05
0000o`3oool0oooo0?ooo`000?l01`3oool01`00o`00oooo0?ooo`3oool0003o0?ooo`000?l00P3o
ool01P00o`00oooo0?ooo`3o0000oooo0?l00080oooo00<00?l00?ooo`000?l05`3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00<0oooo
00@00?l00?ooo`3oool00?l0103oool01@000?l0oooo0000o`3oool00?l000d0oooo00<00?l00?oo
o`3oool03@3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l0303oool0
10000?l0oooo0?ooo`000?l30?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`000?l0103o
ool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3o
ool0103o0000oooo0?ooo`3o00040?ooo`05003o003oool0oooo0?ooo`00o`002P3oool010000?l0
oooo0?ooo`000?lC0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`00
o`00003o0?ooo`020?ooo`80o`00103oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo
0?ooo`00o`002@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool00?l000/0oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo01T0oooo00@0o`00
0?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`0O0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
303oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`000?l0
103oool01000o`00oooo0?ooo`00o`050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o
ool0o`001@3oool20000o`/0oooo00@0003o0?ooo`3oool0003o4`3oool01@00o`00oooo0?ooo`3o
ool00?l001T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0K0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo003o00090?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`0R0?ooo`030000o`3o
ool0003o0300oooo00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo003o00060?ooo`03003o
003o0000oooo00D0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`070000
o`3oool0oooo0?ooo`00o`00oooo003o00050?ooo`030000o`3oool0003o0080oooo00@00?l00?oo
o`3oool0o`00103oool00`3o0000oooo0?ooo`0L0?ooo`050000o`3oool0oooo0?ooo`000?l01`3o
ool01`00o`00oooo0?ooo`3oool0003o0?ooo`000?l00P3oool02000o`00oooo0?ooo`3o0000oooo
0?l0003oool00?l00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00@0003o0?ooo`000?l00?l03P3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`0<0?ooo`040000o`3oool0oooo0000
o`80oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0000o`030?ooo`03003o003oool0oooo
00T0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo
0?l000@0oooo00<00?l00?ooo`3oool00P3oool2003o00P0oooo00@0003o0?ooo`3oool0003o4`3o
ool00`3o0000oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<00?l00000o`3oool00P3o
ool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo
003o000:0?ooo`03003o003oool0oooo00D0oooo00@00?l00?ooo`3oool00?l02`3oool00`00o`00
oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0P0?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`3oool0303oool01`00o`00oooo0?ooo`3oool0003o0?ooo`000?l0
303oool00`000?l0oooo0000o`040?ooo`04003o003oool0oooo003o00D0oooo0P000?l40?ooo`04
0?l0003oool0oooo0?l000@0oooo00@0003o0?ooo`3oool0003o2P3oool01@000?l0oooo0?ooo`3o
ool0003o0180oooo00D00?l00?ooo`3oool0oooo003o000H0?ooo`03003o003oool0oooo00D0oooo
00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo
00@00?l00?ooo`3oool00?l02@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00d0
oooo00<00?l00?ooo`3oool08P3oool00`000?l0oooo0000o`0`0?ooo`040?l0003oool0oooo0?l0
00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0o`00
00l0oooo00<0o`000?ooo`00o`001P3oool00`00o`00o`000?ooo`050?ooo`03003o003oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool2003o00H0oooo00<0003o
0?ooo`000?l00P3oool01000o`00oooo0?ooo`3o00040?ooo`030?l0003oool0oooo01`0oooo00D0
003o0?ooo`3oool0oooo0000o`060?ooo`05003o003oool0oooo0?ooo`000?l00P3oool010000?l0
oooo0?ooo`00o`020?ooo`050?l0003oool0o`000?ooo`00o`000P3oool00`000?l0oooo0?ooo`0E
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D000006P3oool00`000?l0oooo0?ooo`030?oo
o`03003o003oool0oooo0080oooo00L00?l00?ooo`3oool0003o0?ooo`000?l00?l000`0oooo00<0
003o0?ooo`00o`003P3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`000?l0
303oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00o`001@3oool01`00o`00oooo0?ooo`3oool0
003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0003o00<0oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`80o`002`3oool0103o0000oooo0?oo
o`3o00040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool010000?l0oooo
0?ooo`000?l50?ooo`03003o003oool0oooo00/0oooo00<0o`000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`020?ooo`03003o00000?l0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`00o`00
oooo0?ooo`050?ooo`03003o003oool00?l000/0oooo00<00?l00?ooo`3oool0103oool01@00o`00
oooo0?ooo`3oool00?l000/0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`050?oo
o`03003o003oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0240oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0=0?ooo`07003o003oool0oooo0?ooo`000?l0
oooo0000o`0<0?ooo`030000o`3oool0003o00<0oooo00D00?l00?ooo`3oool0oooo003o00040?oo
o`030000o`3oool0003o00@0oooo00@0o`000?ooo`3oool0o`00103oool010000?l0oooo0?ooo`00
0?l90?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool01@00o`00oooo0?oo
o`3oool00?l000`0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo01X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`04003o
003oool0oooo003o00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`80
0?l08`3oool00`000?l0oooo0000o`0L0?ooo`030000o`3oool0oooo0140oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?l0000?0?ooo`030?l0003oool00?l000H0oooo00<00?l00?l0003oool01@3oool00`00
o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00
o`00oooo0?ooo`040?ooo`030000o`3oool0003o0080oooo00@00?l00?ooo`3oool0o`00103oool0
0`3o0000oooo0?ooo`0L0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool01@00o`00oooo0?oo
o`3oool0003o00<0oooo00<0003o0?ooo`00o`000P3oool01@3o0000oooo0?l0003oool00?l00080
oooo00<0003o0?ooo`3oool04@3oool5000001T0oooo000l0?ooo`030000003oool0oooo01`0oooo
00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`07003o003oool0oooo0000o`3o
ool0003o003o000<0?ooo`030000o`3oool00?l000h0oooo00<0o`000?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool0003o00`0oooo00L0003o0?ooo`3oool0oooo0000o`3oool00?l000D0oooo
00L00?l00?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l00`3oool00`00
o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0oooo0P3o000:0?ooo`050?l0003oool0oooo
0?ooo`3o0000103oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00@0003o
0?ooo`3oool0003o103oool00`00o`00oooo003o000<0?ooo`030?l0003oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0o`0000<0oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool00?l000D0oooo00<0
003o0?ooo`3oool0103oool2003o00/0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l002@0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0>0?ooo`06003o003oool0oooo0000
o`3oool0003o303oool00`000?l0oooo0000o`030?ooo`05003o003oool0oooo0?ooo`00o`00103o
ool00`000?l0oooo0000o`040?ooo`040?l0003oool0oooo0?l000@0oooo00D0003o0?ooo`3oool0
oooo0000o`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool02@3oool00`00o`00
oooo0?ooo`060?ooo`03003o00000?l0oooo01X0oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`00o`00203oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00`0oooo00<00?l00?ooo`00o`008`3oool00`000?l0oooo0000o`0L0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l7
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3o00003P3oool0103o0000oooo0?ooo`00
o`060?ooo`03003o003o0000oooo00@0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?l0
00050?ooo`030?l0003oool0oooo01`0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`05003o
003oool0oooo0?ooo`000?l00`3oool02P000?l0oooo0?ooo`00o`00oooo0?l0003oool0o`000?oo
o`00o`020?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00D0
0?l00?ooo`000?l0oooo0000o`0=0?ooo`030000o`3oool00?l000h0oooo00<0o`000?ooo`3oool0
1P3oool0103o0000oooo0?ooo`3oool20000o`/0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0
0?l000D0oooo00L00?l00?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l0
0P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00<0oooo0P3o000:0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`04003o003oool0oooo003o00/0oooo00<0o`00
0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`05003o00000?l0oooo0?ooo`3o00000P3o
ool01@3o0000oooo0?ooo`3oool00?l000L0oooo00<00?l00?ooo`00o`00303oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?ooo`0;0?ooo`05003o003oool0oooo0?ooo`000?l01P3oool01000o`00oooo0?ooo`00o`040?oo
o`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`02
0?ooo`80o`000P3oool00`00o`00oooo0?ooo`0S0?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool03P3oool01P00o`00oooo0?ooo`000?l0oooo0000o`D0oooo00<00?l00?ooo`3oool0
103oool00`000?l0oooo0000o`030?ooo`03003o003oool0oooo0080oooo00L00?l00?ooo`3oool0
oooo0000o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l000X0oooo00<0
0?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0H0?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool00?l002<0oooo00<0
003o0?ooo`000?l06`3oool20000oa80oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?oo
o`000?l70?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3o00003P3oool0103o0000oooo
0?ooo`00o`060?ooo`03003o003o0000oooo00@0oooo00<00?l00?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`000?l00`3oool00`00o`00
o`000?ooo`050?ooo`030?l0003oool0oooo01/0oooo00D0003o0?ooo`3oool0oooo0000o`050?oo
o`03003o003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`07003o003oool0
o`000?ooo`3o0000oooo003o00020?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo00D0oooo00@0003o0?ooo`3oool0003o3@3oool20000o`030?ooo`00o`00oooo00`0oooo
00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool20000o`/0oooo00L0003o0?ooo`3o
ool0oooo0000o`3oool00?l000H0oooo00H00?l00?ooo`3oool0003o0?ooo`000?l30?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo003o00040?ooo`030000
o`3oool0003o0080oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`020?ooo`030?l0
003oool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`0:0?ooo`03
003o003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`05003o003oool0oooo
0?ooo`00o`002P3oool0103o0000oooo0?ooo`3o00020?ooo`030000o`00o`00oooo00@0oooo00@0
0?l00000o`3oool0o`000`3oool0103o0000oooo0?ooo`00o`080?ooo`03003o003oool0oooo00/0
oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool02`3oool01P00o`00oooo0?ooo`000?l0oooo0000o`@0oooo00D00?l00?ooo`3oool0oooo
003o00040?ooo`030000o`3oool0oooo00<0oooo00@00?l00?ooo`3oool00?l01@3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool01P00
0?l0oooo0?ooo`3o0000oooo0?l00080oooo00<00?l00?ooo`3oool0903oool01000o`00oooo0?oo
o`00o`0B0?ooo`05003o003oool0003o0?ooo`000?l0103oool2003o00H0oooo00<0003o0?ooo`00
0?l00`3oool00`00o`00oooo0?ooo`020?ooo`07003o003oool0oooo0?ooo`000?l0oooo0000o`03
0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool0203oool00`00o`00oooo003o00090?ooo`03003o003oool0oooo00P0oooo
00<0003o003o003oool0603oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool02`3oool01000o`00oooo0?ooo`00o`0R0?ooo`030000o`3oool0003o01/0
oooo00<0003o0?ooo`000?l0403oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000
o`P0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?l0000>0?ooo`040?l0003oool0oooo
003o00L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0000o`030?ooo`03003o003o0000
oooo00D0oooo00<0o`000?ooo`3oool06`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0
0?l00?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00L00?l00?ooo`3o0000
oooo0?l0003oool00?l00080oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?oo
o`008@3oool2000000@0oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool010000?l00?l00?ooo`000?l=0?oo
o`80003o00<0oooo003o003oool0303oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0003o
0?ooo`000?l02`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00o`001P3oool01P00o`00oooo
0?ooo`000?l0oooo0000o`<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`03003o003oool00?l000@0oooo00H0003o0?ooo`3oool0003o0?ooo`00o`0<0?ooo`03003o003o
ool0oooo0080oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003o
ool0oooo003o00/0oooo00@00?l00?ooo`3oool0003o103oool00`000?l0oooo003o00050?ooo`03
003o003oool0oooo00L0oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l00?l00?ooo`040?oo
o`04003o00000?l0oooo0?l000<0oooo00<0o`000?ooo`00o`002@3oool00`00o`00oooo0?ooo`0;
0?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0<0?ooo`06003o003oool0oooo0000o`3oool0003o103oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo0080003o103oool01@00o`00oooo0?ooo`3oool00?l000D0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`D0oooo00H0003o
0?ooo`3oool0o`000?ooo`3o00020?ooo`03003o003oool0oooo02D0oooo00<00?l00?ooo`00o`00
4P3oool01@00o`00oooo0000o`3oool0003o00@0oooo00<00?l00?ooo`00o`001@3oool00`000?l0
oooo0000o`030?ooo`03003o003oool0oooo0080oooo00L00?l00?ooo`3oool0oooo0000o`3oool0
003o00<0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l000T0oooo00<0
0?l00?ooo`3oool0203oool00`000?l00?l00?ooo`0H0?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00D0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`04003o003oool0oooo003o0240oooo
00D0003o0?ooo`3oool0oooo0000o`0J0?ooo`030000o`3oool0003o0100oooo00<0o`000?ooo`3o
ool00`3oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3oool0oooo01D0oooo00<0o`000?oo
o`3o00003P3oool0103o0000oooo0?ooo`00o`070?ooo`03003o003o0000oooo00<0oooo00<00?l0
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0000o`030?ooo`03003o003o0000oooo00D0oooo00<0o`00
0?ooo`3oool06`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0003o0080oooo00H00?l00?ooo`3o0000oooo0?l00000o`030?oo
o`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01`0oooo00D0003o
0?ooo`3oool0oooo003o00080?ooo`040000o`00o`000?l00000o``0oooo00D0003o0?ooo`000?l0
oooo003o000=0?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`000?l0oooo0000o`0:0?oo
o`030000o`3oool0oooo0080oooo00<0003o003o003oool01P3oool01P00o`00oooo0?ooo`000?l0
oooo0000o`<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00@0oooo00D00?l00?ooo`3o
ool0oooo003o00030?ooo`060000o`3oool0oooo0000o`3oool00?l03@3oool01`00o`00oooo0?oo
o`3oool0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo003o
00`0oooo00<00?l00?ooo`000?l0103oool00`000?l0oooo003o00060?ooo`03003o003oool0oooo
00H0oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`040?ooo`04003o00000?l0
oooo0?l000<0oooo00<0o`000?ooo`00o`005`3oool00`00o`00oooo003o00090?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0303oool01P00o`00oooo0?ooo`000?l0oooo0000o`@0
oooo00<00?l00?ooo`3oool00P3oool01P00o`00oooo0?ooo`000?l0oooo0000o`<0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l50?ooo`060000o`3oool0oooo0?l0003oool0
o`000P3oool00`00o`00oooo0?ooo`0U0?ooo`800?l04`3oool01@00o`00oooo0000o`3oool0003o
00<0oooo00@00?l00?ooo`3oool00?l0103oool010000?l0oooo0?ooo`000?l30?ooo`03003o003o
ool0oooo0080oooo00L00?l00?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`070?ooo`05003o003oool0oooo0?ooo`00o`00203oool00`00o`00oooo0?ooo`08
0?ooo`80003o00<00?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool02`3oool01@00o`00oooo0?ooo`3oool00?l00200oooo00D0
003o0?ooo`3oool0oooo0000o`0I0?ooo`040000o`3oool0oooo0000oa00oooo00<0o`000?ooo`3o
ool00`3oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3oool0oooo01D0oooo00<0o`000?oo
o`3o00003P3oool0103o0000oooo0?ooo`00o`070?ooo`03003o003o0000oooo00<0oooo00<00?l0
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0000o`030?ooo`03003o003o0000oooo00D0oooo00<0o`00
0?ooo`3oool06`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0003o0080oooo00H00?l00?ooo`3o0000oooo0?l00000o`030?oo
o`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0;0?ooo`L00000603oool01@000?l0oooo0?ooo`3oool0
0?l000P0oooo00D0003o0?ooo`00o`00oooo0000o`0;0?ooo`050000o`3oool0003o0?ooo`00o`00
3@3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0003o0?ooo`000?l02P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`00o`00oooo00H0oooo00H00?l00?ooo`3oool0003o0?ooo`000?l2
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`05003o003oool0oooo0?ooo`00
o`000P3oool01P000?l0oooo0?ooo`3oool0003o003o00h0oooo00D00?l00?ooo`3oool0oooo0?l0
00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo003o
000>0?ooo`03003o00000?l0oooo00<0oooo00<0003o003o003oool01`3oool00`00o`00oooo0?oo
o`050?ooo`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0103oool01000o`00003o
0?ooo`3o00030?ooo`030?l0003oool00?l001P0oooo0P00o`090?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool03@3oool01P00o`00oooo0?ooo`000?l0oooo0000o`@0oooo00<00?l0
0?ooo`3oool00`3oool01@00o`00oooo0000o`3oool0003o0080oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`D0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00020?ooo`03003o003oool0oooo
02H0oooo00<0003o0?ooo`3oool04P3oool01000o`00003o0?ooo`000?l20?ooo`05003o003oool0
oooo0?ooo`00o`00103oool010000?l0oooo0?ooo`000?l20?ooo`03003o003oool0oooo00@0oooo
00H00?l00?ooo`3oool0003o0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool0
1@00o`00oooo0?ooo`3oool00?l000P0oooo00<00?l00?ooo`3oool01`3oool01@000?l0oooo0000
o`3oool00?l001H0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0I0?ooo`03003o
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0I0?ooo`040000o`3oool0oooo0000
o`H0oooo0P00o`070?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o203oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o00003P3oool0
0`3o0000oooo003o00080?ooo`03003o003o0000oooo00<0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0000o`030?ooo`03003o003o0000oooo00D0oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0003o00<0oooo00D00?l00?l0003oool0o`00003o00030?ooo`030000
o`3oool0oooo00l0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool010000?l0oooo0?ooo`00o`080?ooo`05
0000o`3oool0oooo0?ooo`000?l02`3oool01@000?l0oooo0000o`3oool00?l000d0oooo00<0o`00
0?ooo`3oool01`3oool01@3o0000oooo0000o`3oool0003o00X0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l00?l00?ooo`070?ooo`05003o003oool0003o0?ooo`000?l00P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo
0?ooo`3oool0003o0?ooo`000?l00`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo
0000o`<0oooo00<0003o003o003oool02P3oool010000?l0oooo0?ooo`00o`030?ooo`040?l0003o
ool0oooo0?l000P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo003o000>0?ooo`03003o
00000?l0oooo00<0oooo00<0003o003o003oool0203oool00`00o`00oooo0?ooo`040?ooo`040?l0
003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0103oool01000o`00003o0?ooo`3o00030?oo
o`030?l0003oool00?l001P0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00h0oooo00D00?l00?ooo`000?l0oooo0000o`030?ooo`03003o003oool0
oooo00@0oooo00L00?l00?ooo`000?l0oooo0000o`3oool00?l000H0oooo00L00?l00?ooo`3oool0
oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l5
0?ooo`060000o`3oool0oooo0?l0003oool0o`000P3oool00`00o`00oooo0?ooo`0V0?ooo`030000
o`3oool0oooo0180oooo00H00?l00000o`3oool0003o0?ooo`00o`040?ooo`03003o003oool0oooo
0080oooo00@0003o0?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`040?ooo`06003o003oool0
oooo0000o`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`H0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`05003o003oool0oooo0?oo
o`00o`00203oool00`00o`00oooo0?ooo`070?ooo`050000o`3oool0003o0?ooo`00o`005P3oool0
0`00o`00oooo0?ooo`070?ooo`05003o003oool0oooo0?ooo`00o`00203oool00`00o`00oooo0?oo
o`030?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`00o`000`3oool01@000?l0oooo0?oo
o`3oool0003o01T0oooo00@0003o0?ooo`3oool0003o1@3oool00`00o`00oooo0?ooo`02003o00D0
oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3oool0oooo
00d0oooo0P000?l50?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool00`3o0000oooo003o0008
0?ooo`03003o003o0000oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`00
0?l40?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?oo
o`090?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`050000
o`3oool0oooo0?ooo`000?l00`3oool01@00o`00o`000?ooo`3o00000?l00080oooo00<0003o0?oo
o`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000`0oooo00<000000?ooo`3oool07@3oool010000?l0oooo0?ooo`00
o`080?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool01@000?l0oooo0?ooo`000?l00?l000d0
oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0000o`3oool0003o00X0oooo00<0003o0?oo
o`3oool00P3oool00`000?l00?l00?ooo`070?ooo`05003o003oool0003o0?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
1`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0003o00<0oooo00<0003o003o003oool02P3oool010000?l0oooo0?ooo`00o`030?ooo`04
0?l0003oool0oooo0?l000P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo003o000?0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`040?oo
o`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0103oool01000o`00003o0?ooo`3o
00040?ooo`030?l00000o`00oooo02<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0>0?ooo`05003o003oool0003o0?ooo`000?l00`3oool00`00o`00oooo0?ooo`050?ooo`06003o
00000?l0oooo0000o`3oool00?l01`3oool01P00o`00oooo0?ooo`000?l0oooo0000o`<0oooo00<0
o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l50?ooo`060000o`3oool0oooo0?l0003o
ool0o`000P3oool00`00o`00oooo0?ooo`0U0?ooo`80003o503oool01P00o`00003o0?ooo`000?l0
oooo003o00D0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`040000o`3oool0oooo003o00H0
oooo00@00?l00?ooo`3oool0003o0P3oool010000?l0oooo0?ooo`3o00040?ooo`040?l0003oool0
oooo0000o`H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`030000o`3o
ool0003o0080oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`080?ooo`04003o003o
ool0oooo003o00P0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0G0?ooo`03003o
003oool00?l000<0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`800?l00P3oool00`3o0000oooo0?ooo`050?oo
o`040?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0000o`05
0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool00`3o0000oooo003o00080?ooo`03003o003o
0000oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l40?ooo`03003o
003oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool3003o00T0oooo00<0003o0?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`030?oo
o`05003o003oool0oooo0?l00000o`000P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0
oooo01L0oooo000Q0?ooo`8000002P3oool2000000d0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo003o00090?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool01P000?l0oooo0?ooo`00
0?l0oooo003o00X0oooo00<0003o0?ooo`3o00002@3oool01@3o0000oooo0000o`3oool0003o00X0
oooo00<0003o0?ooo`3oool00P3oool00`000?l00?l00?ooo`070?ooo`05003o00000?l0oooo0?oo
o`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0000o`030?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool00?l0
0`3oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`00
o`003`3oool01P000?l00?l00?ooo`3oool00?l00000o`/0oooo00<00?l00000o`3oool00`3oool0
103o0000oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00@0oooo00@00?l00000o`3oool0o`00
103oool00`3o00000?l00?ooo`0T0?ooo`05003o003oool0oooo0?ooo`00o`004@3oool01@00o`00
oooo0000o`3oool0003o00<0oooo00<00?l00?ooo`3oool01@3oool01@00o`00003o0?ooo`000?l0
0?l000P0oooo00H00?l00?ooo`3oool0003o0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo
00H0o`000?ooo`3oool0003o0?ooo`00o`040?ooo`050000o`3oool0o`000?ooo`3o00000P3oool0
0`00o`00oooo0?ooo`0U0?ooo`80003o503oool01@000?l00?l00?ooo`3oool0003o00H0oooo00D0
0?l00?ooo`3oool0oooo0000o`020?ooo`040000o`3oool0oooo003o0080oooo00D0o`000?ooo`3o
ool0oooo003o00020?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool00P3oool0
103o0000oooo0?ooo`000?l70?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo
0?ooo`0<0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo
0000o`030?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo
003o00090?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool05P3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool00?l0203oool2003o00030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`000?l00`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00X0oooo00@0003o
0?ooo`3oool0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`00o`00
203oool00`00o`00o`000?ooo`020?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0000o`030?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool01000o`00
oooo0?ooo`00o`080?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o0005
0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01000o`00oooo0?ooo`00o`030?ooo`030000
o`3oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo003o00090?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool01P000?l0oooo
0?ooo`000?l0oooo003o00X0oooo00<0003o0?l0003oool02@3oool00`3o0000oooo0000o`020?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l00?l00?ooo`070?oo
o`03003o00000?l0oooo0080oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00D0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l20?ooo`03003o003o
ool0oooo00D0oooo00<00?l00000o`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o0P3o
ool01000o`00oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
0`3oool00`3o00000?l00?ooo`0?0?ooo`060000o`3oool00?l00?ooo`00o`00003o303oool00`00
0?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0103oool0
1000o`00003o0?ooo`3o00040?ooo`030?l00000o`00oooo02@0oooo00D00?l00?ooo`3oool0oooo
003o000A0?ooo`03003o003oool0003o0080oooo00<0003o0?ooo`00o`002@3oool00`000?l0oooo
0000o`060?ooo`040?l0003oool0oooo003o0080oooo00<0003o0?ooo`000?l00`3oool00`3o0000
oooo0?ooo`020?ooo`060?l0003oool0oooo0000o`3oool00?l0103oool00`000?l0oooo0?l00002
0?ooo`030?l0003oool00?l002H0oooo00@0003o0?ooo`3oool0003o4`3oool01@000?l00?l00?oo
o`00o`00003o00H0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`040000o`3oool0oooo003o
0080oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`040000o`3oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l70?ooo`040000o`3oool0oooo0000o`D0
oooo00D00?l00?ooo`3oool0oooo0000o`0>0?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool0203oool00`000?l0oooo0000o`030?ooo`03003o003oool0oooo0140oooo00<00?l00?oo
o`3oool02@3oool00`00o`00oooo003o000:0?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool05P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`000?l01@3oool00`000?l0oooo0?oo
o`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`00o`002P3oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0003o00<0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0o`0000d0oooo00<0o`000?ooo`00o`00203oool00`00o`00o`000?ooo`020?ooo`03003o
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0o`0000D0
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00D0oooo00<0o`000?oo
o`3oool0303oool00`00o`00oooo0?ooo`020?ooo`800?l01P3oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo003o00H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040?l00000
o`00oooo003o00<0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool00?l000T0oooo00D0003o0?ooo`3oool0oooo
0000o`0;0?ooo`060000o`3oool0oooo0000o`3oool00?l02@3oool20000o`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`020?ooo`030000o`3oool0o`00
00L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`060?l0003oool0oooo
0000o`3oool0003o0P3oool00`00o`00oooo0?ooo`050?ooo`03003o00000?l0oooo0080oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0000o`020?ooo`04003o003oool0oooo0?l000<0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l00000o`00oooo00h0oooo
00L0003o0?ooo`3oool0oooo003o003oool0003o00`0oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00@0oooo00@00?l00000o`3oool0o`00103o
ool00`3o00000?l00?ooo`0T0?ooo`05003o003oool0oooo0?ooo`00o`004@3oool00`00o`00003o
0?ooo`020?ooo`030000o`3oool00?l000T0oooo00<0003o0?ooo`000?l01P3oool02@3o0000oooo
0?ooo`3oool00?l00?ooo`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00H0o`00
0?ooo`3oool0003o0?ooo`00o`040?ooo`030000o`3oool0o`000080oooo00<0o`000?ooo`00o`00
9P3oool010000?l0oooo0?ooo`000?lC0?ooo`050000o`3oool00?l0003o00000?l01P3oool01@00
o`00oooo0?ooo`3oool0003o00<0oooo00<0003o003o003oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`03003o00000?l0oooo0080oooo00@0003o0?ooo`3oool0o`00103oool0103o0000oooo0?oo
o`000?l80?ooo`030000o`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0;0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0203oool010000?l0oooo
0?ooo`000?l30?ooo`03003o003oool0oooo00/0oooo103o00000`3oool00?l00?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool00?l0
00L0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo
00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool00?l0
00X0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0000o`030?ooo`800?l01@3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0o`0000`0oooo00@0o`000?ooo`3oool00?l02@3oool01@00o`00oooo0?oo
o`3oool00?l000P0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20?l000@0
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00D0oooo00<0o`000?oo
o`3oool0303oool00`00o`00oooo0?ooo`040?ooo`800?l0103oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo003o00D0oooo00<0003o0?ooo`3oool00P3oool02@000?l0oooo0?ooo`3o
ool0o`00003o003oool00?l00?l000020?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3o
ool05`3oool003`0oooo1@00000K0?ooo`030000o`3oool00?l000T0oooo00D0003o0?ooo`3oool0
oooo0000o`0;0?ooo`060000o`3oool0oooo0000o`3oool00?l02@3oool20000o`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00003o0?ooo`080?ooo`070000o`3oool0
oooo0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0000o`030?ooo`030000o`00o`00oooo00P0oooo00H0003o0?ooo`3oool0
oooo003o00000?l:0?ooo`030000o`3oool0003o0080oooo00@00?l00?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?oo
o`0>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020?ooo`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0103oool01000o`00003o
0?ooo`3o00040?ooo`03003o003oool0oooo02D0oooo00<00?l00?ooo`00o`004`3oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`00o`00203oool010000?l0oooo003o00000?l60?ooo`090?l0003o
ool0oooo0?ooo`00o`00oooo0000o`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool01`3o
0000oooo0?ooo`000?l00?l00?ooo`00o`000`3oool00`000?l0oooo0?l000020?ooo`030?l0003o
ool00?l002D0oooo00D0003o0?ooo`3oool0oooo0000o`0C0?ooo`050000o`3oool00?l00?ooo`00
0?l01`3oool01000o`00oooo0?ooo`000?l30?ooo`030000o`00o`00oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`00o`00003o0?ooo`020?ooo`040000o`3oool0oooo0?l000@0oooo00@0o`00
0?ooo`3oool0003o203oool00`000?l0oooo0000o`040?ooo`03003o003oool00?l000<0oooo00<0
003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00@0
003o0?ooo`3oool0003o103oool00`00o`00oooo0?ooo`050?ooo`D0o`000`3oool00`3o00000?l0
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo
0?ooo`3oool0003o00l0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool00?l0
00L0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo
00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`00o`00oooo
00X0oooo00<0o`00003o003oool01P3oool00`3o0000oooo0000o`020?ooo`03003o003oool00?l0
00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03003o003oool0oooo00D0oooo00@0o`00
0?ooo`3oool00?l02@3oool01@00o`00oooo0?ooo`3oool00?l000P0oooo00<0003o0?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool20?l000@0oooo00D0003o0?ooo`3oool0oooo0000o`030?oo
o`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool0303oool00`00o`00003o0?ooo`060?oo
o`05003o003oool0oooo0?ooo`000?l01@3oool01P000?l0oooo0?ooo`00o`00oooo0?l000<0oooo
00<0003o0?ooo`3oool00P3oool02@000?l0oooo0?ooo`3oool0o`00003o003oool00?l00?l00002
0?ooo`030000o`3oool0oooo0180oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0M0?oo
o`030000o`00o`00oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo0080oooo00<0003o003o003oool0203oool20000o`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00003o0?ooo`080?ooo`070000o`3oool0oooo
0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0000o`030?ooo`030000o`00o`00oooo00P0oooo00H0003o0?ooo`3oool00?l0
0?ooo`000?l:0?ooo`030000o`3oool0003o0080oooo00<00?l00?ooo`3o0000103oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?ooo`0>0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`030?oo
o`070?l0003oool0oooo0?l0003oool00?l00000o`070?ooo`030000o`3oool0o`0000@0oooo00<0
0?l00?l0003oool09@3oool00`00o`00oooo003o000C0?ooo`060000o`3oool0oooo0?ooo`000?l0
0?l02@3oool010000?l0oooo0?ooo`000?l60?ooo`030?l0003oool0oooo0080oooo00@00?l00000
o`3oool0003o0P3oool00`3o0000oooo0?ooo`030?ooo`070?l0003oool0003o0?ooo`00o`00oooo
003o00030?ooo`030000o`3oool0o`000080oooo00<0o`00003o003oool09@3oool01@000?l0oooo
0?ooo`3oool0003o01<0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`04003o003oool0oooo
0000o`<0oooo00L0003o003o003oool0oooo0?l0003oool0o`0000<0oooo00<00?l00000o`3oool0
0P3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`3oool0
0`3oool00`00o`00oooo003o00030?ooo`030000o`3oool0oooo00X0oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`090?ooo`040000o`3oool0oooo0000o`@0oooo00<00?l00?ooo`3o
ool00`3oool20?l000P0oooo00<0o`00003o003oool01@3oool00`000?l0oooo0?ooo`040?ooo`80
o`002`3oool01000o`00oooo0?ooo`000?l?0?ooo`030000o`3oool0oooo0080oooo0P3o00030?oo
o`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?oo
o`03003o00000?l0oooo00T0oooo00<0o`000?ooo`00o`001`3oool00`3o0000oooo0000o`020?oo
o`04003o003oool0oooo003o00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`800?l01`3o
ool0103o0000oooo0?ooo`00o`090?ooo`05003o003oool0oooo0?ooo`00o`001`3oool00`000?l0
oooo0?ooo`050?ooo`060000o`3oool0oooo0?l0003oool0o`00103oool01@000?l0oooo0?ooo`3o
ool0003o00<0oooo00<0o`00003o003oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`80003o1`3o
ool01@00o`00oooo0?ooo`3oool0003o00D0oooo00H0003o0?ooo`3oool00?l00?ooo`3o00030?oo
o`030000o`3oool0oooo00<0oooo00P0003o0?ooo`3oool0o`00003o003oool00?l00?l00080oooo
00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`0M0?ooo`030000o`00o`00oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0080oooo00<0003o003o003oool0203oool20000o`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`800?l00P3o
ool00`000?l0oooo0?ooo`030?ooo`03003o00000?l0oooo00P0oooo00L0003o0?ooo`3oool0oooo
0000o`3oool0o`0000L0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0003o00<0oooo00<0003o003o003oool0203oool01P000?l0oooo0?ooo`00o`00
oooo0000o`X0oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?l000040?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`040?ooo`03003o003o0000oooo00h0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0003o0080oooo
00L0o`000?ooo`3oool0oooo0?l0003oool0003o00P0oooo00<00?l00000o`3o0000103oool00`00
o`00o`000?ooo`0U0?ooo`03003o003oool00?l001<0oooo00H0003o0?ooo`3oool0oooo0000o`00
o`090?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?l000030?ooo`07003o
00000?l0oooo0?ooo`000?l0oooo0?l000050?ooo`070?l0003oool0003o0?ooo`00o`00oooo003o
00040?ooo`060000o`3oool0oooo0?ooo`3o00000?l09@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`060?l0003oool0oooo
003o003oool0003o103oool01`000?l00?l00?ooo`3oool0o`000?ooo`3o00000`3oool00`00o`00
003o0?ooo`020?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`000?l02@3oool00`000?l0
oooo0?ooo`020?ooo`04003o003oool0oooo003o00<0oooo00<0003o0?ooo`3oool0103oool40?l0
0080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00H0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`080?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool00`00o`00oooo0?l000020?l000X0oooo00<0o`00003o003oool0103oool2
0000o`H0oooo00@0o`000?ooo`3o0000o`002@3oool01000o`00oooo0?ooo`000?l?0?ooo`030000
o`3oool0oooo0080oooo0P3o00030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
4P3oool00`00o`00oooo0?ooo`050?ooo`030000o`00o`00oooo00<0oooo00<0003o0?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0003o00X0oooo00<0o`000?ooo`00o`00
1`3oool00`3o0000oooo0000o`020?ooo`04003o003oool0oooo003o00D0oooo00<0003o0?ooo`3o
ool00P3oool40000o`L0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`060?l0003oool0oooo
003o003oool00?l01P3oool0103o0000oooo0?ooo`00o`090?ooo`05003o003oool0oooo0?ooo`00
o`001`3oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0?l0003oool0o`00103oool0
1@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`00003o003oool01P3oool00`3o0000oooo0?oo
o`040?ooo`80o`00103oool00`000?l00?l00000o`080?ooo`04003o003oool0oooo0000o`D0oooo
00<0003o0?ooo`00o`000P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00P0003o0?ooo`3o
ool0o`000?ooo`00o`00oooo0?l00080oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00D0003o
0?ooo`00o`00oooo0?l000050?ooo`040000o`3oool0003o0?l000/0oooo00D0o`000000o`3oool0
oooo0000o`030?ooo`03003o003o00000?l00080oooo00<0003o0?ooo`3oool00`3oool00`00o`00
003o0?ooo`080?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000080?ooo`030?l0003oool0
003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`030?ooo`030000o`3oool0
oooo00P0oooo00H0003o003o003oool00?l00?ooo`000?l:0?ooo`080000o`3oool0oooo0000o`3o
ool00?l00?ooo`3o00040?ooo`030?l0003oool0oooo0080003o0P3oool00`3o0000oooo0?ooo`04
0?ooo`03003o003o0000oooo00h0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0003o0080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00P0oooo
00<00?l00000o`3o0000103oool00`00o`00o`000?ooo`0V0?ooo`03003o003oool0oooo0180oooo
00H0003o0?ooo`3oool0oooo0000o`00o`090?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?l000030?ooo`07003o00000?l0oooo0?ooo`000?l0oooo0?l000060?ooo`060?l0
00000?l0oooo003o003oool00?l0103oool01P000?l0oooo0?ooo`3oool0o`00003o02D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000?l0
103oool01P3o0000oooo0?ooo`3oool00?l00000o`@0oooo00L0003o003o003oool0oooo0?l0003o
ool0o`0000@0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0o`0000H0oooo00<0o`000000o`3o
ool03P3oool01000o`00oooo0?ooo`00o`040?ooo`030000o`3oool0o`0000<0o`000`3oool0103o
0000oooo0?ooo`00o`090?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01`3oool0
1@00o`00oooo0?ooo`3oool00?l000X0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0
0000o`00oooo00`0oooo00<0o`00003o003oool0103oool00`000?l0oooo0000o`050?ooo`040?l0
003oool0oooo0?ooo`<0o`001P3oool01000o`00oooo0?ooo`000?l?0?ooo`030000o`3oool0oooo
0080oooo0P3o00020?ooo`05003o003oool0oooo0?ooo`000?l01@3oool00`00o`00oooo0?ooo`0A
0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`00o`00103oool010000?l0oooo0?ooo`3o
ool2003o00h0oooo0P00o`000`000?l00?l0003o0003003o0080oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo003o00080?ooo`050?l000000?l0oooo0?ooo`00o`000P3oool00`00o`00oooo
0?ooo`030?ooo`D0003o2`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`00
o`000P3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo003o00T0oooo00D00?l00?l0
003oool0oooo003o00070?ooo`030000o`3oool0oooo00D0oooo00H0003o0?ooo`3oool0o`000?oo
o`3o00040?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o00000?l00?ooo`060?ooo`03
0?l0003oool0oooo00@0o`0000<0oooo0?l0003oool00P3oool01@000?l0oooo003o003oool0003o
00L0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo003o00020?ooo`050?l0003oool0
oooo0?ooo`000?l01@3oool020000?l0oooo0?ooo`3o0000oooo003o003oool0o`000P3oool00`00
0?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo003o003oool20?l000@0oooo00@0003o0?oo
o`3oool0003o2`3oool01@3o0000003o0?ooo`3oool0003o00<0oooo00H00?l00?ooo`3o00000?l0
0?ooo`000?l40?ooo`03003o003oool0003o00T0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0
o`0000P0oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
003o00<0oooo00<0003o0?ooo`3oool01`3oool01`000?l0oooo003o003oool00?l00?ooo`000?l0
2P3oool010000?l0oooo0?ooo`000?l20?ooo`03003o003o0000oooo00<0oooo00P0o`000?ooo`3o
ool0003o0?ooo`000?l0oooo0?l000H0oooo00<00?l00?l0003oool03P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?oo
o`020?ooo`030?l000000?l0oooo00L0oooo00<00?l00000o`3o0000103oool00`00o`00o`000?oo
o`0V0?ooo`03003o003oool0oooo0180oooo00H0003o0?ooo`3oool0oooo003o00000?l90?ooo`05
0000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?l000040?ooo`060000o`3oool0oooo
0000o`3oool0o`001P3oool00`3o0000003o003o00020?ooo`03003o003oool0oooo0080oooo00H0
003o0?ooo`3oool0oooo0?l00000o`0T0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0403oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00H0o`000?ooo`3oool0oooo003o0000
0?l40?ooo`070000o`00o`00oooo0?ooo`3o0000oooo0?l000040?ooo`070000o`3oool0oooo0?oo
o`000?l0oooo0?l000060?ooo`030?l000000?l0oooo00h0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`030000o`3oool0o`0000H0oooo00@0o`000?ooo`3oool00?l02P3oool01000o`00oooo
0?ooo`00o`0:0?ooo`04003o003oool0oooo003o00/0oooo00D0003o0?ooo`3oool0oooo0000o`05
0?ooo`030?l0003oool00?l000`0oooo00<00?l00?l0003oool0103oool00`000?l0oooo0000o`05
0?ooo`030?l0003oool0oooo00@0oooo0P3o00040?ooo`04003o003oool0oooo0000oa00oooo00T0
003o0?ooo`3oool0oooo0?l0003oool0o`000?ooo`00o`000`3oool00`000?l0oooo0?ooo`040?oo
o`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`04
0?ooo`030000o`00o`000?l00080oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00
0?l70?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo003o00070?ooo`050?l0
00000?l0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0C0?ooo`040000o`3oool0oooo0?l0
00D0oooo00<0o`000?ooo`00o`000P3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo
003o00T0oooo00D00?l00?l0003oool0oooo003o00070?ooo`030000o`3oool0oooo00D0oooo00H0
003o0?ooo`3oool0o`000?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o
00000?l00?ooo`060?ooo`<0o`001@3oool01P3o0000oooo0?ooo`000?l0oooo003o0080oooo00<0
003o0?ooo`3oool0103oool0103o00000?l00?ooo`000?l60?ooo`040000o`3oool00?l00?ooo`80
o`000`3oool00`000?l0oooo0?ooo`030?ooo`080000o`3oool0oooo0?l0003oool00?l00?ooo`3o
00020?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<00000
0?ooo`3oool07@3oool00`00o`00003o0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`070000o`3oool00?l00?ooo`3o0000oooo
0?l000030?ooo`040000o`3oool0oooo0000o`/0oooo00D0o`000000o`3oool0oooo0000o`030?oo
o`06003o003oool0o`000?ooo`00o`00003o103oool00`00o`00oooo0000o`090?ooo`070000o`00
o`00oooo0?ooo`000?l0oooo0?l000080?ooo`050?l0003oool0003o0000o`3o0000203oool00`3o
0000oooo0000o`020?ooo`03003o00000?l0oooo00P0oooo00@0003o0?ooo`3oool00?l00P3oool0
0`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`00o`00o`000?oo
o`040?ooo`070?l0003oool0003o0?ooo`000?l0oooo0?l000060?ooo`03003o003o0000oooo00h0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`060000o`3oool0003o003o
003oool0o`00103oool00`3o0000003o0?ooo`070?ooo`03003o00000?l0o`0000@0oooo00<00?l0
0?l0003oool07`3oool80000oa@0oooo00H0003o003o003oool0oooo003o00000?l90?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?l000030?ooo`070000o`00o`00oooo0?oo
o`000?l0oooo0?l000060?ooo`030?l000000?l00?l00080oooo00<00?l00?ooo`3oool00P3oool0
1P000?l0oooo0?ooo`3oool0o`00003o02@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0@0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool20?l00080oooo00<00?l00000o`3o
ool00`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3o0000oooo00D0oooo00<0o`000000o`3oool03@3oool00`00o`00oooo0?ooo`02
0?ooo`07003o003oool0oooo0?ooo`000?l0oooo0?l000060?ooo`040?l0003oool0oooo003o00X0
oooo00@00?l00?ooo`3oool00?l02P3oool01000o`00oooo0?ooo`00o`0;0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`0;0?ooo`03003o003o
0000oooo00@0oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00<00?l00?ooo`000?l0403oool010000?l0oooo0?ooo`3o00020?ooo`030?l0
003oool00?l00080oooo00<0003o0?ooo`000?l01@3oool00`00o`00oooo0?ooo`0?0?ooo`03003o
003oool0oooo00H0oooo00@0003o0?ooo`3oool00?l00P3oool2003o00030000o`3oool0oooo0080
oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0000o`080?ooo`030000o`3oool0oooo00L0
oooo00D0o`000?ooo`3oool0oooo003o00070?ooo`040?l000000?l0oooo003o00@0oooo00<00?l0
0?ooo`3oool04`3oool010000?l0oooo0?ooo`3o00050?ooo`030?l00000o`00oooo0080oooo00<0
0?l00?ooo`3oool0103oool00`3o0000oooo003o000:0?ooo`05003o003o0000oooo0?ooo`00o`00
1`3oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0?l0003oool0o`00103oool01@00
0?l0oooo0?ooo`3oool0003o00<0oooo00<0o`00003o003oool03P3oool00`3o0000oooo0000o`02
0?ooo`04003o003oool0oooo0000o`H0oooo00@0o`00003o003oool0003o1P3oool010000?l0oooo
003o003oool20?l000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00030?oo
o`040?l0003oool0oooo0000oaP0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000K0?oo
o`03003o00000?l0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo00L0003o0?ooo`00o`00oooo0?l0003oool0o`000080oooo00D0
003o0?ooo`3oool0oooo0000o`0;0?ooo`030000o`3oool0oooo0080oooo00H0003o0?ooo`3oool0
0?l00?ooo`3o00020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`000?l0203oool00`00
0?l0oooo003o00020?ooo`030000o`3o0000oooo00P0oooo00D0o`000000o`3oool0003o0?l00008
0?ooo`030?l0003oool0003o0080oooo00<00?l00000o`3oool0203oool010000?l0oooo0?ooo`00
o`020?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03003o
003o0000oooo00@0oooo00L0o`000?ooo`000?l0oooo0000o`3oool0o`0000D0oooo00<00?l00?oo
o`3o00003`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00H0003o0?oo
o`000?l00?l00?ooo`3o00040?ooo`030?l000000?l0oooo00L0oooo00<00?l00000o`3o0000103o
ool00`00o`00oooo0?l0000N0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3o
ool01P000?l00?l00?ooo`3oool00?l00000o`T0oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0o`0000<0oooo00L0003o003o003oool0oooo0000o`3oool0o`0000H0oooo00<0
o`000000o`00o`000`3oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<00?l00?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo0P3o00020?ooo`03003o00000?l0oooo00<0
oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0o`000?ooo`050?ooo`030?l000000?l0oooo00d0oooo00<00?l00?ooo`3oool00P3oool0
1`00o`00oooo0?ooo`3oool0003o0?ooo`3o00001`3oool00`3o0000oooo003o000:0?ooo`04003o
003oool0oooo003o00/0oooo00<00?l00?ooo`00o`002`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo003o00090?ooo`03003o003oool0o`00
00D0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0080oooo00<00?l00000o`3oool0403oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0
0?l00080oooo00<0003o0?ooo`000?l01@3oool00`00o`00o`000?ooo`0=0?ooo`030?l0003oool0
0?l000P0oooo00@0003o0?ooo`3oool0oooo0P00o`020?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool0203oool01000o`00oooo0?ooo`000?l90?ooo`030000o`3oool0oooo00H0oooo
00D0o`000?ooo`3oool0oooo003o00070?ooo`040?l000000?l0oooo003o00D0oooo00<00?l00?oo
o`3oool04P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l00000o`00oooo00<0oooo00<00?l0
0?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`0:0?ooo`04003o003o0000003o003o00P0oooo
00<0003o0?ooo`3oool01@3oool01P000?l0oooo0?ooo`3o0000oooo0?l000<0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`3o00020?ooo`03003o003oool0oooo00d0oooo00D0003o
0?ooo`3oool0oooo003o00020?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`00o`00003o
1`3oool00`000?l0oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo
0?ooo`3o00030?ooo`040?l0003oool0oooo0000oa@0oooo1@00000I0?ooo`00?03oool00`000000
oooo0?ooo`0M0?ooo`03003o00000?l0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00@0003o003o003oool0o`000P3oool00`3o
0000oooo0000o`030?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo003o00020?ooo`040?l0003oool0oooo0000o`@0oooo00<00?l00?ooo`000?l0203oool0
0`000?l0oooo003o00020?ooo`030000o`3o0000oooo00P0oooo00D0o`000000o`3oool0003o0?l0
00080?ooo`050?l0003oool0003o0?ooo`00o`000P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00<00?l00?l0003oool0103oool01`3o0000oooo0000o`3oool0003o0?ooo`3o00001@3oool0
0`00o`00oooo0?l000030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`070?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000040?ooo`030?l0
00000?l0oooo00L0oooo00<00?l00000o`3o0000103oool00`00o`00oooo0?l0000N0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo003o00020?ooo`03003o
00000?l0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0o`0000<0oooo00L0003o0?ooo`00o`00oooo0000o`3oool0o`0000H0oooo00<0o`000000
o`00o`000`3oool01P00o`00oooo0?ooo`3oool0o`000000o`<0oooo00<00?l00?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`060000o`3oool0oooo0?l0003oool0o`000`3oool00`000?l0
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01P3o0000oooo0?ooo`3oool0
003o003o00<0oooo00<0003o0?l0003oool01@3oool00`3o0000003o0?ooo`0<0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l00000
o`00oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo003o00060?ooo`030000o`3o
ool0oooo00<0oooo00<00?l00?ooo`00o`002`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`00o`00oooo0?ooo`060?ooo`04003o003oool0oooo0?l000@0
oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0080oooo00<00?l00000o`3oool0403oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0
0?l00080oooo00<0003o0?ooo`000?l01P3oool00`00o`00o`000?l0000:0?ooo`<0o`0000<00?l0
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<00?l0
0?ooo`3oool0203oool01000o`00oooo0?ooo`000?l90?ooo`030000o`3oool0oooo00H0oooo00D0
o`000?ooo`3oool0oooo003o00070?ooo`040000o`3oool0oooo003o00D0oooo00<00?l00?ooo`3o
ool0403oool00`00o`00oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`020?ooo`040?l0003oool0oooo003o00/0oooo00<00?l00000
o`00o`00203oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0?l0003oool0o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l00080oooo00<00?l00?ooo`3oool0
303oool00`000?l0o`000?ooo`020?ooo`04003o003oool0oooo0000o`D0oooo0P3o00000`3oool0
0?l00000o`070?ooo`030000o`3oool0oooo0080o`000`3oool00`000?l0oooo0?ooo`030?ooo`04
0000o`3oool0oooo0?l000<0oooo00@0o`000?ooo`3oool0003o603oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0M0?ooo`03003o00000?l0oooo00P0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`00o`00o`000`3oool01P3o0000003o0?ooo`3oool0o`000000o`/0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo003o00020?ooo`050?l0003oool0oooo0000o`00o`000`3oool00`00o`00
oooo0000o`080?ooo`030000o`3oool00?l000<0oooo00<0003o0?ooo`3oool01`3oool01@3o0000
003o0?ooo`000?l0o`0000P0oooo00D0o`000000o`3oool0oooo003o00020?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo00@0003o0?ooo`00o`00o`001@3oool01P3o0000003o0?ooo`3oool0003o0?l000H0
oooo00<00?l00?ooo`3o00000`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o0000103oool0
0`3o0000003o0?ooo`070?ooo`03003o00000?l0o`0000<0oooo00@00?l00?ooo`3oool0o`007@3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00L0003o0?ooo`00o`00oooo
003o003oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0o`0000<0oooo00L0003o0?ooo`00o`00oooo0000o`3oool0o`0000H0oooo00<0o`00
0000o`3oool00`3oool01P00o`00oooo0?ooo`3oool0o`000000o`<0oooo00<00?l00?ooo`3oool0
803oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo0P3o00040?ooo`030000
o`3oool0oooo00<0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00030?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool0o`000`3oool01P3o0000oooo0?ooo`3oool0003o003o00<0oooo
00<0003o0?l0003oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo00@0oooo
00D00?l00?ooo`3oool0oooo0000o`080?ooo`030?l00000o`00oooo00<0oooo0P000?l50?ooo`03
003o003oool00?l000D0oooo00<0003o0?ooo`000?l0103oool2003o00`0oooo00<0003o0?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<00?l00?ooo`3oool00`3oool2003o
00<0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`00o`00003o0?ooo`0A0?ooo`030000o`3o0000
oooo0080oooo00D0o`00003o003oool0oooo0000o`030?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool00P3o00060?ooo`80o`000`3oool00`00o`00oooo0?ooo`070?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`04003o003o
ool0oooo0000o`X0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`03003o
003oool0oooo00@0oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`0@0?ooo`80
0?l000@0003o0?ooo`3oool0o`001@3oool01000o`00oooo0?ooo`3oool40000o`<0oooo00@0o`00
0?ooo`3oool00?l02`3oool00`00o`00003o0000o`080?ooo`030000o`3oool0oooo00D0oooo00H0
003o0?ooo`3oool0o`000?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3o
ool0o`000P3oool4003o00/0oooo00<0003o0?l0003oool00P3oool01@00o`00oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3o00000?l00000o`070?ooo`060000o`3oool0oooo0?l0003oool0
o`000P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000<0oooo00@0o`000?oo
o`3oool0003o603oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0L0?oo
o`03003o003oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo003o00040?oo
o`060000o`3o0000oooo0?ooo`3o0000003o2`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool00?l00080oooo00H0o`000?ooo`3oool0003o0?ooo`00o`020?ooo`03003o003oool0003o00P0
oooo00<0003o0?ooo`00o`000`3oool00`000?l0oooo0?ooo`070?ooo`050?l000000?l0oooo0000
o`3o00002@3oool010000?l0oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool00?l01@3oool01P3o0000003o0?ooo`3oool0003o0?l000H0oooo00<00?l00?ooo`3o
00000`3oool20000o`T0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`00
00D0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0o`0000@0oooo00<00?l00000o`3oool01`3o
ool00`00o`00003o0?l000030?ooo`04003o003oool0oooo0?l001d0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0@0?ooo`070000o`3oool00?l00?ooo`00o`00oooo0000o`080?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o0002
0?ooo`070000o`3oool00?l00?ooo`000?l0oooo0?l000060?ooo`030?l000000?l0oooo00<0oooo
00H00?l00?ooo`3oool0oooo0?l000000?l30?ooo`03003o003oool0oooo0200oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`80o`00103oool00`000?l0oooo0?ooo`030?oo
o`060000o`3oool0oooo0?l0003oool0o`000`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3o
ool0oooo0?l000<0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`030?ooo`030000o`3o0000oooo
00H0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo
0?ooo`000?l0203oool00`3o00000?l00?ooo`030?ooo`030000o`3oool0003o00D0oooo0P00o`05
0?ooo`040000o`3oool0oooo0000o`@0oooo00<00?l00?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool01@00o`00oooo0?ooo`3oool00?l000D0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo00<0003o0?l0
003oool00P3oool01@3o00000?l00?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o00000?l00?ooo`020?ooo`80o`000P3oool20?l000@0oooo00<00?l00?l0003oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool0
1@00o`00oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`03003o003oool0oooo00@0oooo00@0003o0?ooo`3oool00?l01P3oool00`00o`00oooo
0?ooo`0>0?ooo`07003o003oool0oooo0000o`00o`00oooo0?l000040?ooo`03003o003o0000oooo
0080oooo00@0003o0?ooo`00o`00oooo1@000?l00`3oool00?l00?ooo`0:0?ooo`03003o00000?l0
003o00P0oooo00<0003o0?ooo`3oool01@3oool01P000?l0oooo0?ooo`3o0000oooo0?l000<0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l000060?ooo`@00?l01P3oool00`000?l0oooo
0?l000030?ooo`05003o003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?l0003oool0003o
00L0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00020?ooo`030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0o`000`3oool00`3o0000oooo0000o`0I0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo01`0oooo00<00?l00?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool00?l000@0oooo00H0003o0?ooo`3o0000oooo0?l000000?l;0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`00o`000P3oool0103o0000oooo0?ooo`000?l20?ooo`800?l00P3oool0
0`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo003o0080oooo00<0003o0?ooo`3oool0203o
ool010000?l0oooo0?ooo`000?l90?ooo`030000o`3oool00?l000<0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo003o00H0oooo00D0003o0?ooo`3oool0003o0?l00005
0?ooo`04003o003oool0oooo0?l000<0oooo0P000?l90?ooo`030000o`3oool0oooo00D0oooo00D0
003o0?ooo`3oool0oooo0?l000050?ooo`070000o`3oool0oooo0?ooo`000?l00?l00?l000040?oo
o`03003o00000?l0oooo00L0oooo00<00?l00000o`3o00000`3oool01@00o`00oooo0?ooo`3oool0
o`0001/0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00800?l000<0oooo0000o`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0
oooo0?l000<0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00oooo0000o`070?ooo`030?l0
00000?l0oooo00<0oooo00H00?l00?ooo`3oool0oooo0?l000000?l30?ooo`03003o003oool0oooo
0200oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0o`00
00<0oooo00<0003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`3o0000oooo0?l000<0oooo00<0
003o003o003oool00P3oool010000?l0oooo0?ooo`3o00030?ooo`060?l0003oool0oooo0000o`3o
ool00?l00`3oool00`000?l0o`000?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<00?l00?oo
o`3oool01@3oool01@00o`00oooo0?ooo`3oool0003o00P0oooo00<0o`00003o003oool00P3oool0
10000?l0oooo0?ooo`000?l50?ooo`03003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo
0000o`040?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000L0oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0403oool00`000?l0o`000?ooo`020?ooo`050?l00000o`00oooo
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool00?l000D0oooo0P3o0005
0?ooo`04003o003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`040?ooo`03003o003oool0oooo00@0oooo00@00?l00?ooo`000?l0003o303oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo
003o00070?ooo`03003o003oool0oooo00h0oooo00H00?l00?ooo`3oool0003o0?ooo`00o`050?oo
o`03003o003oool0o`000080oooo00@0003o0?ooo`3oool00?l00P3oool01@3o0000oooo0000o`3o
ool00?l000/0oooo00<00?l00000o`000?l01`3oool00`000?l0oooo0?ooo`060?ooo`060000o`3o
ool0oooo0?l0003oool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000T0
oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?l000020?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?l0003oool0003o00L0oooo00<0003o0?oo
o`3o00000P3oool0103o0000oooo0?ooo`000?l50?ooo`040000o`3oool0oooo0?l000<0oooo00<0
o`000?ooo`000?l06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0L
0?ooo`03003o003oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo003o00040?ooo`060000o`3o
ool0o`000?ooo`3o0000003o1@3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0003o003o003o00000P3oool00`3o0000oooo0000o`030?ooo`800?l00P3oool00`000?l0
oooo0?ooo`060?ooo`040000o`3oool0oooo003o0080oooo00<0003o0?ooo`3oool0203oool01000
0?l0oooo0?l000000?l90?ooo`030000o`3oool00?l000<0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`040000o`3oool0oooo003o00H0oooo00D0003o0?ooo`3oool0003o0?l000050?ooo`04
003o003oool0oooo0?l00080oooo00<0003o0?ooo`000?l02@3oool00`000?l0oooo0?ooo`060?oo
o`040000o`3oool0oooo0?l000D0oooo00L0003o0?ooo`3oool0oooo0000o`00o`00o`0000@0oooo
00<00?l00000o`3oool0203oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o
00006`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00l0oooo00@0003o0?ooo`3o
ool00?l00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`3oool0o`000`3oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0003o00L0oooo00<0
o`000000o`3oool00`3oool01P00o`00oooo0?ooo`3oool0o`000000o`<0oooo00<00?l00?ooo`3o
ool0603oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool0103o0000oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`3oool0o`000P3oool01@3o0000oooo0000o`3oool00?l00080oooo00D00?l00?ooo`000?l0oooo
0?l000030?ooo`040?l0003oool0oooo0000o`80oooo00@00?l00?ooo`3oool0003o1`3oool00`00
0?l0o`000?ooo`0;0?ooo`03003o003oool0oooo00D0oooo00H00?l00?ooo`3oool0oooo0?l00000
0?l70?ooo`030?l00000o`00oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`03003o
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0o`00203oool00`00o`00oooo0?ooo`050?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0080oooo00D0o`00003o003oool0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00@0o`00
0?ooo`3oool00?l02`3oool01000o`00oooo0?ooo`3o00070?ooo`030000o`3oool0oooo00L0oooo
00@0003o0?ooo`3oool0o`000`3oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0003o00h0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00@0
oooo00<0003o0?ooo`00o`00203oool00`00o`00oooo0?ooo`0=0?ooo`07003o003oool0oooo0?oo
o`000?l0o`00003o00030?ooo`06003o003oool0oooo0?l0003oool0003o0`3oool02000o`00oooo
0?ooo`3o0000oooo0000o`3oool00?l02`3oool00`00o`00003o0000o`070?ooo`030000o`3oool0
oooo00H0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00030?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3o00002P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0o`000080oooo
00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0o`000?ooo`00
0?l01P3oool01000o`00003o0?ooo`3o00020?ooo`030?l0003oool0003o00H0oooo00@0003o0?oo
o`3oool0o`000`3oool00`3o0000oooo0000o`0I0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`D000006P3oool01000o`00oooo0?ooo`000?l20?ooo`80o`000`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l00?l00?ooo`03
0?ooo`030000o`3oool0oooo0080o`0000<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0003o003o003oool00`3oool00`3o0000003o0?ooo`03
0?ooo`05003o003oool0oooo0?ooo`000?l01`3oool010000?l0oooo0?ooo`00o`020?ooo`030000
o`3oool0oooo00L0oooo00D0003o0?l0003oool0o`000000o`090?ooo`030000o`3oool00?l000<0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0o`00003o00H0oooo00D0003o
0?ooo`3oool0oooo0000o`050?ooo`04003o003oool0oooo0?l00080oooo00@0003o0?ooo`3oool0
003o203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080o`00103oool01P000?l0
oooo0?ooo`3oool0003o003o00D0oooo00<00?l00000o`3oool0203oool00`000?l0oooo0?ooo`02
0?ooo`05003o003oool0oooo0?ooo`3o00006P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00l0oooo00@0003o0?ooo`3oool00?l00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`000`3oool0103o0000oooo0?ooo`000?l30?oo
o`03003o00000?l0oooo00H0oooo00<00?l00000o`3oool0103oool01@00o`00oooo0?ooo`3o0000
003o00<0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0
oooo0?l000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00020?ooo`050?l0
003oool0003o0?ooo`00o`000P3oool01@00o`00oooo0000o`3oool0o`0000<0oooo00@0o`000?oo
o`3oool0003o0P3oool01000o`00oooo0?ooo`000?l70?ooo`030000o`3o0000oooo00/0oooo00<0
0?l00?ooo`3oool01P3oool01@00o`00oooo0?ooo`3o0000003o00L0oooo00D00?l00?ooo`3oool0
oooo0000o`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0103oool010000?l0
oooo0?ooo`3o000A0?ooo`040?l0003oool0oooo0000o`@0oooo00D0003o0?ooo`3oool0oooo0?l0
000;0?ooo`060?l0003oool0oooo0?ooo`000?l00?l04@3oool00`3o0000003o0?ooo`020?ooo`04
003o003o0000oooo0000o`D0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000L0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?l00080oooo00@00?l00?ooo`3oool0oooo
0P000?l@0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo
0?ooo`040?ooo`030000o`3oool00?l000P0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo
0?ooo`020?ooo`030000o`3o0000oooo00800?l000L0oooo003o003oool0oooo0?l0003oool0003o
00<0oooo00P00?l00?ooo`3oool0o`000?ooo`000?l0oooo003o00/0oooo00@00?l00000o`00o`00
003o1P3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00080oooo00@0o`000?oo
o`3oool0003o1@3oool00`000?l0oooo0?l0000:0?ooo`03003o003oool0oooo0080oooo00@0003o
0?ooo`3oool0o`000P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3o0000oooo0000o`060?ooo`04003o00000?l0oooo0?l00080oooo00<0o`000?ooo`00
0?l01P3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0003o01D0oooo1@00000I0?oo
o`00?03oool00`000000oooo0?ooo`0K0?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`00o`00oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000003o0?ooo`030?ooo`03003o003oool00?l000@0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l00?l00?ooo`030?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool01@3oool01000
0?l0oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00L0oooo00D0003o0?l0003oool0o`000000
o`090?ooo`030000o`3oool00?l000<0oooo00@0003o0?ooo`3oool0oooo0P3o00020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3o00000?l000D0oooo00<0003o0?l0003oool00P3oool00`000?l0oooo0?ooo`020?ooo`05003o
003oool0oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`000?l80?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3o00030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`03003o00000?l0oooo0080oooo00D00?l00?oo
o`3oool0oooo0?l0000I0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3o00030?ooo`040?l0003oool0oooo0000o`<0oooo00<00?l00000o`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0o`000080oooo00@0003o0?ooo`00o`00
o`002`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`3o00020?ooo`050?l0003oool0003o0?ooo`00o`000P3o
ool01@00o`00oooo0000o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0003o0P3oool01000o`00
oooo0?ooo`000?l70?ooo`030000o`3o0000oooo00X0oooo00<00?l00?ooo`3oool01`3oool01@00
o`00oooo0?ooo`3o0000003o00L0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3o000A0?ooo`040?l0003oool0oooo0000
o`@0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?ooo`060?l0003oool0oooo0000o`3oool00?l0
4@3oool00`3o0000003o0?ooo`020?ooo`04003o003o0000oooo0000o`D0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`05003o003oool0oooo0?ooo`000?l0103oool00`00o`00oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o
00020?ooo`80o`0000D00?l00?ooo`000?l0003o003o000A0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool00?l000P0oooo
00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`030000o`3o0000oooo0080oooo
00L00?l00?ooo`3oool0oooo0?l0003oool0003o00<0oooo00P00?l00?ooo`3oool0o`000?ooo`00
0?l0oooo003o00/0oooo00@00?l00000o`00o`00003o1P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?l0000:0?oo
o`03003o003oool0oooo0080oooo00L0003o0?ooo`3oool0oooo0?l0003oool00?l000D0oooo00@0
003o0?ooo`3oool0o`000P3oool0103o0000oooo0000o`00o`050?ooo`04003o00000?l0oooo0?l0
0080oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0003o
01T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool06`3oool01@00o`00
oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`00003o00020?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o00040?oo
o`030000o`3o0000oooo0080oooo00<0003o0?l0003oool00`3oool00`3o0000003o0?ooo`070?oo
o`030000o`3oool0oooo00D0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00T0oooo00H0
003o0?l0003oool0o`000?ooo`000?l80?ooo`030000o`00o`00oooo00@0oooo00P0003o0?ooo`3o
ool0o`000?ooo`3o0000oooo0000o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3o00000?l000D0oooo00H0003o0?l0003oool0oooo0?l000000?l30?ooo`03
003o003oool0oooo00<0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00L0oooo00D0003o0?ooo`3o0000oooo0?l000030?ooo`030000o`3oool0oooo
00<0oooo00<0003o003o003oool00`3oool00`000?l0oooo0?ooo`080?ooo`03003o00000?l0oooo
0080oooo00D00?l00?ooo`3oool0oooo0?l0000I0?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00030?ooo`040?l0003oool0oooo0000o`@0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0o`000080oooo
00@0003o0?ooo`00o`00o`002P3oool20?l000h0oooo0P3o00050?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0003o0080oooo00L00?l0
0?ooo`00o`00oooo0000o`3oool0o`0000@0oooo00<0o`000?ooo`000?l00`3oool00`00o`00oooo
0000o`070?ooo`030000o`3o0000oooo00X0oooo00<00?l00?ooo`3oool01`3oool01P00o`00oooo
0?ooo`3o0000oooo0000o`H0oooo00@00?l00?l0003oool0003o1P3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00@0oooo00@0003o0?ooo`3oool0o`004@3oool0103o0000oooo0?ooo`000?l40?ooo`05
0000o`3oool0oooo0?ooo`3o00002`3oool01P3o0000oooo0?ooo`000?l0oooo003o0140oooo00<0
o`000000o`3oool00P3oool01000o`00o`000?ooo`000?l50?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool01P00o`00oooo0?ooo`000?l0oooo0000o`<0oooo00<00?l00?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00001@3oool0
103o00000?l00000o`00o`0B0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool00?l000T0oooo00<00?l00?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?l0003oool01P3o
ool00`3o0000oooo0000o`040?ooo`07003o003o0000oooo0?ooo`000?l0oooo003o000;0?ooo`04
003o00000?l0oooo0000o`H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l000020?oo
o`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3o00002`3oool01@00o`00oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`00o`001@3oool010000?l0oooo0?ooo`3o00020?ooo`040?l0
003oool0003o003o00D0oooo00@00?l00000o`3oool0o`000P3oool00`3o0000oooo0000o`070?oo
o`030000o`3o0000oooo00<0oooo00<0o`000?ooo`000?l06@3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0K0?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3o00000?l00080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`04003o003oool0oooo003o00<0oooo00<0003o0?l0003oool00P3oool0
0`00o`00003o0?ooo`030?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`03003o003oool0003o00T0oooo00H0003o0?l0003oool0o`000?oo
o`000?l70?ooo`030000o`3o00000?l000D0oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000oooo
0000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`040000o`3o0000
oooo003o00@0oooo00H0003o0?ooo`3o0000oooo0?l000000?l20?ooo`03003o003oool0oooo00@0
oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3o0000oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0003o003o
003oool00`3oool00`000?l0oooo0?ooo`080?ooo`03003o00000?l0oooo0080oooo00<00?l00?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool03@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool010000?l0oooo0?ooo`3o00040?ooo`030?l000000?l0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0o`000080oooo00D0003o
0?ooo`00o`00oooo0?l000090?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3o00001@3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00000`3oool00`3o0000oooo
0000o`020?ooo`06003o003oool00?l00?ooo`000?l0o`001@3oool00`3o0000oooo0000o`030?oo
o`04003o003oool0o`000000o`H0oooo00<0003o0?l0003oool02@3oool00`00o`00oooo0?ooo`09
0?ooo`03003o003o0000oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00o`000000o`08
0?ooo`030000o`3oool0oooo0080o`0000<0oooo0000o`3oool02@3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00004P3oool0103o0000oooo0?ooo`00
0?l50?ooo`040000o`3oool0oooo0?l000`0oooo00D0o`000?ooo`000?l0oooo003o000@0?ooo`03
0?l0003oool0003o00<0oooo00<00?l00?l000000?l01`3oool010000?l0oooo0?ooo`3o00040?oo
o`05003o003oool0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?l000060?ooo`030000o`3o0000
0?l001<0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`03003o003oool0oooo00<0oooo00<0
003o003o003oool02@3oool00`00o`00oooo0?ooo`050?ooo`80o`000`3oool00`00o`00oooo0?oo
o`030?ooo`030000o`3o0000oooo00H0oooo00<0o`000?ooo`000?l0103oool01P00o`00o`000?oo
o`3oool0003o003o00d0oooo00@0003o0?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?l0000;
0?ooo`04003o003oool0oooo0000o`@0oooo00<0o`00003o003oool01@3oool010000?l0oooo0?oo
o`3o00030?ooo`030000o`3oool00?l000@0oooo00D00?l00?ooo`000?l0oooo0?l000020?ooo`03
0?l0003oool0003o00L0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0000o`0I0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01l0oooo00H0003o0?ooo`3oool0
o`000?ooo`3o00020?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103oool0
0`000?l0oooo0?ooo`050?ooo`050000o`3o00000?l00?ooo`000?l01P3oool01@000?l0oooo0?oo
o`3oool00?l000<0oooo00H00?l00?ooo`3oool0oooo0000o`3o00030?ooo`03003o00000?l0oooo
00<0oooo00<0o`000000o`3oool01`3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0
oooo00<0oooo00<00?l00000o`3oool0203oool01P000?l0o`000?ooo`3o0000oooo0000o`L0oooo
00<0003o0?l00000o`001@3oool020000?l0oooo0?ooo`3o0000oooo0?l0003oool0003o203oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00@0003o0?l0003oool00?l0103o
ool020000?l0oooo0?l0003oool0o`000000o`3oool00?l01`3oool00`3o0000oooo0000o`030?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?l0003oool0
o`0000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l00?l00?ooo`030?ooo`030000o`3oool0
oooo00P0oooo00D00?l00000o`3oool0oooo003o00050?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0
o`00103oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`00o`00oooo0?l000020?ooo`050000o`3oool00?l00?ooo`3o00002@3oool00`3o
0000oooo0?l0000<0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0o`0000@0oooo00X0o`000000o`3oool0oooo003o003oool00?l00?ooo`00
0?l0o`001@3oool00`3o0000oooo0000o`040?ooo`03003o003o0000003o00H0oooo00<0003o0?oo
o`3o00002@3oool00`00o`00oooo0?ooo`090?ooo`03003o003o0000oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00o`000000o`080?ooo`070000o`3oool0o`000?ooo`3o0000oooo0000
o`0;0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l0
000B0?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3o00003@3oool00`3o0000oooo
0000o`020?ooo`03003o003oool0oooo00d0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00
o`000000o`070?ooo`030000o`3oool0o`0000D0oooo00<00?l00000o`3oool00P3oool00`000?l0
0?l00?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0
o`000?ooo`050?ooo`030000o`00o`00oooo01<0oooo00D0003o0?ooo`3oool0oooo0?l000080?oo
o`03003o003oool0oooo00<0oooo00<0003o003o003oool02P3oool00`00o`00oooo0?ooo`030?oo
o`030?l0003oool0o`0000<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0o`000?ooo`060?oo
o`030?l0003oool0003o00@0oooo00H00?l00?l0003oool0oooo0000o`00o`0<0?ooo`050000o`00
o`00oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0o`000080oooo
00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?l0000;0?ooo`04003o003oool0oooo0000
o`@0oooo00<0o`00003o003oool01@3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0
0?l000@0oooo00@00?l00?ooo`3oool0003o0`3oool00`3o0000oooo0000o`070?ooo`030000o`3o
0000oooo00<0oooo00<0o`000?ooo`000?l06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0O0?ooo`030000o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o1`3o
ool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00L0oooo00@0003o003o003oool0
003o1P3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0003o0?l00003
0?ooo`03003o00000?l0oooo00<0oooo00<0o`000000o`3oool01`3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo00<0oooo00<00?l00000o`3oool0203oool00`000?l0oooo0?l0
00020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l00000o`001@3oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`040000o`3o0000oooo003o00@0oooo00L0003o0?ooo`3o0000oooo0?l000000?l00?l0
00P0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3o00000P3oool0103o0000oooo0?ooo`000?l50?ooo`030000o`00o`00
oooo0080oooo00<00?l00000o`3oool02@3oool01@00o`00003o0?ooo`3oool00?l000D0oooo0P3o
000E0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?oo
o`050?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0o`0000D0oooo00<0o`000000o`3oool0103oool00`000?l00?l00?ooo`040?ooo`03003o
00000?l0oooo00D0oooo00<00?l00?ooo`3o00000`3oool010000?l00?l00?ooo`3o00090?ooo`03
0?l0003oool0o`0000`0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`070?ooo`03
0000o`3o0000oooo00<0oooo00@0o`000000o`3oool0oooo0P00o`020?ooo`030000o`3o0000oooo
00@0oooo00<0o`000?ooo`000?l01@3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool0o`00
00P0oooo00<00?l00?ooo`3oool02P3oool00`00o`00o`000?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<00?l00000o`3oool02@3oool01@000?l0o`000?ooo`3o0000003o00`0oooo00@0003o
0?l0003o0000o`00203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`000180oooo00<0
o`000?ooo`000?l01P3oool00`000?l0oooo0?l0000=0?ooo`030?l0003oool0003o0080oooo00<0
0?l00?ooo`3oool03@3oool02@3o0000oooo0?ooo`000?l0oooo003o003oool0o`000000o`070?oo
o`030000o`3oool0o`0000H0oooo00H0003o0?ooo`3oool0oooo0000o`00o`080?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`040?ooo`040000o`3o
ool0oooo0?l001<0oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`07003o003oool0oooo0?oo
o`000?l0oooo003o000;0?ooo`03003o003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`000P3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool01P00o`00o`000?ooo`3oool0003o003o00`0oooo00D0003o003o003oool0oooo0000o`050?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0000o`060?oo
o`030000o`3oool0o`0000/0oooo00@00?l00?ooo`3oool0003o103oool00`3o00000?l00?ooo`05
0?ooo`040000o`3oool0oooo0?l000<0oooo00@0003o0?ooo`3oool00?l00`3oool01000o`00oooo
0?ooo`000?l30?ooo`030?l0003oool0003o00L0oooo00<0003o0?l0003oool00`3oool00`3o0000
oooo0000o`0I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01l0oooo
00<0003o0?ooo`3o00000P3oool0103o0000oooo0?ooo`000?l70?ooo`040000o`3oool0oooo0?l0
00<0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo003o00000?l70?ooo`040000o`3oool0
oooo003o00@0oooo00D00?l00?ooo`3oool0003o0?l000020?ooo`03003o003o0000003o00@0oooo
00<0o`000000o`3oool01`3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00<0
oooo00<00?l00?ooo`000?l01`3oool010000?l0oooo0?ooo`3o00020?ooo`030000o`3oool0oooo
00D0oooo00<0003o003o003oool01@3oool00`000?l0oooo0?l000020?ooo`030?l0003oool0003o
00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`040000o`3o0000oooo
003o00<0oooo00L0003o0?ooo`3oool0o`000?ooo`3o0000003o00T0oooo00<0o`000?ooo`000?l0
103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o0000
0P3oool0103o0000oooo0?ooo`000?l50?ooo`030000o`3oool00?l00080oooo00<00?l00000o`3o
ool02@3oool01@00o`00003o0?ooo`3oool00?l000L0oooo0P3o000C0?ooo`030000o`3oool0oooo
00h0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0o`00
0?l00080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000050?ooo`030?l000000?l0
oooo00@0oooo00<0o`000000o`3oool0103oool00`00o`00003o0?ooo`060?ooo`03003o003o0000
oooo0080oooo00@0003o003o003oool0o`00203oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0
003oool0o`0000@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`000?l01`3oool00`000?l0o`000?ooo`030?ooo`030?l0
00000?l0oooo0080oooo00D00?l00?ooo`3oool0003o0?l000050?ooo`030?l0003oool0003o00D0
oooo00<00?l00000o`3oool01@3oool00`000?l0oooo0?l000070?ooo`03003o003oool0oooo00/0
oooo00<00?l00?l0003oool0103oool01P000?l0oooo0?ooo`00o`00oooo0000o`X0oooo00D0003o
0?l0003oool0o`000000o`0<0?ooo`040000o`3oool0oooo0?ooo`D0o`000`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3o0000oooo0140oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo
0?l0000>0?ooo`050?l000000?l0oooo0?ooo`00o`003P3oool02@3o0000oooo0?ooo`3oool0003o
0?ooo`00o`00oooo0000o`090?ooo`030000o`3o0000oooo00D0oooo00H0003o0?ooo`3oool0oooo
003o00000?l90?ooo`050?l0003oool0oooo0?ooo`000?l02`3oool00`000?l0o`000?ooo`040?oo
o`040000o`3oool0oooo0?l001<0oooo00@0003o0?ooo`3oool0o`002P3oool01`00o`00oooo0?oo
o`3oool0003o0?ooo`00o`00303oool01@00o`00oooo0?ooo`3oool0o`0000<0oooo00<0o`000?oo
o`00o`001P3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00H0o`00003o
003oool0oooo0000o`00o`0<0?ooo`050000o`00o`00oooo0?ooo`000?l0103oool00`000?l0oooo
0?ooo`080?ooo`030000o`3o0000oooo0080oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo
0?l0000<0?ooo`03003o00000?l0oooo00@0oooo00<0o`00003o003oool01P3oool00`000?l0oooo
0?l000030?ooo`040000o`3oool0oooo003o00<0oooo00@00?l00?ooo`3oool0003o0`3oool00`3o
0000oooo0000o`070?ooo`030000o`3o0000oooo00@0oooo00<0o`000000o`3oool0603oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool5000001d0oooo00<0003o0?ooo`3o00000P3oool00`3o0000
oooo0000o`080?ooo`040000o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0000o`080?ooo`030000o`3oool00?l000H0oooo00@00?l00000o`3oool0o`000P3oool0
0`00o`00o`000000o`040?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool00P3o0002
0?ooo`030000o`3oool0oooo00<0oooo00<0o`00003o00000?l01`3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo00@0oooo00<0003o003o003oool01@3oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool00?l000<0oooo00P0003o0?ooo`3oool0o`000?ooo`00o`00oooo0000
o`P0oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0000o`060?ooo`030?l000000?l00?l0
0080oooo00<00?l00000o`3oool02@3oool01@00o`00003o0?ooo`3oool00?l000T0oooo0P3o000@
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`06
0?ooo`070000o`3oool0o`000?ooo`3o0000oooo0000o`070?ooo`030000o`3o0000oooo00@0oooo
00<0o`000000o`3oool0103oool00`3o0000003o003o00040?ooo`03003o00000?l0o`0000H0oooo
00<00?l00?l0003oool00P3oool010000?l00?l00?ooo`3o00080?ooo`040?l0003oool0oooo0?l0
00`0oooo00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`070?ooo`030000o`3o0000
oooo00<0oooo00<0o`000000o`3oool00P3oool01@00o`00oooo0?ooo`000?l0o`0000D0oooo00<0
o`000?ooo`000?l01@3oool00`3o0000003o0?ooo`040?ooo`040000o`3oool0oooo0?l000H0oooo
00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool00?l00000o`3o
00002`3oool010000?l0oooo0000o`3o000<0?ooo`030?l000000?l0oooo00D0oooo00@0o`000?oo
o`3oool0003o203oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0003o00H0oooo00<0003o
0?ooo`3o00003P3oool01@3o0000003o0?ooo`3oool00?l000h0oooo00T0o`000?ooo`3oool0oooo
0000o`3oool00?l00?ooo`000?l02@3oool00`000?l0o`000?ooo`040?ooo`070000o`3oool00?l0
0?ooo`00o`00oooo0000o`090?ooo`050?l0003oool0oooo0?ooo`000?l02`3oool00`000?l0o`00
0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00004P3oool010000?l0oooo0?ooo`3o000:0?oo
o`07003o003oool0oooo0?ooo`000?l0oooo003o000<0?ooo`04003o003oool0oooo0?l000@0oooo
00<0o`000?ooo`00o`001P3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00<0oooo
00H0o`00003o003oool0oooo0000o`00o`0<0?ooo`030000o`3o0000oooo0080oooo00D0003o0?oo
o`3oool0oooo0000o`0:0?ooo`030000o`3o0000oooo0080oooo00<0o`000?ooo`000?l01P3oool0
0`000?l0oooo0?l0000<0?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0o`000?ooo`030?ooo`040000o`3oool0oooo003o0080oooo00D00?l00?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0003o00L0oooo00<0003o0?l0003oool0103oool00`3o0000003o
0?ooo`0D0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0003o00P0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`030000
o`3oool0oooo00H0oooo00D0o`000000o`3oool0003o003o00070?ooo`030000o`3oool00?l000H0
oooo00@00?l00000o`3oool0o`000P3oool00`00o`00oooo0000o`040?ooo`030000o`3o0000oooo
00L0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
003o00000?l01`3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00@0oooo00<0
003o003o003o00001@3oool00`000?l0oooo0?l000020?ooo`030?l0003oool0003o00P0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool00?l000<0oooo00<0
003o0?ooo`3oool00P00o`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00000P3o
ool00`3o0000oooo0000o`060?ooo`030?l000000?l00?l00080oooo00<00?l00000o`3oool02@3o
ool01@00o`00003o0?ooo`3oool00?l000/0oooo1@3o000;0?ooo`030000o`3oool0oooo0100oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`070000o`3oool0o`000?ooo`3o
0000oooo0000o`070?ooo`030000o`3o0000oooo00@0oooo00<0o`000000o`3oool00`3oool0103o
0000oooo0000o`00o`040?ooo`03003o00000?l0o`0000H0oooo00<00?l00?l0003oool00P3oool0
10000?l00?l00?ooo`3o00080?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo
0?ooo`030?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l01`3oool00`000?l0
o`000?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l000000?l0oooo00@0oooo00@0003o0?ooo`3oool0o`001@3oool00`00
o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo00D0oooo00@0003o003o00000?l0o`002`3oool0
10000?l0oooo0000o`3o000;0?ooo`030?l0003oool0003o00H0oooo00@0o`000?ooo`3oool0003o
203oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3o0000
3P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00H0o`000?ooo`3oool0
oooo003o00000?l20?ooo`030000o`3o0000oooo00L0oooo00<0003o0?l0003oool0103oool01@00
0?l0oooo003o003oool00?l00080oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3o
ool0003o00/0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3o00002P3oool01`00o`00oooo0?ooo`3oool0003o003o003o
00003@3oool00`00o`00o`000?ooo`040?ooo`030?l0003oool00?l000H0oooo00<0o`000000o`3o
ool01`3oool00`000?l0oooo0?ooo`030?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0o`000?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`00
0?l0o`000?ooo`020?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3o0000303oool00`00
0?l0oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0003o0?l0003oool00`3oool01`00
0?l0oooo0?ooo`3oool00?l00?ooo`00o`000`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`00
0?l01`3oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0oooo01P0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0803oool00`000?l0o`000?ooo`020?ooo`030?l0
00000?l0oooo00L0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00H0
oooo00D0o`000000o`3oool0003o003o00070?ooo`030000o`3oool00?l000L0oooo00<0003o0?oo
o`3o00000P3oool00`00o`00oooo0000o`040?ooo`030000o`3o0000oooo00L0oooo00D0003o0?oo
o`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l01`3oool0
10000?l0oooo0?ooo`00o`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001P3o
ool00`000?l0o`000?ooo`020?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo003o0080oooo00D0003o003o0000o`00
oooo0?l000020?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool01@3oool01@000?l0
oooo0?ooo`3oool0003o00/0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o00H0oooo00<0
o`000000o`00o`000P3oool00`00o`00003o0?ooo`090?ooo`050?l000000?l0oooo0?ooo`00o`00
403oool50?l000H0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00H0oooo00L0003o0?ooo`3o0000oooo0?l0003oool0003o00L0oooo00<0003o0?l0
003oool0103oool00`3o0000003o0?ooo`030?ooo`040?l0003oool0003o003o00<0oooo00@00?l0
0?ooo`000?l0o`001P3oool00`00o`00o`000?ooo`030?ooo`030000o`3oool0o`0000P0oooo00D0
o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0003o00L0oooo00<0003o0?l0003oool00`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
003o003o00040?ooo`040000o`3oool0oooo0?l000D0oooo00<00?l00?ooo`3oool03P3oool00`00
o`00oooo0?ooo`050?ooo`05003o00000?l0oooo0?ooo`3o00002P3oool0103o0000003o0?ooo`3o
000;0?ooo`030?l0003oool0003o00H0oooo00@0o`000?ooo`3oool0003o203oool00`000?l0o`00
0?ooo`0B0?ooo`030?l000000?l0oooo00H0oooo00<0003o0?l0003oool03@3oool00`000?l0o`00
0?ooo`020?ooo`03003o003oool0oooo00X0oooo00L0o`000?ooo`3oool0oooo003o003oool0003o
0080oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`00o`000`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0003o00`0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0100oooo00<0003o
0?l0003oool02P3oool01`00o`00oooo0?ooo`3oool0003o003o003o00003@3oool00`3o00000?l0
0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0o`000000o`3oool01`3oool00`000?l0oooo
0?ooo`030?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`00
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`000?l0o`000?ooo`020?ooo`03
0?l0003oool0003o00L0oooo00<0003o0?l0003oool02`3oool00`000?l00?l00?ooo`040?ooo`03
003o003o0000oooo00H0oooo00<0003o0?l0003oool00`3oool01`000?l0o`000?ooo`3oool00?l0
0?ooo`00o`000`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l01`3oool00`000?l0o`00
0?ooo`040?ooo`030?l000000?l0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00L0oooo00D0
003o0?ooo`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00H0oooo00H0o`000?ooo`000?l0
003o0?ooo`00o`060?ooo`030000o`00o`00oooo00L0oooo00P0003o0?ooo`3o0000oooo003o003o
0000oooo0000o`@0oooo00<0003o0?l0003oool01`3oool01@000?l0oooo0?l0003oool0o`000080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0000o`070?ooo`050000o`3oool00?l00?oo
o`00o`000P3oool00`000?l0oooo0?ooo`030?ooo`040000o`00o`00oooo0?l000H0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool01`000?l0oooo0?ooo`00o`00oooo003o00000?l00`3oool0103o0000oooo
0?ooo`000?l80?ooo`030?l000000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`0;0?oo
o`030000o`3o0000oooo0080oooo00<0o`000000o`3oool0103oool0103o0000oooo0000o`00o`02
0?ooo`03003o00000?l0oooo00T0oooo00D0o`000000o`3oool0oooo003o000E0?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00L0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o00L0oooo00<0003o0?l0003o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0003o0?ooo`00o`000P3oool01000
o`00oooo0000o`3o00060?ooo`03003o003o0000oooo00<0oooo00<0003o0?ooo`3o00001`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l01`3oool00`000?l0o`000?oo
o`030?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`050?l0003oool0003o0?ooo`00o`000`3oool010000?l0oooo0?ooo`3o00040?ooo`03
003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0oooo00P0oooo00@0o`000?ooo`3oool0o`002`3oool00`3o0000oooo0000o`070?oo
o`030?l0003oool0003o00P0oooo00<0003o0?l0003oool04P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3o0000oooo00d0oooo00<0003o0?l0003oool00P3oool00`00o`00oooo0?ooo`0:0?oo
o`040?l0003oool00?l0003o0080oooo00D0003o0?ooo`000?l0oooo0?l000080?ooo`030?l00000
0?l0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0003o00`0oooo00<0o`000000o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?l0003oool02`3oool01P00o`00oooo0?ooo`000?l00?l00?l000d0
oooo00<0o`000?ooo`00o`001@3oool00`00o`00oooo0?ooo`050?ooo`030?l000000?l0oooo00H0
oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`00o`020?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0003o
0?l0003oool00P3oool00`3o0000oooo0000o`070?ooo`030000o`3o0000oooo00/0oooo00<0003o
003o003oool0103oool00`00o`00o`000?ooo`060?ooo`030000o`3o0000oooo00<0oooo00L0003o
0?l0003oool0oooo003o003oool00?l000<0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0003o
00L0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo
01L0oooo000K0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000003@3oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`3oool01`3oool01@000?l0
oooo0?l0003oool0o`000080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`020?oo
o`03003o003oool0oooo00@0oooo00<0003o003o003oool01`3oool01P000?l00?l00?l0003oool0
0?l00?l00080oooo00H0003o0?ooo`3oool0oooo0000o`3o00080?ooo`030000o`3oool0o`000080
oooo00<0o`000000o`3oool01@3oool0103o0000oooo0000o`00o`060?ooo`050000o`00o`00oooo
0?ooo`00o`000P3oool00`000?l0oooo0?ooo`030?ooo`040000o`00o`00oooo0?l000H0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01@3oool0103o0000003o0?ooo`3oool2003o00030?ooo`000?l0oooo0080oooo
00@0o`000?ooo`3oool0003o203oool00`3o0000003o0?ooo`050?ooo`050000o`3oool0oooo0?oo
o`000?l02`3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00@0oooo00T0o`000?oo
o`000?l0oooo003o003oool00?l00000o`3o00002@3oool01@3o0000003o0?ooo`3oool00?l001H0
oooo00D0o`000?ooo`3oool0oooo0000o`0D0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool01`3oool01P000?l0o`000?ooo`3oool0o`000000o`P0oooo00<0003o0?l0003oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0003o0?ooo`00o`000P3oool01000o`00oooo
0000o`3o00070?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool0o`001P3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`000?l00`3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3o
ool0o`0000L0oooo00<0o`000?ooo`000?l01`3oool00`000?l0o`000?ooo`030?ooo`030000o`3o
0000oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`050?l0003o
ool0003o0?ooo`00o`000`3oool010000?l0oooo0?ooo`3o00030?ooo`03003o003oool0oooo00l0
oooo00<0o`000?ooo`00o`00103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00L0
oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`00
0?ooo`000?l0203oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?l0003oool03@3oool00`000?l0o`000?ooo`030?ooo`03003o003oool0oooo00T0oooo0P00o`04
0?ooo`050000o`3oool0003o0?ooo`3o0000203oool00`3o0000003o0?ooo`020?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`0<0?ooo`030?l00000
0?l0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
0000oooo00/0oooo00H00?l00?ooo`3oool0003o003o003o000<0?ooo`040?l0003oool0oooo003o
00D0oooo00<00?l00?ooo`3oool01@3oool00`3o0000003o0?ooo`060?ooo`030000o`3o0000oooo
00<0oooo00@0o`000?ooo`3oool00?l00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
o`0000<0oooo00@0003o0?ooo`3oool0003o2P3oool00`000?l0o`000?ooo`020?ooo`030?l0003o
ool0003o00L0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo003o00050?ooo`03003o003o
0000oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000?l0o`000?ooo`3oool2003o00<0oooo
00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00@0oooo
00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`3oool01`3oool01@00
0?l0oooo0?l0003oool0o`000080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`03
0?ooo`03003o003oool0oooo00<0oooo00<0003o003o003oool01`3oool01P000?l00?l00?l0003o
ool00?l00?l00080oooo00H0003o0?ooo`3oool0oooo0000o`3o00090?ooo`060000o`3o0000oooo
0?ooo`3o0000003o1P3oool0103o0000oooo0000o`00o`050?ooo`030000o`00o`00oooo00<0oooo
00@00?l00?ooo`3oool0003o103oool010000?l00?l00?ooo`3o00060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000000o`3oool01P3oool010000?l0oooo0?l000000?l;0?ooo`030000o`3oool0
oooo0080oooo00<0o`000000o`3oool0103oool02@3o0000oooo0000o`3oool00?l00?ooo`000?l0
oooo0?l000090?ooo`040?l00000o`00003o003o01L0oooo00D0o`000?ooo`3oool0oooo0000o`0D
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool01P000?l0o`000?ooo`3o
ool0o`000000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0o`000?ooo`030?ooo`030?l0
003oool0003o0080oooo00H00?l00?ooo`00o`00oooo0000o`3o00060?ooo`030?l00000o`00oooo
00<0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
003o00h0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`030?l000000?l0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`050?ooo`030?l000000?l0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`000?l0oooo00<00?l000L0003o0?ooo`3oool0
oooo0?l0003oool00?l00180oooo00<0o`000?ooo`00o`000`3oool00`00o`00oooo0?ooo`040?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?oo
o`050?l0003oool0oooo0?ooo`000?l01P3oool00`3o0000oooo0000o`080?ooo`030?l000000?l0
oooo0180oooo00<0003o0?ooo`3oool01P3oool00`000?l0o`000?ooo`0=0?ooo`030000o`3oool0
o`0000<0oooo00<00?l00?ooo`3oool0203oool00`00o`00o`000?ooo`050?ooo`80003o00<0oooo
0?l0003oool01`3oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`050?l000000?l0oooo0?ooo`000?l0203o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo00H00?l00?ooo`3oool0003o
003o003o000;0?ooo`030?l0003oool0oooo0080oooo00H00?l00?ooo`3oool0oooo003o003o0007
0?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3o00000`3oool0103o0000oooo0?ooo`00
o`020?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o00000`3oool010000?l0oooo0?oo
o`000?l:0?ooo`030000o`3o0000oooo0080oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo
0?ooo`0:0?ooo`040000o`3oool0oooo003o00@0oooo00<00?l00?l0003oool01P3oool00`3o0000
003o0?ooo`030?ooo`030000o`3o0000oooo0080oooo00H00?l00?ooo`3oool0oooo0?l000000?l4
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`0H
0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`L00000703oool00`000?l0oooo0?ooo`02
0?ooo`030?l000000?l0oooo00L0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`030000o`00
o`00oooo00L0oooo00D0003o0?ooo`00o`00oooo003o00030?ooo`060000o`3oool0oooo0?ooo`00
0?l0o`002@3oool01P000?l0o`000?ooo`3oool0o`000000o`H0oooo00@0o`000?ooo`000?l00?l0
1@3oool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo0000o`@0oooo00@0003o0?ooo`3o
ool0o`001P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00D0003o0?oo
o`3oool0oooo0000o`080?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3o0000003o2`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00@0oooo00@0o`000?ooo`3oool0003o
0P00o`000`000?l0oooo0?l000090?ooo`040?l00000o`00003o003o01P0oooo00@0o`000?ooo`3o
ool0003o503oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?oo
o`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool00`3oool0
0`3o0000oooo0000o`020?ooo`800?l000@0oooo0000o`3oool0o`001P3oool00`3o00000?l00?oo
o`020?ooo`05003o003oool0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0003o00h0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`030?l000000?l0oooo00H0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`050?ooo`030?l000000?l0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`00o`000?l0
00<00?l04`3oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00D0o`000?oo
o`3oool0oooo0000o`060?ooo`030?l0003oool0003o00P0oooo00<0o`000000o`3oool04P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o00000`3oool0
0`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00203o
ool00`3o0000oooo0000o`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103o
ool20000o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00h0oooo00<0o`000000o`3oool02`3oool01P00o`00oooo0?oo
o`000?l0oooo0?l000/0oooo00<0o`000?ooo`3oool00`3oool01P00o`00oooo0?ooo`00o`00oooo
0?l000D0oooo00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?l000030?ooo`040?l0003o
ool0oooo003o0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000030?ooo`040000
o`3oool0oooo0000o`X0oooo00<0003o0?l0003oool00P3oool00`3o0000oooo0000o`070?ooo`03
0000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool00?l0103oool00`00o`00o`000?ooo`060?oo
o`030?l000000?l0oooo0080oooo00<0003o0?ooo`3o00000`3oool01P00o`00oooo0?ooo`3oool0
o`000000o`@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0o`000?ooo`040?ooo`030000o`3o
ool0oooo0180oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`00000;0?ooo`040000003o
ool0oooo0?ooo`8000003@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0080oooo
00<0o`000000o`3oool01`3oool01`000?l0oooo0?l0003oool0o`000?ooo`000?l02@3oool00`3o
0000oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool01@00
0?l0oooo003o0000o`00o`0000<0oooo00H0003o0?ooo`3oool0oooo0000o`3o00090?ooo`060000
o`3oool0oooo0?ooo`3o0000003o1P3oool01@3o0000oooo0000o`3oool00?l000<0oooo00<00?l0
0000o`3oool01@3oool00`00o`00oooo0000o`040?ooo`040000o`3oool0oooo0?l000H0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0o`000?ooo`000?l0
203oool00`3o0000oooo0000o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0o`000?ooo`060?ooo`040000o`3o0000o`000000o`/0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`800?l000<0003o0?oo
o`3o00002@3oool0103o00000?l00000o`00o`0I0?ooo`030?l0003oool0003o01@0oooo00<0003o
0?ooo`3oool01@3oool40?l000030?ooo`000?l0oooo00P0oooo00<0o`000000o`3oool00P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool00`3oool0
103o0000oooo0?ooo`000?l20?ooo`05003o003oool0003o0?ooo`3o00001P3oool00`3o00000?l0
0?ooo`020?ooo`05003o003oool0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`040?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`000?l03P3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`050?ooo`030?l000000?l0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`050000o`3oool0oooo0?ooo`3o
0000203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool00?l00080oooo00<00?l00?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool01`3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`000?l0203oool00`3o
0000003o0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0303oool01000
0?l0oooo0?ooo`3o00030?ooo`03003o003oool0oooo00L0oooo00<00?l00?l0003oool01P3oool0
10000?l0oooo0?ooo`3o00080?ooo`050?l0003oool0003o0?ooo`000?l0303oool00`000?l0oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0000o`020?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000003o0?ooo`0<0?ooo`05
003o003oool0003o0?ooo`3o00002`3oool00`3o0000oooo0?ooo`040?ooo`05003o003oool00?l0
0?ooo`3o00001@3oool0103o0000oooo0?ooo`000?l60?ooo`030000o`3oool0o`000080oooo00<0
o`000?ooo`3oool00P3oool2003o00030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o0000103o
ool00`000?l0oooo0000o`0:0?ooo`030000o`3o0000oooo00<0oooo00<0o`000000o`3oool01P3o
ool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`00o`00103oool00`00o`00oooo
0?l000060?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3o00001`3oool00`3o0000003o
0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01l0
oooo00<0o`000000o`3oool00`3oool00`3o0000003o0?ooo`080?ooo`060000o`3o0000oooo0?l0
003oool0003o2@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool01`3oool01@000?l0oooo0?ooo`00o`00o`0000<0oooo00H0003o0?ooo`3oool0oooo
0000o`3o00090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool01@3o0000
oooo0?ooo`000?l00?l00080oooo00<00?l00?ooo`000?l01`3oool00`00o`00003o0?ooo`030?oo
o`040000o`3oool0oooo0?l000D0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`08
0?ooo`050000o`3oool0o`000?ooo`000?l0203oool00`3o0000oooo0000o`030?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`070?ooo`030000o`3o
ool0003o00/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0o`000?ooo`040?ooo`090?l0003o
ool0oooo0000o`3oool00?l00000o`3oool0o`0000T0oooo00@0o`00003o00000?l00?l06P3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0o`0000@0o`000`3oool00`3o0000oooo0000o`09
0?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o0P3oool01@00o`00oooo0000
o`3oool0o`0000H0oooo00<0o`00003o003oool00P3oool01@00o`00oooo0000o`3oool0o`0000D0
oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0o`00
00D0oooo00<0o`000000o`3oool03P3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`3oool0
oooo00H0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?l000050?ooo`030?l000000?l0
oooo00D0oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool01@3oool20?l000/0oooo00<0o`000?ooo`3oool00P00
o`080?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0000
o`080?ooo`030?l000000?l0oooo0140oooo00<0003o0?l0003oool01`3oool00`3o0000003o0?oo
o`0<0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`060?ooo`03003o
003o0000oooo00T0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0000o`3oool0003o00`0
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00T0oooo00D0o`000?oo
o`000?l0oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`3oool0303oool0
1@00o`00003o003o003oool0o`0000/0oooo00<0o`000?ooo`3oool0103oool2003o0080oooo00<0
o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l60?ooo`030000o`3oool0o`000080oooo
00<0o`000?ooo`3oool00P3oool2003o00030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0
o`000`3oool20000o`/0oooo00<0003o0?l0003oool00`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`020?oo
o`030?l0003oool0oooo00@0oooo00<0o`000000o`3oool00P3oool00`000?l0oooo0?l000070?oo
o`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00000:0?ooo`80
0000103oool3000000`0oooo00<000000?ooo`3oool07`3oool00`3o0000003o0?ooo`030?ooo`03
0000o`3oool0oooo00P0oooo00H0003o0?ooo`3oool0oooo0?l000000?l90?ooo`030?l0003oool0
oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo0080o`000`3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o0000203oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0003o0?ooo`02003o0080oooo00<0003o0?oo
o`3oool01@3oool00`00o`00003o0?ooo`030?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`00
0?ooo`000?l00`3oool00`000?l0o`000?ooo`080?ooo`050000o`3o0000o`000?ooo`000?l0203o
ool00`3o0000oooo0000o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0o`000?ooo`070?ooo`80003o00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3o0000oooo00@0oooo00T0o`000?ooo`3oool0003o0?ooo`00o`00003o0?oo
o`3o00002@3oool0103o00000?l00000o`00o`0J0?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?l0003oool0203oool00`3o0000003o0?ooo`080?ooo`030?l000000?l0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo00<0oooo00@0o`00
0?ooo`3oool0003o103oool00`000?l0oooo0?l000060?ooo`030?l00000o`00oooo0080oooo00D0
0?l00?ooo`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0
003o0`3oool00`000?l0oooo0?l000050?ooo`030?l000000?l0oooo00l0oooo00<0003o0?ooo`3o
00002@3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3o
00001@3oool00`3o0000003o0?ooo`050?ooo`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3o
ool0003o0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3o00002`3oool0103o0000oooo0?ooo`00o`0:0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000003o0?ooo`080?ooo`030?l000000?l0oooo0140oooo00<0003o
0?l0003oool01`3oool00`3o0000003o0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003o0000oooo00/0oooo00<0o`000?ooo`3oool0103o
ool01@3o0000oooo0?ooo`3oool0003o00h0oooo0`000?l50?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool00P000?l;0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`000?l0
3@3oool01@00o`00003o003o003oool0o`0000X0oooo00<0o`000?ooo`3oool01P3oool01000o`00
oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000o`D0oooo00@0003o0?ooo`3oool0o`000P3o
ool00`3o0000oooo0?ooo`020?ooo`800?l000<0003o0?ooo`3oool02P3oool010000?l0oooo0?oo
o`3o00030?ooo`80003o303oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo003o0080
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0000o`020?ooo`040000o`3oool0oooo0?l0
00H0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0O0?ooo`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool0203oool01P000?l0
oooo0?ooo`3oool0o`000000o`T0oooo00<0o`000?ooo`3oool01@3oool01@00o`00oooo0?ooo`00
o`00003o00T0oooo00@0003o0?ooo`3oool0o`00103oool01`000?l0oooo0?ooo`3oool0003o0?oo
o`3o0000203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00H0o`000?oo
o`3oool0003o0?ooo`00o`030?ooo`030000o`3oool0oooo00H0oooo00H00?l00000o`3oool0oooo
003o00000?l20?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l00`3oool00`000?l0
o`000?ooo`080?ooo`050000o`3o0000o`000?ooo`000?l0203oool01P3o0000oooo0?ooo`000?l0
oooo0000o`T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`070?ooo`80003o00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo00@0oooo00T0
o`000?ooo`3oool0003o0?ooo`00o`00003o0?ooo`3o00002@3oool0103o00000?l00000o`00o`0J
0?ooo`030000o`3o0000oooo01@0oooo00<0003o0?ooo`3oool0203oool00`3o0000003o0?ooo`07
0?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`04
0?ooo`030000o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?l0
00060?ooo`030?l0003oool00?l00080oooo00D00?l00?ooo`3oool0003o0?l000050?ooo`030?l0
003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?l000060?ooo`03
0000o`3oool0oooo00h0oooo00<0003o0?l0003oool02@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l000000?l0oooo0080oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0000o`060?oo
o`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000000o`3oool04@3oool00`000?l0oooo0?l000070?ooo`030?l00000
0?l0oooo00`0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`03003o003oool0oooo00D0oooo
00<00?l00?l0003oool02`3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`00
0?l03P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3o
ool0003o3@3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0000o``0oooo00D00?l0
0000o`00o`00oooo0?l0000:0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3o
ool0103o0000oooo0?ooo`000?l50?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3o
ool00P3oool2003o00030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`000`3oool20000
o``0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`00o`020?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`000?l00P3oool010000?l0oooo0?ooo`3o00050?ooo`040?l0003o
ool0oooo0000o`<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07`3o
ool00`3o0000oooo0000o`030?ooo`030000o`3o0000oooo00P0oooo00H0003o0?ooo`3oool0oooo
0?l000000?l90?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`00o`00003o2@3oool01000
0?l0oooo0?ooo`3o00040?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0003o00<0oooo00<0003o0?l0003oool02@3oool010000?l0
oooo0?l000000?l80?ooo`060?l0003oool0oooo0000o`3oool0003o2@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3o0000oooo00H0oooo00@0o`000?ooo`000?l0o`002`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3o0000oooo00@0oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0
oooo0?l000090?ooo`040?l00000o`00003o003o01X0oooo00<0003o0?ooo`3o00004`3oool00`3o
0000003o0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l00P3oool00`00
0?l0o`000?ooo`070?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo003o0002
0?ooo`05003o003oool0oooo0000o`3o0000103oool00`3o0000oooo0?ooo`050?ooo`040?l0003o
ool0oooo0000o`<0oooo00<0003o0?ooo`3o00001P3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3o0000oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`020?ooo`040000
o`3oool0oooo0?l000@0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`000?ooo`030?ooo`04
0?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0003o0140oooo00<0003o0?ooo`3o00001`3oool00`3o0000003o0?ooo`0<0?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`03003o003oool0
o`0000`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0
oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`0=0?ooo`030?l0003oool0oooo00/0oooo00@0
o`000?ooo`3oool0003o3@3oool010000?l0oooo0?ooo`3o000:0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l50?ooo`060000o`3oool0oooo
0?l0003oool0o`001P3oool00`00o`00003o0?ooo`0;0?ooo`040000o`3oool0oooo0?l000@0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo003o0080
oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l20?ooo`040000o`3oool0oooo
0?l000D0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l00000
0?l0oooo00@0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`00?03oool5
000001`0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0o`000?ooo`080?ooo`060000o`3o
ool0oooo0?ooo`3o0000003o203oool00`3o0000oooo0?ooo`070?ooo`04003o003oool00?l00000
o`T0oooo00@0003o0?ooo`3oool0o`001@3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0o`000?ooo`030?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0000o`@0oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`060000o`3oool0oooo0?ooo`000?l0o`002P3oool0
10000?l0oooo0?l000000?l80?ooo`060?l0003oool0oooo0000o`3oool0003o2@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3o0000oooo00H0oooo00@0o`000?ooo`000?l0o`002P3oool00`3o
0000003o0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00T0o`000?ooo`3oool0oooo0000o`3o
ool0003o0?ooo`3o00002@3oool0103o0000oooo003o00000?l=0?ooo`030000o`3oool0oooo00T0
oooo00@0003o0?ooo`3oool0o`004@3oool20?l00080oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0o`000?ooo`070?ooo`080?l0003oool0oooo0000o`3oool0003o0?ooo`3o00070?ooo`030?l0
00000?l0oooo00@0oooo00<0003o0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo003o00020?ooo`06003o003oool0oooo0000
o`3oool0o`000`3oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo00@0oooo00<0003o
0?l0003oool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o0000oooo00T0oooo00<0003o
0?l0003oool01P3oool00`3o0000003o0?ooo`020?ooo`040000o`3oool0oooo0?l000@0oooo00<0
o`000?ooo`000?l01@3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo0000o`<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0000oa40
oooo00<0003o0?ooo`3o00001`3oool00`3o0000003o0?ooo`0<0?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`03003o003o0000oooo00`0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool0403oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000o`d0oooo00@0003o
0?ooo`3oool0o`002P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`060000o`3oool0oooo0?l0003oool0o`001P3oool00`00
o`00003o0?ooo`0;0?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`040?ooo`03003o003oool00?l00080oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0?l000D0oooo00@0o`000?ooo`3oool0
003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3o
ool0503oool5000001T0oooo000l0?ooo`030000003oool0oooo01h0oooo00@0o`000?ooo`3oool0
003o0`3oool00`000?l0o`000?ooo`080?ooo`060000o`3oool0oooo0?ooo`3o0000003o203oool0
0`3o0000oooo0?ooo`080?ooo`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00H0oooo00L0003o0?ooo`3oool0oooo
0000o`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo
00P0oooo00@0003o003o003oool0003o103oool01@3o0000oooo0?ooo`3oool0o`000080oooo00H0
003o0?ooo`3oool0003o0?ooo`3o00090?ooo`040?l000000?l0oooo0000o`T0oooo00H0o`000?oo
o`3oool0003o0?ooo`000?l90?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool01P3o
ool0103o0000oooo0?ooo`3o000:0?ooo`030?l0003oool0003o0080oooo00@0003o0?ooo`3oool0
o`00103oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000080?ooo`050?l0003o
ool0oooo003o00000?l03@3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o
00003`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0003o
ool01`3oool0203o0000oooo0?ooo`000?l0oooo0000o`3oool0o`001P3oool00`3o0000oooo0000
o`050?ooo`030000o`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000
o`3oool0o`0000H0oooo00<0o`000?ooo`00o`000P3oool01P00o`00oooo0?ooo`000?l0oooo0?l0
00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo
00@0oooo00<0003o0?l0003oool03`3oool00`000?l0o`000?ooo`090?ooo`030000o`3o0000oooo
00D0oooo00<0o`000?ooo`000?l00`3oool010000?l0oooo0?ooo`3o00040?ooo`030?l0003oool0
003o00D0oooo00<0003o0?ooo`3o0000103oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o
ool0oooo00<0oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo00@0o`000?ooo`3oool0003o403oool010000?l0oooo0?ooo`3o00070?oo
o`030?l000000?l0oooo00`0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`00o`04
0?ooo`03003o003oool0o`0000d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0I
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`000?l00?l00?ooo`02
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20?l000L0oooo
00<0003o0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0o`000100oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00P0oooo00<0003o0?ooo`3o
ool0103oool00`00o`00oooo003o00020?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
ool0003o0P3oool010000?l0oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000o`<0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo01P0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07P3oool0103o0000oooo0?ooo`00
0?l30?ooo`030000o`3o0000oooo00P0oooo00H0003o0?ooo`3oool0oooo0?l000000?l80?ooo`03
0?l0003oool0oooo00P0oooo00@00?l00?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000003o0?ooo`020?oo
o`030000o`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0
oooo00T0oooo00<0003o003o00000?l0103oool01@3o0000oooo0?ooo`3oool0o`000080oooo00H0
003o0?ooo`3oool0003o0?ooo`3o00090?ooo`040?l000000?l0oooo0000o`P0oooo00L0o`000?oo
o`3oool0oooo0000o`3oool0003o00T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l0
00070?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`3o0000oooo0000o`020?ooo`040000
o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0000o`3oool0o`00
00P0oooo00D0o`000?ooo`3oool00?l00000o`0<0?ooo`030000o`3oool0003o00X0oooo00D0003o
0?ooo`3oool0oooo0?l0000>0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?l000060?ooo`090?l0003oool0oooo0?ooo`000?l0oooo0000o`3oool0o`00
00H0oooo00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?l000020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`000?l0oooo0?l000060?ooo`030?l0003oool00?l00080oooo00H00?l0
0?ooo`3oool0oooo0000o`3o00030?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00l0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0003o00<0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030?l0003oool0003o00D0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`3o00001P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool0003o203o
ool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`000?l0
2`3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo003o00@0oooo00<00?l00?ooo`3o
00003@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`3oool20?l000L0oooo00<0003o0?ooo`3oool02P3oool0
1@000?l0oooo0?ooo`3oool0o`000100oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0oooo00P0oooo00<0003o0?ooo`3oool0103oool2003o00@0oooo00<0
o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`3o0000
oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000003o0?ooo`040?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool07P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o0000oooo
00P0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0003o0080oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`0000@0oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo00T0oooo00<0003o003o00000?l0103o
ool01@3o0000oooo0?ooo`3oool0o`000080oooo00H0003o0?ooo`3oool0003o0?ooo`3o00090?oo
o`040?l000000?l0oooo0000o`P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`000?l00P3oool010000?l0oooo0?ooo`3o
00030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`000?l0oooo0?l000080?ooo`060?l0
003oool0oooo003o003oool0003o2`3oool00`000?l0oooo0000o`0:0?ooo`050000o`3oool0oooo
0?ooo`3o00003@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3o00001P3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000060?ooo`03
0?l0003oool0003o00@0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?oo
o`070000o`3oool0oooo0?ooo`000?l0oooo0?l000060?ooo`030?l0003oool00?l00080oooo00H0
0?l00?ooo`3oool0oooo0000o`3o00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000l0oooo00<0o`000000o`3o
ool02@3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0003o00<0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030?l0003oool0003o00D0oooo00@0003o0?ooo`3oool0o`000P3oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`D0oooo0P3o00070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l70?ooo`030000
o`3oool0003o00H0oooo00@0003o0?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`000?l;0?oo
o`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`03003o003oool0
o`0000h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`3o00040?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo
00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`02
0?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`040?l0003oool0oooo0000o`<0oooo00<0
003o0?l0003oool0203oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool0
o`000`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0000o`02
0?ooo`030?l0003oool0oooo00H0oooo00@0o`000000o`3oool0003o203oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l0
00060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0000
o`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool20000o`80oooo
00<0o`000?ooo`3oool01P3oool01P3o0000oooo0?ooo`00o`00oooo0000o`/0oooo00@0003o0?oo
o`3oool0003o2@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0oooo00T0o`00
0?ooo`3oool0oooo0000o`3oool0003o0?ooo`3o00001P3oool00`3o0000oooo0000o`040?ooo`07
0000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`000?l00P3o
ool00`3o0000oooo0?ooo`030?ooo`060?l0003oool0oooo003o003oool00?l00`3oool01@000?l0
o`000?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?ooo`040?oo
o`030000o`3oool0o`0000l0oooo00<0o`000000o`3oool0203oool00`000?l0oooo0?l000060?oo
o`030?l0003oool0003o00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0
003o00D0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0003o00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
0000oooo00H0oooo00@0o`000?ooo`3oool0003o1@3oool20000o`<0oooo00<0003o0?ooo`3oool0
0`3oool010000?l0oooo0?ooo`3o00060?ooo`040?l0003oool0oooo0000o`/0oooo00<0003o0?oo
o`3oool01@3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0o`0000h0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool02`3oool0103o0000oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`000?l0
103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P000?l40?ooo`030?l0003oool0oooo0080
oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0o`000?ooo`070?ooo`030?l000000?l0oooo
00@0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0M0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0o`000?ooo`070?oo
o`030?l000000?l0oooo0080oooo00<0003o0?l0003oool01`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`030?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l00P3oool010000?l0oooo0?ooo`3o0003
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0003o00@0oooo00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0000o`020?ooo`030?l0
003oool0oooo00D0oooo00H0o`000?ooo`000?l0oooo0000o`3o00070?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo
0?l000D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
003o0080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo0080oooo0P00
0?l20?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`090?ooo`040000o`3oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo
0?ooo`3o00040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`000?l0oooo0?l000060?oo
o`030?l0003oool0003o00@0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000@0oooo00@0
003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`070?l0003oool0oooo0?ooo`00
o`00oooo003o00030?ooo`050000o`3o0000oooo0?ooo`3o00002@3oool00`000?l0o`000?ooo`04
0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3o00003`3oool00`3o0000003o0?ooo`08
0?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`000?l00`3oool01@000?l0oooo0?ooo`3o
ool0o`000080oooo00@0o`000?ooo`3oool0003o1@3oool010000?l0oooo0?ooo`3o00020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`000?l0403oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3o0000oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
00@0oooo0P000?l30?ooo`040000o`3oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0003o2`3o
ool00`000?l0oooo0?ooo`050?ooo`060?l0003oool0oooo003o003oool00?l00P3oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`00103oool01@00
0?l0oooo0?ooo`3oool0003o00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3o
ool0o`0000@0oooo0P000?l40?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo
0?ooo`000?l0o`0000P0oooo00<0o`000000o`3oool00`3oool00`000?l0o`000?ooo`0I0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`D000006`3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00<0003o0?ooo`3o00001`3oool00`3o0000003o0?ooo`020?ooo`030000o`3o0000oooo00L0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0003o0080
oooo00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo
0000o``0oooo0P000?l50?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`000?l00P3o
ool00`3o0000oooo0?ooo`050?ooo`060?l0003oool0003o0?ooo`000?l0o`001`3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00103oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`000?l00P3oool01@00
0?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`3o
00080?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?oo
o`3oool0003o00P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo0P000?l60?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
ool0003o0`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000103oool010000?l0oooo0?oo
o`000?l30?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P00o`050?ooo`04
0000o`3oool0oooo0?l000T0oooo00<0003o0?l0003oool0103oool00`3o0000003o0?ooo`030?oo
o`040000o`3oool0oooo0?l000h0oooo00<0o`000?ooo`000?l02@3oool00`000?l0oooo0?l00006
0?ooo`040?l0003oool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`000?l0403oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool01P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o00001`3o
ool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0000o`030?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o2`3oool00`000?l0
oooo0?ooo`050?ooo`080?l0003oool0oooo003o003oool00?l00?ooo`3o000@0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0003o00d0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo
00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00L0oooo
00<0003o0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P000?l40?ooo`05
0?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`000?l0o`0000P0oooo00<0o`00
0000o`3oool00`3oool00`000?l0oooo0?l0000E0?ooo`D000006@3oool003`0oooo00<000000?oo
o`3oool07@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o0080oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0000o`020?ooo`030000o`3o0000oooo00L0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0003o0080oooo00@0003o0?oo
o`3oool0o`000`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`d0oooo00<0
003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0003o0080oooo
00<0o`000?ooo`3oool01@3oool01P3o0000oooo0?ooo`000?l0oooo0?l000L0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0003o0?ooo`000?l0103o
ool0103o0000oooo0?ooo`3o00050?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o
0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool0103o0000oooo0?ooo`00
0?l30?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`040000o`3oool0oooo0000
o`<0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool2003o00D0oooo00<0003o
0?ooo`3o00002P3oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0oooo00<0oooo00@0003o
0?ooo`3oool0o`003P3oool00`3o0000oooo0000o`090?ooo`040000o`3oool0oooo0?l000D0oooo
00H0o`000?ooo`3oool0003o0?ooo`000?l50?ooo`030?l0003oool0o`0000<0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`000?l0403oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00002@3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020?ooo`<0
003o2`3oool20000o`@0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l;0?oo
o`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool00?l00P3oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`00
0?l=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l000000?l0oooo0080oooo00<0003o0?l0003oool01`3oool00`3o0000003o0?oo
o`070?ooo`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0003o0?oo
o`3o00001`3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0o`0001T0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`020?ooo`03
0000o`3o0000oooo00L0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`04
0?l0003oool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0
oooo0080oooo00@0003o0?ooo`3oool0003o3@3oool00`000?l0oooo0?ooo`030?ooo`040?l0003o
ool0oooo0?l000@0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`060?l0
003oool0oooo0000o`3oool0o`001`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00<0oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00H0oooo00D0o`000?ooo`000?l0oooo0000o`040?ooo`040?l0003oool0oooo0?l000D0oooo
00@0003o0?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`80003o0P3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0?l000040?ooo`040000o`3oool0oooo0000o`<0oooo00<0o`000?ooo`3oool00P3oool0103o
0000oooo0?ooo`3oool2003o00D0oooo00<0003o0?l0003o00002P3oool00`000?l0o`000?ooo`03
0?ooo`040?l0003oool0oooo0000o`<0oooo00D0003o0?ooo`3oool0oooo0?l0000=0?ooo`030?l0
003oool0003o00T0oooo00@0003o0?ooo`3oool0o`001@3oool01P3o0000oooo0?ooo`000?l0oooo
0000o`D0oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
oooo0?l00080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`0@0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`060000o`3oool0oooo0000o`3o
ool0o`001P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l02P3oool0
0`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo003o0080oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`000?l03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0303o
ool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`000?l0203o
ool00`000?l0oooo0?ooo`0<0?ooo`040?l0003oool0oooo0?l000D0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`000?l0oooo0?l000070?oo
o`030?l0003oool0003o00<0oooo00<0003o0?ooo`3o00006@3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o0080oooo00<0003o0?l0003o
ool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
ool0003o0P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool00P3oool0
10000?l0oooo0?ooo`000?l=0?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0o`00
103oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00@0oooo00L0o`000?ooo`3oool0
oooo0000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`060?l0003oool0oooo0000o`3oool0003o103oool0103o0000oooo0?ooo`3o00050?ooo`04
0000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool30000o`@0oooo00@0o`000?oo
o`3oool0o`001P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`040000o`3oool0oooo0?ooo`80o`001@3oool010000?l0oooo0?ooo`000?l30?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P00o`050?ooo`030000o`3o0000
o`0000T0oooo00<0003o0?ooo`3o0000103oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3o
ool0oooo0?ooo`3o0000303oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00@0003o0?ooo`3o
ool0o`001@3oool01P3o0000oooo0?ooo`000?l0oooo0000o`D0oooo00<0o`000?ooo`3o00000`3o
ool00`000?l0oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`03
0000o`3oool0003o0140oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`00
00X0oooo00H0003o0?ooo`3oool0003o0?ooo`3o00060?ooo`030?l0003oool0oooo01H0oooo00<0
o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00D0o`000?ooo`3oool0
oooo0?l0000O0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03@3oool20?l000H0
oooo00<0003o0?ooo`000?l03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0303oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`0000H0
oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`0=0?ooo`040?l0003oool0oooo0?l0
00D0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3o00006@3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
003o0080oooo00<0003o0?l0003oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l40?ooo`040?l0003oool0oooo0?l000@0
oooo00@0003o0?ooo`3oool0003o4`3oool00`3o0000oooo0?l000050?ooo`80003o103oool00`3o
0000oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0?l000070?ooo`030?l0003o
ool0oooo00l0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`3o
00001`3oool00`3o0000oooo0?ooo`050?ooo`060?l0003oool0oooo0000o`3oool0003o1@3oool0
0`3o0000oooo0?l000080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000H0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool010000?l0oooo0?ooo`3oool20?l000D0
oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool0103oool00`000?l0o`000?ooo`080?ooo`040000o`3oool0oooo
0?l000<0oooo00@0o`000?ooo`3oool0003o0`3oool01@000?l0oooo0?ooo`3oool0o`0000`0oooo
00D0o`000?ooo`3oool0oooo0000o`080?ooo`040000o`3oool0oooo0?l000@0oooo00L0o`000?oo
o`3oool0oooo0000o`3oool0003o00D0oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?oo
o`020?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`030000o`3oool0003o0140
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00H0003o0?oo
o`3oool0003o0?ooo`3o00060?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0003o0?ooo`3oool0203oool01@3o0000oooo
0?ooo`3oool0o`000140oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o
00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00/0oooo00<0o`000000o`3oool00P3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0003o
00L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?l0000<0?ooo`040?l0003oool0oooo
0?l000@0oooo00D0003o0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0003o00<0oooo00<0
003o0?ooo`3o00006@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0L
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`05
0?ooo`070?l0003oool0003o0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool01P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00<0o`000?oo
o`3o00001@3oool00`000?l0oooo0000o`0E0?ooo`80o`001P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00l0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0
oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`80003o
1@3oool00`3o0000oooo0?l000090?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
5P3oool00`3o0000oooo0?l0000:0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`000`3oool0103o
0000oooo0?ooo`000?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool0
1@3o0000oooo0?ooo`3oool0003o00P0oooo00@0003o0?ooo`3oool0o`00103oool01`3o0000oooo
0?ooo`3oool0003o0?ooo`000?l01@3oool00`3o0000oooo0?l000030?ooo`050000o`3oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?l000050?ooo`80003o4@3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`07
0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool010000?l0oooo0?ooo`000?l20?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`030?ooo`050?l0
003oool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?ooo`080?ooo`050?l0003oool0oooo0?oo
o`3o00004@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool0
1@000?l0oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`000?l03`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0000
o`020?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3o00001@3oool01@000?l0oooo0000
o`3oool0o`0000L0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?l0000I0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`D000006P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0003o0080oooo00<0o`000?ooo`3oool01@3oool01`3o0000oooo0000o`3oool0003o0?ooo`3o
00001`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00H0o`000?ooo`3o
ool0003o0?ooo`000?l50?ooo`80o`001@3oool00`000?l0oooo0000o`0E0?ooo`80o`001P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00D0003o0?ooo`3oool0oooo0000
o`030?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`050?ooo`040?l0
003oool0oooo0?ooo`80003o1@3oool20?l000X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0F0?ooo`030?l0003oool0o`0000/0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo00@0oooo00<0o`000000o`3oool0203oool010000?l0oooo0?ooo`3o00030?ooo`070?l0003o
ool0oooo0?ooo`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00X0oooo00D0o`000?ooo`3o
ool0oooo0000o`080?ooo`040000o`3oool0oooo0?l000@0oooo00L0o`000?ooo`3oool0oooo0000
o`3oool0003o00D0oooo0P3o00040?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?l000050?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?l0000<0?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o00004P3oool01@3o0000
oooo0?ooo`3oool0o`000200oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0F0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`000?l9
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0003o00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?l00006
0?ooo`030?l0003oool0003o00L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?l0000<
0?ooo`030?l0003oool0o`0000D0oooo00D0003o0?ooo`000?l0oooo0?l000070?ooo`030?l0003o
ool0003o00<0oooo00<0003o0?ooo`3o00005@3oool5000001T0oooo000l0?ooo`030000003oool0
oooo01`0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0
oooo00@0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l20?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool00P3oool01P3o0000oooo0?ooo`000?l0oooo0000o`D0oooo0P3o00050?oo
o`030000o`3oool0003o01D0oooo0P3o00060?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0403oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0o`00203o
ool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool20?l000X0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00X0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1`3o0000oooo0?ooo`3oool0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o00040?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000o`060?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`80o`001P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo
00<0o`000?ooo`3o0000303oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0o`0001<0oooo
00@0o`000?ooo`3oool0o`00803oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01H0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0003o00X0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0G0?ooo`80003o3`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0000o`020?ooo`030000o`3oool0o`0000H0oooo00@0o`000?ooo`3oool0003o1P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3o00001@3oool01@00
0?l0oooo0000o`3oool0o`0000L0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?l0000I
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01`0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00H0o`000?oo
o`3oool0003o0?ooo`000?l20?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00P3o
ool01P3o0000oooo0?ooo`000?l0oooo0000o`D0oooo0P3o00050?ooo`030000o`3oool0003o01D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0100
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`00
0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00H0oooo0P3o000:0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool01@3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0000o`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0003o00@0oooo0P3o00060?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo
0?l0000<0?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01H0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?l0000C0?ooo`040?l0003oool0oooo0?l00240
oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool0
0`000?l0oooo0000o`0:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3o00001P3oool0
103o0000oooo0?ooo`000?l60?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o0000303o
ool00`3o0000oooo0?l000050?ooo`050000o`3oool0003o0?ooo`3o00001`3oool00`3o0000oooo
0000o`030?ooo`030000o`3oool0o`0001T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool06`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo00<0
o`000?ooo`3oool00`3oool01P3o0000oooo0?ooo`000?l0oooo0000o`80oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool03`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`000?l01@3oool20?l0
00D0oooo00<0003o0?ooo`000?l05@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0100oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0?l000T0oooo00<0
o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`X0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0U0?ooo`040?l0003oool0oooo0?l000D0oooo00<0003o0?oo
o`000?l0303oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`050?l0
003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?l0000<0?ooo`80003o0`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000060?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0B0?oo
o`030?l0003oool0o`000280oooo00@0o`000?ooo`3oool0o`006P3oool01@3o0000oooo0?ooo`3o
ool0o`0000`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01L0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0000o`020?ooo`030000o`3o
ool0o`0000H0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00
303oool00`3o0000oooo0?l000050?ooo`050000o`3oool0003o0?ooo`3o00001`3oool00`3o0000
oooo0000o`030?ooo`030000o`3oool0o`0001T0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool01P3o0000oooo0?ooo`000?l0oooo0000o`80oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool03`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`000?l01P3oool0
0`3o0000oooo0?ooo`040?ooo`80003o5@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0100oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0?l000T0oooo
00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3o
ool0oooo0000o`0:0?ooo`040000o`3oool0oooo0000o`X0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0U0?ooo`040?l0003oool0oooo0?l000D0oooo00<0003o0?ooo`000?l0303o
ool00`000?l0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo
01P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`050?l0003oool0oooo
0?ooo`3o0000303oool00`3o0000oooo0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`3o0000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
0?l0000R0?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`003@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3o00001P3oool0103o
0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo0?l000050?ooo`80003o0P3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0
oooo0000o`<0oooo00<0003o0?ooo`3o00006@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`060?l0003oool0oooo0000o`3oool0003o0P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool20000o`H0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0R0?ooo`040?l0003oool0oooo0?l000P0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0003o00D0oooo0P3o000:0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0
003o00X0oooo00@0003o0?ooo`3oool0003o2`3oool01@3o0000oooo0?ooo`3oool0o`0002P0oooo
00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0000o`0<0?ooo`80003o103oool01@3o0000
oooo0?ooo`3oool0o`000100oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0
oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0
303oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool0603oool01@3o0000
oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0P0?oo
o`030?l0003oool0o`000280oooo00@0o`000?ooo`3oool0o`006`3oool00`3o0000oooo0?l0000J
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0000o`02
0?ooo`030000o`3oool0o`0000H0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3o00060?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3o00006@3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool500000240oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80003o0P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`05
0?l0003oool0oooo0?ooo`3o0000103oool20000o`d0oooo00<0003o0?ooo`3oool08P3oool0103o
0000oooo0?ooo`3o00090?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0000o`050?ooo`80o`002P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`050000o`3oool0
oooo0?ooo`000?l02`3oool00`000?l0oooo0000o`0;0?ooo`050?l0003oool0oooo0?ooo`3o0000
:@3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o00`0oooo0P000?l40?ooo`050?l0
003oool0oooo0?ooo`3o00004@3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0o`000?oo
o`3o00001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0003o1@3o
ool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0403o
ool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00006P3oool01@3o0000oooo0?ooo`3oool0o`00
00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0o`00
02<0oooo00<0o`000?ooo`3o00006`3oool00`3o0000oooo0?l0000J0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0000o`3oool0003o0080oooo00<0o`00
0?ooo`3oool0103oool0103o0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000H0oooo
00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?l0000E0?ooo`D000006@3oool003`0oooo
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00D0o`000?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool08P3oool0103o
0000oooo0?ooo`3o00090?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0000o`050?ooo`80o`002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
oooo0000o``0oooo0P000?l<0?ooo`050?l0003oool0oooo0?ooo`3o0000:@3oool00`3o0000oooo
0?l000050?ooo`030000o`3oool0003o00d0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0o`000140oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0o`00
00d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0
oooo00/0oooo00@0003o0?ooo`3oool0003o803oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0140oooo00@0o`000?ooo`3oool0o`00803oool01@3o0000oooo0?ooo`3oool0o`0001X0
oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`050000o`3oool0oooo0?ooo`000?l08P3oool0
0`3o0000oooo0?l0000S0?ooo`030?l0003oool0o`0001/0oooo00<0o`000?ooo`3o00006P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00D0o`000?ooo`000?l0oooo0000
o`020?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo
0?ooo`0N0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001P3oool0103o0000
oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0?l001T0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo00@0o`00
0?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo0280oooo00@0
o`000?ooo`3oool0o`002@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`000?l01@3oool20?l000/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0000o`0=0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o0000:P3oool00`3o0000oooo
0?l000050?ooo`030000o`3oool0003o00d0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo
0?ooo`3o000B0?ooo`040000o`3oool0oooo0000o`D0oooo0P3o000>0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0
oooo0000ob00oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003o
ool0o`000240oooo00D0o`000?ooo`3oool0oooo0?l0000J0?ooo`050?l0003oool0oooo0?ooo`3o
00002@3oool01@000?l0oooo0?ooo`3oool0003o0280oooo00<0o`000?ooo`3o00008`3oool00`3o
0000oooo0?l0000L0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`060?l0003oool0oooo0000o`3oool0003o0P3oool00`3o0000oooo0?oo
o`040?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo
0?ooo`050?ooo`040000o`3oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0003o0P3oool01000
0?l0oooo0?ooo`3o000I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
02P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0403oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0
oooo0340oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`000?l03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
o`0002X0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`0=0?ooo`030000o`3oool0
oooo00<0oooo00@0o`000?ooo`3oool0o`004`3oool20000o`L0oooo00<0o`000?ooo`3oool03@3o
ool20?l000D0oooo00<0o`000?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o00D0oooo
00<0o`000?ooo`3o00004`3oool00`000?l0oooo0000o`0R0?ooo`050?l0003oool0oooo0?ooo`3o
00004`3oool00`3o0000oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o00006P3oool01@3o
0000oooo0?ooo`3oool0o`0000X0oooo00@0003o0?ooo`3oool0003o8`3oool00`3o0000oooo0?oo
o`0R0?ooo`80o`007@3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0oooo00<0o`000?ooo`3o
ool00`3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0oooo02L0oooo00@0003o0?oo
o`3oool0o`001P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`3o0000oooo
0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`800000103oool2000000D0oooo0`00
000;0?ooo`030000003oool0oooo02T0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000050?ooo`030000
o`3oool0oooo0340oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`000?l06`3oool00`3o0000oooo0?l0000Z0?ooo`030?l0
003oool0o`0000D0oooo00<0003o0?ooo`000?l03@3oool00`000?l0oooo0?ooo`030?ooo`040?l0
003oool0oooo0?l001<0oooo0P000?l70?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o
0000oooo0?l0000C0?ooo`030000o`3oool0003o0280oooo00D0o`000?ooo`3oool0oooo0?l0000C
0?ooo`030?l0003oool0o`000240oooo00D0o`000?ooo`3oool0oooo0?l0000J0?ooo`040?l0003o
ool0oooo0?l000/0oooo00<0003o0?ooo`000?l0903oool00`3o0000oooo0?ooo`0S0?ooo`030?l0
003oool0oooo03L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`060?l0
003oool0oooo0000o`3oool0003o0`3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo
0000o`@0oooo00<0003o0?ooo`3oool09`3oool010000?l0oooo0?ooo`3o00060?ooo`070?l0003o
ool0oooo0?ooo`000?l0oooo0000o`020?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02T0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000050?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`000?l04P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
01D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
01/0oooo00<0o`000?ooo`3oool0:@3oool20?l000L0oooo00<0003o0?ooo`3oool04P3oool0103o
0000oooo0?ooo`3o000D0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0403oool0
1@3o0000oooo0?ooo`3oool0o`0000/0oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo
0?l0000C0?ooo`030000o`3oool0003o0280oooo00@0o`000?ooo`3oool0o`00503oool00`3o0000
oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l001/0oooo00@0o`000?ooo`3oool0o`00303oool2
0000ob@0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0g0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0oooo
00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0oooo02/0
oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo
000000P0oooo1@00000;0?ooo`L000009@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?l0000j0?ooo`80o`002`3oool0103o0000oooo0?oo
o`3o000D0?ooo`030000o`3oool0003o0180oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0K0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0B0?ooo`040?l0003oool0oooo0?l00300oooo0`3o000<0?ooo`030000o`3oool0003o00H0
oooo00<0o`000?ooo`3o00004`3oool00`000?l0oooo0000o`0R0?ooo`040?l0003oool0oooo0?l0
01@0oooo00<0o`000?ooo`3o00008P3oool00`3o0000oooo0?l0000L0?ooo`030?l0003oool0o`00
00`0oooo0P000?lT0?ooo`030?l0003oool0oooo05d0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`060?l0003oool0oooo0000o`3oool0003o0`3oool00`3o0000oooo0?oo
o`030?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo
0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo
0100oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000`0oooo00<000000?ooo`3oool0:@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?l0000j0?ooo`030?l0003oool0oooo00X0oooo00@0
o`000?ooo`3oool0o`005@3oool00`000?l0oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`3o
00005`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0B0?ooo`040?l0003oool0oooo0?l00380oooo00<0o`000?oo
o`3oool02`3oool20000o`H0oooo00<0o`000?ooo`3o00004`3oool00`000?l0oooo0000o`0R0?oo
o`040?l0003oool0oooo0?l001@0oooo00<0o`000?ooo`3o00008P3oool00`3o0000oooo0?l0000L
0?ooo`030?l0003oool0o`0000d0oooo00<0003o0?ooo`3oool0PP3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o02d0
oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0Y0?ooo`050?l0003oool0
oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0o`0003X0oooo00<0
o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3o000E0?ooo`030000o`3oool0oooo0180oooo
00@0o`000?ooo`3oool0o`00603oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo05@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`040?l0003oool0oooo0?l0
0400oooo0P000?l60?ooo`030?l0003oool0o`0001<0oooo00<0003o0?ooo`000?l08`3oool00`3o
0000oooo0?l0000D0?ooo`030?l0003oool0o`000280oooo00<0o`000?ooo`3o0000703oool00`3o
0000oooo0?l0002B0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0103o
0000oooo0?ooo`3oool20000o`<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l0;@3oool00`3o0000oooo0?ooo`030?ooo`070?l0003o
ool0oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3o
ool05`3oool00240oooo0P00000;0?ooo`800000303oool00`000000oooo0?ooo`0Y0?ooo`050?l0
003oool0oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0o`0003X0
oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3o000E0?ooo`030000o`3oool0oooo
0180oooo00@0o`000?ooo`3oool0o`00603oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo05`0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?l000120?ooo`030000o`3oool0
oooo00@0oooo0P3o000D0?ooo`030000o`3oool0003o02<0oooo00<0o`000?ooo`3o00005@3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0o`0001`0oooo00<0o`000?ooo`3o0000TP3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0P00
0?l30?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`000?l^0?ooo`030?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o
00<0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0Y0?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo04H0oooo00@0o`000?ooo`3oool0o`005@3oool00`000?l0oooo0?ooo`0B
0?ooo`040?l0003oool0oooo0?l001P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`1a0?ooo`030?l0003oool0o`000480oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0003o02<0oooo00<0o`000?ooo`3o00005@3oool00`3o0000oooo0?oo
o`0Q0?ooo`030?l0003oool0o`0001`0oooo00<0o`000?ooo`3o0000TP3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l^0?ooo`03
0?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`00
0?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Y0?oo
o`040?l0003oool0oooo0?l000/0oooo00D0o`000?ooo`3oool0oooo0?l0000A0?ooo`050000o`3o
ool0oooo0?ooo`000?l0503oool00`3o0000oooo0?ooo`160?ooo`040?l0003oool0oooo0?l002X0
oooo00@0o`000?ooo`3oool0o`00603oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
0740oooo00<0o`000?ooo`3o0000BP3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0003o
02<0oooo00<0o`000?ooo`3o00005@3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0o`00
01`0oooo00<0o`000?ooo`3o0000TP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
02X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l^0?ooo`030?l0003oool0oooo00<0oooo00L0
o`000?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool05P3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0o`0000/0oooo
00D0o`000?ooo`3oool0oooo0?l0000A0?ooo`050000o`3oool0oooo0?ooo`000?l0503oool00`3o
0000oooo0?ooo`170?ooo`030?l0003oool0o`0002X0oooo00@0o`000?ooo`3oool0o`006@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0740oooo00<0o`000?ooo`3o0000BP3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0003o02<0oooo00<0o`000?ooo`3o00005@3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0o`0001`0oooo00<0o`000?ooo`3o0000T`3oool0
1@3o0000oooo0?ooo`3oool0o`0002`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l^0?ooo`03
0?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`00
0?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5000002P0oooo00<0o`000?oo
o`3o00002`3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00D0003o0?ooo`3oool0oooo0000
o`0D0?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3o0000:`3oool00`3o0000oooo0?l0
000I0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0L@3oool00`3o0000oooo0?l0
001:0?ooo`030?l0003oool0oooo01<0oooo0P000?lS0?ooo`80o`00>`3oool00`3o0000oooo0?oo
o`0K0?ooo`030?l0003oool0o`0009<0oooo00D0o`000?ooo`3oool0oooo0?l0000]0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0003o;P3oool00`3o0000oooo0?ooo`030?ooo`070?l0003oool0oooo
0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0180oooo1@00000I0?ooo`00?03oool0
0`000000oooo0?ooo`0Z0?ooo`030?l0003oool0o`0000/0oooo00@0o`000?ooo`3oool0o`004P3o
ool01@000?l0oooo0?ooo`3oool0003o05h0oooo00<0o`000?ooo`3o0000:`3oool00`3o0000oooo
0?l0000I0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0L@3oool00`3o0000oooo
0?l0001P0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo
0?ooo`0L0?ooo`030?l0003oool0oooo0980oooo00D0o`000?ooo`3oool0oooo0?l0000]0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3oool0003o;P3oool00`3o0000oooo0?ooo`030?ooo`070?l0003oool0
oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?l0000;0?ooo`040?l0003o
ool0oooo0?l00180oooo00D0003o0?ooo`3oool0oooo0000o`1N0?ooo`030?l0003oool0o`0002/0
oooo00<0o`000?ooo`3o00006@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0740
oooo00<0o`000?ooo`3o0000H03oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo03T0
oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`2B0?ooo`050?l0003oool0oooo0?oo
o`3o0000;@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o02l0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0o`00
00/0oooo00@0o`000?ooo`3oool0o`004P3oool01@000?l0oooo0?ooo`3oool0003o05h0oooo0P3o
000/0?ooo`030?l0003oool0o`0001T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`1a0?ooo`030?l0003oool0o`000600oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?oo
o`0i0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0TP3oool0103o0000oooo0?oo
o`3o000^0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0003o02l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0o`0000/0oooo00@0o`000?ooo`3oool0
o`004P3oool01@000?l0oooo0?ooo`3oool0003o05h0oooo0P3o000/0?ooo`80o`006P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0740oooo00<0o`000?ooo`3o0000H03oool00`00
0?l0oooo0?ooo`1n0?ooo`030?l0003oool0oooo0980oooo00@0o`000?ooo`3oool0o`00;P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0000
o`0_0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<00000
0?ooo`3oool0:P3oool00`3o0000oooo0?l0000;0?ooo`040?l0003oool0oooo0?l00180oooo00D0
003o0?ooo`3oool0oooo0000o`1O0?ooo`030?l0003oool0oooo02X0oooo0P3o000J0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0LP3oool20?l00600oooo00<0003o0?ooo`3oool0
OP3oool00`3o0000oooo0?ooo`2B0?ooo`040?l0003oool0oooo0?l002h0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`000?l0;`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000:03oool20?l000d0
oooo00<0o`000?ooo`3o00004P3oool01@000?l0oooo0?ooo`3oool0003o05l0oooo00<0o`000?oo
o`3oool0:`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0LP3oool20?l00600oooo00<0003o0?ooo`3oool0o`3ooolD0?ooo`040?l0003oool0oooo
0?l002h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo0P00
0?l_0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0180oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o00004P3oool01@000?l0oooo0?ooo`3o
ool0003o05l0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`3o0?ooogH0oooo00@0
o`000?ooo`3oool0o`00;P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o
00001@3oool20000oc00oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0[0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o00004P3oool01@000?l0
oooo0?ooo`3oool0003o05l0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`3o0?oo
ogH0oooo00@0o`000?ooo`3oool0o`00;P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0
oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`0_0?ooo`050?l0003oool0oooo0?ooo`3o0000
1@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0o`000180oooo00D0003o0?ooo`3oool0oooo0000o`2X0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`3o0?ooogH0oooo00@0o`000?ooo`3oool0
o`00;P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`00
0?l0oooo0?ooo`0_0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?ooo`0F
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02/0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?l0000B0?ooo`050000o`3oool0oooo0?ooo`000?l0Z03oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0780oooo00<0o`000?ooo`3oool0o`3ooomf
0?ooo`030?l0003oool0o`0002l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3o
ool0o`0000D0oooo00<0003o0?ooo`3oool0;`3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo
00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`0i0?ooo`030?l0003oool0o`0001<0oooo00<0003o0?ooo`000?l0Z@3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0780oooo00<0o`000?ooo`3oool0o`3ooomf0?ooo`030?l0003o
ool0o`0002l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o00060?ooo`030000
o`3oool0oooo02l0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo01H0
oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000g0?ooo`80o`00503oool00`000?l0oooo
0000o`2Y0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0LP3oool00`3o0000oooo
0?ooo`3o0?ooogH0oooo00<0o`000?ooo`3o0000;`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`040?l0
003oool0oooo0?l003P0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0oooo
0140oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0i0?ooo`80o`00503oool00`000?l0
oooo0000o`2Y0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oooo/0?ooo`03
0?l0003oool0o`0002l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o000h0?oo
o`050?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0000o`2Y0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oooo]0?oo
o`80o`00;`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l003P0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0
003o0:T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooond0oooo0P3o000_
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3oool0o`00>03oool01@3o0000oooo0?oo
o`3oool0o`0000/0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`000?l0Z@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0ooook@3oool20?l002l0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o000h0?ooo`050?l0003oool0oooo0?ooo`3o
00002`3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo03X0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0000o`2Y0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oooo]0?ooo`80o`00;`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0o`0003P0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03
0?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00001=0?ooo`030000
o`3oool0003o0:X0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooonl0oooo00<0o`000?ooo`3o
ool0;P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`0003P0oooo00D0o`000?ooo`3o
ool0oooo0?l0000;0?ooo`030?l0003oool0oooo0140oooo1@00000I0?ooo`00?03oool00`000000
oooo0?ooo`1?0?ooo`030000o`3oool0003o0:X0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?oo
onl0oooo00<0o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`00
03P0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`000?l0ZP3oool01@3o
0000oooo0?ooo`3oool0o`000?l0ooook`3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3o0000>03oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003o
ool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0C`3oool0
0`000?l0oooo0000o`2Z0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3oooo_0?ooo`030?l0003o
ool0oooo02l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l0000h0?ooo`040?l0003o
ool0oooo0?l000`0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`006`3o
ool2000000@0oooo0P0000050?ooo`<000000P3oool2000000d0oooo00<000000?ooo`3oool0C`3o
ool00`000?l0oooo0000o`2Z0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooooo0?ooob80oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l0000i0?ooo`030?l0003oool0o`0000`0oooo
00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?oo
o`00000;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1?0?ooo`030000o`3oool0003o0:X0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?oo
ool0oooo8P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00d0oooo00D0o`000?oo
o`3oool0oooo0?l0000<0?ooo`030?l0003oool0o`0003T0oooo00<0o`000?ooo`3o0000303oool0
0`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo
000000P0oooo1@0000040?ooo`030000003oool0oooo00X0oooo1`00001;0?ooo`030000o`3oool0
003o0:X0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooool0oooo8P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00d0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0
003oool0o`0003T0oooo00<0o`000?ooo`3o0000303oool00`3o0000oooo0?ooo`0?0?ooo`L00000
6@3oool001X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`80
00003@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0:T0oooo00D0o`000?ooo`3o
ool0oooo0?l0003o0?ooool0oooo8P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00d0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0o`0003T0oooo00<0o`00
0?ooo`3o0000303oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000J0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool0Z@3oool01@3o0000oooo0?ooo`3o
ool0o`000?l0ooooo`3ooolR0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03@3o
ool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3o0000>@3oool00`3o0000oooo
0?l0000<0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00
000;0?ooo`8000000`3oool3000000`0oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?oo
o`2Y0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooooo0?ooob80oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0=0?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`3o0000
oooo0?l0000i0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3oool05@3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0:T0oooo
00D0o`000?ooo`3oool0oooo0?l0003o0?ooool0oooo8P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00d0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`80o`00>P3oool00`3o
0000oooo0?l0000<0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`2Y0?ooo`050?l0003oool0oooo0?oo
o`3o0000o`3ooooo0?ooob80oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?oo
o`050?l0003oool0oooo0?ooo`3o0000303oool20?l003X0oooo00<0o`000?ooo`3o0000303oool0
0`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000CP3oool00`00
0?l0oooo0?ooo`2Y0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooooo0?ooob80oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003oool0oooo0?l000d0oooo00<0
o`000?ooo`3oool0>03oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo0140oooo1@00
000I0?ooo`00?03oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0:T0oooo00D0o`00
0?ooo`3oool0oooo0?l0003o0?ooool0oooo8P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00l0oooo00@0o`000?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0
003oool0o`0000d0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`3l0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooooo0?ooob80oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003oool0oooo0?l000d0
oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo01@0
oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o03oool01@3o0000oooo
0?ooo`3oool0o`000?l0ooooo`3ooolR0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool03`3oool0103o0000oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo03P0oooo00<0o`000?oo
o`3o00003@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo0?`0oooo00@0o`000?ooo`3oool0o`00o`3ooooo0?ooob<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`00
0?ooo`3oool0>03oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo01@0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o03oool0103o0000oooo0?ooo`3o003o
0?ooool0oooo8`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00@0o`00
0?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0o`0000d0oooo00<0
o`000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000?X0oooo00@0o`00
0?ooo`3oool0o`00o`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0?0?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool0>03oool20?l000h0oooo
00<0o`000?ooo`3oool0403oool5000001T0oooo000l0?ooo`030000003oool0oooo0?d0oooo00<0
o`000?ooo`3o0000o`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0o`0004T0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0D0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?d0oooo00<0o`00
0?ooo`3o0000o`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0o`0004T0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0D
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?d0oooo00<0o`000?oo
o`3o0000o`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?oo
o`80o`00BP3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01@0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0o@3oool00`3o0000oooo0?l0003o0?ooool0
oooo8`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo0P3o001:0?ooo`03
0?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`3m0?ooo`030?l0003oool0o`000?l0ooooo`3ooolS0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool20?l004X0oooo00<0o`000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3m0?ooo`030?l0003o
ool0o`000?l0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403o
ool20?l004X0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5
00000?/0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooob@0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0@0?ooo`80o`00BP3oool00`3o0000oooo0?ooo`0O0?ooo`D000006@3oool0
03`0oooo00<000000?ooo`3oool0o@3oool00`3o0000oooo0?l0003o0?ooool0oooo903oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0B03oool00`3o
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?d0
oooo00<0o`000?ooo`3o0000o`3ooooo0?ooob@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo06h0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0o@3oool00`3o0000oooo0?l0003o0?ooool0oooo903oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0KP3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3m0?ooo`030?l0003oool0o`000?l0ooooo`3o
oolT0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`1^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?d0oooo00<0o`00
0?ooo`3o0000o`3ooooo0?ooob@0oooo00D0003o0?ooo`3oool0oooo0000o`250?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`D00000n`3oool00`3o0000oooo0?l0003o0?ooool0oooo903oool0
1@000?l0oooo0?ooo`3oool0003o0840oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3m
0?ooo`030?l0003oool0o`000?l0ooooo`3ooolT0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3m0?ooo`030?l0003oool0
o`000?l0ooooo`3ooolT0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3m0?ooo`030?l0003oool0o`000?l0ooooo`3ooolT
0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000@0oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`3m0?ooo`030?l0003oool0
o`000?l0ooooo`3ooolT0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?oo
o`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo
00<000000?ooo`3oool0o@3oool00`3o0000oooo0?l0003o0?ooool0oooo903oool01@000?l0oooo
0?ooo`3oool0003o08D0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`0:0?ooo`L00000n@3oool20?l00?l0ooooo`3ooolU0?ooo`05
0000o`3oool0oooo0?ooo`000?l0O`3oool7000001T0oooo000P0?ooo`040000003oool0oooo0000
00T0oooo0P00000=0?ooo`030000003oool0oooo0?h0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
ob<0oooo00D0003o0?ooo`3oool0oooo0000o`250?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3n
0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolS0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3o
ool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000X0oooo0`00000<0?ooo`030000003oool0
oooo0?h0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooob<0oooo00D0003o0?ooo`3oool0oooo0000
o`250?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?h0oooo00<0o`00
0?ooo`3oool0o`3ooooo0?ooob<0oooo00D0003o0?ooo`3oool0oooo0000o`250?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?h0oooo00<0o`000?ooo`3oool0o`3ooooo
0?ooob<0oooo00D0003o0?ooo`3oool0oooo0000o`250?ooo`030000003oool0oooo01L0oooo000l
0?ooo`D00000o03oool00`3o0000oooo0?ooo`3o0?ooool0oooo8`3oool01@000?l0oooo0?ooo`3o
ool0003o0840oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3n0?ooo`030?l0003oool0
oooo0?l0ooooo`3ooolS0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3n0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolT
0?ooo`040000o`3oool0oooo0000ohD0oooo00<000000?ooo`3oool05`3oool003`0oooo00<00000
0?ooo`3oool0oP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo903oool010000?l0oooo0?ooo`00
0?n50?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?h0oooo00<0o`00
0?ooo`3oool0o`3ooooo0?ooob@0oooo00@0003o0?ooo`3oool0003oQ@3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0
003o08H0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00003o0?ooool0ooooo`3ooolT0?oo
o`030000o`3oool0003o0880oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo0000o`260?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0
003o0?ooo`000?l0QP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo0000o`260?oo
o`030000003oool0oooo01L0oooo000l0?ooo`D00000o`3ooooo0?ooool0oooo903oool00`000?l0
oooo0000o`220?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
9P3oool00`000?l0oooo0000o`260?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0003o0?ooo`000?l0QP3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0
003o08H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo9P3oool00`000?l0oooo0000o`260?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0003o0?ooo`000?l0QP3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool500000?l0ooooo`3ooooo0?ooob@0oooo00<0003o0?ooo`000?l0
PP3oool5000001T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0
003o0?ooo`000?l0QP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo0000o`260?oo
o`030000003oool0oooo01L0oooo000K0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
00003@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0003o08H0
oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo9`3oool20000ohH0oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo1`00003o
0?ooool0ooooo`3ooolS0?ooo`030000o`3oool0oooo07l0oooo1`00000I0?ooo`006P3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool2000000d0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo9`3oool00`000?l0oooo0?ooo`250?ooo`030000003oool0oooo01L0oooo000J0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobL0oooo00<0003o0?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0G0?ooo`006`3oool2000000X0oooo0`0000030?ooo`<00000303oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`030000o`3oool0oooo08D0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9`3oool00`000?l0
oooo0?ooo`250?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooobL0oooo00<0003o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`030000o`3oool0oooo08D0oooo00<0
00000?ooo`3oool05`3oool003`0oooo1@00003o0?ooool0ooooo`3ooolU0?ooo`030000o`3oool0
oooo0840oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?oo
o`030000o`3oool0oooo08D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool06`3oool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000B0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00P0oooo1@00000I0?ooo`00?03ooooo00000?l00000o`00002c000001T0oooo0000\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {549.938, 345.063}} -> {-15.4951, \
0.858862, 0.132742, 0.00163192}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Raw Tapping Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions1b];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0080032 -0.0936631 0.59442 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18387 -0.0125 -6 -9 ]
[.18387 -0.0125 6 0 ]
[.34394 -0.0125 -6 -9 ]
[.34394 -0.0125 6 0 ]
[.504 -0.0125 -6 -9 ]
[.504 -0.0125 6 0 ]
[.66407 -0.0125 -6 -9 ]
[.66407 -0.0125 6 0 ]
[.82413 -0.0125 -9 -9 ]
[.82413 -0.0125 9 0 ]
[.98419 -0.0125 -9 -9 ]
[.98419 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02522 -18 -4.5 ]
[-0.0125 .02522 0 4.5 ]
[-0.0125 .08466 -18 -4.5 ]
[-0.0125 .08466 0 4.5 ]
[-0.0125 .1441 -18 -4.5 ]
[-0.0125 .1441 0 4.5 ]
[-0.0125 .20355 -18 -4.5 ]
[-0.0125 .20355 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18387 0 m
.18387 .00625 L
s
[(20)] .18387 -0.0125 0 1 Mshowa
.34394 0 m
.34394 .00625 L
s
[(40)] .34394 -0.0125 0 1 Mshowa
.504 0 m
.504 .00625 L
s
[(60)] .504 -0.0125 0 1 Mshowa
.66407 0 m
.66407 .00625 L
s
[(80)] .66407 -0.0125 0 1 Mshowa
.82413 0 m
.82413 .00625 L
s
[(100)] .82413 -0.0125 0 1 Mshowa
.98419 0 m
.98419 .00625 L
s
[(120)] .98419 -0.0125 0 1 Mshowa
.125 Mabswid
.06383 0 m
.06383 .00375 L
s
.10384 0 m
.10384 .00375 L
s
.14386 0 m
.14386 .00375 L
s
.22389 0 m
.22389 .00375 L
s
.26391 0 m
.26391 .00375 L
s
.30392 0 m
.30392 .00375 L
s
.38395 0 m
.38395 .00375 L
s
.42397 0 m
.42397 .00375 L
s
.46399 0 m
.46399 .00375 L
s
.54402 0 m
.54402 .00375 L
s
.58403 0 m
.58403 .00375 L
s
.62405 0 m
.62405 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.7441 0 m
.7441 .00375 L
s
.78411 0 m
.78411 .00375 L
s
.86415 0 m
.86415 .00375 L
s
.90416 0 m
.90416 .00375 L
s
.94418 0 m
.94418 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02522 m
.00625 .02522 L
s
[(0.2)] -0.0125 .02522 1 0 Mshowa
0 .08466 m
.00625 .08466 L
s
[(0.3)] -0.0125 .08466 1 0 Mshowa
0 .1441 m
.00625 .1441 L
s
[(0.4)] -0.0125 .1441 1 0 Mshowa
0 .20355 m
.00625 .20355 L
s
[(0.5)] -0.0125 .20355 1 0 Mshowa
.125 Mabswid
0 .03711 m
.00375 .03711 L
s
0 .049 m
.00375 .049 L
s
0 .06089 m
.00375 .06089 L
s
0 .07277 m
.00375 .07277 L
s
0 .09655 m
.00375 .09655 L
s
0 .10844 m
.00375 .10844 L
s
0 .12033 m
.00375 .12033 L
s
0 .13222 m
.00375 .13222 L
s
0 .15599 m
.00375 .15599 L
s
0 .16788 m
.00375 .16788 L
s
0 .17977 m
.00375 .17977 L
s
0 .19166 m
.00375 .19166 L
s
0 .01333 m
.00375 .01333 L
s
0 .00144 m
.00375 .00144 L
s
0 .21544 m
.00375 .21544 L
s
0 .22732 m
.00375 .22732 L
s
0 .23921 m
.00375 .23921 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.18387 .24375 m
.18387 .25 L
s
.34394 .24375 m
.34394 .25 L
s
.504 .24375 m
.504 .25 L
s
.66407 .24375 m
.66407 .25 L
s
.82413 .24375 m
.82413 .25 L
s
.98419 .24375 m
.98419 .25 L
s
.125 Mabswid
.06383 .24625 m
.06383 .25 L
s
.10384 .24625 m
.10384 .25 L
s
.14386 .24625 m
.14386 .25 L
s
.22389 .24625 m
.22389 .25 L
s
.26391 .24625 m
.26391 .25 L
s
.30392 .24625 m
.30392 .25 L
s
.38395 .24625 m
.38395 .25 L
s
.42397 .24625 m
.42397 .25 L
s
.46399 .24625 m
.46399 .25 L
s
.54402 .24625 m
.54402 .25 L
s
.58403 .24625 m
.58403 .25 L
s
.62405 .24625 m
.62405 .25 L
s
.70408 .24625 m
.70408 .25 L
s
.7441 .24625 m
.7441 .25 L
s
.78411 .24625 m
.78411 .25 L
s
.86415 .24625 m
.86415 .25 L
s
.90416 .24625 m
.90416 .25 L
s
.94418 .24625 m
.94418 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .02522 m
1 .02522 L
s
.99375 .08466 m
1 .08466 L
s
.99375 .1441 m
1 .1441 L
s
.99375 .20355 m
1 .20355 L
s
.125 Mabswid
.99625 .03711 m
1 .03711 L
s
.99625 .049 m
1 .049 L
s
.99625 .06089 m
1 .06089 L
s
.99625 .07277 m
1 .07277 L
s
.99625 .09655 m
1 .09655 L
s
.99625 .10844 m
1 .10844 L
s
.99625 .12033 m
1 .12033 L
s
.99625 .13222 m
1 .13222 L
s
.99625 .15599 m
1 .15599 L
s
.99625 .16788 m
1 .16788 L
s
.99625 .17977 m
1 .17977 L
s
.99625 .19166 m
1 .19166 L
s
.99625 .01333 m
1 .01333 L
s
.99625 .00144 m
1 .00144 L
s
.99625 .21544 m
1 .21544 L
s
.99625 .22732 m
1 .22732 L
s
.99625 .23921 m
1 .23921 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03181 .11213 m
.03982 .12702 L
.04782 .17143 L
.05582 .11267 L
.06383 .13502 L
.07183 .09416 L
.07983 .10594 L
.08784 .04846 L
.09584 .14847 L
.10384 .0934 L
.11184 .16675 L
.11985 .07095 L
.12785 .15546 L
.13585 .05088 L
.14386 .17875 L
.15186 .05204 L
.15986 .09869 L
.16787 .10879 L
.17587 .16202 L
.18387 .08068 L
.19188 .1586 L
.19988 .08717 L
.20788 .12164 L
.21589 .04795 L
.22389 .15788 L
.23189 .10964 L
.2399 .1217 L
.2479 .07427 L
.2559 .14788 L
.26391 .04703 L
.27191 .13857 L
.27991 .0645 L
.28792 .10795 L
.29592 .12771 L
.30392 .11804 L
.31192 .14404 L
.31993 .10853 L
.32793 .11226 L
.33593 .08572 L
.34394 .10243 L
.35194 .14322 L
.35994 .10484 L
.36795 .14886 L
.37595 .08878 L
.38395 .1363 L
.39196 .06375 L
.39996 .17497 L
.40796 .04409 L
.41597 .08003 L
.42397 .14786 L
Mistroke
.43197 .14444 L
.43998 .12406 L
.44798 .12832 L
.45598 .12045 L
.46399 .09347 L
.47199 .13848 L
.47999 .16396 L
.488 .10896 L
.496 .16542 L
.504 .08067 L
.512 .16081 L
.52001 .05127 L
.52801 .12859 L
.53601 .10956 L
.54402 .14833 L
.55202 .10795 L
.56002 .10662 L
.56803 .10003 L
.57603 .09959 L
.58403 .10268 L
.59204 .09766 L
.60004 .08175 L
.60804 .1449 L
.61605 .13079 L
.62405 .13523 L
.63205 .12245 L
.64006 .15744 L
.64806 .12787 L
.65606 .0862 L
.66407 .06787 L
.67207 .13412 L
.68007 .10053 L
.68808 .09763 L
.69608 .11463 L
.70408 .09685 L
.71208 .13349 L
.72009 .08986 L
.72809 .09833 L
.73609 .1405 L
.7441 .12029 L
.7521 .10815 L
.7601 .07821 L
.76811 .12272 L
.77611 .10304 L
.78411 .07251 L
.79212 .09279 L
.80012 .14073 L
.80812 .11052 L
.81613 .08804 L
.82413 .08523 L
Mistroke
.83213 .07893 L
.84014 .13149 L
.84814 .08721 L
.85614 .00595 L
.86415 .18876 L
.87215 .09803 L
.88015 .16648 L
.88816 .10261 L
.89616 .14873 L
.90416 .08902 L
.91216 .16832 L
.92017 .07755 L
.92817 .0959 L
.93617 .13177 L
.94418 .14946 L
.95218 .04401 L
.96018 .16818 L
.96819 .06137 L
.97619 .13793 L
Mfstroke
0 1 0 r
.03181 .1032 m
.03982 .06848 L
.04782 .08839 L
.05582 .07736 L
.06383 .09216 L
.07183 .108 L
.07983 .1159 L
.08784 .09514 L
.09584 .07483 L
.10384 .07277 L
.11184 .07638 L
.11985 .09736 L
.12785 .06981 L
.13585 .10456 L
.14386 .05649 L
.15186 .0978 L
.15986 .11878 L
.16787 .07539 L
.17587 .07862 L
.18387 .1099 L
.19188 .06793 L
.19988 .08611 L
.20788 .1077 L
.21589 .10455 L
.22389 .08245 L
.23189 .08674 L
.2399 .10536 L
.2479 .09908 L
.2559 .08167 L
.26391 .11137 L
.27191 .13031 L
.27991 .11109 L
.28792 .07337 L
.29592 .07096 L
.30392 .071 L
.31192 .06804 L
.31993 .10031 L
.32793 .09159 L
.33593 .12217 L
.34394 .10858 L
.35194 .07928 L
.35994 .08218 L
.36795 .07387 L
.37595 .09234 L
.38395 .07985 L
.39196 .08098 L
.39996 .07779 L
.40796 .11297 L
.41597 .11721 L
.42397 .06258 L
Mistroke
.43197 .06529 L
.43998 .0754 L
.44798 .09092 L
.45598 .09831 L
.46399 .10937 L
.47199 .06592 L
.47999 .07562 L
.488 .07553 L
.496 .06412 L
.504 .09373 L
.512 .06441 L
.52001 .11196 L
.52801 .07505 L
.53601 .11275 L
.54402 .10896 L
.55202 .09512 L
.56002 .08783 L
.56803 .12155 L
.57603 .0886 L
.58403 .10087 L
.59204 .0967 L
.60004 .10533 L
.60804 .10992 L
.61605 .06773 L
.62405 .08821 L
.63205 .06163 L
.64006 .10022 L
.64806 .06549 L
.65606 .10578 L
.66407 .14029 L
.67207 .08579 L
.68007 .10911 L
.68808 .10007 L
.69608 .10881 L
.70408 .09635 L
.71208 .07419 L
.72009 .09701 L
.72809 .10256 L
.73609 .08646 L
.7441 .0685 L
.7521 .09436 L
.7601 .10895 L
.76811 .10375 L
.77611 .0996 L
.78411 .12405 L
.79212 .10392 L
.80012 .11601 L
.80812 .10209 L
.81613 .10128 L
.82413 .11562 L
Mistroke
.83213 .10509 L
.84014 .0893 L
.84814 .09415 L
.85614 .06343 L
.86415 .04568 L
.87215 .11933 L
.88015 .08662 L
.88816 .06594 L
.89616 .08813 L
.90416 .08619 L
.91216 .07187 L
.92017 .11665 L
.92817 .12448 L
.93617 .05768 L
.94418 .07921 L
.95218 .10569 L
.96018 .09185 L
.96819 .11859 L
.97619 .1221 L
Mfstroke
0 0 1 r
.03181 .0981 m
.03982 .11793 L
.04782 .05361 L
.05582 .1234 L
.06383 .08625 L
.07183 .11127 L
.07983 .0916 L
.08784 .16983 L
.09584 .09012 L
.10384 .14725 L
.11184 .0703 L
.11985 .14512 L
.12785 .08816 L
.13585 .15798 L
.14386 .07819 L
.15186 .1636 L
.15986 .09597 L
.16787 .12924 L
.17587 .07279 L
.18387 .12285 L
.19188 .0869 L
.19988 .14015 L
.20788 .08409 L
.21589 .16092 L
.22389 .07311 L
.23189 .11704 L
.2399 .08637 L
.2479 .14008 L
.2559 .08389 L
.26391 .15503 L
.27191 .04456 L
.27991 .13784 L
.28792 .13211 L
.29592 .11477 L
.30392 .12439 L
.31192 .10135 L
.31993 .1046 L
.32793 .10958 L
.33593 .10554 L
.34394 .10243 L
.35194 .09093 L
.35994 .12641 L
.36795 .0907 L
.37595 .13231 L
.38395 .09728 L
.39196 .1687 L
.39996 .06067 L
.40796 .15637 L
.41597 .11619 L
.42397 .10299 L
Mistroke
.43197 .1037 L
.43998 .11397 L
.44798 .09419 L
.45598 .09467 L
.46399 .11059 L
.47199 .10904 L
.47999 .07385 L
.488 .12894 L
.496 .08389 L
.504 .13904 L
.512 .08821 L
.52001 .1502 L
.52801 .10979 L
.53601 .09113 L
.54402 .05614 L
.55202 .11036 L
.56002 .11899 L
.56803 .09185 L
.57603 .12524 L
.58403 .10988 L
.59204 .11907 L
.60004 .12635 L
.60804 .05861 L
.61605 .11491 L
.62405 .08999 L
.63205 .12935 L
.64006 .05576 L
.64806 .12007 L
.65606 .12145 L
.66407 .10527 L
.67207 .09352 L
.68007 .1038 L
.68808 .11573 L
.69608 .08999 L
.70408 .12023 L
.71208 .10575 L
.72009 .12656 L
.72809 .11254 L
.73609 .08646 L
.7441 .12465 L
.7521 .11091 L
.7601 .12627 L
.76811 .08696 L
.77611 .11079 L
.78411 .11687 L
.79212 .11672 L
.80012 .05669 L
.80812 .10082 L
.81613 .12411 L
.82413 .11258 L
Mistroke
.83213 .12942 L
.84014 .09264 L
.84814 .13208 L
.85614 .24405 L
.86415 .07899 L
.87215 .09607 L
.88015 .06033 L
.88816 .14487 L
.89616 .07657 L
.90416 .13823 L
.91216 .07324 L
.92017 .11923 L
.92817 .09305 L
.93617 .12398 L
.94418 .08476 L
.95218 .16373 L
.96018 .0534 L
.96819 .13347 L
.97619 .05341 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00C`3oool200000940oooo100000030?ooo`800000T03oool30000
0080oooo0P00002=0?ooo`<00000103oool2000008l0oooo0P0000040?ooo`800000R`3oool50000
0080oooo0P0000040?ooo`800000R03oool5000000030?ooo`0000000000008000000`3oool20000
02D0oooo001>0?ooo`040000003oool0oooo00000900oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00002@0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0RP3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000008d0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00002<0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo000002@0oooo001>0?ooo`040000003oool0oooo0000
0940oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00002=0?ooo`D0000000D0oooo
0000003oool0oooo0000002<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000S@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000008`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000903oool004h0oooo00@000000?ooo`3oool00000TP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0R`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000008`0oooo0`0000030?ooo`040000003oool0oooo000008h0oooo0P0000030?ooo`040000
003oool0oooo000008`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?ooo`00CP3oool010000000oooo0?ooo`00
002@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000SP3oool00`000000
oooo000000020?ooo`040000003oool0oooo000008d0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00002=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
S03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0280oooo001?0?ooo`800000TP3oool2000000@0oooo0P00002@
0?ooo`8000000`3oool2000008h0oooo0`0000030?ooo`800000S`3oool2000000@0oooo0P00002<
0?ooo`800000103oool2000000@0oooo0P0000290?ooo`800000103oool2000000@0oooo0P00000U
0?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00
o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo
0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0
ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3o
ool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?oo
o`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00o`3o
oooo0?ooool0ooooo`3oool90?ooo`00>@3ooooo00000?l00000o`00002c000001`0oooo000i0?oo
o`D000004P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`080?ooo`D00000703oool003T0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooobL0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`030?l0003oool0oooo08D0oooo
00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9`3o
ool00`3o0000oooo0?ooo`250?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooobL0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW0?ooo`030?l0003oool0oooo
08D0oooo00<000000?ooo`3oool06P3oool003T0oooo1@00003o0?ooool0ooooo`3ooolT0?ooo`80
o`00P`3oool5000001`0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo
0P3o00270?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooobH0oooo0P3o00270?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooobH0oooo0P3o00270?ooo`030000003oool0oooo01X0oooo000i0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo0P3o00270?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0o`000?ooo`3o
0000QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolV0?ooo`030?l0003oool0o`0008H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`3o0000oooo0?l000260?ooo`030000003o
ool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0o`00
0?ooo`3o0000QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolV0?ooo`030?l0003oool0o`0008H0oooo00<000000?ooo`3oool06P3oool001h0
oooo0P0000040?ooo`8000000`3oool4000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo9P3oool00`3o0000oooo0?l000260?ooo`030000003oool0oooo01X0oooo000M0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolU0?ooo`040?l0003oool0oooo0?l008H0oooo00<000000?ooo`3oool06P3oool001d0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0<0?ooo`L00000o`3ooooo0?oo
ool0oooo8@3oool0103o0000oooo0?ooo`3o00200?ooo`L00000703oool001d0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooobD0oooo00@0o`000?ooo`3oool0o`00QP3oool00`000000oooo0?ooo`0J0?ooo`007@3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo9@3oool0103o0000oooo0?ooo`3o00260?ooo`030000003oool0oooo01X0
oooo000N0?ooo`8000002P3oool2000000d0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
9@3oool0103o0000oooo0?ooo`3o00260?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooobD0oooo00@0o`000?ooo`3oool0o`00QP3oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`040?l0
003oool0oooo0?l008H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo9@3oool0103o0000oooo0?ooo`3o00260?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobD0oooo00@0o`000?ooo`3oool0
o`00QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolU0?ooo`040?l0003oool0oooo0?l008H0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool0103o0000oooo0?ooo`3o00260?ooo`03
0000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooob@0oooo
00D0o`000?ooo`3oool0oooo0?l000260?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000
o`3ooooo0?ooool0oooo8P3oool01@3o0000oooo0?ooo`3oool0o`000880oooo1@00000L0?ooo`00
>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`050?l0003oool0oooo0?ooo`3o
0000QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolT0?ooo`050?l0003oool0oooo0?ooo`3o0000QP3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`050?l0003oool0oooo0?ooo`3o
0000QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolT0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`3o0?ooogl0oooo00<0o`000?ooo`3oool0o`3ooonQ0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo0?h0oooo00<0003o0?ooo`3oool0O@3oool00`3o
0000oooo0?ooo`3o0?oooj40oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1F0?oo
o`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3o
ool0oP3oool00`000?l0oooo0?ooo`1m0?ooo`030?l0003oool0oooo0?l0ooooX@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0D03oool00`3o0000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1m0?ooo`80o`00o`3ooonQ0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`1@0?ooo`030?l0
003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0b@3o
ool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0O@3o
ool20?l00?l0ooooX@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P00
o`1B0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool003T0oooo1@00001>
0?ooo`030?l0003oool0oooo07H0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo07d0oooo0P3o003o0?oooj40oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`800?l0DP3oool00`3o0000oooo0?ooo`0V0?ooo`D00000703oool0
03T0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`1f0?ooo`030?l0003oool0oooo
02X0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1m0?ooo`80o`00o`3ooonQ0?oo
o`030?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l00580oooo00<0
o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1@
0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0O@3oool20?l006L0oooo00<0o`00
0?ooo`3oool0o`3ooolg0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o
00020?ooo`03003o003oool0oooo04h0oooo0P3o000/0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0003o07d0oooo00@0o`000?ooo`3oool0o`00IP3oool00`3o0000oooo0?oo
o`3o0?ooocL0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`00o`030?ooo`03003o
003oool0oooo04h0oooo0P3o000/0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02/0oooo00<0003o0?ooo`3oool08@3oool20?l002`0oooo00<0o`000?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0h0?ooo`80o`00;03oool20?l000D0oooo00<0003o0?ooo`000?l0O@3o
ool0103o0000oooo0?ooo`3o001V0?ooo`030?l0003oool0oooo0?l0oooo=`3oool00`3o0000oooo
0?ooo`030?ooo`040?l0003oool0oooo003o00<0oooo00<00?l00?ooo`3oool0CP3oool00`3o0000
oooo0?l000050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0503oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0240oooo
0P3o000/0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0>03oool20?l002/0oooo
00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1m0?ooo`040?l0003oool0oooo0?l006H0
oooo00<0o`000?ooo`3oool0o`3ooolg0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`00
o`00103oool00`00o`00oooo0?ooo`1>0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo02/0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?l0000[0?ooo`030?l0
003oool0oooo00d0oooo00<0o`000?ooo`3oool0>03oool20?l002/0oooo00<0o`000?ooo`3o0000
1@3oool00`000?l0oooo0000o`1m0?ooo`040?l0003oool0oooo0?l006H0oooo00<0o`000?ooo`3o
ool0K`3oool00`000?l0oooo0?ooo`340?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`00
o`00103oool00`00o`00oooo0?ooo`1>0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo02/0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?l0000[0?ooo`030?l0
003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool20?l003T0oooo00<0o`000?ooo`3o0000
:P3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o07d0oooo00@0o`000?ooo`3oool0
o`00IP3oool20?l001D0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`2C0?ooo`03
0000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?ooo`040?ooo`03
003o003oool0oooo04h0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
:P3oool20000ob<0oooo00<0o`000?ooo`3o0000:`3oool00`3o0000oooo0?ooo`050?ooo`03003o
003oool0oooo00D0oooo0P3o000i0?ooo`030?l0003oool0o`0002X0oooo00<0o`000?ooo`3o0000
1@3oool00`000?l0oooo0000o`1m0?ooo`050?l0003oool0oooo0?ooo`3o0000I@3oool20?l001D0
oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`2C0?ooo`030000o`3oool0oooo02h0
oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?ooo`040?ooo`03003o003oool0oooo0400
oooo00<00?l00?ooo`3oool02`3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo
0?ooo`0Z0?ooo`030000o`3oool0003o0280oooo00<0o`000?ooo`3o0000:P3oool20?l000L0oooo
00<00?l00?ooo`3oool01@3oool20?l003T0oooo00<0o`000?ooo`3o0000:P3oool00`3o0000oooo
0?l000050?ooo`030000o`3oool0003o07d0oooo00D0o`000?ooo`3oool0oooo0?l0001U0?ooo`80
o`005@3oool00`000?l0oooo0?ooo`0i0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3o
ool0T`3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00oooo0?ooo`100?ooo`03003o003oool0oooo00/0oooo00<0o`000?ooo`3o
00001@3oool20000o`d0oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0003o0280oooo00<0o`000?ooo`3o0000
:P3oool00`3o0000oooo0?l000050?ooo`03003o003oool00?l000H0oooo0P3o000i0?ooo`030?l0
003oool0o`0002X0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1m0?ooo`050?l0
003oool0oooo0?ooo`3o0000I03oool00`3o0000oooo0?l0000D0?ooo`80003o>`3oool00`000?l0
oooo0?ooo`0L0?ooo`030000o`3oool0oooo09<0oooo0P000?l^0?ooo`030?l0003oool0oooo00@0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`100?ooo`800?l0303oool00`3o0000
oooo0?l000050?ooo`80003o303oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`D00000:03oool00`000?l0oooo0000o`0R0?ooo`030?l0003oool0o`0002X0oooo
00<0o`000?ooo`3o00001@3oool00`00o`00oooo003o00050?ooo`030?l0003oool0o`0003T0oooo
00<0o`000?ooo`3o0000:P3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o07H0oooo
00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0006@0oooo00<0o`000?ooo`3o
0000503oool00`000?l0oooo0000o`0j0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`00
0?l0U03oool20000obh0oooo00<0o`000?ooo`3oool00`3oool00`00o`00o`000?ooo`050?ooo`03
003o003oool0oooo00/0oooo00<0003o0?ooo`3oool0<P3oool2003o00`0oooo00<0o`000?ooo`3o
00001@3oool20000o``0oooo00<0003o0?ooo`3oool04@3oool5000001`0oooo000i0?ooo`030000
003oool0oooo02X0oooo00<0003o0?ooo`000?l08@3oool0103o0000oooo0?ooo`3o000Z0?ooo`03
0?l0003oool0o`0000D0oooo00<00?l00?ooo`00o`001@3oool00`3o0000oooo0?l0000i0?ooo`03
0?l0003oool0o`0002X0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1f0?ooo`03
0000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0001T0?ooo`030?l0003oool0o`00
01@0oooo00<0003o0?ooo`000?l0>P3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo
00@0oooo00<0003o0?ooo`000?l0T`3oool00`000?l0oooo0000o`0^0?ooo`030?l0003oool0oooo
00<0oooo00<00?l00?l0003oool01P3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0340oooo00<00?l00?ooo`00o`00303oool00`3o0000oooo0?l000040?ooo`030000o`3oool0003o
00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`000?l08@3oool0103o0000
oooo0?ooo`3o000Z0?ooo`030?l0003oool0o`0000D0oooo00<00?l00?ooo`00o`001@3oool0103o
0000oooo0?ooo`3o000g0?ooo`040?l0003oool0oooo0?l002X0oooo00<0o`000?ooo`3o00001@3o
ool00`000?l0oooo0000o`1f0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`080?ooo`800?l0E`3oool00`3o0000oooo0?l0000D0?ooo`030000o`3o
ool0003o03X0oooo0P000?lE0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`000?l0T`3o
ool00`000?l0oooo0000o`0^0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3o00001`3o
ool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo0340oooo00@00?l00?ooo`3oool00?l0
2`3oool00`3o0000oooo0?l000040?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02X0oooo00<0003o0?ooo`000?l08@3oool0103o0000oooo0?ooo`3o000Z0?ooo`030?l0
003oool0o`0000D0oooo00<00?l00?ooo`00o`001@3oool0103o0000oooo0?ooo`3o000g0?ooo`04
0?l0003oool0oooo0?l002X0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1_0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00P0oooo00<00?l00?ooo`00o`000`00o`0n0?ooo`03003o003oool0oooo
0180oooo00<0o`000?ooo`3o0000503oool00`000?l0oooo0000o`0i0?ooo`030000o`3oool0003o
01@0oooo0P00o`060?ooo`030000o`3oool0003o09<0oooo00<0003o0?ooo`000?l0;P3oool00`3o
0000oooo0?ooo`020?ooo`04003o003oool0oooo0?l000H0oooo00<00?l00?ooo`3oool02@3oool2
0000oc<0oooo00@00?l00?ooo`3oool00?l02P3oool0103o0000oooo0?ooo`3o00040?ooo`030000
o`3oool0003o00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`000?l08@3o
ool0103o0000oooo0?ooo`3o000Z0?ooo`030?l0003oool0o`0000D0oooo00@00?l00?ooo`3oool0
0?l0103oool0103o0000oooo0?ooo`3o000g0?ooo`040?l0003oool0oooo0?l002X0oooo00@0o`00
0?ooo`3oool0o`00103oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0oooo06L0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0203oool00`00o`00oooo0?ooo`030?ooo`<00?l0>P3oool2003o00h0oooo
00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?l0000C0?ooo`040000o`3oool0oooo0000ocT0
oooo00<0003o0?ooo`000?l0503oool00`00o`00oooo003o00050?ooo`030000o`3oool0003o09<0
oooo00@0003o0?ooo`3oool0003o;@3oool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo
0?l000H0oooo00<00?l00?ooo`3oool02@3oool20000oc<0oooo00@00?l00?ooo`3oool00?l02P3o
ool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02T0oooo00@0003o0?ooo`3oool0003o8@3oool0103o0000oooo0?ooo`3o000Z0?ooo`03
0?l0003oool0o`0000@0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`040?l0003oool0oooo
0?l003L0oooo00@0o`000?ooo`3oool0o`00:P3oool0103o0000oooo0?ooo`3o00030?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`1W0?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0
oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0Q0?ooo`03003o003oool0oooo01<0
oooo0P00o`0>0?ooo`03003o003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`004P3oool01000
0?l0oooo0?ooo`000?li0?ooo`030000o`3oool0003o01@0oooo00<00?l00?ooo`00o`001@3oool0
0`000?l0oooo0000o`050?ooo`03003o003oool0oooo08/0oooo00@0003o0?ooo`3oool0003o;@3o
ool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo0?l000H0oooo00<00?l00?ooo`3oool0
2@3oool20000o`H0oooo00<00?l00?ooo`3oool0:P3oool01@00o`00oooo0?ooo`3oool00?l000T0
oooo00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0000o`060?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0Y0?ooo`040000o`3oool0oooo0000ob40oooo00@0o`000?ooo`3oool0o`00:P3oool0
0`3o0000oooo0?l000040?ooo`05003o003oool0oooo0?ooo`00o`00103oool0103o0000oooo0?oo
o`3o000g0?ooo`040?l0003oool0oooo0?l002X0oooo00@0o`000?ooo`3oool0o`000`3oool01@00
0?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0I`3oool00`3o0000oooo0?ooo`04
0?ooo`80003o1@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<00?l0
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0Q0?ooo`800?l04`3oool01000o`00oooo0?ooo`00
o`0<0?ooo`800?l01@3oool0103o0000oooo0?ooo`3o000B0?ooo`050000o`3oool0oooo0?ooo`00
0?l0>03oool00`000?l0oooo0000o`0D0?ooo`03003o003oool00?l000D0oooo00<0003o0?ooo`00
0?l01@3oool00`00o`00oooo0?ooo`2;0?ooo`040000o`3oool0oooo0000obd0oooo00D0o`000?oo
o`3oool0oooo003o00030?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool0
0`000?l0oooo0000o`050?ooo`03003o003oool0oooo02X0oooo00D00?l00?ooo`3oool0oooo003o
00090?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool08`3oool00`00o`00oooo0?ooo`030?ooo`040000o`3oool0oooo0000ob40oooo
00D0o`000?ooo`3oool0oooo0?l0000Y0?ooo`030?l0003oool0o`0000@0oooo00D00?l00?ooo`3o
ool0oooo003o00040?ooo`040?l0003oool0oooo0?l00280oooo00<00?l00?ooo`3oool04P3oool0
103o0000oooo0?ooo`3o000Z0?ooo`040?l0003oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0
oooo0000o`040?ooo`80o`006`3oool2003o04/0oooo00<0o`000?ooo`3oool0103oool20000o`D0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo00P0
oooo00<00?l00?ooo`3oool0803oool00`00o`00oooo003o000A0?ooo`05003o003oool0oooo0?oo
o`00o`00303oool2003o00D0oooo00@0o`000?ooo`3oool0o`004P3oool01@000?l0oooo0?ooo`3o
ool0003o03P0oooo00<0003o0?ooo`000?l01P3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003o
ool0oooo003o00D0oooo00<0003o0?ooo`000?l01@3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0
003oool0oooo04T0oooo00<00?l00?ooo`3oool0<03oool010000?l0oooo0?ooo`000?l]0?ooo`05
0?l0003oool0oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
00P0oooo00@0003o0?ooo`3oool0003o103oool00`00o`00oooo003o000[0?ooo`05003o003oool0
oooo0?ooo`00o`002@3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0003o00H0oooo
0P3o00040?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool08`3oool00`00o`00oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0
803oool01@3o0000oooo0?ooo`3oool0o`0002T0oooo00<0o`000?ooo`3o0000103oool01@00o`00
oooo0?ooo`3oool00?l000@0oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`03003o003oool0
oooo0180oooo00@0o`000?ooo`3oool0o`00:@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0000o`040?ooo`80o`006@3oool2003o00030?ooo`00o`00oooo04T0
oooo0P3o00050?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool07P3oool01@00o`00
oooo0?ooo`3oool00?l000l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0:0?oo
o`03003o003oool00?l000@0oooo00@0o`000?ooo`3oool0o`004@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo03H0oooo00@0003o0?ooo`3oool0003o1@3oool00`00o`00oooo0?oo
o`0:0?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`000?l0oooo0000o`040?ooo`03003o
003oool00?l000d0oooo00<0o`000?ooo`3oool0B@3oool00`00o`00oooo0?ooo`0`0?ooo`040000
o`3oool0oooo0000obd0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo
00@0oooo00<00?l00?ooo`3oool0203oool010000?l0oooo0?ooo`000?l40?ooo`03003o003oool0
0?l002/0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`040?l0003oool0
oooo0?l000@0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?l000040?ooo`030000
o`3oool0oooo01D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool08`3o
ool2003o00@0oooo00D0003o0?ooo`3oool0oooo0000o`0O0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo00<0oooo
00<0o`000?ooo`3o0000103oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o
00000`3oool00`3o0000oooo0?ooo`0O0?ooo`800?l04`3oool0103o0000oooo0?ooo`3o000Y0?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3o00005`3oool2003o00@0oooo00<00?l00?ooo`3oool0A`3oool20?l000D0oooo00<0
003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0N0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?ooo`00o`00103oool0103o0000oooo0?ooo`3o000A0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0=P3oool010000?l0oooo0?ooo`000?l50?ooo`800?l02`3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03003o003oool0
0?l000`0oooo0P3o001:0?ooo`03003o003oool00?l00300oooo00D0003o0?ooo`3oool0oooo0000
o`0/0?ooo`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l000060?ooo`03003o
003oool0oooo00P0oooo00@0003o0?ooo`3oool0003o103oool01000o`00oooo0?ooo`00o`0Y0?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool0103o0000oooo0?ooo`3o0004
0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?oo
o`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0280oooo00<00?l0
0?ooo`00o`00103oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0o`0000@0oooo00<00?l00?ooo`3oool00P3o
ool01@00o`00oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool07P3oool00`00o`00oooo
003o000B0?ooo`050?l0003oool0oooo0?ooo`3o0000:@3oool01@3o0000oooo0?ooo`3oool0o`00
00<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0o`0000`0oooo2`00o`06
0?ooo`03003o003oool0oooo04L0oooo0P3o00050?ooo`030000o`3oool0003o00@0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool07@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo003o00@0oooo00@0
o`000?ooo`3oool0o`004@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03H0oooo
00@0003o0?ooo`3oool0003o103oool00`00o`00oooo003o000:0?ooo`03003o003oool0oooo0080
oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`070000o`3oool0oooo0?ooo`00o`00oooo003o
000<0?ooo`80o`00BP3oool00`00o`00oooo003o000`0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0:@3oool01@3o0000oooo0?ooo`3oool00?l000@0oooo00<0o`000?ooo`3oool0
103oool00`00o`00oooo0?ooo`080?ooo`040000o`3oool0oooo0000o`<0oooo00D00?l00?ooo`3o
ool0oooo003o000Y0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?l0
00030?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool06P3oool003T0oooo1@00000P
0?ooo`04003o003oool0oooo003o00<0oooo00D0003o0?ooo`3oool0oooo0000o`0O0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool2003o00L0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`800?l01@3oool00`3o0000oooo0?l000030?ooo`03003o
003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool02`3oool01000o`00oooo0?ooo`00o`0A0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool09P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0o`0000P0oooo1000o`0A0?ooo`03003o003o
ool0oooo04L0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`040?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003o
ool0oooo01`0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0203oool01000o`00oooo0?ooo`00o`040?ooo`040?l0
003oool0oooo0?l00140oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0f0?ooo`04
0000o`3oool0oooo0000o`@0oooo00@00?l00?ooo`3oool00?l02@3oool00`00o`00oooo0?ooo`02
0?ooo`05003o003oool0oooo0?ooo`000?l00`3oool01`000?l0oooo0?ooo`3oool00?l00?ooo`00
o`002`3oool0103o0000oooo0?ooo`3o00180?ooo`04003o003oool0oooo003o02<0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00D0o`00
0?ooo`3oool0oooo003o00040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D00?l00?ooo`3oool0oooo003o000D0?ooo`03
003o003oool0oooo0180oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0
o`0000<0oooo00<0003o0?ooo`3oool04P3oool5000001`0oooo000i0?ooo`030000003oool0oooo
0280oooo00@00?l00?ooo`3oool00?l00`3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`@00?l00P3oool2003o00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03003o003oool00?l000<0oooo00@0
o`000?ooo`3oool0o`000`3oool00`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`3o
00000`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00/0oooo00@00?l00?ooo`3o
ool00?l04@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool08@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000
o`030?ooo`040?l0003oool0oooo0?l000D0oooo0P00o`0E0?ooo`03003o003oool0oooo04L0oooo
00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo01/0oooo
00<00?l00?ooo`3oool0103oool00`00o`00oooo0000o`070?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool0203oool01000o`00oooo0?ooo`00o`040?ooo`040?l0003oool0oooo0?l0
0140oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0d0?ooo`050000o`3oool0oooo
0?ooo`000?l0103oool01000o`00oooo0?ooo`00o`090?ooo`03003o003oool0oooo0080oooo00D0
0?l00?ooo`3oool0oooo0000o`030?ooo`040000o`3oool0oooo003o0080oooo00<00?l00?ooo`3o
ool02@3oool0103o0000oooo0?ooo`3o00180?ooo`04003o003oool0oooo003o02<0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00D0o`00
0?ooo`3oool0oooo003o00040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0@0?ooo`03003o00000?l0oooo01<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`000?l40?oo
o`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?oo
o`00>@3oool00`000000oooo0?ooo`0R0?ooo`07003o003oool0oooo0?ooo`00o`00oooo0000o`04
0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`800?l0203oool2003o00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`03003o003oool00?l000<0oooo00@0o`000?ooo`3oool0o`000`3oool00`00o`00oooo0?oo
o`030?ooo`05003o003oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o000@0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00X0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0
103o0000oooo0?ooo`3o00050?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool0<03o
ool00`00o`00oooo0?ooo`0C0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo00D0oooo00<00?l00000o`3oool01P3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00L0oooo00D00?l00?ooo`3oool0oooo
003o00040?ooo`040?l0003oool0oooo0?l00100oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0d0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@00o`00oooo0?ooo`3oool0
0?l000P0oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l30?ooo`040000o`3o
ool0oooo003o00<0oooo00<00?l00?ooo`3oool0203oool0103o0000oooo0?ooo`3o000[0?ooo`03
003o003oool0oooo01T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0P0?ooo`80
o`002`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00D0o`000?ooo`3o
ool0oooo003o00040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0@
0?ooo`03003o00000?l0oooo01<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`05
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0
003oool0o`0000<0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`000?l0103o
ool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`090?ooo`800?l00P000?l60?ooo`030?l0003oool0oooo00<0oooo00@0
0?l00?ooo`3oool00?l00`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<00?l00?ooo`3o
ool0103oool01000o`00oooo0?ooo`3o00030?ooo`030?l0003oool0oooo00T0oooo0P00o`050?oo
o`030000o`3oool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o000@0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3o
ool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo01D0oooo
00<00?l00?ooo`3oool0;`3oool2003o01D0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo
0000o`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo
0?ooo`0>0?ooo`03003o003oool0oooo01T0oooo00<00?l00?ooo`3oool01`3oool00`000?l00?l0
003o0005003o00X0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`04003o
003oool0oooo0?l000@0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`080?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=03oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00D00?l00?ooo`3oool0oooo003o00070?ooo`03003o003oool0oooo00@0oooo00@00?l0
0?ooo`3oool0003o0`3oool010000?l0oooo0?ooo`00o`030?ooo`03003o003oool0oooo00L0oooo
00D0o`000?ooo`3oool0oooo0?l0000[0?ooo`03003o003oool0oooo01T0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003oool0o`0000/0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0Y0?ooo`040?l0003oool0oooo003o00D0oooo00<0o`000?oo
o`3oool01@3oool00`00o`00oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00l0oooo00@00?l00?ooo`000?l00?l04`3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0240oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0000o`040?ooo`030000o`3oool0oooo01d0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo
00<0003o003o00000?l01@3oool20?l000@0oooo00@00?l00?ooo`3oool00?l00`3oool01@3o0000
oooo0?ooo`3oool0o`000080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?l000050?oo
o`030?l0003oool0oooo00P0oooo00@00?l00?ooo`00o`000?l00P3oool00`000?l0oooo0000o`0<
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool03@3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo0P000?lE0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3oool0
;P3oool01000o`00oooo0?ooo`00o`0D0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo00H0oooo0P000?lA0?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00040?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`04
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`00
0?l30?ooo`040000o`3oool0oooo003o00<0oooo00<00?l00?ooo`3oool01`3oool01@3o0000oooo
0?ooo`3oool0o`0002X0oooo00<00?l00?ooo`00o`006@3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo01l0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo02P0oooo00@0o`000?ooo`3oool00?l01@3oool00`3o0000oooo0?ooo`05
0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo003o0007
0?ooo`05003o003oool0oooo0?ooo`000?l0303oool01000o`00oooo0000o`000?lC0?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?l000030?ooo`030000o`3oool0oooo
01H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool08@3oool00`00o`00
oooo0?ooo`030?ooo`03003o00000?l0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0G0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0<0?ooo`030000o`00o`00003o00D0oooo0P3o00040?ooo`05003o003oool0oooo0?oo
o`00o`000P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00o`001`3oool00`00o`00oooo0?l0
00050?ooo`030?l0003oool0oooo00P0oooo00@00?l00?ooo`3oool0oooo0P00o`000`000?l0oooo
0000o`0;0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool03@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P000?lE0?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?oo
o`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo01H0oooo00<00?l00?oo
o`3oool0;@3oool01@00o`00oooo0?ooo`3oool00?l001<0oooo00@0o`000?ooo`3oool0o`00103o
ool00`000?l00?l00000o`040?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool01P3o
ool00`000?l0oooo0000o`0@0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3o
ool01000o`00oooo0?ooo`3o00040?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0
0P3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o
ool0103oool01000o`00oooo0?ooo`000?l30?ooo`040000o`3oool0oooo003o00<0oooo00<00?l0
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02P0oooo00<00?l0
0?ooo`00o`006@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01h0oooo00@0o`00
0?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02P0oooo00@0
o`000?ooo`3oool00?l01@3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo003o00070?ooo`05003o003oool0oooo0?ooo`00
0?l02`3oool00`00o`00oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool02P3oool00`00o`00
oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0103o0000
oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`00
0?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0240
oooo00<00?l00?ooo`3oool00`3oool00`00o`00003o0?ooo`040?ooo`060000o`3oool0oooo003o
003oool00?l0603oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00o`003`3o
ool00`000?l0oooo0000o`040?ooo`030?l0003oool0o`0000@0oooo00D00?l00?ooo`3oool0oooo
003o00020?ooo`070?l0003oool0oooo0?ooo`3o0000oooo003o00030?ooo`070000o`3oool0oooo
0?ooo`00o`00oooo0?l000050?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0103o
ool00`000?l00?l00000o`0;0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0303o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P000?lD0?ooo`80o`00303o
ool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`@0oooo00@0003o0?ooo`3oool0
o`000`3oool01@3o0000oooo0?ooo`3oool00?l001T0oooo00<00?l00?ooo`3oool0:`3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo0100oooo00@0o`000?ooo`3oool0o`000P3oool2
003o00040000o`00o`00oooo0000o`<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?oo
o`060?ooo`030000o`3oool0003o0100oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`030?ooo`04003o003oool0oooo0?l000@0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l0
00T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
oooo00D0oooo00<00?l00000o`3oool0103oool00`000?l00?l00?ooo`040?ooo`03003o003oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0X0?ooo`04003o003oool0
oooo003o01L0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`030?l0003o
ool0oooo0180oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0=0?ooo`040?l0003oool0oooo003o00D0
oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`070?ooo`030000o`3oool0oooo
00<0oooo00<0003o003o003oool01`3oool01000o`00oooo0?ooo`000?l;0?ooo`05003o003oool0
003o0?ooo`000?l01P3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`@0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`040?l0003oool0oooo0000oaP0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00H0003o0?ooo`3oool00?l00?ooo`00o`0H0?ooo`030?l0003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo003o000?0?ooo`030000o`3oool0003o00@0oooo00<0
o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0?l000<0oooo
00<0o`000?ooo`00o`000`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000oooo00@0oooo
00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`030000o`00o`00003o00/0oooo
00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo
00L0o`000?ooo`3oool0oooo0000o`3oool0003o01@0oooo00<0o`000?ooo`3o00002`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0003o00D0oooo00@0003o0?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool00?l001T0oooo00<00?l00?ooo`3oool0803oool2003o00P0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:0?ooo`@00?l00P3oool0103o0000oooo0?oo
o`3o0002003o0080oooo00@0003o003o003oool0003o0`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`0G0?ooo`03
003o003oool0oooo00H0oooo00<0003o0?ooo`000?l04@3oool00`00o`00oooo0?ooo`040?ooo`03
003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0o`00103oool01`3o0000oooo0?ooo`3oool0
0?l00?ooo`00o`00203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03@0oooo00<0
003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool01P3oool00`00o`00003o0?ooo`040?ooo`030000o`00o`00oooo00@0oooo
00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02L0oooo
00D00?l00?ooo`3oool0oooo003o000G0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01L0oooo0P3o000?0?ooo`03
0?l0003oool00?l000H0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`070?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool01000o`00oooo0?ooo`000?l:
0?ooo`06003o003oool0oooo0000o`3oool0003o1P3oool20?l000X0oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0
003o103oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0003o603oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o00030?ooo`03003o003oool0oooo
01D0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`00o`0?0?ooo`030000o`3oool0
003o00@0oooo00<0o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0
oooo0?l000<0oooo00<0o`000?ooo`00o`000`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o
0000oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3o
ool0003o00H0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`00
0?l0503oool00`3o0000oooo0?l0000;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`00
0?l01@3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo003o01X0oooo00<00?l00?oo
o`3oool0803oool00`00o`00oooo003o0003003o00<0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo1P00o`040?ooo`040000o`3oool00?l0
0000o`<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo0180oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`050?ooo`040000o`3oool0
oooo0000oa40oooo00@00?l00?ooo`3oool0o`000`3oool00`00o`00oooo0?ooo`030?ooo`04003o
003oool0oooo0?l000@0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l000P0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool00?l01P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<0
0?l00000o`3oool0103oool00`000?l00?l00?ooo`040?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0V0?ooo`05003o003oool0oooo0?ooo`00o`00
5P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo0P3o000C0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01D0oooo0P3o00000`3oool0o`000?ooo`0>0?ooo`030?l0003oool00?l000H0oooo
00<0o`000?ooo`3oool00P3oool20000o`030?ooo`00o`00oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`070?ooo`05003o003oool0003o0?ooo`000?l02@3oool01`00o`00
oooo0?ooo`000?l0oooo0000o`00o`001@3oool20?l000X0oooo00<00?l00?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o103o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0003o603oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo00@0oooo
00<0003o003o003oool0103oool00`000?l00?l00?ooo`030?ooo`03003o003oool0oooo01D0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo003o000@0?ooo`040000o`3oool0003o003o00<0
oooo00<0o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0?l0
00<0oooo00<0o`000?ooo`00o`000`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000oooo
00@0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o
00H0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
00X0oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?l000060?ooo`03003o003oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0o`0000@0oooo00@0o`00
0?ooo`3oool00?l06P3oool00`00o`00oooo0?ooo`0O0?ooo`03003o003oool0oooo00@0oooo0`00
o`090?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?oo
o`3o00040?ooo`040000o`3oool00?l00000o`<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool05@3oool00`00o`00
oooo0?ooo`060?ooo`040000o`3oool0oooo0000oa40oooo00@00?l00?ooo`3oool0o`000P3oool0
0`00o`00oooo0?ooo`050?ooo`03003o003oool0o`0000@0oooo00L0o`000?ooo`3oool0oooo003o
003oool00?l000P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo003o00070?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00003o0?ooo`040?ooo`030000
o`00o`00oooo00@0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo02H0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o
003oool0oooo00L0oooo00<00?l00?ooo`3oool01`3oool20?l001<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
4`3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00@0o`000?ooo`3oool00?l01P3oool00`3o
0000oooo0?ooo`020?ooo`80003o00<0oooo003o003oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00P0oooo00@00?l00000o`3oool0003o203oool02000o`00oooo0?ooo`3o
ool0003o0?ooo`000?l00?l01@3oool00`3o0000oooo0?l000090?ooo`03003o003oool0oooo00P0
oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`040?l0003oool0oooo0000o`@0oooo00@0003o
0?ooo`3oool0o`000`3oool0103o0000oooo0?ooo`000?lH0?ooo`030000003oool0oooo01X0oooo
000N0?ooo`800000103oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo0200oooo00<0
0?l00?ooo`3oool0103oool00`000?l0oooo003o00040?ooo`030000o`3oool0oooo00@0oooo00<0
0?l00?ooo`3oool0503oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool00?l00100oooo00@0
003o0?ooo`000?l00?l00`3oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3o00000`3oool00`3o0000oooo003o00030?ooo`030000o`3oool0oooo0080oooo
00<00?l00?l0003oool01@3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo
00@0003o0?ooo`00o`00003o1@3oool01@3o0000oooo0?ooo`3oool00?l000T0oooo00<00?l00?oo
o`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`080?l0003oool0oooo0?ooo`000?l00?l00?oo
o`000?lC0?ooo`030?l0003oool0o`0000D0oooo0P00o`030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo003o01/0
oooo00<00?l00?ooo`3oool07P3oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo00H0
oooo00<00?l00?ooo`3oool01@3oool0103o0000oooo0?ooo`3o00040?ooo`040000o`3oool00?l0
0000o`<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo01<0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`060?ooo`040000o`3oool0
oooo0000oa40oooo00@00?l00?ooo`3oool0o`000P3oool00`00o`00oooo0?ooo`050?ooo`03003o
003oool0o`0000@0oooo00@0o`000?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;@3oool20?l000<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo003o00080?ooo`04003o003oool0oooo003o00T0oooo00<00?l00000
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool04P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo00<0o`000?oo
o`3o00004P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool02`3oool0103o0000oooo0?ooo`00o`060?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`000?l0oooo003o00050?ooo`030000o`3oool0oooo00<0oooo00<00?l00000o`3oool02@3o
ool01000o`00003o0?ooo`000?l80?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0o`0000T0oooo00<00?l00?ooo`3oool0203oool01@00o`00
oooo0?ooo`3oool0o`0000@0oooo00@0o`000?ooo`3oool0003o103oool010000?l0oooo0?ooo`3o
00030?ooo`030?l0003oool0003o01T0oooo00<000000?ooo`3oool06P3oool001d0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01l0oooo
00<00?l00?ooo`3oool01@3oool00`000?l0oooo003o00040?ooo`030000o`3oool0oooo00@0oooo
00<00?l00?ooo`3oool0503oool00`3o0000oooo0?ooo`040?ooo`030?l00000o`00oooo0100oooo
00@0003o0?ooo`000?l00?l00`3oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3o00000`3oool00`3o00000?l00?ooo`020?ooo`80003o103oool00`00o`00
o`000?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool010000?l0
oooo003o00000?l50?ooo`050?l0003oool0oooo0?ooo`00o`002@3oool00`00o`00oooo0?ooo`05
0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool0003o00800?l0
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?l000050?ooo`03003o00000?l0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0o`0000D0oooo
00<0o`000?ooo`00o`006`3oool00`00o`00oooo0?ooo`0N0?ooo`03003o003oool0oooo0140oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`040?l0003oool0oooo0?l000<0
oooo00D0003o0?ooo`3oool00?l00000o`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo01@0oooo00<00?l00?oo
o`3oool01P3oool010000?l0oooo0?ooo`000?l=0?ooo`030000o`3oool0oooo0080oooo00<00?l0
0?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0o`0000@0oooo00@0o`00
0?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0;@3oool20?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l00?l00?oo
o`070?ooo`04003o003oool0oooo003o00X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0U0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool04P3oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3o00004@3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0@0?ooo`80o`001P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool00?l000L0oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0000o`3oool00?l000D0oooo00<0003o0?ooo`3o
ool00`3oool00`00o`00003o0?ooo`090?ooo`04003o00000?l0oooo0000o`L0oooo00<00?l00?oo
o`3oool00P3oool010000?l0oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0?l000T0oooo00<0
0?l00?ooo`3oool0203oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo00@0o`000?ooo`3oool0
003o103oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0003o01T0oooo00<000000?oo
o`3oool06P3oool001d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;0?oo
o`L000006`3oool00`00o`00oooo0?ooo`050?ooo`040000o`3oool0oooo003o0080oooo00<00?l0
0000o`3oool01P3oool00`00o`00oooo0?ooo`0C0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
003o003oool03`3oool01P000?l0oooo0?ooo`000?l0oooo003o0080oooo00<0o`000?ooo`3o0000
0P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0o`0000<0oooo00<0o`00003o003oool0
0P3oool00`000?l0oooo0000o`040?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool01@3o0000
oooo0?ooo`3oool00?l000X0oooo00<00?l00?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0
o`0000D0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000o`00o`000?l00100oooo00@0
o`000?ooo`3oool0o`00103oool01000o`00oooo0000o`00o`020?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?l000050?ooo`030?l0003oool00?l001/0
oooo00<00?l00?ooo`3oool07P3oool00`00o`00oooo0?ooo`0B0?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool01P3oool0103o0000oooo0?ooo`3o00030?ooo`050000o`3oool0oooo
0?ooo`000?l00P3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`00o`005P3o
ool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo
0000o`0=0?ooo`030000o`3oool0oooo0080oooo00D00?l00?ooo`3o0000oooo003o00080?ooo`03
003o003oool0o`0000D0oooo00<0o`000?ooo`00o`000`3oool00`00o`00oooo0?ooo`040?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?l000030?ooo`03
0000o`3oool0oooo00@0oooo00<0003o003o003oool0203oool00`00o`00oooo003o000:0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool01@00o`00oooo0?ooo`3oool0o`00
00P0oooo00<0o`000?ooo`3oool09@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
0100oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`060?ooo`040?l0003oool0oooo
0?l00140oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool03P3oool20?l000P0oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo003o00070?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0003o003o
00040?ooo`030000o`3oool0oooo00@0oooo00<00?l00000o`3oool02P3oool00`000?l0oooo0000
o`070?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool0003o103oool01@3o0000oooo
0?ooo`3oool0o`0000P0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo003o00020?ooo`03
0?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o103oool010000?l0oooo0?ooo`3o0003
0?ooo`030?l0003oool0003o01<0oooo1`00000L0?ooo`007@3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`05
0?ooo`080000o`3oool0oooo003o003oool00?l00?ooo`000?l80?ooo`04003o003oool0oooo0000
oa00oooo00<0o`000?ooo`3oool01@3oool00`3o00000?l00?ooo`0?0?ooo`060000o`3oool0oooo
0000o`3oool00?l00P3oool01@3o0000oooo0?l0003oool00?l000L0oooo00<00?l00?ooo`3o0000
0`3oool00`3o00000?l00?ooo`020?ooo`030000o`3oool0003o00@0oooo00<00?l00?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0
oooo0000o`040?ooo`80o`000`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00@0
oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`02003o00T0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
00040?ooo`04003o003oool0003o003o0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0000o`050?ooo`030000o`3oool0o`0000D0oooo00<0o`00003o003oool0703oool00`00o`00oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00L0oooo00@0o`000?ooo`3oool0o`000`3oool01@000?l0
oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0
0?l001H0oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0
o`000?l00000o`00203oool00`00o`00oooo0?l000050?ooo`030?l0003oool00?l000<0oooo00<0
0?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02`0oooo00<0
o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`00o`00oooo00P0oooo00<0
0?l00?ooo`00o`002P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00D0
0?l00?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
7P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool0
2P3oool00`00o`00oooo0?ooo`050?ooo`040?l0003oool0oooo0?l00140oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0303oool20?l000X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo003o00070?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0003o003o00040?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`000?l02`3oool00`000?l0oooo0000o`050?ooo`800?l01@3oool01000
0?l0oooo0?ooo`000?l40?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`00o`00oooo0?oo
o`070?ooo`030000o`3oool00?l00080oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?oo
o`000?l40?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`000?l06@3oool00`000000
oooo0?ooo`0J0?ooo`007@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00`0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`050?ooo`040000o`3oool0oooo
0?ooo`800?l000<0oooo0000o`3oool01`3oool01000o`00oooo0?ooo`000?l@0?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool01P000?l0oooo0?ooo`3oool0003o003o0080
oooo00D0o`000?ooo`3oool0o`00003o00070?ooo`03003o003oool0o`0000<0oooo00<0o`00003o
003oool00P3oool00`000?l0oooo0000o`040?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?l000020?ooo`04003o003oool0oooo0000o`L0oooo00<00?l00?ooo`3oool0103o
ool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`04
0000o`3oool0oooo0?ooo`800?l01`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo
0?l000<0oooo00D00?l00?ooo`3oool0003o003o00020?ooo`030?l0003oool0oooo00@0oooo00<0
o`000000o`3oool0103oool00`000?l0oooo0?l000050?ooo`030?l00000o`00oooo01`0oooo00<0
0?l00?ooo`3oool03`3oool20?l000/0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050000
o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo003o
01P0oooo00<00?l00?ooo`3oool04P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool02@3oool20000o`@0oooo00D00?l00?l0003oool0o`00003o0008
0?ooo`03003o003oool0o`0000D0oooo00<0o`00003o003oool0103oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0:P3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`03003o003o
ool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`05003o003o
ool0oooo0?ooo`3o0000203oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo01h0oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo00X0oooo
00<00?l00?ooo`3oool01@3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool20?l000`0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo003o00080?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l00?l00?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<00?l00?ooo`000?l02`3oool010000?l00?l00000o`3oool4
003o00L0oooo00D0003o0?ooo`3oool0003o003o00030?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool00?l00080oooo00<0
o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l40?ooo`040000o`3oool0oooo0?l000<0
oooo00<0o`000?ooo`000?l06@3oool00`000000oooo0?ooo`0J0?ooo`007P3oool2000000X0oooo
0P00000=0?ooo`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool01P3oool01@000?l0oooo
0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool01`3oool01000o`00oooo0000o`000?l?0?oo
o`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool02@000?l0oooo0?ooo`3oool0
003o0?ooo`00o`00oooo0?l000020?ooo`030?l00000o`00oooo00<0oooo00D0003o0?ooo`3oool0
oooo003o00040?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`000?l0103oool00`00o`00
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool01@000?l0
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o00000P3oool01000o`00oooo0?ooo`000?l7
0?ooo`030?l00000o`00oooo00<0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo00@0o`00
0?ooo`00o`00003o0`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo0P00
0?l40?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@00o`00oooo0000o`000?l00?l00080
oooo00<0o`000?ooo`3oool0103oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0o`0000D0
oooo00<0o`00003o003oool0703oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0o`0000/0
oooo00<00?l00?ooo`3oool0503oool01@00o`00oooo0?ooo`3oool00?l000T0oooo00<0o`000?oo
o`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`040000o`3oool0oooo0?l000X0oooo00@0
o`000?ooo`3oool00?l0603oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo00H0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0003o00@0oooo
00<00?l00?ooo`00o`001P3oool01P000?l0oooo0?ooo`00o`00oooo0?l000D0oooo00<0o`00003o
003oool0103oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo0140oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02@3oool0
0`00o`00oooo0?ooo`080?ooo`030000o`3oool00?l000<0oooo00<00?l00?ooo`000?l01P3oool0
1@00o`00oooo0?ooo`3oool0o`0000P0oooo00<0o`000?ooo`3oool00`3oool2003o01l0oooo00<0
0?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0>0?ooo`80003o303oool00`00o`00oooo0?oo
o`040?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo0P3o000>0?ooo`030?l0003oool0oooo00/0oooo00<0o`00003o003oool0
203oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`03003o003oool0003o00/0oooo00@0003o003o0000o`00003o2P3oool00`00
0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`04
0?ooo`03003o003oool0oooo00L0oooo0P000?l20?ooo`03003o003oool0o`0000D0oooo00<0o`00
0?ooo`000?l0103oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0003o01T0oooo00<0
00000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool01000o`00003o0?ooo`00
0?l?0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?l0003oool0403oool02@000?l0oooo0?oo
o`3oool0003o0?ooo`00o`00oooo0?l000020?ooo`03003o003oool0oooo00<0oooo00D0003o0?oo
o`3oool0oooo003o00040?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`000?l0103oool0
0`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`090000o`3oool0oooo0?ooo`3o0000oooo0?l0003oool00?l000<0
oooo00<0003o0?ooo`3oool01@3oool00`3o00000?l00?ooo`030?ooo`030000o`3oool0003o0080
oooo00<0o`000?ooo`3oool0103oool0103o0000oooo003o00000?l30?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool20000o`@0oooo00L0o`000?ooo`3oool0oooo0?l0003o
ool00?l00080oooo00H0003o0?ooo`000?l00?l00?ooo`3o00060?ooo`030?l000000?l0oooo00@0
oooo00<0003o0?ooo`3o00001@3oool00`3o00000?l00?ooo`0L0?ooo`03003o003oool0oooo00h0
oooo00@0o`000?ooo`3oool0o`002P3oool00`00o`00oooo0?ooo`0E0?ooo`04003o003o0000oooo
003o00T0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`040000o`00
o`00oooo0?l000X0oooo00@0o`000?ooo`3oool00?l06@3oool00`00o`00oooo0?ooo`0@0?ooo`03
003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0003o00@0oooo00<00?l00?ooo`00o`001P3oool01P000?l0oooo0?ooo`3oool00?l0
0?l000D0oooo00<0o`00003o003oool0103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool01P3oool2003o00h0oooo0P00o`0A0?ooo`030?l0003oool0
oooo0080oooo00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3o
ool00?l000<0oooo00<00?l00?ooo`000?l01`3oool00`00o`00oooo0?l0000:0?ooo`030?l0003o
ool0oooo0080oooo0P00o`0N0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool03P3o
ool00`000?l0oooo0000o`0<0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`80003o2@3oool00`3o0000oooo0?ooo`080?ooo`050?l0003o
ool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00d0oooo
00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`030?l00000o`00oooo00P0oooo
00@0o`000?ooo`3oool0003o103oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00@00?l00?oo
o`3oool0003o2P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo
0?ooo`030?ooo`03003o003oool0oooo00L0oooo0P000?l20?ooo`03003o003oool0o`0000D0oooo
00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?l000040?ooo`030?l000000?l0oooo01P0oooo
00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000
o`0?0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?l0003oool00`3oool00`000?l0oooo0?oo
o`0:0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool01@00o`00o`000?ooo`3oool00?l000D0
oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`000?l0103oool00`3o00000?l00?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<00?l00?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`090000o`3oool0oooo0?ooo`3o0000oooo0?l0
003oool00?l00080oooo0P000?l70?ooo`030?l00000o`00oooo00<0oooo00D0003o0?ooo`000?l0
oooo0?l000070?ooo`040?l0003oool00?l00000o`<0oooo00<0003o0?ooo`3oool00`3oool00`00
o`00oooo0?ooo`030?ooo`030000o`3oool0003o00<0oooo00L0o`000?ooo`3oool0oooo0?l0003o
ool00?l00080oooo00H0003o0?ooo`000?l00?l00?ooo`3o00060?ooo`030?l000000?l0oooo00@0
oooo00<0003o0?ooo`3o00001@3oool00`00o`00o`000?ooo`0M0?ooo`03003o003oool0oooo00d0
oooo00@0o`000?ooo`3oool0o`002@3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00@0oooo00<00?l00?l00000o`002P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo
0000o`<0oooo00@0003o003o003oool0o`002P3oool0103o0000oooo0?ooo`00o`0I0?ooo`03003o
003oool0oooo0100oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo003o00060?ooo`050000
o`3oool0oooo0?ooo`00o`001P3oool00`3o00000?l00?ooo`040?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`04003o003oool0oooo003o
00d0oooo0P00o`0A0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1P3oool0
0`00o`00003o0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`00o`000`3oool0
0`00o`00oooo0000o`070?ooo`03003o003oool0o`0000X0oooo00L0o`000?ooo`3oool0oooo003o
003oool00?l001@0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`03003o
003oool0o`0000`0oooo00@00?l00000o`3oool0003o303oool00`00o`00oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00T0oooo00<0o`00
0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo0`00o`040?ooo`030?l0003o
ool00?l000T0oooo00@0o`000?ooo`3oool0003o103oool01@00o`00003o0?ooo`3oool0003o00D0
oooo00@00?l00?ooo`3oool0003o2P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo00H0003o0?ooo`000?l0oooo
003o003o00060?ooo`030?l0003oool0003o00D0oooo00<0003o0?ooo`3o0000103oool00`3o0000
003o0?ooo`0H0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01h0oooo
00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`000?l03@3oool00`000?l0oooo0?l000060?ooo`03003o003o0000oooo00<0oooo
00<0003o0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00D00?l00?l0003o
ool0oooo003o00050?ooo`050000o`3oool0oooo0?ooo`00o`00103oool00`00o`00o`000?ooo`02
0?ooo`030000o`3oool0003o00@0oooo00<0o`00003o003oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool02@000?l0oooo0?ooo`3o
ool0o`000?ooo`3o0000oooo003o00020?ooo`030000o`3oool0003o00H0oooo0P3o00002@00o`00
oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000070?ooo`040?l00000o`00oooo0000o`<0oooo
00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0003o00<0oooo
00H0o`000?ooo`3oool0oooo0?l00000o`030?ooo`060000o`3oool0003o003o003oool0o`001P3o
ool00`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo00D0oooo00<00?l00?l0003oool07@3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`060?ooo`04003o003oool0oooo0000o`h0oooo00<0003o0?ooo`3oool0
1@3oool2003o00X0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l40?ooo`03
0000o`3oool0o`0000X0oooo00@0o`000?ooo`3oool00?l06P3oool00`00o`00oooo0?ooo`0?0?oo
o`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0003o00@0oooo00<00?l00?ooo`00o`001@3oool20000o`<0oooo00<00?l00?oo
o`3oool0103oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`00o`001P3oool0
0`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo003o00l0oooo00<0o`000?ooo`3oool00`3o
ool0103o0000oooo0?ooo`000?l50?ooo`03003o003oool0003o00X0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo003o00030?ooo`03003o003oool0003o00L0oooo00<00?l00?ooo`3o0000
2P3oool01@3o0000oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool04@3oool00`000?l0
oooo0?ooo`070?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`3o0000o`002`3oool01000
o`00003o0?ooo`000?l<0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
1`3o0000oooo0?ooo`3oool0003o0?ooo`000?l02@3oool00`3o0000oooo0?ooo`090?ooo`040?l0
003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0?0?ooo`05
0?l0003oool0oooo0?ooo`00o`000`3oool01`00o`00oooo0?ooo`3oool0o`000?ooo`00o`002@3o
ool0103o0000oooo0?ooo`000?l40?ooo`05003o00000?l0oooo0?ooo`000?l01@3oool01@00o`00
oooo0?ooo`3oool0003o00T0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0
o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0003o0080oooo00<0
0?l00?ooo`3oool0103oool01@3o0000oooo0000o`3oool00?l000<0oooo00<0003o0?ooo`3o0000
103oool00`3o0000003o0?ooo`0H0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo01d0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00@0003o003o003oool0003o303oool00`000?l0oooo0?l000050?ooo`03003o
003oool0o`0000@0oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`80003o0`3oool00`3o00000?l00?ooo`020?oo
o`03003o003o0000oooo0080oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo003o00060?oo
o`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?oo
o`090000o`00o`00oooo0?ooo`3o0000oooo0?l0003oool00?l00080oooo00<0003o0?ooo`000?l0
1@3oool0103o0000oooo0?l00000o`030?ooo`050000o`3oool0003o0?ooo`3o00001`3oool00`3o
00000?l00000o`050?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`02
0?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`00003o003oool00P3oool01P000?l0oooo0000
o`00o`00oooo0?l000H0oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
003o003o0000oooo01d0oooo00<00?l00?ooo`3oool01@3oool2003o00D0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`060?ooo`04003o003oool0003o0000o`h0oooo00<0003o0?oo
o`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00@0o`000?oo
o`3oool0003o103oool00`000?l0oooo0?l0000:0?ooo`040?l0003oool0oooo003o01/0oooo00<0
0?l00?ooo`3oool03P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0203oool010000?l0oooo0?ooo`000?l40?ooo`030?l00000o`00o`0000D0oooo
0P000?l30?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool01@00o`00oooo
0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool00?l0
00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`060?ooo`03003o003oool0003o
00T0oooo0P000?l:0?ooo`030000o`3oool00?l000<0oooo00<00?l00?ooo`000?l01`3oool00`00
o`00oooo0?l0000:0?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0@
0?ooo`030000o`3oool0003o00L0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?l0003o
ool0o`0000T0oooo00D00?l00000o`3oool0oooo0000o`0<0?ooo`03003o003oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0@0?ooo`060?l0003oool0oooo0?ooo`00o`00003o0`3o
ool2003o00030?ooo`3o00000?l000X0oooo00@0o`000?ooo`3oool0003o103oool01@00o`00oooo
0000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo0000o`090?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0003o
003o003oool0oooo0?l000060?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01`3o
ool00`000?l0oooo0000o`020?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`000?l00P00
o`030?ooo`030000o`3oool0o`0000@0oooo00<0o`000000o`3oool0603oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool00?l00?ooo`000?l02`3o
ool20000o`030?ooo`3o0000oooo00@0oooo00@00?l00?ooo`3oool0o`000`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`05
0?l00000o`00oooo003o003o0000103oool00`000?l0oooo0000o`020?ooo`030?l00000o`00oooo
0080oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0000o`030?ooo`030?l0003oool00?l0
00H0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00T0003o003o003oool0oooo0?l0003oool0o`000?ooo`00o`000P3oool00`000?l0oooo
0000o`050?ooo`040?l0003oool0o`00003o00<0oooo00D0003o0?ooo`000?l0oooo0?l000070?oo
o`03003o003oool0003o00D0oooo00<0003o0?ooo`3oool0103oool01000o`00oooo0?ooo`000?l2
0?ooo`040000o`3oool0oooo0?l000@0oooo00<00?l00?ooo`3oool00P3oool01P000?l0oooo0000
o`3oool00?l00?l000H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
003o003o0000oooo01d0oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`00o`040?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0000o`000?l=
0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`02
0?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o003o003o00002`3oool00`3o00000?l00?oo
o`0L0?ooo`03003o003oool0oooo00X0oooo00@0o`000?ooo`3oool00?l01`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000
0?l00?l000050?ooo`030000o`3oool0003o0080oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`050?ooo`04003o003oool0oooo0000o``0oooo00<0003o0?ooo`3oool00P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo0P000?l50?ooo`05003o003oool0oooo
0?ooo`00o`003@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0003o00H0oooo00<00?l0
0?ooo`000?l02@3oool00`000?l0oooo0000o`090?ooo`060000o`3oool0oooo003o003oool00?l0
0P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0o`0000X0oooo00P0o`000?ooo`3oool0
oooo003o00000?l0oooo003o0180oooo00<0003o0?ooo`000?l01`3oool00`00o`00oooo0?ooo`0:
0?ooo`05003o003oool0oooo0?ooo`3o0000203oool00`00o`00003o0?ooo`020?ooo`030000o`3o
ool0oooo00X0oooo00D00?l00?ooo`3oool0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3o
ool0003o2P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0100oooo00H0o`000?oo
o`3oool00?l00?ooo`000?l50?ooo`<00?l02P3oool0103o0000oooo0?ooo`000?l50?ooo`03003o
00000?l0003o00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool010000?l0
oooo0?ooo`3o00060?ooo`030?l000000?l0oooo0080oooo00<00?l00?ooo`3oool01P3oool01000
0?l0oooo0?ooo`000?l20?ooo`03003o003oool0oooo00@0oooo00H0o`000000o`3oool00?l00?oo
o`00o`020?ooo`030000o`3oool0o`0000@0oooo00<0003o0?ooo`3oool0603oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo003o00000?l0
103oool00`3o0000oooo0?ooo`040?ooo`80003o00<0o`000?ooo`3oool00`3oool01@00o`00oooo
0?ooo`3oool0o`0000<0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool020000?l0oooo0?ooo`3o00000?l00?ooo`00o`00o`00103oool00`000?l0oooo0000
o`020?ooo`030?l00000o`00oooo0080oooo00D00?l00?l0003oool0oooo0000o`020?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo003o00060?ooo`030?l0003oool0oooo0080oooo00<00?l00?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`090000o`00o`00oooo0?ooo`3o0000oooo0?l0
003oool00?l00080oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?l0003oool00?l00080
oooo00D0003o0?ooo`000?l0oooo0?l000070?ooo`03003o003oool0003o00D0oooo00<0003o0?oo
o`3oool0103oool01000o`00oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0?l000@0oooo00D0
0?l00?ooo`3oool0oooo0000o`020?ooo`040000o`3oool00?l00?l000H0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003o0000oooo01h0oooo00<00?l00?ooo`3o
ool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`03003o003oool0003o0080oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0000o`050?ooo`030?l0003oool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool0103o
0000oooo0?ooo`000?l40?ooo`030000o`00o`00o`0000/0oooo00<0o`00003o003oool06P3oool8
0000o`L0oooo00<0o`000?ooo`00o`001`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00L0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?l000050?ooo`030000o`3o
ool0003o0080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo0000o`d0oooo00@0003o0?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0003o00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l01P3oool00`00o`00oooo0000o`090?ooo`03
0000o`3oool0003o00T0oooo00H0003o0?ooo`3oool00?l00?ooo`00o`020?ooo`030000o`3oool0
oooo00H0oooo00<00?l00?ooo`3oool02@3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0
oooo003o000A0?ooo`030000o`3oool0003o00L0oooo00<00?l00?ooo`3oool02P3oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`000?l00`3oool00`000?l0
oooo0?ooo`0:0?ooo`05003o003oool0oooo0?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0
oooo0000o`X0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`060?l0003o
ool0oooo003o003oool0003o1P3oool00`3o00000?l00?ooo`090?ooo`040?l0003oool0oooo0000
o`D0oooo00<00?l00?ooo`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo
00L0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`80o`00103oool00`000?l0oooo0?ooo`03
0?ooo`040000o`3oool0oooo0?l000L0oooo00D0003o0?ooo`3oool0oooo003o00080?ooo`040000
o`3oool0oooo0000o`80oooo00<00?l00?ooo`3oool0103oool00`3o0000003o003o00020?ooo`06
003o003oool0oooo0000o`3oool0o`00103oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00H0003o0?ooo`3oool00?l00?ooo`00
0?l30?ooo`80o`00103oool010000?l0oooo0000o`3o00050?ooo`05003o003oool0oooo0?ooo`3o
00000P3oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool020000?l0oooo0?ooo`3o00000?l00?ooo`00o`00o`00103oool00`000?l0oooo0000
o`020?ooo`070?l00000o`00oooo0?ooo`00o`00oooo0?l000020?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool0103o0000oooo0?ooo`00o`060?ooo`050000o`3oool0oooo0?ooo`00o`001`3o
ool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?l0003oool0o`00003o00020?ooo`04
0000o`3oool0oooo0000o`D0oooo00D0o`000?ooo`3oool0o`00003o00020?ooo`050000o`3oool0
003o0?ooo`3o00001`3oool00`00o`00oooo0000o`050?ooo`030000o`3oool0oooo00D0oooo00<0
0?l00?ooo`000?l00P3oool010000?l0oooo0?ooo`3o00030?ooo`03003o003o0000oooo0080oooo
00L0003o0?ooo`3oool0003o0?ooo`00o`00o`0000H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`04003o003oool0oooo0?l001h0oooo00D00?l00?ooo`3oool0oooo003o
00040?ooo`05003o003oool0oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`030?ooo`03003o
00000?l0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000o`050?ooo`030?l0
003oool0o`0000T0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`03
0000o`00o`00o`0000/0oooo00<0o`00003o003oool06P3oool01@000?l0oooo0?ooo`3oool00?l0
00<0oooo00<0003o0?ooo`3oool00`3oool20?l000030?ooo`00o`00oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`00
0?ooo`3o00001@3oool00`000?l0oooo0000o`020?ooo`030?l00000o`00oooo00@0oooo00<00?l0
0?l0003oool01@3oool00`00o`00oooo0000o`0>0?ooo`030000o`3oool00?l000P0oooo00<00?l0
0?ooo`3oool00P3oool00`000?l0oooo0000o`030?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo00D0oooo00<00?l0
0?ooo`000?l0203oool010000?l0oooo0?ooo`000?l90?ooo`060000o`3oool0oooo003o003oool0
0?l00P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00T0oooo00T0o`000?ooo`3o
ool0oooo0000o`3oool0003o0?ooo`00o`004@3oool00`000?l0oooo0000o`060?ooo`03003o003o
ool0oooo00/0oooo00<0o`00003o003oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o0000
0?l0oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?l000070?ooo`030?l0003o
ool0003o00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0003o00/0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`070?l0003o
ool00?l00?ooo`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3o
ool0003o1@3oool00`00o`00oooo0000o`050?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000L0oooo00D0003o0?l000000?l0oooo003o
00090?ooo`040000o`3oool0oooo0000o`80oooo00<0o`00003o003oool0103oool00`3o0000003o
003o00020?ooo`05003o003oool0oooo0000o`3o00001@3oool00`000?l0oooo0?ooo`0H0?ooo`03
0000003oool0oooo01X0oooo000i0?ooo`D000006P3oool00`00o`00oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool01P000?l0oooo0?ooo`3oool00?l00000
o`<0oooo0P3o00040?ooo`040000o`3oool0003o0?l000D0oooo00D00?l00?ooo`3oool0oooo0?l0
00020?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`080000o`3oool0oooo0?l0003oool00?l00?ooo`3o00040?ooo`030000o`3oool0003o
0080oooo00L0o`00003o003oool0oooo003o003oool0o`000080oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`040?l0003oool0oooo003o00H0oooo00D0003o0?ooo`3oool0oooo003o00070?oo
o`030000o`3oool0oooo00@0oooo00<0003o003o003o00000P3oool01@3o00000?l00?ooo`3oool0
003o0080oooo00<0003o0?ooo`3oool00`3oool01`3o0000oooo0?ooo`3o00000?l00?ooo`000?l0
0P3oool00`000?l0oooo0?l000060?ooo`04003o003o0000oooo0000o`D0oooo00<0003o0?ooo`3o
ool01@3oool00`00o`00003o0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<00?l00?l0
003oool00P3oool01`000?l0oooo0?ooo`000?l0oooo003o003o00001P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00@00?l00?ooo`3oool0o`007P3oool01@00o`00oooo
0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o
00D0oooo00<0o`000?ooo`3o00002@3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo
0000o`@0oooo00<0003o003o003o00002`3oool00`3o00000?l00?ooo`0I0?ooo`030000o`3oool0
oooo00<0oooo00@00?l00?ooo`3oool0003o1@3oool20?l000030?ooo`00o`00oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0
0`3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0003o0080oooo00<0o`00003o003o
ool00`3oool00`00o`00oooo0?l000070?ooo`03003o00000?l0oooo00d0oooo00<0003o003o003o
ool0203oool01@00o`00oooo0?ooo`3oool0003o0080oooo00D0003o0?ooo`3oool0oooo003o0006
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?l0003oool01`3oool00`3o0000003o0?ooo`04
0?ooo`04003o003oool0oooo0000o`P0oooo00@0003o0?ooo`3oool0003o2@3oool01P000?l0oooo
0?ooo`00o`00oooo003o0080oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`090?oo
o`040?l0003oool0oooo0000o`<0oooo00<0003o003o003oool03`3oool01@000?l0oooo0?ooo`3o
ool0003o00D0oooo00<00?l00?ooo`3oool02`3oool00`3o00000?l00?ooo`040?ooo`030?l0003o
ool0oooo0080oooo00<00?l00000o`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003o
ool0o`0000L0oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000000o`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0140oooo00L0o`000?ooo`00o`00oooo0000o`3oool0003o00@0oooo00<0o`000?ooo`3o
ool02P3oool0103o0000oooo0?ooo`000?l50?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00L0003o0?oo
o`3oool0oooo0?l0003oool0o`000080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l0
00070?ooo`050000o`3o0000003o0?ooo`00o`002@3oool010000?l0oooo0?ooo`000?l20?ooo`03
0?l00000o`00oooo00@0oooo00<0o`000000o`3oool00`3oool01000o`00oooo0000o`3o00050?oo
o`030000o`3oool0oooo01@0oooo1@00000L0?ooo`00>@3oool00`000000oooo0?ooo`0K0?ooo`03
0000o`00o`00oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo00D00?l00000o`3oool0oooo0?l000020?ooo`040?l0003oool0oooo
0000o`<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`060?l0003oool0
oooo0000o`3oool0003o103oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo
0?l0003oool00?l00080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o0080oooo00L0o`00
0?ooo`00o`00oooo003o003oool0o`000080oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`04
0?l0003oool0oooo003o00H0oooo00D0003o0?ooo`3oool0oooo003o00070?ooo`030000o`3oool0
oooo00@0oooo00<0003o003o003o00000`3oool01000o`00oooo0?ooo`000?l30?ooo`030000o`3o
ool0oooo0080oooo00L0o`000?ooo`3oool0o`000?ooo`00o`00003o0080oooo00<0003o0?ooo`3o
00001P3oool01000o`00o`000?ooo`000?l50?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?l000020?ooo`04003o003oool0oooo0?l00080oooo00L0003o
0?ooo`3oool0003o0?ooo`3o00000?l000H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`04003o003oool0oooo0?l001h0oooo00@00?l00?ooo`3oool00?l01P3oool00`00
o`00oooo0?l000090?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3o00001@3oool01@00
0?l0oooo0?ooo`3oool0o`0000D0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo003o
000;0?ooo`030?l00000o`00oooo01T0oooo00<0003o0?ooo`3oool0103oool01000o`00oooo0?oo
o`000?l40?ooo`040?l0003oool0o`00003o00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`3o0003
0?ooo`040000o`3oool0oooo0000o`80oooo00<0o`00003o003oool00`3oool00`00o`00oooo0?l0
00070?ooo`030000o`3oool0oooo00d0oooo00<0003o003o003oool0203oool01@00o`00oooo0?oo
o`3oool0003o0080oooo00D0003o0?ooo`3oool0oooo003o00070?ooo`03003o003oool0oooo00@0
oooo0P00o`000`3o00000?l00?ooo`070?ooo`030?l000000?l0oooo00@0oooo00D00?l00?ooo`3o
ool0oooo0000o`070?ooo`040000o`3oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool02P3oool0
0`3o0000003o003o00040?ooo`030000o`3oool0oooo00P0oooo0P3o00040?ooo`050000o`3oool0
oooo0?ooo`000?l0103oool00`00o`00o`000?ooo`0<0?ooo`030?l0003oool00?l000D0oooo00H0
o`000?ooo`3oool00?l00?ooo`000?l40?ooo`030000o`3oool0oooo00`0oooo00<00?l00?l0003o
ool01P3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0303oool00`3o0000003o0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool04P3oool01P00o`00oooo0?ooo`000?l0oooo0000o`@0oooo00<0o`000?ooo`3oool02P3oool0
103o0000oooo0?ooo`000?l50?ooo`03003o003oool0o`0000@0oooo00<00?l00?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0o`000080oooo00<0003o0?ooo`3oool0103oool00`000?l00?l00?l000070?ooo`05
0000o`3o0000003o0?ooo`00o`002@3oool010000?l0oooo0?ooo`000?l20?ooo`030?l00000o`00
oooo00@0oooo00<0o`000000o`3oool00`3oool01000o`00oooo0000o`3o00050?ooo`030000o`3o
ool0oooo01P0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool06`3oool0
0`000?l00?l00?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00H0o`000?ooo`3oool0003o
0?ooo`000?l40?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?l000040?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`020?ooo`070?l0003oool0
0?l00?ooo`00o`00oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0103o0000
oooo0?ooo`00o`060?ooo`80003o0P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0003o003o003o00000`3oool01000o`00oooo0?ooo`000?l30?ooo`030000o`3oool0
oooo0080oooo00L0o`000?ooo`3oool0o`000?ooo`00o`00003o00<0oooo00<0003o0?l0003oool0
1@3oool01000o`00o`000?ooo`000?l60?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0o`000?ooo`020?ooo`04003o003oool0oooo0?l00080oooo00L0003o0?oo
o`3oool0003o0?ooo`3o00000?l000H0oooo00<0003o0?l0003oool01@3oool00`000?l0oooo0?oo
o`030?ooo`04003o003oool0oooo0?l001l0oooo0P00o`070?ooo`03003o003oool0o`0000T0oooo
00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3o
ool0oooo0000o`040?ooo`030?l0003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0?l00005
0?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`00o`002`3oool00`3o00000?l00?oo
o`0H0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`000?l00`3oool01@3o0000oooo0?oo
o`3o00000?l000H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool01@000?l0oooo0?ooo`3o00000?l000@0oooo00<00?l00?ooo`3o00001`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00@00?l00?ooo`3oool0003o0`3o
ool010000?l0oooo0?ooo`00o`080?ooo`04003o003oool0oooo0?ooo`800?l00P3o00020?ooo`03
003o003oool0oooo00D0oooo00<0o`000000o`3oool0103oool01@00o`00oooo0?ooo`3oool0003o
00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030?l00000o`00oooo
00X0oooo00<0003o0?ooo`00o`00103oool00`000?l00?l00?ooo`060?ooo`80o`0000<0oooo0?l0
003oool00`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<00?l00?l0003oool02`3oool0
103o0000oooo0?ooo`3oool2003o00@0oooo00D0o`000?ooo`00o`00oooo0000o`050?ooo`030000
o`3oool0oooo00/0oooo00<00?l00?l0003oool01P3oool00`3o0000oooo0000o`050?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`3o0000003o0?ooo`0;0?ooo`050000
o`3oool0oooo0?ooo`3o00005@3oool01P00o`00oooo0?ooo`000?l0oooo0000o`@0oooo00<0o`00
0?ooo`3oool02P3oool0103o0000oooo0?ooo`000?l50?ooo`03003o003oool0o`0000@0oooo00<0
0?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00L0
003o0?ooo`3oool0oooo0?l0003oool0o`000080oooo00<0003o0?ooo`3oool0103oool00`000?l0
0?l00?l000070?ooo`050000o`3oool0003o0?ooo`00o`002@3oool010000?l0oooo0?ooo`000?l2
0?ooo`030?l0003oool00?l000@0oooo00<00?l00000o`3oool00`3oool01000o`00oooo0?ooo`00
0?l50?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0703oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`04003o00000?l0oooo0?l000@0oooo00<0
o`000000o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00H0
o`000?ooo`3oool0003o0?ooo`000?l40?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo0000o`80oooo00X0003o0?oo
o`3oool0o`000?ooo`00o`00oooo003o003oool0o`000P3oool01@000?l0oooo0?ooo`3oool0003o
0080oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`80003o0P3oool00`00o`00oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`00o`000`3oool01000o`00oooo0?ooo`00
0?l30?ooo`030000o`3oool0oooo0080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00<0
oooo00<0003o0?ooo`3oool0103oool01@00o`00oooo0?l0003oool0003o00H0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo003o00030?ooo`050000o`3o0000oooo0?ooo`00o`000`3oool0
103o0000oooo0?ooo`000?l30?ooo`030000o`3o00000?l000H0oooo00<0003o0?l0003oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o00007`3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0o`0000X0oooo00@0o`000?ooo`000?l00?l01P3oool00`000?l0
oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`3o0004
0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0000o`050?ooo`030000o`3o
ool00?l000/0oooo00<0o`00003o003oool0603oool00`000?l0oooo0?ooo`070?ooo`03003o003o
ool0003o0080oooo00D0o`000?ooo`3oool0o`00003o00060?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050000o`3oool0oooo0?l00000o`00103oool0
0`00o`00oooo0?l000060?ooo`030000o`00o`00oooo00h0oooo00<0003o0?ooo`3oool02@3oool0
1@00o`00oooo0?ooo`000?l0oooo0080o`0000@0003o0?l0003o00000?l00`3o00050?ooo`06003o
003oool00?l0003o003oool0o`001@3oool00`00o`00oooo0?ooo`040?ooo`030?l000000?l0oooo
00@0oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo003o000;0?ooo`030000o`3oool00?l000D0oooo00<0003o
0?ooo`3oool00P3oool30?l000<0oooo00D00?l00?l0003oool0oooo0000o`050?ooo`070000o`3o
ool0oooo003o003o0000oooo0?l0000;0?ooo`030?l0003oool0oooo00<0oooo00P00?l00?ooo`3o
ool0oooo0?l00000o`00oooo0000o`H0oooo00<0003o0?ooo`3oool02`3oool00`3o00000?l00?oo
o`060?ooo`030?l0003oool0003o00D0oooo00H0003o0?ooo`3oool0oooo003o003o000>0?ooo`03
0?l000000?l0oooo00/0oooo00D0003o0?ooo`3oool0oooo0?l0000D0?ooo`05003o003o0000oooo
0?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000`0oooo00@0o`000?ooo`3oool0003o
1@3oool00`00o`00oooo0?l000040?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000020?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool01@3oool01P000?l0oooo0?ooo`3o0000
003o003o00P0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?l0003oool00?l000@0oooo
00<00?l00000o`3oool00`3oool01000o`00oooo0?ooo`000?l50?ooo`030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool06`3oool00`00o`00003o
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool00?l000D0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l40?ooo`030?l0003oool0
o`0000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0
oooo0000o`80oooo00X0003o0?ooo`3oool0o`000?ooo`00o`00oooo003o003oool0o`000P3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo003o00040?ooo`050000
o`3oool0003o0?l00000o`001`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool00?l00080
oooo00@00?l00?l0003oool0003o103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`00
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`040?ooo`05003o003oool0o`000?ooo`000?l01P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool00?l000<0oooo00@0003o0?l0003oool00?l0
103oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o00000?l000H0oooo00<0003o0?l0003o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool0503oool20000o`l0oooo00<00?l00?ooo`3o00002P3oool0103o0000oooo0000o`00o`060?oo
o`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0
oooo0?ooo`3o00000`3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000
o`050?ooo`030000o`3oool00?l000/0oooo00<00?l00?ooo`3oool05`3oool00`000?l0oooo0?oo
o`090?ooo`05003o00000?l0oooo0?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`040000
o`3oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050000o`3oool0oooo
0?l00000o`000`3oool01000o`00oooo0?ooo`3o00060?ooo`030000o`00o`00oooo00d0oooo00<0
0?l00?ooo`000?l02P3oool01@00o`00oooo0000o`3oool0o`000080oooo00<0003o0?ooo`00o`00
103oool20?l000@0oooo00@00?l00?ooo`3oool0o`001`3oool00`00o`00oooo0?ooo`030?ooo`03
0?l000000?l0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`00o`002P3oool010000?l0o`000?ooo`00o`050?ooo`03003o00000?l0
oooo0080o`001@3oool00`00o`00oooo003o00020?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`00o`00o`000P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00L0
0?l00?ooo`3oool0o`00003o003oool0003o00H0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
0?l00?ooo`060?ooo`030?l0003oool0003o00H0oooo00@0003o003o0000o`000?l03`3oool00`3o
0000003o0?ooo`0;0?ooo`050000o`3oool0oooo0?l0003oool01000o`0@0?ooo`04003o003o0000
oooo0000o`<0oooo00D0003o0?ooo`3oool0oooo0?l0000<0?ooo`040?l0003oool0oooo0000o`D0
oooo00<00?l00?ooo`3o0000103oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00020?ooo`040?l0003oool0oooo
0000o`L0oooo00<0003o0?l0003oool01@3oool01P000?l0oooo0?ooo`3o0000003o003o00P0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?l0003oool00?l000<0oooo00<00?l00?l00000
0?l01@3oool00`00o`00oooo0000o`050?ooo`030000o`3o0000oooo01P0oooo00<000000?ooo`3o
ool06P3oool003T0oooo00<000000?ooo`3oool06`3oool00`00o`00oooo0000o`070?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0o`0000@0oooo00<0003o0?l0003oool00P3oool01@000?l0oooo0?ooo`3oool00?l000D0
oooo00H0o`000?ooo`3oool0003o0?ooo`000?l40?ooo`030?l0003oool0o`0000<0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo0000o`80oooo00@0
003o0?ooo`3oool0o`000P3oool01000o`00oooo0?ooo`3o00020?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool01@3o0000oooo0?ooo`3oool00?l000@0oooo00D0003o0?ooo`000?l0oooo003o
00070?ooo`030000o`3oool0oooo00H0oooo00P0003o003o003oool0oooo003o003o0000oooo0000
o`@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0003o00<0oooo00<0003o
0?ooo`3oool0103oool01@00o`00oooo0?l0003oool0003o00H0oooo00<0003o0?ooo`3oool0103o
ool010000?l0oooo0?ooo`00o`020?ooo`030000o`00o`000?l000D0oooo00<0o`000?ooo`000?l0
103oool010000?l0o`000?ooo`00o`050?ooo`030000o`3o0000oooo00@0oooo00<0o`000000o`3o
ool00`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo01@0oooo00@0003o0?ooo`00
0?l0003o3P3oool00`00o`00oooo0?ooo`090?ooo`80003o00<0oooo003o003oool01@3oool00`00
0?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o
ool0o`0000<0oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l01@3o
ool010000?l0o`000?ooo`00o`0:0?ooo`03003o003o0000oooo01L0oooo00<0003o0?ooo`3oool0
2@3oool01000o`00oooo0000o`3o00030?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3o
ool0o`000`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0003o0?ooo`3o0000oooo003o
00020?ooo`04003o003oool0oooo0?l000D0oooo00@0003o0?ooo`3oool00?l0303oool01000o`00
oooo0?ooo`000?l:0?ooo`04003o003oool0003o0?l000<0oooo00<0003o0?ooo`00o`001P3oool3
0?l00080oooo0P3o00090?ooo`03003o003oool0oooo0080oooo00<0o`000000o`3oool00`3oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo003o00090?ooo`050000o`3oool0o`000?ooo`00o`001P3oool00`00o`00003o0?l0
00050?ooo`07003o003oool0oooo0?ooo`00o`00oooo0000o`050?ooo`040000o`00o`00oooo0?l0
0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`<00?l000<0o`000?oo
o`000?l01P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool00?l000L0oooo00<0003o0?oo
o`3oool0103oool01P00o`00003o0?ooo`3oool0o`00003o00h0oooo00<0o`000000o`3oool02`3o
ool00`000?l00?l0003o0002003o00<0oooo00<00?l00?ooo`3oool03@3oool01@00o`00oooo0?l0
003oool0003o00<0oooo00@0003o0?ooo`3oool0o`003@3oool0103o0000oooo0?ooo`000?l50?oo
o`03003o003oool0o`0000<0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`00
0?l70?ooo`030000o`3o0000oooo00D0oooo00H0003o0?ooo`3oool0o`000000o`00o`080?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3o00000P3oool01P00o`00oooo0?ooo`00o`00o`00
0000o`D0oooo00<00?l00?ooo`000?l01@3oool00`000?l0o`000?ooo`0H0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`000?l01`3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0o`000?ooo`020?ooo`070000o`3oool0oooo0?l0003oool0o`000000o`020?ooo`03003o003o
ool0oooo00@0oooo00@0o`000?ooo`3oool0003o0P3oool01`000?l0oooo0?ooo`3oool0o`000?oo
o`3o00000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00@0o`000?oo
o`3oool0003o0P3oool00`000?l0oooo0?l000030?ooo`04003o003oool0oooo0?l00080oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0
oooo0000o`020?ooo`030000o`00o`00o`0000H0oooo00<0003o0?ooo`3oool01P3oool020000?l0
0?l00?ooo`3oool00?l00?l0003oool0003o103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00@0o`000?ooo`000?l00?l00P3oool00`000?l0oooo0?ooo`030?ooo`06003o003oool0oooo0?l0
003oool0003o1P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo003o0080oooo00<0
003o0?l0003oool01@3oool00`3o0000oooo0000o`040?ooo`040000o`3o0000oooo003o00D0oooo
00<0003o0?l0003oool0103oool00`3o0000003o0?ooo`030?ooo`03003o003oool0oooo0080oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`020?ooo`<0003o2`3oool00`00o`00oooo
0?ooo`070?ooo`80003o00<0oooo0?l00000o`00203oool00`000?l0oooo0?ooo`070?ooo`050000
o`3oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0003o00H0oooo00<0003o0?oo
o`00o`002P3oool00`00o`00o`000?ooo`030?ooo`@0003o3`3oool00`000?l0oooo0?ooo`0;0?oo
o`03003o00000?l0o`0000<0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o0003
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@000?l0oooo0?l0003oool00?l00080oooo
00@00?l00?ooo`3oool0o`001@3oool010000?l0oooo0?ooo`00o`0<0?ooo`04003o003oool0oooo
0000o`/0oooo00<00?l00000o`3oool00`3oool00`000?l0oooo003o00090?ooo`80o`00303oool0
1@00o`00oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`00o`00203oool01@000?l0oooo0?oo
o`3o00000?l000L0oooo00<00?l00000o`3o0000103oool00`00o`00oooo0?ooo`020?ooo`030?l0
00000?l0oooo00D0oooo00<0003o003o003o00000`3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00@00?l00?l0003oool0003o1`3oool00`000?l0oooo0?ooo`090?ooo`05
0?l0003oool0oooo0?ooo`00o`001P3oool00`000?l0oooo0?ooo`020?ooo`800?l000H0oooo0000
o`3oool0oooo0?l00000o`0?0?ooo`030000o`3oool0oooo00T0oooo00D00?l00?ooo`000?l0oooo
0?l000050?ooo`03003o003oool0oooo00`0oooo00D00?l00?ooo`3o0000oooo0000o`030?ooo`04
0000o`3oool0oooo0?l000d0oooo00@0o`000?ooo`3oool0003o1@3oool01000o`00oooo0?l0003o
00020?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103oool00`000?l0oooo
0?ooo`030?ooo`040000o`3oool0oooo0?l00080oooo00@0o`000?ooo`3oool0003o1`3oool00`00
0?l00?l00?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o003o003oool01`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0o`000080oooo00H00?l00?ooo`00o`00oooo0?l00000
0?l50?ooo`03003o003oool0003o00D0oooo00<0003o0?l0003oool0603oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20?l000040000o`3oool0oooo003o00H0oooo
00@0o`000?ooo`3oool0003o0P3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00000P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000@0oooo00@0o`000?ooo`3oool0003o0`3o
ool00`000?l0o`000?ooo`020?ooo`06003o003oool0oooo0?l0003oool0003o103oool010000?l0
oooo0?ooo`3o00040?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`000?l00?l00?l00006
0?ooo`030000o`3oool0oooo00H0oooo00P0003o0?l00000o`00oooo003o003o0000oooo0000o`D0
oooo00@0003o0?ooo`3oool0o`00103oool0103o0000003o0?ooo`00o`020?ooo`030000o`3oool0
oooo0080oooo0P00o`030?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`800?l000<0003o0?l0003oool01@3oool00`3o0000oooo0000o`04
0?ooo`040000o`3o0000oooo003o00D0oooo00<0003o0?l0003oool0103oool00`3o0000003o0?oo
o`030?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`050?ooo`80003o2@3oool00`00o`00oooo0?ooo`040?ooo`<0003o0`3oool00`3o00000?l00?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?oo
o`3o00030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030?l0003oool0oooo
00@0oooo00<0o`000000o`3oool01@3oool00`000?l0oooo003o000:0?ooo`03003o003o0000oooo
0080oooo00<0003o0?ooo`3oool00P3oool50000o`X0oooo00<0003o0?ooo`3oool0303oool00`00
o`00003o0?ooo`020?ooo`03003o003o0000oooo00@0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00000`3oool0103o
0000oooo0?ooo`000?l40?ooo`050000o`3oool0o`000?ooo`00o`000P3oool01000o`00oooo0?oo
o`3o00040?ooo`050000o`3oool0oooo0?ooo`00o`002`3oool01@00o`00oooo0?ooo`3oool0003o
00X0oooo00<0o`000000o`3oool01@3oool00`000?l00?l00?ooo`0G0?ooo`04003o003oool0oooo
0000o`D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00@0oooo00@0o`000?ooo`3oool00?l01`3oool01@000?l0oooo0?ooo`3o00000?l000L0oooo
00<00?l00?l000000?l00`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<00?l00000o`3o00000`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0o`000000o`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`00
o`001P3oool00`000?l0oooo0?ooo`02003o00@0oooo00@0003o0?ooo`3o00000?l03@3oool00`00
o`00003o0?l0000;0?ooo`04003o003oool0003o0?l000H0oooo00<00?l00?ooo`3oool02`3oool0
1P00o`00oooo0?ooo`3o0000oooo0000o`<0oooo00@0003o0?ooo`3oool0o`003@3oool0103o0000
oooo0?ooo`000?l60?ooo`03003o003o0000o`000080oooo00<00?l00?ooo`3oool01@3oool01000
0?l0oooo0?ooo`3o00040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00000P3oool0
103o0000oooo0?ooo`000?l70?ooo`030000o`00o`00oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`00o`00003o0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003oool00P3o
ool01P00o`00oooo003o003oool0o`000000o`H0oooo00<00?l00000o`3oool0103oool00`000?l0
o`000?ooo`0H0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01P3oool00`000?l00?l00?ooo`020?ooo`040000o`3oool0oooo0?ooo`80
o`0000@0003o0?ooo`3oool00?l01`3oool00`3o0000oooo0000o`020?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o0000103o
ool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`000?l0
103oool010000?l0oooo0?ooo`3o00040?ooo`05003o003oool0oooo0?ooo`000?l00P3oool01000
0?l00?l00?ooo`3o00050?ooo`030000o`3oool0oooo00H0oooo00L0003o0?l00000o`00oooo003o
003o0000003o00H0oooo00@0003o0?ooo`3oool0o`001@3oool00`000?l0oooo003o00020?ooo`03
0000o`3oool0oooo00800?l01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0000o`070?ooo`030?l0003oool0003o00@0
oooo00@0003o0?l0003oool00?l01@3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0003o
0080oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00L0oooo0P000?l60?ooo`030?l0003oool00?l000<0oooo0P000?l70?ooo`03003o003oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00@0003o
0?ooo`3oool0o`000`3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000070?oo
o`030?l000000?l0oooo00D0oooo00<0003o0?ooo`00o`002P3oool00`00o`00o`000?ooo`020?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l000000?l0oooo0080oooo00<00?l00?l0003oool0103oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000030?oo
o`040?l0003oool0oooo0000o`@0oooo00L0003o0?ooo`3o0000oooo003o003oool00?l000@0oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`060?ooo`80o`0000<0oooo0000o`3oool01@3oool00`000?l0
oooo0?ooo`0H0?ooo`04003o003oool0003o0?l000@0oooo00<00?l00?ooo`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`030000o`3o
ool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`020?ooo`03003o003o
ool0oooo00@0oooo00<0003o003o003oool00`3oool00`00o`00oooo0000o`050?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o0?ooo`070?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030000o`00
o`000?l000H0oooo00D0003o0?l0003oool0oooo003o000<0?ooo`03003o00000?l0o`0000X0oooo
00D00?l00?ooo`3oool0003o0?l000070?ooo`03003o003oool0oooo00X0oooo00H00?l00?ooo`3o
ool0o`000?ooo`000?l40?ooo`030000o`3oool0o`0000d0oooo00@0o`000?ooo`3oool0003o1P3o
ool01@00o`00oooo0?l0003oool00?l000P0oooo00@0003o0?ooo`3oool0o`00103oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o203oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<00?l00000o`3oool01P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3o0000oooo00<0oooo00D00?l00?ooo`3oool0o`000000o`06
0?ooo`03003o00000?l0oooo00<0oooo00<0003o0?ooo`3o00006@3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00D0o`000000
o`3oool0oooo0000o`050?ooo`040?l000000?l0oooo003o00P0oooo00<0o`000000o`3oool00P3o
ool010000?l0oooo0?ooo`3o00020?ooo`040?l0003oool0oooo0000o`H0oooo00<0003o0?l0003o
ool0103oool00`3o0000oooo0000o`040?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`00
0?l01@3oool00`000?l0oooo0?l000050?ooo`04003o003oool0oooo0000o`80oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00H0oooo00L0003o0?l00000o`00oooo003o
003o0000003o00H0oooo00@0003o0?ooo`3oool0o`001@3oool01P000?l0oooo0?ooo`00o`00oooo
0000o`800?l01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0003o00@0oooo00D0003o
0?l0003oool0oooo003o00040?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`000?l00P3o
ool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`030?ooo`040?l0003oool00?l00?ooo`80003o2@3oool00`00o`00oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`04
0000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?l000070?oo
o`030?l000000?l0oooo00D0oooo00@0003o0?ooo`3oool00?l02@3oool01@00o`00o`000?ooo`3o
ool0003o00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0003o0080oooo00<00?l00?l0003oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000040?ooo`030?l0003o
ool0003o00@0oooo00L0003o0?l0003oool0oooo003o003oool00?l000@0oooo00@0o`000?ooo`3o
ool0003o1@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool20?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0I0?oo
o`03003o00000?l0o`0000@0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
003o00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`030000o`3oool0oooo0080oooo00<0
0?l00?ooo`3oool01P3oool01@00o`00oooo0000o`3oool00?l000L0oooo00<0003o0?ooo`00o`00
0P3oool01000o`00oooo0?ooo`000?l50?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01`3oool010000?l0oooo0?ooo`00o`0;0?ooo`04003o003oool0003o0?l000X0oooo00D00?l0
0?ooo`3oool0oooo0000o`070?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000d0oooo00@0o`000?ooo`3oool0003o
1P3oool01@00o`00oooo0?l0003oool00?l000P0oooo00<0003o0?ooo`3oool00P3o00020?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0000o`080?ooo`03
0?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00003o0?ooo`060?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?l0003oool00`3oool01@00o`00oooo0?ooo`3oool0003o
00H0oooo00<00?l00000o`3oool00`3oool00`000?l0oooo0?l0000I0?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool01@3o0000
003o003o003oool0003o00H0oooo00<0003o0?ooo`00o`00203oool00`3o0000003o0?ooo`020?oo
o`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`000?ooo`04
0?ooo`030?l0003oool0003o00@0oooo00<0003o0?l0003oool01P3oool00`3o0000003o0?ooo`04
0?ooo`030000o`3oool0o`0000D0oooo00@00?l00?ooo`3oool0003o0P3oool00`00o`00003o0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0203oool01`000?l0oooo003o0000o`00oooo0?l0
00000?l01P3oool010000?l0oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00800?l000<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l01`3o
ool00`3o0000003o0?ooo`060?ooo`030?l000000?l0oooo00<0oooo00D0003o0?l0003oool0oooo
003o00030?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`000?l00P3oool00`00o`00oooo
0?ooo`040?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0003o0000o`X0oooo00<00?l00?l0003oool0203oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o0004
0?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3o00001`3oool00`3o0000003o0?ooo`05
0?ooo`040000o`3oool0oooo003o00P0oooo00D00?l00?ooo`3o0000oooo0000o`0<0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03@3oool01`3o0000oooo0000o`3oool00?l00?oo
o`3o0000103oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?l000040?ooo`030?l0003oool0003o00@0oooo00L0003o0?l0
003oool0oooo003o003oool00?l000@0oooo00@0o`000?ooo`3oool0003o1@3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3o00000`3o00040?ooo`030000
o`3oool00?l000D0oooo00<0003o0?ooo`3oool06P3oool00`000?l00?l0003o00020?ooo`03003o
003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o203oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l0
00D0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`04003o003oool0oooo
0000o`L0oooo00/0003o0?ooo`3o0000oooo003o003oool00?l00?ooo`3o0000oooo0000o`040?oo
o`040?l0003oool0oooo0?ooo`80003o103oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`06003o003oool0
oooo0?ooo`000?l0o`00203oool01@3o0000003o0?ooo`3oool00?l000/0oooo00@00?l00?ooo`00
0?l00?l02@3oool01P00o`00oooo0?ooo`3oool0o`000000o`P0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool03@3o
ool0103o0000oooo0?ooo`000?l60?ooo`05003o003oool0o`000?ooo`00o`00203oool00`000?l0
oooo0?ooo`020?l00080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l000030?ooo`03
0?l000000?l0oooo00L0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
003o003o0000003o00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`070?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?l0000I0?ooo`03
0000003oool0oooo01X0oooo000i0?ooo`D000007@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`040?l000000?l00?l00000
o`P0oooo00<0003o003o003oool01`3oool00`3o0000003o0?ooo`020?ooo`040000o`3oool0oooo
0?l000<0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`040?ooo`030?l000000?l0
oooo00<0oooo00<0003o0?l0003oool01P3oool00`3o0000003o0?ooo`040?ooo`030000o`3o0000
oooo00D0oooo00@00?l00?ooo`3oool0003o0P3oool00`00o`00003o0?ooo`030?ooo`040?l0003o
ool0oooo0000o`P0oooo00L0o`000000o`3oool00?l00?ooo`3o0000003o00H0oooo00@0003o0?oo
o`3oool0o`001@3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l0203oool00`000?l0oooo
0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`3o0000003o0?ooo`060?ooo`03
0?l000000?l0oooo00<0oooo00D0003o0?l0003oool0oooo003o00030?ooo`030000o`3oool0o`00
00D0oooo00<0o`000?ooo`000?l00P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`80003o00D0oooo0?l0
00000?l0003o003o000;0?ooo`03003o003o0000oooo00P0oooo00P0003o0?ooo`3oool0o`000?oo
o`3o0000oooo0000o`H0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0000o`020?ooo`03
0000o`3oool0o`0000L0oooo00<0o`000000o`3oool01@3oool010000?l0oooo0?ooo`00o`080?oo
o`05003o003oool0o`000?ooo`000?l03@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00h0oooo00L0o`000?ooo`3oool0003o003o003oool0o`0000@0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o0000
103oool00`3o0000oooo0000o`040?ooo`030000o`3o0000oooo0080oooo0P00o`040?ooo`030?l0
003oool0003o00H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`030000
o`3o0000oooo00L0oooo00<0003o0?ooo`00o`001@3oool00`000?l0oooo0?ooo`0J0?ooo`030000
o`3o0000oooo00<00?l01P3oool010000?l0oooo0?ooo`000?l80?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`00o`001@3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00D0oooo00H0o`000?oo
o`00o`000?l00?ooo`000?l60?ooo`030000o`3oool0o`000080oooo00H00?l00?ooo`3oool0o`00
0?ooo`000?l40?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo00L00?l00?ooo`00o`000?l00000o`3oool0o`0000L0oooo00D0o`000000o`3oool0
oooo003o000:0?ooo`06003o003oool0oooo0000o`3o00000?l01`3oool00`00o`00oooo0?ooo`02
0?ooo`030?l0003oool0003o00L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool03@3oool0103o0000oooo0?ooo`00
0?l60?ooo`05003o003oool0o`000?ooo`00o`00203oool01@000?l0oooo0?l0003oool0o`000080
oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`030?ooo`030?l000000?l0oooo00L0
oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003o0000003o00H0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`060?ooo`030000o`3o0000oooo00D0
oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?l0000E0?ooo`D00000703oool003T0oooo
00<000000?ooo`3oool0803oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00D0003o0?ooo`3o
ool0oooo0000o`080?ooo`050?l0003oool0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`07
0?ooo`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0000
o`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3oool00`3oool00`000?l0o`000?oo
o`060?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003oool01P3oool00`00o`00oooo0000
o`020?ooo`03003o00000?l0oooo00<0oooo00<0o`000?ooo`000?l02@3oool0103o0000003o0?oo
o`00o`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001P3oool01`000?l0oooo
0?ooo`3oool0o`000?ooo`000?l0203oool00`000?l0oooo0?ooo`070?ooo`040000o`3o0000oooo
0000o`L0oooo00<0o`000000o`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0
oooo003o00<0oooo00<0003o0?ooo`3o00001@3oool01@3o0000oooo0000o`3oool00?l000L0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`080?ooo`<0o`00103oool20000o`<0oooo
00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?l000090?ooo`080000o`3oool0oooo0?l0003o
ool0o`000?ooo`000?l70?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`000?l00P3oool0
0`000?l0oooo0?l000070?ooo`030?l000000?l0oooo00D0oooo00@0003o0?ooo`3oool00?l0203o
ool01000o`00oooo0?l000000?l?0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
3@3oool02@3o0000oooo0?ooo`3oool0003o003o003oool0o`000?ooo`040000o``0oooo00<0003o
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0o`0000@0oooo00<0o`00
0?ooo`000?l0103oool00`000?l0o`000?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0o`00
0?ooo`000?l01P3oool00`00o`00o`000?ooo`040?ooo`800?l01`3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool00?l000@0oooo00<00?l00?ooo`000?l02P3oool00`000?l0oooo0?ooo`0>
0?ooo`030000o`3o0000oooo0080oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`00
0?l80?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`03003o003oool0oooo00D0
oooo00<0o`000?ooo`00o`000`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l0
00<0oooo00@0o`000?ooo`3oool0003o103oool0103o0000oooo0?ooo`000?l20?ooo`040000o`3o
ool0oooo0?l000`0oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00H00?l00?ooo`3oool0003o0?ooo`3o00060?ooo`040?l0003oool0oooo
0000o`80oooo00<00?l00?ooo`3oool01`3oool01P00o`00oooo0?ooo`000?l0o`00003o00L0oooo
00D00?l00?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003o
ool03P3oool00`3o0000oooo0000o`060?ooo`04003o003oool0o`00003o00T0oooo00D0003o0?oo
o`3o0000oooo0?l000020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool00`3oool0
0`3o0000003o0?ooo`070?ooo`030?l000000?l00?l000<0oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00o`000000o`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool01P3oool0
0`000?l0o`000?ooo`050?ooo`030?l00000o`00003o00<0oooo00<0003o0?ooo`3o00006@3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0P0?ooo`050000o`3oool0oooo
0?ooo`000?l0303oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00H0o`000?ooo`3oool0003o
0?ooo`00o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000000o`3oool00P3oool010000?l0
oooo0?ooo`3o00030?ooo`030?l0003oool0003o00L0oooo00<0003o0?ooo`3oool0103oool00`3o
0000003o0?ooo`030?ooo`030000o`3o0000oooo00H0oooo00<0o`000000o`3oool0103oool00`00
0?l0o`000?ooo`060?ooo`03003o00000?l0oooo0080oooo00<00?l00000o`3oool00`3oool00`3o
0000oooo0000o`090?ooo`030?l000000?l0oooo0080oooo00<0003o0?l0003oool01P3oool00`00
0?l0o`000?ooo`050?ooo`070000o`3o0000oooo0?ooo`3o0000oooo0000o`080?ooo`030000o`3o
ool0oooo00L0oooo00@0003o0?l0003o0000003o1`3oool00`3o0000003o0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo003o00020?ooo`040000o`3oool0oooo0?l0
00@0oooo00D0o`000?ooo`000?l0oooo003o00080?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?l000<0oooo00D0o`000?ooo`3oool0oooo003o
00090?ooo`03003o003oool0o`0000T0oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000oooo0000
o`L0oooo00<0003o0?l0003oool0103oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`00
00L0oooo00<0o`000000o`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00@00?l0
0?ooo`000?l0o`00403oool010000?l0oooo0?ooo`000?l@0?ooo`030?l0003oool0oooo0080oooo
10000?l@0?ooo`030000o`3oool0o`000080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?l000040?ooo`030?l000000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`03
0?l0003oool0003o00L0oooo00@00?l00?ooo`3oool0oooo0P00o`090?ooo`030000o`3oool0oooo
00H0oooo00@0003o0?ooo`3oool00?l0103oool00`00o`00oooo0000o`090?ooo`030000o`3oool0
003o00l0oooo00<0003o0?l0003oool02@3oool00`000?l0oooo0000o`0:0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00D0
0?l00?ooo`3oool0oooo0000o`050?ooo`03003o003o0000oooo00H0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0103o0000
oooo0?ooo`000?l50?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3o0000303oool00`00
0?l0o`000?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool02@3oool00`00
0?l0oooo0?l000060?ooo`040?l0003oool0oooo0000o`80oooo00<00?l00?ooo`3oool01P3oool0
2000o`00oooo0?ooo`3oool0003o0?ooo`3o00000?l01@3oool00`00o`00oooo0?ooo`020?ooo`04
0?l0003oool0oooo0000o`P0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000003o0?ooo`060?oo
o`04003o003oool0o`00003o00T0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?l0003oool00`3oool00`3o0000003o0?ooo`070?ooo`030?l0003o
ool0003o0080oooo00<0003o0?ooo`3oool0103oool00`00o`00o`000000o`050?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`050?ooo`030?l0003o
ool0003o00<0oooo00<0003o0?ooo`3o00006@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`0P0?ooo`050000o`3oool0oooo0?ooo`000?l0303oool01@000?l0oooo0?oo
o`3oool0003o00P0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`030?ooo`03
003o00000?l0oooo00P0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?l000030?ooo`03
0?l0003oool0003o00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?ooo`030?ooo`03
0000o`3o0000oooo00H0oooo00<0o`000000o`3oool0103oool00`000?l0o`000?ooo`070?ooo`04
0000o`3oool0oooo003o0080oooo00L0003o0?ooo`3oool0oooo0?l0003oool0003o00T0oooo00<0
o`000000o`3oool00P3oool00`000?l0o`000?ooo`060?ooo`030000o`3o0000oooo00D0oooo00L0
003o0?l0003oool0oooo0?l0003oool0003o00P0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
o`000000o`080?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool0103oool01@000?l0
oooo0?ooo`3oool00?l00080oooo00@0003o0?ooo`3oool0o`00103oool01@3o0000oooo0000o`3o
ool00?l000P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00<0oooo0`3o00040?ooo`03003o003oool0oooo00H0oooo00D00?l00?ooo`3oool0oooo
0?l000090?ooo`070000o`3oool0o`000?ooo`3o0000oooo0000o`070?ooo`030000o`3o0000oooo
00@0oooo00<0o`000000o`3oool00`3oool00`000?l0o`000?ooo`060?ooo`030?l000000?l0oooo
00D0oooo00D0003o0?ooo`3oool0oooo003o00070?ooo`04003o003oool0003o0?l00100oooo00@0
003o0?ooo`3oool0003o403oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3o00000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00@0oooo
00<0o`000000o`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`000?ooo`00
0?l01P3oool00`3o00000?l00?ooo`02003o00X0oooo00<0o`000?ooo`000?l01`3oool01@000?l0
oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`000?l02@3oool010000?l0oooo0?ooo`000?l>
0?ooo`030000o`3o0000oooo00X0oooo0P000?l:0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00@00?l00?ooo`3oool0003o
1P3oool00`00o`00o`000?ooo`060?ooo`030?l0003oool0oooo00@0oooo00D0003o0?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
003o0?ooo`030?ooo`030000o`3oool0o`0000/0oooo00<0003o0?ooo`3o00002@3oool00`000?l0
oooo0?ooo`050?ooo`040?l000000?l0oooo0000o`T0oooo00<0003o0?ooo`3o00001P3oool01`3o
0000oooo0?ooo`3oool0003o0?ooo`00o`00203oool02000o`00oooo0?ooo`3oool0003o0?ooo`3o
00000?l0103oool00`00o`00oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0203oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<0003o0?l0003oool01@3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l000000?l0oooo00H0oooo00@00?l00?ooo`3oool00?l02@3o
ool01@000?l0oooo0?l0003oool0o`000080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`030?l000000?l0oooo00L0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo
0?ooo`040?ooo`04003o003oool0o`000000o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`000?l00`3oool010000?l0
oooo0?ooo`3o000H0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01/0
oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l<0?ooo`040000o`3o0000oooo
0000o`T0oooo00<0o`000?ooo`3oool0103oool2003o00<0oooo00<00?l00000o`3oool0203oool0
0`3o0000003o0?ooo`030?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`000?l01`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool01P3oool0
0`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo00L0oooo00@0003o0?ooo`3oool00?l00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00P0oooo00<0o`000000o`3oool00P3o
ool00`000?l0o`000?ooo`060?ooo`030000o`3o0000oooo00@0oooo00<0003o0?ooo`3o00000P3o
ool00`3o0000oooo0000o`080?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`000?l0o`00
1P3oool00`3o0000oooo0000o`070?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`3oool0
0P3oool01000o`00oooo0?ooo`000?l20?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`00
0?l0oooo003o00090?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool01@00
o`00oooo0?ooo`3oool0o`0000T0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o00L0oooo
00<0003o0?l0003oool0103oool00`3o0000003o0?ooo`030?ooo`030000o`3o0000oooo00H0oooo
00<0o`000000o`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00@00?l00000o`3o
ool0o`004@3oool20000oa00oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0o`000080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`030?l000000?l0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000003o0?ooo`060?oo
o`030?l00000o`000?l000`0oooo00@0o`000?ooo`3oool0003o1P3oool01@000?l0oooo0?ooo`3o
ool00?l000<0oooo00<00?l00?ooo`000?l0203oool01@000?l0oooo0?ooo`3oool0003o00d0oooo
00<0003o0?ooo`3o00002`3oool20000o`X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool01000o`00oooo0?ooo`000?l60?oo
o`03003o003o0000oooo00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`000?l4
0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`04
0?ooo`030000o`3o0000oooo00X0oooo00<0003o0?ooo`3o00002P3oool00`000?l0oooo0?ooo`03
0?ooo`050?l0003oool0003o0?ooo`000?l0203oool010000?l0oooo0?ooo`3o00050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`00o`001`3oool01000o`00oooo0?ooo`000?l20?ooo`03
0?l0003oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00D00?l00?ooo`000?l0oooo003o00080?ooo`030000o`3o0000oooo
00@0oooo00<0o`000000o`3oool03P3oool00`3o0000003o0?ooo`060?ooo`04003o003oool0oooo
003o00T0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0000o`080?ooo`030000o`3oool0
oooo0080oooo00<0o`000000o`3oool01`3oool00`3o0000oooo0000o`020?ooo`030000o`3oool0
oooo00<0oooo00D00?l00?ooo`3oool0o`000000o`040?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0003o00<0oooo00@0
003o0?ooo`3oool0o`00603oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`0L0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o303oool010000?l0o`00
0?ooo`000?l90?ooo`030?l0003oool0oooo00H0oooo00D00?l00?ooo`3oool00?l00000o`090?oo
o`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0000o`070?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool01`3oool010000?l0oooo0?ooo`00o`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`3oool0203oool00`3o0000003o0?ooo`02
0?ooo`030000o`3o0000oooo00H0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?l00002
0?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0000o`3o
ool0o`0000D0oooo00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
00000?l0oooo00<0oooo00<00?l00?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0o`000080
oooo00<0003o003o003oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool01P000?l0o`000?ooo`3oool0o`000000o`P0oooo00<0003o
0?l0003oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0000o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`800?l0103oool01@00o`00003o0?ooo`3o
ool0o`000180oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00h0oooo00H0003o0?l0003oool0o`000?ooo`000?l80?ooo`030000o`3oool0oooo00<0
oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00D0
oooo00@0o`000?ooo`3oool0o`00303oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00D0003o
0?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000X0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3o
ool0oooo0?l000060?ooo`03003o00000?l0oooo00H0oooo00<00?l00?ooo`3o00001@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool02@3oool01@00
0?l0oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`02
0?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?oo
o`040?ooo`80003o1P3oool01@00o`00oooo0?ooo`3oool0003o0080oooo00H0o`000?ooo`3oool0
0?l00?ooo`00o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool20000
o`030?ooo`00o`00oooo00L0oooo00<0003o0?ooo`3o0000103oool00`3o0000003o0?ooo`0>0?oo
o`030?l000000?l0oooo00H0oooo00@00?l00?ooo`00o`00o`002@3oool00`000?l0oooo0?l00002
0?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`07
0?ooo`050?l0003oool0003o0?ooo`000?l01P3oool01@00o`00oooo0?ooo`3o0000003o00@0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00D0oooo
00<0o`000?ooo`000?l00`3oool010000?l0oooo0?ooo`3o000H0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool00`3oool20000o`d0oooo
00@0003o0?l0003o0000003o203oool00`3o0000oooo0?ooo`080?ooo`800?l000<0oooo0000o`3o
ool0203oool00`3o0000003o0?ooo`030?ooo`030000o`3o0000oooo00<0oooo00<0o`000000o`3o
ool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00L0oooo00@0003o003o003o
ool00?l00P3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00P0oooo00<0o`000?oo
o`000?l00P3oool00`000?l0o`000?ooo`060?ooo`030000o`3o0000oooo00@0oooo00P0003o0?oo
o`3oool0o`000?ooo`3o0000oooo0000o`P0oooo00<0003o0?ooo`3oool01`3oool01@3o0000003o
0000o`3oool0o`0000D0oooo00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`030?oo
o`030?l000000?l0oooo00<0oooo00<00?l00?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0
o`000080oooo00<0003o003o003oool02@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000
oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0
oooo00@0oooo0P00o`020?ooo`05003o00000?l0oooo0?ooo`3o00008`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00h0oooo00D0003o0?l0003oool0o`000000o`090?ooo`030000
o`3oool0oooo00<0oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00303oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0
oooo0?l000X0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00T0oooo00@0003o0?ooo`3oool0o`001`3oool00`00o`00003o0?ooo`060?ooo`03003o
003oool0o`0000D0oooo00<0o`000?ooo`3oool01`3oool20000o`H0oooo00<0o`000?ooo`3oool0
103oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?l0003oool02@3oool01@000?l0
oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0000o`030?oo
o`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0
oooo00H0oooo00<00?l00000o`3oool0103oool01@00o`00oooo0?ooo`3oool0003o0080oooo00H0
o`000?ooo`3oool00?l00?ooo`00o`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0000o`090?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`00
0?l03P3oool00`3o0000003o0?ooo`060?ooo`040?l00000o`000?l00?l000X0oooo00H0003o0?l0
003oool0oooo0?l000000?l90?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`3oool01`3o
ool01@3o0000oooo0000o`00o`00003o00H0oooo00H00?l00?ooo`3oool0o`000?ooo`000?l30?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`050?oo
o`040?l0003oool0003o003o0080oooo00@0003o0?ooo`3oool0o`00603oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0080oooo0P000?l=
0?ooo`040000o`3o0000o`000000o`P0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0000
o`090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool00`3oool00`3o0000003o0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool01`3oool010000?l00?l00?oo
o`00o`030?ooo`060000o`3oool0oooo0?ooo`3o0000003o2@3oool01`3o0000oooo0000o`3oool0
003o0?ooo`3o00001`3oool00`000?l0o`000?ooo`040?ooo`080000o`3oool0oooo0?l0003oool0
o`000?ooo`000?l80?ooo`030000o`3oool0oooo00L0oooo00<0o`000000o`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3o0000103oool0
0`3o0000003o0?ooo`040?ooo`05003o00000?l0oooo0?ooo`3o00000`3oool0103o0000oooo0?oo
o`000?l<0?ooo`040?l0003oool0oooo0?ooo`80003o2@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03
0?l0003oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030?l000000?l0oooo
00@0oooo00<0003o0?l0003oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000000o`3oool01P3oool2003o00050000o`3oool0oooo0?ooo`3o00008P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00h0oooo00D0003o0?l0003oool0o`000000
o`090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`03003o003oool00?l000<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00P0
oooo00@0003o0?ooo`3oool0o`005`3oool010000?l0oooo0?ooo`000?l=0?ooo`030000o`3oool0
o`0000L0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?l000050?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02`3oool01P000?l0oooo0?ooo`000?l0oooo0?l000D0oooo
00<0o`000000o`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00L0oooo00<00?l00000o`3o
ool00P3oool00`00o`00oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<00?l00?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00@0003o0?oo
o`00o`00003o2@3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0003o00h0oooo00<0o`00
0000o`3oool01P3oool0103o00000?l0003o003o000:0?ooo`060000o`3o0000oooo0?ooo`3o0000
003o203oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`00
0?l00?l00000o`060?ooo`06003o003oool0oooo0?l0003oool0003o0`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool01@3oool0103o0000oooo0000
o`00o`020?ooo`040000o`3oool0oooo0?l001P0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo
00@0003o0?ooo`000?l0o`00203oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`00o`000?l000@0
oooo00H0003o0?ooo`3oool0oooo0?l000000?l80?ooo`080?l0003oool0oooo0000o`3oool0003o
0?ooo`3o00070?ooo`030000o`3o0000oooo00@0oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000
oooo0000o`P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000003o0?ooo`030?ooo`050?l0003o
ool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000@0oooo
00<0o`000000o`3oool0103oool01@00o`00003o0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3o
ool0003o303oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0=0?ooo`05003o003oool0oooo0?ooo`00o`001`3o
ool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`3o0000003o
0?ooo`040?ooo`030000o`3o0000oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l000000?l0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l0000R0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool010000?l0oooo0?l000000?l90?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool01@3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0
oooo00@0oooo00@0003o0?ooo`3oool0003o1@3oool00`00o`00oooo003o00030?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`040000o`3o
ool0oooo0?l001L0oooo00@0003o0?ooo`3oool0003o3@3oool00`000?l0oooo0?l000070?ooo`03
0000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`0F0?oo
o`060000o`3oool0oooo0000o`3oool0o`001@3oool00`3o0000003o0?ooo`080?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`00
0?l01@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0003o00P0003o0P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0000o`0>
0?ooo`030?l000000?l0oooo00H0oooo00@0o`00003o0000o`00o`002P3oool01P000?l0oooo0?oo
o`3oool0o`000000o`P0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo0080003o1P3oool01P00o`00oooo0?ooo`3oool0o`000000o`80oooo00<0003o
0?ooo`3oool01@3oool00`3o0000003o0?ooo`060?ooo`030000o`3o0000oooo00D0oooo00H0o`00
0?ooo`000?l00?l00?ooo`000?l30?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00/0oooo00@0003o0?ooo`000?l0o`00203oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?l0003oool00`3oool00`000?l0o`000?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
00000?l0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool00?l000@0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`080?l0003oool0oooo0000
o`3oool0003o0?ooo`3o00080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
00030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool0203oool00`3o0000oooo0?oo
o`030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0o`0000@0oooo00<0o`000000o`3oool01@3oool010000?l0oooo0?ooo`3o00030?ooo`04
0?l0003oool0oooo0000o``0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0003o00X0oooo00<0o`000?ooo`3oool03@3oool01000o`00oooo0?ooo`00
o`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`000?l02@3oool01@000?l0oooo0?oo
o`3oool0o`000280oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`040000
o`3oool0o`000000o`T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`050?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool20000o`H0oooo00<00?l00?ooo`00
o`000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool010000?l0oooo0?ooo`3o000G0?ooo`040000o`3oool0oooo0000o`d0oooo00<0003o
0?ooo`3o00001P3oool00`000?l00?l00?ooo`060?ooo`04003o003oool0oooo0?l000@0oooo00<0
o`000?ooo`3oool05`3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00D0
003o0?ooo`3o0000oooo0000o`070?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0?l000020?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool010000?l0
oooo0?ooo`3o00030?ooo`040?l0003oool0oooo0000o`h0oooo00<0o`000000o`3oool01@3oool0
1@3o0000oooo003o003oool0o`0000X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool01P3oool01P3o0000oooo0?oo
o`3oool0003o003o00H0oooo00H00?l00?ooo`3oool0oooo0?l000000?l20?ooo`030000o`3oool0
oooo00D0oooo00<0o`000000o`3oool01P3oool00`000?l0o`000?ooo`050?ooo`060?l0003oool0
003o0?ooo`00o`00003o0`3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0403oool0103o0000003o0000
o`3o00080?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`00
0?ooo`030?ooo`030000o`3o0000oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0000o`050?ooo`030000o`3o0000oooo00<0oooo00<0o`000000o`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`00o`00103oool01@000?l0oooo
0?ooo`3oool0003o00T0oooo00P0o`000?ooo`3oool0003o0?ooo`000?l0oooo0?l000L0oooo00<0
o`000000o`3oool0103oool00`000?l0oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o00000`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00<0o`000000o`3oool01@3o
ool010000?l0oooo0?ooo`3o00030?ooo`050?l0003oool00?l00?ooo`000?l0303oool00`3o0000
003o0?ooo`040?ooo`030000o`3oool0oooo0080o`0000<0oooo0000o`3oool02@3oool00`3o0000
oooo0?ooo`0=0?ooo`04003o003oool0oooo003o00P0oooo00<0o`000?ooo`3oool01P3oool01P3o
0000003o0?ooo`3oool0003o0?l000P0oooo00<0o`000000o`3oool0103oool00`000?l0o`000?oo
o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0000
o`080?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo00h0oooo00@0003o0?ooo`3o0000003o2@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`00
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo0P00o`050?ooo`050000o`3oool0oooo0?ooo`00
0?l02`3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l001L0oooo00@0003o0?oo
o`3oool0003o3@3oool00`000?l0oooo0?l000060?ooo`030000o`3oool00?l000H0oooo00@00?l0
0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`0H0?ooo`80003o0P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`080?ooo`050000o`3oool0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`002P3oool01@00o`00oooo0?ooo`3oool00?l0
00T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo
0?l000<0oooo00@0o`000?ooo`3oool0003o3P3oool00`3o0000003o0?ooo`050?ooo`050?l0003o
ool00?l00?ooo`3o00002P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`000?l00`3oool00`000?l0o`000?ooo`060?ooo`070?l0003oool0oooo0?ooo`00
0?l0oooo003o00050?ooo`09003o003oool0oooo0?ooo`3o0000oooo0000o`3oool0003o00L0oooo
00<0o`000000o`3oool01P3oool00`000?l0o`000?ooo`050?ooo`060?l0003oool0oooo0000o`00
o`00003o0`3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D0
00007@3oool00`3o0000oooo0?ooo`0?0?ooo`050?l000000?l0003o0?ooo`3o00001`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`000?l01@3oool00`00
0?l0o`000?ooo`030?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0003o0?l00008
0?ooo`060?l0003oool0oooo0000o`3oool0003o0P3oool00`3o0000oooo0?ooo`040?ooo`030?l0
00000?l0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`060?ooo`80o`000`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`000?l01@3oool010000?l0
0?l00?ooo`3o00030?ooo`050?l0003oool00?l00?ooo`000?l0303oool00`3o0000003o0?ooo`04
0?ooo`030000o`3oool0o`000080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0>
0?ooo`03003o003oool00?l000T0oooo00<0o`000?ooo`3oool01P3oool01P3o0000oooo0000o`3o
ool0003o0?l000P0oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?l000030?ooo`030?l0
00000?l0oooo00H0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0000o`080?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00h0oooo00@0003o0?ooo`3oool0003o2@3oool00`3o0000003o0?ooo`030?ooo`03
0000o`3o0000oooo00D0oooo00<0o`000000o`3oool01`3oool00`000?l0o`000?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`03
003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`030000o`3oool0oooo
00D0oooo00@0003o0?ooo`3oool0o`005`3oool010000?l0oooo0?ooo`000?l=0?ooo`@0003o103o
ool010000?l0oooo0?ooo`00o`060?ooo`04003o003oool0oooo0?l000@0oooo00<0o`000?ooo`3o
ool0603oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`000?l01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00@0003o0?l0003oool0003o2@3oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o0000303oool01000o`00oooo0?oo
o`00o`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool01@000?l0oooo
0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3o00030?oo
o`050?l0003oool0oooo0?ooo`000?l03@3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`000?l00`3oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0
oooo00@0oooo00<00?l00?ooo`3oool00P3oool02@00o`00oooo0?ooo`3oool0o`000?ooo`000?l0
oooo0000o`070?ooo`030?l0003oool0003o00H0oooo00<0003o0?l0003oool01@3oool01P3o0000
oooo0?ooo`000?l0oooo0000o`800?l000<0oooo0?l0003oool04`3oool5000001`0oooo000i0?oo
o`030000003oool0oooo0200oooo00<0o`000?ooo`3oool03P3oool01@3o0000003o0?ooo`3oool0
o`0000H0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000
oooo00<0oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
003o00@0oooo00<0003o0?ooo`3o0000103oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0
oooo0000o`3o0000203oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0
103oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`060?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool01P3oool20?l000@0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0003o00@0
oooo00<0003o0?ooo`00o`000P3oool01@3o0000oooo0?ooo`3o00000?l00080oooo00<0003o0?oo
o`3oool02P3oool00`000?l0o`000?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool0
0`3o0000oooo0?ooo`0?0?ooo`800?l02@3oool00`3o0000oooo0?ooo`060?ooo`070?l0003oool0
003o0?ooo`000?l0oooo0?l000070?ooo`030?l0003oool0003o00<0oooo00@0003o0?ooo`3oool0
o`000`3oool00`3o0000003o0?ooo`060?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`00
0?l0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0=0?ooo`050?l000000?l0oooo0000o`3o00002@3oool00`3o
0000003o0?ooo`030?ooo`030000o`3o0000oooo00D0oooo00<0o`000000o`3oool01`3oool00`00
0?l0o`000?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0?0?ooo`03003o003oool0oooo00<0oooo00@0003o0?ooo`3oool0003o3P3oool0
0`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l001L0oooo00@0003o0?ooo`3oool0003o
3P3oool00`3o0000oooo0?ooo`050000o`80oooo00<00?l00?ooo`3oool0103oool01000o`00oooo
0?ooo`3o00040?ooo`030?l0003oool0oooo01d0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`040000o`3o0000oooo0000o`T0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`80o`00303o
ool00`00o`00oooo003o000:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3o
ool010000?l0oooo0?ooo`000?l80?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`000?l03@3oool00`3o0000003o0?ooo`050?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`000?l00`3oool00`000?l0o`000?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00@00?l00?ooo`3oool00?l01@3oool0103o0000003o0?ooo`00
0?l70?ooo`030?l0003oool0003o00H0oooo00<0003o0?l0003oool01@3oool01P3o0000oooo0?oo
o`000?l0oooo0000o`80oooo0P00o`0H0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo0200oooo00<0o`000?ooo`3oool03P3oool01@3o0000003o0?ooo`3oool0o`0000H0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00<0
oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o00@0
oooo00<0003o0?ooo`3o0000103oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0000
o`3o0000203oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`060?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0000
o`040?ooo`030000o`3oool00?l00080oooo00D0o`000?ooo`3oool0o`00003o00020?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0000o`020?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`080?ooo`030?l0
003oool0oooo00D0oooo00P0o`000?ooo`3oool0003o0?ooo`000?l0oooo0?l000L0oooo00<0o`00
0?ooo`000?l00`3oool010000?l0oooo0?ooo`3o00030?ooo`030?l000000?l0oooo00H0oooo00<0
003o0?l0003oool0103oool00`3o0000oooo0000o`080?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00D0
o`000000o`3oool0003o0?l000090?ooo`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool0
103oool00`3o0000oooo0000o`070?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01D0oooo00@0003o0?ooo`3oool0
003o3`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0o`000000o`0>0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3o
ool0103oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool07P3oool01@3o
0000oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000000o`000?l02`3oool010000?l0oooo0?ooo`000?l50?ooo`030?l0
003oool0oooo00/0oooo00<00?l00?ooo`00o`002P3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`000?l02@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`030?ooo`03
0000o`3o0000oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo003o00050?ooo`03
0?l000000?l0003o00P0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`000?ooo`040?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`800?l05P3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0o`000?ooo`030?ooo`030?l000000?l0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0o`0000@0oooo00<0o`000000
o`3oool01P3oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool01@000?l0oooo0?ooo`000?l0o`0000P0oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?oo
o`0<0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0003o00@0oooo00X0003o0?ooo`3oool00?l00?ooo`3o0000oooo0?l0003oool00?l00P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`3oool00P00
0?l00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0103o
ool0203o0000oooo0?ooo`000?l0oooo0000o`3oool0o`001P3oool0103o0000oooo0?ooo`000?l3
0?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`000?l01`3oool00`000?l0o`000?oo
o`040?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool01@3o0000003o0?oo
o`000?l0o`0000P0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?l000050?ooo`030?l0
003oool0003o00L0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool05P3oool20000oa40oooo0P000?l20?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool05@3oool00`000?l0o`000000o`0>0?ooo`030?l0
003oool0oooo00L0oooo00<00?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0o`000080
oooo00<0o`000?ooo`3oool07P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00@0003o0?oo
o`3oool0003o2@3oool00`3o0000oooo0?ooo`070?ooo`030?l000000?l0003o00/0oooo00@0003o
0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00T0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`80003o2P3oool01@000?l0oooo0?oo
o`3oool0003o00@0oooo00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0?l000060?ooo`040?l0003oool0oooo0000o`<0oooo00<0
003o0?l0003oool01P3oool00`3o0000oooo0?ooo`070?ooo`800?l01@3oool00`3o0000oooo0000
o`080?ooo`030?l0003oool0003o00H0oooo00<0003o0?l0003oool0103oool01`3o0000oooo0?oo
o`3oool0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3o0000oooo00<0oooo00<0o`000000o`3oool00`3oool00`000?l0o`00
0?ooo`060?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo
0000o`050?ooo`030000o`3oool0o`0000D0oooo00<0o`000000o`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`040000o`3oool0003o0?l000P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool0303oool01@000?l0
oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0000o`040?oo
o`090000o`3oool0oooo003o003oool0o`000?ooo`3o00000?l000<0oooo00<0003o0?ooo`3oool0
2@3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
0000203oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`020?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o0`3oool0
10000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0003o00L0oooo00<0003o0?l0003oool0103o
ool00`3o0000oooo0000o`080?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0303o
ool01@3o0000003o0?ooo`000?l0o`0000P0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo
0?l000050?ooo`030?l0003oool0003o00L0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00080?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool05P3oool20000oa<0oooo00<0003o0?oo
o`000?l0103oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o0000003o00h0oooo00<0o`000?oo
o`3oool0203oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00@0o`000?oo
o`3oool0o`00803oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`000?l02P3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0003o00d0oooo0P000?lE0?ooo`03003o003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0o`0000@0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool01`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o00001P3oool0103o
0000oooo0?ooo`000?l20?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool0203oool0
0`00o`00oooo0?ooo`030?ooo`030?l0003oool0003o00P0oooo00<0o`000?ooo`000?l01@3oool0
10000?l0oooo0?ooo`3o00040?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`03
0?l0003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
8P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o0000
103oool00`3o0000003o0?ooo`030?ooo`030000o`3o0000oooo00H0oooo00<0o`000?ooo`000?l0
103oool00`000?l0oooo0?l000040?ooo`030?l0003oool0003o00D0oooo00<0003o0?ooo`3o0000
1@3oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`000?l0
o`00203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
00001P3oool00`3o0000oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01`3o
0000oooo0?ooo`3oool0o`000?ooo`000?l0103oool02@000?l0oooo0?ooo`3oool00?l00?l0003o
ool0o`00003o00030?ooo`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0o`000P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0703oool0
0`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?oo
o`040?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`030?ooo`060?l0003oool0oooo0?l0
003oool0003o1`3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0003o00L0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`<0o`00203oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00`0oooo00D0o`000?ooo`000?l0003o0?l000080?ooo`030?l0003o
ool0003o00<0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0000o`070?ooo`030000o`3o
ool0oooo0080o`002@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01H0oooo00<0
003o0?ooo`3oool04`3oool20000o`@0oooo00<0o`000?ooo`3oool0503oool0103o0000003o0000
o`3o000=0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`020?ooo`040?l0003oool0oooo0?l00200oooo00D0o`000?ooo`3oool0oooo0?l000050?oo
o`80003o2P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00d0oooo0P000?lR0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05P3oool010000?l0oooo0?ooo`000?l4
0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000003o0?ooo`05
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool01`000?l0oooo0?ooo`3o
ool0003o0?ooo`3o00001P3oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3oool0o`0000L0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0003o00D0
oooo00@0003o0?ooo`3oool0o`00103oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo0280oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0
oooo0?ooo`3o0000403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0o`0000@0oooo00<0
o`000000o`3oool00`3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0003o00@0oooo00<0
003o0?ooo`3o0000103oool00`3o0000oooo0000o`050?ooo`030000o`3oool0o`0000D0oooo00<0
o`000000o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0oooo0?l0003oool01`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001P3o
ool00`3o0000oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0103o0000oooo
0?ooo`3o00020?ooo`030000o`3oool0oooo0080oooo00T0003o0?ooo`3oool0oooo003o003o0000
oooo0?l00000o`000`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo0P3o
00080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?oo
o`040?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`040?ooo`070?l0
003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`050?l0003oool0o`000?ooo`000?l01`3oool0
0`000?l0o`000?ooo`040?ooo`040?l0003oool0oooo0000o`H0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0oooo0?ooo`80o`001@3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00D0o`000?ooo`000?l0oooo0?l000080?ooo`03
0?l0003oool0003o00<0oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0000o`070?oo
o`030000o`3oool0oooo0080o`002@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
02h0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0D0?ooo`040?l000000?l0003o
0?l000d0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo0080oooo00@0o`000?ooo`3oool0o`008@3oool00`3o0000oooo0?l000060?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0F0?ooo`040000o`3o
ool0oooo0000o`@0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
00000?l0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l0
00000?l0oooo0080oooo00<0003o0?ooo`3o00001P3oool0103o0000oooo0?ooo`000?l20?ooo`03
0000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0003o00D0oooo00@0003o0?ooo`3oool0o`00103oool01`3o0000oooo0?ooo`3oool0
003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`04
0?ooo`050?l0003oool0oooo0?ooo`3o0000403oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0o`0000@0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?l000060?ooo`030?l0003o
ool0003o00@0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0000o`050?ooo`030000o`3o
ool0o`0000D0oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0
oooo0?l0003oool01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00@0
o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`00
0?l00`3oool0103o0000oooo0?ooo`3o00020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool0703oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0103oool01@3o0000oooo0?l0
003oool0003o00L0oooo00<0003o0?l0003oool0103oool0103o0000oooo0?ooo`000?l60?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`80
o`000P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0000o`80oooo00@0003o0?oo
o`3oool0o`00103oool00`3o0000oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`3o00002P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool04`3o
ool01@3o0000oooo0?ooo`000?l0o`0000d0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o00008P3oool00`3o0000oooo
0?l0000C0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo01L0oooo0P000?l50?ooo`030?l0003oool0o`0000D0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000o`020?ooo`030000o`3oool0o`0000H0oooo
00T0o`000?ooo`3oool0oooo0000o`3oool0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`000?l01@3oool010000?l0oooo0?ooo`3o
00040?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`030?l0003oool0oooo01D0
oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool0o`00403oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`000?l00`3oool00`000?l0
oooo0?l000060?ooo`030?l0003oool0003o00<0oooo00@0003o0?ooo`3oool0o`00103oool00`3o
0000oooo0000o`050?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`000?l01P3oool00`00
0?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`80oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`3oool03@3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`00o`00103oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0L0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`050?l0003oool0
o`000?ooo`000?l01`3oool00`000?l0o`000?ooo`040?ooo`040?l0003oool0oooo0000o`H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00D0oooo
0P3o000C0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo
0?ooo`050?ooo`040?l0003oool0oooo0000o`80oooo00@0003o0?ooo`3oool0o`00103oool0103o
0000oooo0?ooo`000?l50?ooo`050000o`3oool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool04P3oool01P3o0000oooo0?oo
o`3oool0003o0?l000d0oooo00<0o`000?ooo`3oool02P3oool01@00o`00oooo0?ooo`3oool00?l0
00@0oooo00<0o`000?ooo`3o00008P3oool00`3o0000oooo0?l0000C0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
01P0oooo0P000?l60?ooo`80o`001@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l000000?l0oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o
0080oooo00<0003o0?ooo`3o00001P3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo
0?l000070?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0000o`050?ooo`040000o`3oool0oooo0?l000@0oooo00@0o`000?ooo`3oool0oooo0P000?l50?oo
o`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3o
ool0o`00403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0o`0000<0oooo00@0o`000?oo
o`3oool0003o0`3oool00`000?l0oooo0?l000060?ooo`040?l0003oool0oooo0000o`80oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0003o00D0oooo00<0003o0?ooo`3o0000
1@3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0
o`001P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
ool0003o0P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3o00001P3oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0000o`<0oooo00@0o`00
0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`00003o003o0000103oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo0000o`040?ooo`030?l0003oool0o`000080oooo00<0003o0?ooo`3oool0103oool00`000?l0
o`000?ooo`040?ooo`040?l0003oool0oooo0000o`H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00H0o`000?ooo`3oool0003o0?ooo`00
0?l30?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0<`3oool00`3o0000oooo
0?ooo`0B0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo
00/0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`030?l0003oool0o`000280oooo00<0o`00
0?ooo`3o00004`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo03<0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030?l000000?l0oooo00D0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o0080oooo00@0003o
0?ooo`3oool0o`001@3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool01P3oool0103o0000
oooo0?ooo`000?l40?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00D0oooo00@0o`000?ooo`3oool0o`00403oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0
oooo0?l00080oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?l000060?ooo`040?l0
003oool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0003o
00D0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00X0oooo00<0003o0?ooo`3oool00P3o
ool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`000?l0
103oool0103o0000oooo0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`3o
00000?l00?l000040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0o`000080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?l000050?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00H0o`000?ooo`3oool0003o0?oo
o`000?l30?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0<`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00@00?l00?ooo`3oool00?l01P3oool20?l0
0280oooo00<0o`000?ooo`3o00004`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
03<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`020?ooo`040000o`3oool0oooo
0?l000@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool010000?l0oooo0?ooo`3o00040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0o`000140oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?oo
o`3o00020?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3o00001P3oool0103o0000
oooo0?ooo`000?l20?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0000o`05
0?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`0:0?ooo`030000o`3oool0oooo0080oooo
00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0003o00@0
oooo00@0o`000?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`050?l0003oool0oooo0?ooo`3o00002@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool20?l000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l000050?ooo`040?l0003o
ool0oooo0000o`D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo01d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l30?ooo`030?l0003oool0oooo
0080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0
o`000?l000L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo00@00?l00?ooo`3oool00?l01P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0
003oool0oooo01<0oooo00D0o`000?ooo`3oool0oooo0?l0000g0?ooo`040?l0003oool0oooo0?l0
02<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0003o
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0o`00
0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0003o0?ooo`3oool0o`00
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool500000280oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`060?ooo`80o`004P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3o
ool0oooo0?l00080oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?l000050?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0o`00
0?ooo`3oool0003o1@3oool00`000?l0oooo0?l000050?ooo`030?l0003oool0003o00D0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l02P3oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0000o`040?ooo`040?l0003oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0000
o`050?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`050?l0003oool0oooo0?ooo`3o0000
2@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3o00001@3oool0103o0000
oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`050?ooo`060?l0003oool0oooo0000o`3oool0003o0`3oool00`3o0000oooo0?oo
o`020?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo
0?ooo`3oool20?l000@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00/0oooo00@00?l00?ooo`3oool00?l01P3oool00`3o0000oooo0?ooo`0R0?oo
o`030?l0003oool0oooo01<0oooo00D0o`000?ooo`3oool0oooo0?l0000g0?ooo`040?l0003oool0
oooo0?l002/0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0000o`3oool0003o00<0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o0080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00D0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0100oooo1@00000L0?oo
o`00>@3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool0o`000P3oool0103o0000oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0?l000D0oooo00D0
o`000?ooo`3oool0oooo0000o`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0000o`05
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo0080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00X0oooo
00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`000?l0103oool0103o0000oooo0?ooo`3o00030?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P000?lD
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool07`3oool01@3o0000oooo0?ooo`3o
ool0o`0000X0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`050?l0003oool0oooo0?ooo`00
0?l01@3oool00`000?l0oooo0?l000050?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00H0o`000?oo
o`3oool0003o0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o
103oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
=@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo0P3o00020?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0=0?ooo`03003o
003oool00?l000H0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0C0?ooo`050?l0
003oool0oooo0?ooo`3o0000=`3oool0103o0000oooo0?ooo`3o000[0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00D0o`000?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`040000o`3o
ool0oooo0?l000@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0903o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l00080oooo00@0o`000?ooo`3oool0
003o0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00L0o`000?ooo`3oool0oooo0000o`3o
ool0003o00@0oooo00@0o`000?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080
oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00X0oooo00<0003o0?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0000
o`050?ooo`030?l0003oool0o`0000<0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l05P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0200oooo00@0o`000?ooo`3oool0o`002P3oool01@3o0000oooo0?ooo`3oool0
o`0000`0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0o`0000@0oooo00D0
o`000?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`060?l0003oool0oooo0000o`3oool0003o0`3oool00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`80o`002@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00d0oooo00<00?l00?ooo`00o`00@@3oool0103o0000oooo0?ooo`3o000h0?ooo`040?l0003o
ool0oooo0?l002/0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool01P3o0000oooo0?ooo`000?l0oooo0000
o`@0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02D0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`03
0?ooo`030?l0003oool0oooo0080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00@0oooo
00@0o`000?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00L0o`000?oo
o`3oool0oooo0000o`3oool0003o00X0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0000o`050?ooo`030?l0
003oool0o`0000<0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`040?ooo`04
0000o`3oool0oooo0000oaP0oooo00D0o`000?ooo`3oool0oooo0?l0000R0?ooo`040?l0003oool0
oooo0?l000X0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`050?l0003oool0oooo0?ooo`00
0?l01@3oool010000?l0oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo003o
00110?ooo`040?l0003oool0oooo0?l003P0oooo00<0o`000?ooo`3o0000;03oool00`000?l0oooo
0?ooo`090?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`060?l0003oool0oooo0000o`3oool0003o103oool01@3o0000oooo0?ooo`3oool0
o`0000D0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo01<0oooo00<0
o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0003o0?ooo`3oool0
o`000`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3o
ool06P3oool003T0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool01`000?l0oooo0?ooo`3oool0o`000?oo
o`3o0000103oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00L0o`000?oo
o`3oool0oooo0000o`3oool0003o00@0oooo00@0o`000?ooo`3oool0o`000`3oool01@000?l0oooo
0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`050?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`05
0?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?l000030?ooo`040000o`3oool0oooo0000o`H0oooo00<0
o`000?ooo`3oool0103oool30000oaT0oooo00D0o`000?ooo`3oool0oooo0?l0000R0?ooo`030?l0
003oool0o`0000/0oooo00D0o`000?ooo`3oool0oooo0?l0000@0?ooo`030000o`3oool0oooo00<0
oooo00@0003o0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000@0oooo00D0
003o0?ooo`3oool0oooo0000o`0A0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0=0?ooo`800?l0@P3oool00`3o0000oooo0?l0000i0?ooo`030?l0003oool0o`0002`0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool01P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00D0o`00
0?ooo`3oool0oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo
0?ooo`0C0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`04
0000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0D0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00<0oooo00L0003o0?ooo`3o
ool0oooo0?l0003oool0o`0000@0oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`02
0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`040?l0003oool0oooo0?l000<0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00@0o`000?oo
o`3oool0003o103oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool02P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0?l0000C0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3o00000`3oool010000?l0oooo0?ooo`000?l60?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool06@3oool0103o0000oooo0?ooo`3o000S
0?ooo`030?l0003oool0o`0000/0oooo00@0o`000?ooo`3oool0o`004P3oool00`000?l0oooo0?oo
o`020?ooo`040000o`3oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o00040?oo
o`040000o`3oool0oooo0000oa80oooo00D0o`000?ooo`3oool0oooo0?l0000h0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00l0oooo00<00?l00?ooo`3oool0@@3oool20?l003X0oooo0P3o000/0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l40?ooo`040?l0003oool0oooo0?l0
00H0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo01<0oooo00<0o`00
0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0003o0?ooo`3oool0o`00
0`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o
0000103oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00L0o`000?ooo`3o
ool0oooo0000o`3oool0003o00@0oooo00@0o`000?ooo`3oool0o`000`3oool01@000?l0oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0
oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00X0oooo00D0003o0?oo
o`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`3o00004`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0o`0000<0oooo00@0003o0?ooo`3oool0003o:P3oool00`3o0000oooo
0?l0000S0?ooo`030?l0003oool0o`0000/0oooo00@0o`000?ooo`3oool0o`004P3oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0P
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o
00040?ooo`040000o`3oool0oooo0000oa80oooo00D0o`000?ooo`3oool0oooo0?l0000h0?ooo`05
0?l0003oool0oooo0?ooo`3o00005`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00l0oooo00<00?l00?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0i0?ooo`80o`00;03oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80003o103oool0103o0000oooo0?ooo`3o
000:0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`050?l0
003oool0oooo0?ooo`3o00008`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo
0?ooo`0U0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo
0?ooo`030?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`030000o`3oool0003o
00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3oool00`3o
0000oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o
ool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3o
ool02P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0?l0000C
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`0Z
0?ooo`030?l0003oool0o`0002<0oooo00<0o`000?ooo`3o0000303oool00`3o0000oooo0?l0000B
0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo0280oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o00040?ooo`04
0000o`3oool0oooo0000oa80oooo00D0o`000?ooo`3oool0oooo0?l0000i0?ooo`030?l0003oool0
o`0001P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0
oooo0440oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0o`0000X0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l30?ooo`050?l0003oool0oooo0?ooo`3o
00008`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`030?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`030000o`3oool0003o00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3oool00`3o0000oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0
003o0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
203oool01@3o0000oooo0?ooo`3oool0o`000180oooo00D0003o0?ooo`3oool0oooo0000o`030?oo
o`050?l0003oool0oooo0?ooo`3o00006P3oool20?l000D0oooo00<0003o0?ooo`000?l0:P3oool0
0`3o0000oooo0?l0000T0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o00004P3oool0
0`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0R0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3oool0o`00103oool010000?l0
oooo0?ooo`000?lC0?ooo`030?l0003oool0o`0003X0oooo00<0o`000?ooo`3o0000603oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo08l0oooo00<0o`000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`3o0000oooo0?l0000;
0?ooo`050?l0003oool0oooo0?ooo`3o0000603oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo
00@0003o0?ooo`3oool0003o103oool0103o0000oooo0?ooo`3o000S0?ooo`030000003oool0oooo
01X0oooo000N0?ooo`800000103oool2000000D0oooo0`00000;0?ooo`030000003oool0oooo02H0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080
oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000@0oooo00<0003o0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3o000B0?ooo`050000o`3oool0oooo
0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0o`0001X0oooo0P3o00050?ooo`030000o`3o
ool0003o02X0oooo0P3o000U0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o00004P3o
ool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0
0P3oool010000?l0oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?oo
o`000?l0503oool00`3o0000oooo0?l0000j0?ooo`80o`006P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0;l0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0
003o00H0oooo00<0o`000?ooo`3o00002`3oool01@3o0000oooo0?ooo`3oool0o`0001P0oooo00D0
o`000?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0oooo0000o`@0oooo00@0o`000?ooo`3o
ool0o`008`3oool00`000000oooo0?ooo`0J0?ooo`007@3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`80o`00103oool20000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o0140oooo00D0
o`000?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0?l00180oooo00@0003o0?ooo`3o
ool0003o103oool0103o0000oooo0?ooo`3o000L0?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`000?l0:`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3o00004P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0
o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000@0
oooo00<0003o0?ooo`000?l0503oool00`3o0000oooo0?l0000j0?ooo`80o`006P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0;l0oooo00<0003o0?ooo`3oool0203oool00`000?l0
o`000?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool01@3o0000
oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3o00002`3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00<0o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l40?ooo`040?l0003o
ool0oooo0?l002<0oooo00<000000?ooo`3oool06P3oool001d0oooo00@000000?ooo`3oool00000
203oool5000000/0oooo1`00000R0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0P3o00050?ooo`030000
o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o0140oooo00D0o`000?ooo`3oool0oooo0?l0
000;0?ooo`040?l0003oool0oooo0?l00180oooo00@0003o0?ooo`3oool0003o103oool0103o0000
oooo0?ooo`3o000L0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l0:`3oool00`3o
0000oooo0?ooo`0a0?ooo`030?l0003oool0o`000180oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o303o
ool00`3o0000oooo0?ooo`040?ooo`80o`009P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`040?l0003o
ool0oooo0?l000@0oooo00<0003o0?ooo`000?l0503oool00`3o0000oooo0?l0000j0?ooo`030?l0
003oool0oooo01T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2o0?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0o`0000/0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0o`0000D0
oooo00@0003o0?ooo`3oool0003o103oool0103o0000oooo0?ooo`3o000M0?ooo`L00000703oool0
01d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003o
ool0oooo02H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0M0?ooo`050000o`3o
ool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
0000103oool00`000?l0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0003o0140oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003o
ool0o`0001<0oooo00@0003o0?ooo`3oool0003o103oool0103o0000oooo0?ooo`3o000L0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l0G`3oool20?l001<0oooo00<0003o0?ooo`3o
ool00P3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080oooo00@0003o0?oo
o`3oool0003o303oool00`3o0000oooo0?ooo`020?ooo`80o`00:03oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0o`0000D0oooo0P000?lD0?ooo`030?l0003oool0o`0005H0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2o0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?l0003oool00`3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00002`3o
ool20?l000`0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0o`0000D0oooo
00@0003o0?ooo`3oool0003o103oool0103o0000oooo0?ooo`3o000S0?ooo`030000003oool0oooo
01X0oooo000M0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool07@3oool01@00
0?l0oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o0140
oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0o`0001<0oooo00@0003o0?oo
o`3oool0003o103oool0103o0000oooo0?ooo`3o000L0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`000?l0H03oool00`3o0000oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000?l0
0`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00@0003o0?ooo`3oool0003o303oool00`3o
0000oooo0?l000020?l002/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l000050?oo
o`80003o5@3oool00`3o0000oooo0?ooo`1F0?ooo`050?l0003oool0oooo0?ooo`3o0000`P3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3o0000oooo00<0oooo00<0o`000?ooo`3oool01`3oool0
1@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0?oo
o`3oool0o`0001X0oooo0P3o00050?ooo`040000o`3oool0oooo0000o`@0oooo00@0o`000?ooo`3o
ool0o`008`3oool00`000000oooo0?ooo`0J0?ooo`007P3oool2000000/0oooo0P00000<0?ooo`03
0000003oool0oooo02L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0M0?ooo`05
0000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00@0o`000?ooo`3oool0o`00303oool20?l000D0oooo00<0003o0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`0A0?ooo`040?l0
003oool0oooo0?l000`0oooo00<0o`000?ooo`3o0000503oool00`000?l0oooo0000o`040?ooo`04
0?l0003oool0oooo0?l001`0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`1P0?oo
o`030?l0003oool0oooo0180oooo00@0003o0?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`000?l03@3oool20?l002h0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`3o0000oooo
0?l000050?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0EP3oool01@3o0000oooo
0?ooo`3oool0o`000<80oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`030?ooo`03
0?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo
00X0oooo00D0o`000?ooo`3oool0oooo0?l0000J0?ooo`80o`001@3oool010000?l0oooo0?ooo`00
0?l40?ooo`040?l0003oool0oooo0?l002<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool09`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01d0oooo00D0
003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3oool0
o`00303oool20?l000D0oooo00<0003o0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0o`00
00@0oooo00@0003o0?ooo`3oool0003o4@3oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003o
ool0o`0001@0oooo00<0003o0?ooo`000?l0103oool0103o0000oooo0?ooo`3o000R0?ooo`80003o
H@3oool00`3o0000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0000o`<0oooo00D0o`000?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0003o03d0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o00001@3oool0
0`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo05H0oooo00D0o`000?ooo`3oool0oooo0?l0
00320?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?oo
o`070?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?ooo`0:0?ooo`050?l0
003oool0oooo0?ooo`3o00006`3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo0000
o`@0oooo00<0o`000?ooo`3o0000903oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0W0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool07@3oool01@000?l0
oooo0?ooo`3oool0003o0180oooo00@0o`000?ooo`3oool0o`00303oool20?l000D0oooo00<0003o
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`000?l04P3o
ool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003oool0o`0001@0oooo00<0003o0?ooo`000?l0
103oool00`3o0000oooo0?l0000S0?ooo`80003oMP3oool010000?l0oooo0?ooo`000?l30?ooo`05
0?l0003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0000o`0n0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003oool0
o`0000D0oooo00<0003o0?ooo`3oool0K@3oool01@3o0000oooo0?ooo`3oool0o`000<80oooo00<0
003o0?ooo`3oool0203oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo00L0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00006`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3o0000903oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool07P3oool01@000?l0oooo0?ooo`3oool0003o0180oooo00@0o`000?ooo`3o
ool0o`003@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0003o0180oooo00@0o`000?ooo`3oool0o`00303o
ool00`3o0000oooo0?l0000D0?ooo`030000o`3oool0003o00D0oooo0P3o000T0?ooo`030000o`3o
ool0oooo07@0oooo00@0003o0?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`3o00060?ooo`80
003o?P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3o
ool0o`00303oool00`3o0000oooo0?l0001f0?ooo`030?l0003oool0o`000<<0oooo00<0003o0?oo
o`3oool0203oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo00L0oooo00D0o`000?oo
o`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00008P3oool00`000?l0oooo0000
o`040?ooo`030?l0003oool0o`0002@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool09`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01h0oooo00D0003o
0?ooo`3oool0oooo0000o`0B0?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0000o`0C0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3o0000503oool00`000?l0
oooo0000o`050?ooo`80o`00903oool00`000?l0oooo0?ooo`1d0?ooo`040000o`3oool0oooo0000
o`@0oooo00<0o`000?ooo`3o00001P3oool20000och0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o0000MP3oool0
0`3o0000oooo0?l000330?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o0000103oool0
0`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00006P3oool00`3o0000oooo0?l0
000S0?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3o0000903oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool07P3oool01@000?l0oooo0?ooo`3oool0003o0180oooo00@0o`000?ooo`3oool0o`00
3@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0003o01<0oooo00<0o`000?ooo`3o00003@3oool20?l001@0
oooo00<0003o0?ooo`000?l01@3oool20?l002@0oooo00<0003o0?ooo`3oool0M03oool010000?l0
oooo0?ooo`000?l40?ooo`030?l0003oool0o`0000H0oooo0P000?lo0?ooo`050?l0003oool0oooo
0?ooo`3o00002`3oool0103o0000oooo0?ooo`3o000<0?ooo`80o`00M`3oool00`3o0000oooo0?l0
00330?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0?oo
o`070?ooo`050?l0003oool0oooo0?ooo`3o00006P3oool00`3o0000oooo0?l0000S0?ooo`030000
o`3oool0003o00@0oooo00<0o`000?ooo`3o0000903oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool07`3o
ool010000?l0oooo0?ooo`000?lC0?ooo`030?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0000o`0C0?ooo`030?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0000o`050?ooo`80o`00903oool00`000?l0oooo0?ooo`1d0?ooo`040000o`3oool0oooo0000
o`@0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`0n0?ooo`050?l0003oool0oooo
0?ooo`3o00002`3oool0103o0000oooo0?ooo`3o000<0?ooo`80o`00M`3oool00`3o0000oooo0?l0
00330?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0o`0001/0oooo00<0o`000?ooo`3o00008`3oool00`000?l0oooo0000
o`040?ooo`030?l0003oool0o`0002@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01l0oooo00<0003o
0?ooo`000?l0503oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o01<0oooo00<0o`00
0?ooo`3o00003@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o00D0oooo0P3o000T
0?ooo`030000o`3oool0oooo07@0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?l0
00060?ooo`030000o`3oool0oooo03h0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`040?l0
003oool0oooo0?l000`0oooo0P3o001h0?ooo`030?l0003oool0oooo0<80oooo00<0003o0?ooo`3o
ool01`3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3o00006`3oool00`3o0000oooo0?l0000S0?ooo`030000o`3oool0003o00@0oooo00<0o`000?oo
o`3o0000903oool00`000000oooo0?ooo`0J0?ooo`00>@3oool5000002H0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0003o01@0oooo00<0o`000?ooo`3o
0000503oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`00
0?l04`3oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo01<0oooo0P000?l60?ooo`03
0?l0003oool0oooo09/0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?l000060?ooo`03
0000o`3oool0oooo03l0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?l0000=0?oo
o`030?l0003oool0oooo07H0oooo00<0o`000?ooo`3oool0``3oool00`000?l0oooo0?ooo`060?oo
o`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l0000K
0?ooo`030?l0003oool0o`0002<0oooo0P000?l50?ooo`030?l0003oool0o`000200oooo1@00000L
0?ooo`00>@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool07`3oool00`000?l0oooo0000o`0D0?ooo`030?l0003oool0o`0001@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o01<0oooo00<0o`000?oo
o`3o00003@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0V`3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0o`0004P0oooo00@0o`000?oo
o`3oool0o`00303oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo07H0oooo00<0o`00
0?ooo`3oool0``3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00080oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?l0000K0?ooo`030?l0003oool0o`0002<0oooo0P00
0?l50?ooo`030?l0003oool0o`0002@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0:@3oool01@3o0000oooo0?ooo`3oool0o`000240oooo00<0003o0?ooo`000?l0503o
ool00`3o0000oooo0?l0000D0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o00001@3o
ool00`000?l0oooo0000o`0C0?ooo`80o`003P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0V`3oool00`000?l0oooo0000o`040?ooo`030?l0003o
ool0o`0004P0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?l0000=0?ooo`030?l0
003oool0oooo0?l0oooo?@3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00080
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l0000K0?ooo`030?l0003oool0o`0002<0
oooo0P000?l50?ooo`030?l0003oool0o`0002@0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0:@3oool0103o0000oooo0?ooo`3o000R0?ooo`030000o`3oool0003o01@0
oooo00<0o`000?ooo`3o00006`3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`2R0?ooo`030000o`3oool0003o00@0
oooo00<0o`000?ooo`3o0000B@3oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0o`0000d0
oooo00<0o`000?ooo`3oool0o`3ooolm0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3o
ool0o`000P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`0001/0oooo00<0o`000?oo
o`3o0000903oool00`000?l0oooo0?ooo`040?ooo`80o`00903oool00`000000oooo0?ooo`0J0?oo
o`00>@3oool00`000000oooo0?ooo`0Y0?ooo`040?l0003oool0oooo0?l00280oooo00<0003o0?oo
o`000?l0503oool20?l001`0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0XP3oool00`000?l0oooo0000o`040?oo
o`030?l0003oool0o`0004T0oooo0P3o000=0?ooo`80o`003P3oool00`3o0000oooo0?ooo`3o0?oo
ocd0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3o00006`3oool00`3o0000oooo0?l0000T0?ooo`030000o`3oool0
oooo00@0oooo0P3o000T0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
02T0oooo00@0o`000?ooo`3oool0o`008P3oool00`000?l0oooo0000o`0D0?ooo`80o`00703oool0
0`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`2R0?ooo`80003o1@3oool00`3o0000oooo0?l000190?ooo`80o`003@3oool2
0?l00?l0ooooCP3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00080oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?l0000K0?ooo`030?l0003oool0o`0002@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo02T0oooo00@0o`000?ooo`3oool0o`008P3oool00`000?l0oooo0000
o`0E0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo0<P0oooo0P000?l50?ooo`030?l0003oool0o`0004X0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?oood`0oooo00<0003o0?ooo`3oool01P3o
ool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
6P3oool00`3o0000oooo0?l0000T0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003o
ool0o`000280oooo00<0003o0?ooo`000?l05@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003o
ool0o`0000H0oooo00<0003o0?ooo`3oool0gP3oool20000o`D0oooo00<0o`000?ooo`3o0000BP3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0ooooC03oool00`000?l0oooo0?oo
o`060?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02X0oooo00<0
o`000?ooo`3o00008`3oool20000oaD0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?l0
003X0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o0000F@3oool00`3o0000oooo0?oo
o`3o0?oood`0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0
003oool0oooo02<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0:P3o
ool00`3o0000oooo0?l0000S0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool06P3o
ool00`3o0000oooo0?l0003X0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o0000F@3o
ool00`3o0000oooo0?ooo`3o0?oood`0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?oo
o`3o00020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool0:P3oool00`3o0000oooo0?l0000S0?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool06P3oool00`3o0000oooo0?l0003X0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3o0000o`3ooonX0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0o`00
0P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
:P3oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000:03o
ool20?l002@0oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?l0003X0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooonW0?ooo`030000o`3oool0oooo00H0oooo00@0
003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo02X0oooo
00<0o`000?ooo`3oool07`3oool5000001`0oooo000i0?ooo`030000003oool0oooo02/0oooo00<0
o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0o`000>P0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooojL0oooo00<0003o0?ooo`3oool01P3o
ool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0
D03oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?l0003_0?ooo`030?l0003o
ool0oooo0?l0ooooY`3oool00`000?l0oooo0?ooo`060?ooo`060000o`3oool0oooo0?l0003oool0
o`00OP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0[0?ooo`030?l0
003oool0oooo05L0oooo00<0o`000?ooo`3oool0kP3oool00`3o0000oooo0?ooo`3o0?ooojL0oooo
00<0003o0?ooo`3oool01P3oool01P000?l0oooo0?ooo`3o0000oooo0?l007h0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool0Q@3oool00`3o0000oooo0?ooo`3^0?ooo`03
0?l0003oool0oooo0?l0ooooZ03oool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?oo
o`3o0000oooo0?l0001n0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
08D0oooo00<0o`000?ooo`3oool0kP3oool00`3o0000oooo0?ooo`3o0?ooojP0oooo00<0003o0?oo
o`3oool0103oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000OP3oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`250?ooo`030?l0003oool0oooo0>h0oooo00<0o`00
0?ooo`3oool0o`3ooonX0?ooo`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0?l0
003oool0o`0007h0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0Q@3o
ool00`3o0000oooo0?ooo`3^0?ooo`030?l0003oool0oooo0?l0ooooZ03oool00`000?l0oooo0?oo
o`040?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0001n0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo08D0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooiX0oooo
00<0003o0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000OP3oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`250?ooo`030?l0003oool0oooo0?l0
ooooo`3ooonJ0?ooo`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0
o`0007h0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0Q@3oool00`3o
0000oooo0?ooo`3o0?ooool0ooooVP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo0P3o001n0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?ooool0
oooo8@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P3o001j0?ooo`D0
0000703oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo8`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P3o001n0?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`80o`00OP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooolS0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo01X0oooo000i0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo07d0oooo00<000000?ooo`3oool06P3oool003T0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo8`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolS0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooob<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo07d0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo8`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooob@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`220?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?ooob@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`220?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?ooool0oooo8P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07h0oooo1@00000L0?ooo`00>@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0P`3o
ool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0J0?ooo`007P3oool2000000@0oooo0P0000040?ooo`800000
3@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolT0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0J0?ooo`007@3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
oooo903oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo08<0oooo00<000000?ooo`3o
ool06P3oool001d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0:0?ooo`L0
0000o`3ooooo0?ooool0oooo803oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo07d0
oooo1`00000L0?ooo`007@3oool010000000oooo0?ooo`0000090?ooo`8000003@3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`00
0000oooo0?ooo`0J0?ooo`007@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool01@000?l0oooo0?ooo`3oool0
003o08D0oooo00<000000?ooo`3oool06P3oool001h0oooo0P00000:0?ooo`<00000303oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?oo
o`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?oo
o`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`050000o`3oool0oooo0?ooo`000?l0Q@3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?oo
o`050000o`3oool0oooo0?ooo`000?l0Q@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolU0?ooo`040000o`3oool0oooo0000ohH0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool01000
0?l0oooo0?ooo`000?n60?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?oo
ool0oooo8`3oool010000?l0oooo0?ooo`000?n20?ooo`D00000703oool003T0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo9@3oool010000?l0oooo0?ooo`000?n60?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobD0oooo00@0003o0?oo
o`3oool0003oQP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolU0?ooo`040000o`3oool0oooo0000ohH0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9@3oool010000?l0oooo0?ooo`000?n6
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
obH0oooo00<0003o0?ooo`000?l0QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3o
ool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo
0000o`260?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooobH0oooo00<0003o0?ooo`000?l0QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool00`00
0?l0oooo0000o`260?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?ooool0
oooo903oool00`000?l0oooo0000o`220?ooo`D00000703oool003T0oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo0000o`260?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0003o0?ooo`000?l0QP3o
ool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolV
0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo9P3oool00`000?l0oooo0000o`260?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobH0oooo00<0003o0?ooo`00
0?l0QP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooolV0?ooo`030000o`3oool0003o08H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool20000ohL0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9P3oool20000ohL0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo9`3oool00`00
0?l0oooo0?ooo`250?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooobL0oooo00<0003o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool500000?l0ooooo`3ooooo0?ooobD0oooo00<0003o0?ooo`3oool0P@3oool5000001`0oooo
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobL0oooo00<0003o0?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolW
0?ooo`030000o`3oool0oooo08D0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo9`3oool00`000?l0oooo0?ooo`250?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooobL0oooo00<0003o0?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo07H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool06P3oool003T0ooooo`00003o00000?l00000/`00000L0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {253.313, 48.4375}} -> {-15.0969, \
0.228665, 0.132742, 0.00178722}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in A minor, Op. 7, No. 2 performed by Friedman 1930", \
"Subsection"],

Cell[CellGroupData[{

Cell["Manually Corrected Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.0834875 0.618033 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04012 -18 -4.5 ]
[-0.0125 .04012 0 4.5 ]
[-0.0125 .10192 -18 -4.5 ]
[-0.0125 .10192 0 4.5 ]
[-0.0125 .16373 -18 -4.5 ]
[-0.0125 .16373 0 4.5 ]
[-0.0125 .22553 -18 -4.5 ]
[-0.0125 .22553 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04012 m
.00625 .04012 L
s
[(0.2)] -0.0125 .04012 1 0 Mshowa
0 .10192 m
.00625 .10192 L
s
[(0.3)] -0.0125 .10192 1 0 Mshowa
0 .16373 m
.00625 .16373 L
s
[(0.4)] -0.0125 .16373 1 0 Mshowa
0 .22553 m
.00625 .22553 L
s
[(0.5)] -0.0125 .22553 1 0 Mshowa
.125 Mabswid
0 .05248 m
.00375 .05248 L
s
0 .06484 m
.00375 .06484 L
s
0 .0772 m
.00375 .0772 L
s
0 .08956 m
.00375 .08956 L
s
0 .11428 m
.00375 .11428 L
s
0 .12664 m
.00375 .12664 L
s
0 .139 m
.00375 .139 L
s
0 .15136 m
.00375 .15136 L
s
0 .17609 m
.00375 .17609 L
s
0 .18845 m
.00375 .18845 L
s
0 .20081 m
.00375 .20081 L
s
0 .21317 m
.00375 .21317 L
s
0 .02776 m
.00375 .02776 L
s
0 .0154 m
.00375 .0154 L
s
0 .00304 m
.00375 .00304 L
s
0 .23789 m
.00375 .23789 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .04012 m
1 .04012 L
s
.99375 .10192 m
1 .10192 L
s
.99375 .16373 m
1 .16373 L
s
.99375 .22553 m
1 .22553 L
s
.125 Mabswid
.99625 .05248 m
1 .05248 L
s
.99625 .06484 m
1 .06484 L
s
.99625 .0772 m
1 .0772 L
s
.99625 .08956 m
1 .08956 L
s
.99625 .11428 m
1 .11428 L
s
.99625 .12664 m
1 .12664 L
s
.99625 .139 m
1 .139 L
s
.99625 .15136 m
1 .15136 L
s
.99625 .17609 m
1 .17609 L
s
.99625 .18845 m
1 .18845 L
s
.99625 .20081 m
1 .20081 L
s
.99625 .21317 m
1 .21317 L
s
.99625 .02776 m
1 .02776 L
s
.99625 .0154 m
1 .0154 L
s
.99625 .00304 m
1 .00304 L
s
.99625 .23789 m
1 .23789 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .13633 m
.0423 .10386 L
.05155 .05588 L
.0608 .07927 L
.07004 .11748 L
.07929 .0936 L
.08853 .09823 L
.09778 .13226 L
.10703 .11135 L
.11627 .09943 L
.12552 .01719 L
.13477 .06244 L
.14401 .14664 L
.15326 .10738 L
.16251 .0674 L
.17175 .14835 L
.181 .10044 L
.19025 .1258 L
.19949 .12507 L
.20874 .12119 L
.21798 .18414 L
.22723 .13929 L
.23648 .13814 L
.24572 .09193 L
.25497 .14181 L
.26422 .09521 L
.27346 .0466 L
.28271 .10399 L
.29196 .11333 L
.3012 .11631 L
.31045 .10308 L
.31969 .13808 L
.32894 .09795 L
.33819 .13319 L
.34743 .12116 L
.35668 .12882 L
.36593 .15087 L
.37517 .13853 L
.38442 .11966 L
.39367 .09038 L
.40291 .13543 L
.41216 .0709 L
.42141 .05419 L
.43065 .09702 L
.4399 .14116 L
.44914 .06914 L
.45839 .1533 L
.46764 .1234 L
.47688 .1778 L
.48613 .1261 L
Mistroke
.49538 .1053 L
.50462 .1147 L
.51387 .10942 L
.52312 .09309 L
.53236 .09569 L
.54161 .06817 L
.55086 .11416 L
.5601 .10084 L
.56935 .10062 L
.57859 .05884 L
.58784 .13755 L
.59709 .108 L
.60633 .07442 L
.61558 .06375 L
.62483 .11074 L
.63407 .12802 L
.64332 .10686 L
.65257 .1137 L
.66181 .10724 L
.67106 .0945 L
.68031 .08252 L
.68955 .07369 L
.6988 .14614 L
.70804 .13081 L
.71729 .13003 L
.72654 .0609 L
.73578 .14769 L
.74503 .11517 L
.75428 .05807 L
.76352 .06799 L
.77277 .18961 L
.78202 .15601 L
.79126 .12214 L
.80051 .08501 L
.80975 .12233 L
.819 .11103 L
.82825 .11171 L
.83749 .00595 L
.84674 .18706 L
.85599 .0683 L
.86523 .05833 L
.87448 .10553 L
.88373 .11497 L
.89297 .10594 L
.90222 .10637 L
.91147 .09489 L
.92071 .18602 L
.92996 .07303 L
.9392 .01535 L
.94845 .10408 L
Mistroke
.9577 .13315 L
.96694 .09993 L
.97619 .05375 L
Mfstroke
0 1 0 r
.03306 .10885 m
.0423 .09418 L
.05155 .19953 L
.0608 .14965 L
.07004 .10343 L
.07929 .15127 L
.08853 .14596 L
.09778 .16223 L
.10703 .13067 L
.11627 .10593 L
.12552 .20339 L
.13477 .11775 L
.14401 .08462 L
.15326 .1334 L
.16251 .14742 L
.17175 .11857 L
.181 .12036 L
.19025 .10192 L
.19949 .10307 L
.20874 .08656 L
.21798 .12532 L
.22723 .09168 L
.23648 .08306 L
.24572 .09261 L
.25497 .14862 L
.26422 .12587 L
.27346 .18295 L
.28271 .07873 L
.29196 .09323 L
.3012 .10941 L
.31045 .14572 L
.31969 .12538 L
.32894 .11761 L
.33819 .10168 L
.34743 .10423 L
.35668 .09258 L
.36593 .13892 L
.37517 .10857 L
.38442 .10657 L
.39367 .08914 L
.40291 .15464 L
.41216 .13247 L
.42141 .17466 L
.43065 .10262 L
.4399 .09281 L
.44914 .13941 L
.45839 .12328 L
.46764 .08654 L
.47688 .12798 L
.48613 .12931 L
Mistroke
.49538 .10961 L
.50462 .10359 L
.51387 .10635 L
.52312 .13049 L
.53236 .11322 L
.54161 .11111 L
.55086 .15703 L
.5601 .12554 L
.56935 .12726 L
.57859 .11796 L
.58784 .12071 L
.59709 .1258 L
.60633 .17289 L
.61558 .14576 L
.62483 .23429 L
.63407 .11703 L
.64332 .10198 L
.65257 .1011 L
.66181 .10418 L
.67106 .11782 L
.68031 .10282 L
.68955 .07674 L
.6988 .12209 L
.70804 .1018 L
.71729 .11964 L
.72654 .11122 L
.73578 .11977 L
.74503 .09877 L
.75428 .15416 L
.76352 .16046 L
.77277 .12153 L
.78202 .11444 L
.79126 .09025 L
.80051 .10698 L
.80975 .11638 L
.819 .12014 L
.82825 .0871 L
.83749 .04495 L
.84674 .11264 L
.85599 .10923 L
.86523 .18654 L
.87448 .13102 L
.88373 .06611 L
.89297 .14373 L
.90222 .13785 L
.91147 .1109 L
.92071 .09849 L
.92996 .09501 L
.9392 .24768 L
.94845 .08828 L
Mistroke
.9577 .08141 L
.96694 .11369 L
.97619 .17111 L
Mfstroke
0 0 1 r
.03306 .12239 m
.0423 .16953 L
.05155 .11216 L
.0608 .13865 L
.07004 .14665 L
.07929 .12269 L
.08853 .12338 L
.09778 .07308 L
.10703 .12555 L
.11627 .16221 L
.12552 .14699 L
.13477 .18738 L
.14401 .13631 L
.15326 .12679 L
.16251 .15275 L
.17175 .10065 L
.181 .14677 L
.19025 .13985 L
.19949 .13943 L
.20874 .15982 L
.21798 .05811 L
.22723 .1366 L
.23648 .14638 L
.24572 .18303 L
.25497 .07715 L
.26422 .14649 L
.27346 .13802 L
.28271 .18485 L
.29196 .16101 L
.3012 .14185 L
.31045 .11877 L
.31969 .10411 L
.32894 .15202 L
.33819 .1327 L
.34743 .14218 L
.35668 .14617 L
.36593 .07778 L
.37517 .12047 L
.38442 .14133 L
.39367 .18805 L
.40291 .0775 L
.41216 .1642 L
.42141 .13872 L
.43065 .16792 L
.4399 .1336 L
.44914 .15902 L
.45839 .09099 L
.46764 .15763 L
.47688 .06179 L
.48613 .11216 L
Mistroke
.49538 .15266 L
.50462 .14928 L
.51387 .15181 L
.52312 .14398 L
.53236 .15866 L
.54161 .18829 L
.55086 .09638 L
.5601 .1412 L
.56935 .13969 L
.57859 .19077 L
.58784 .10931 L
.59709 .13378 L
.60633 .12026 L
.61558 .15806 L
.62483 .02254 L
.63407 .12252 L
.64332 .15872 L
.65257 .15276 L
.66181 .15615 L
.67106 .15526 L
.68031 .18224 L
.68955 .21714 L
.6988 .09934 L
.70804 .13496 L
.71729 .11791 L
.72654 .19545 L
.73578 .10011 L
.74503 .15364 L
.75428 .15534 L
.76352 .13912 L
.77277 .05643 L
.78202 .09712 L
.79126 .15518 L
.80051 .17558 L
.80975 .12887 L
.819 .1364 L
.82825 .16876 L
Mfstroke
.82825 .16876 m
.83333 .25 L
s
.83997 .25 m
.84674 .06787 L
.85599 .19004 L
.86523 .1227 L
.87448 .13102 L
.88373 .18649 L
.89297 .1179 L
.90222 .12336 L
.91147 .16178 L
.92071 .08306 L
.92996 .19953 L
.9392 .10454 L
.94845 .17521 L
.9577 .15301 L
.96694 .15395 L
.97619 .14271 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00C`3oool200000:P0oooo100000030?ooo`800000Y`3oool30000
0080oooo0P00002V0?ooo`<00000103oool200000:H0oooo0P0000040?ooo`800000XP3oool50000
0080oooo0P0000040?ooo`800000A`3oool004h0oooo00@000000?ooo`3oool00000Y`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000Y03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
A03oool004h0oooo00@000000?ooo`3oool00000Z03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:@0oooo1@0000001@3oool000000?ooo`3oool000000:D0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`140?ooo`00CP3oool010000000oooo0?ooo`00002Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool3000000<0oooo00@000000?ooo`3o
ool00000Y@3oool2000000<0oooo00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`140?ooo`00CP3o
ool010000000oooo0?ooo`00002W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000:H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`140?ooo`00C`3oool200000:T0oooo0P0000040?oo
o`800000Y`3oool2000000<0oooo0P00002W0?ooo`<000000`3oool200000:H0oooo0P0000040?oo
o`800000X`3oool2000000@0oooo0P0000040?ooo`800000A`3oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03T0ooooo`00003o00000?l00000/`00000L0?ooo`00>@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo000i0?ooo`D000004P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3o
ool6000001`0oooo000i0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`1U0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`3o0000oooo0?ooo`2F0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0oooo00<0
o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolF0?ooo`030?l0003oool0oooo09H0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`3o0000oooo0?ooo`2F0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooaH0
oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`80o`00V03oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`80o`00V03oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool500000?l0ooooo`3ooooo0?oooa<0oooo0P3o001O0?ooo`030?l0003oool0
oooo0380oooo1@00000L0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?oo
o`80o`00G`3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo01X0oooo000i0?ooo`03
0000003oool0oooo07@0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooid0oooo0P3o001O0?ooo`03
0?l0003oool0oooo03H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
M03oool00`3o0000oooo0?ooo`3o0?ooool0ooooW@3oool00`3o0000oooo0?l0001N0?ooo`030?l0
003oool0oooo03H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0M03o
ool00`3o0000oooo0?ooo`3o0?ooool0ooooW@3oool00`3o0000oooo0?l0001M0?ooo`80o`00>03o
ool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1d0?ooo`80o`00o`3ooooo
0?oooih0oooo00<0o`000?ooo`3o0000G@3oool20?l003P0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0M03oool20?l00?l0ooooo`3ooonN0?ooo`030?l0003oool0o`00
05d0oooo00<0o`000?ooo`3o0000=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`1c0?ooo`030?l0003oool0o`000?l0ooooe@3oool00`000?l0oooo0?ooo`350?ooo`03
0?l0003oool0o`0005d0oooo00<0o`000?ooo`3o0000=`3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`1c0?ooo`030?l0003oool0o`000?l0ooooe@3oool00`000?l0oooo
0?ooo`350?ooo`030?l0003oool0o`0005d0oooo00<0o`000?ooo`3o0000=`3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1c0?ooo`030?l0003oool0o`000?l0ooooe@3o
ool00`000?l0oooo0?ooo`340?ooo`040?l0003oool0oooo0?l005d0oooo00<0o`000?ooo`3o0000
=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1c0?ooo`030?l0003o
ool0o`000?l0ooooe@3oool00`000?l0oooo0?ooo`340?ooo`040?l0003oool0oooo0?l005`0oooo
00@0o`000?ooo`3oool0o`00=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo
0?ooo`1c0?ooo`040?l0003oool0oooo0?l00?l0ooooe03oool00`000?l0oooo0?ooo`340?ooo`04
0?l0003oool0oooo0?l005`0oooo00@0o`000?ooo`3oool0o`00=`3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool500000740oooo00@0o`000?ooo`3oool0o`00o`3ooooD0?ooo`030000o`3oool0
oooo0<@0oooo00@0o`000?ooo`3oool0o`00G03oool0103o0000oooo0?ooo`3o000c0?ooo`D00000
703oool003T0oooo00<000000?ooo`3oool0L`3oool0103o0000oooo0?ooo`3o003o0?ooom@0oooo
0P000?o50?ooo`040?l0003oool0oooo0?l005`0oooo00@0o`000?ooo`3oool0o`00=`3oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1c0?ooo`040?l0003oool0oooo0?l0
0?l0ooooe03oool20000olD0oooo00@0o`000?ooo`3oool0o`00G03oool0103o0000oooo0?ooo`3o
000g0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0780oooo00D0o`00
0?ooo`3oool0oooo0?l0003o0?ooom<0oooo00<0003o0?ooo`000?l0a@3oool0103o0000oooo0?oo
o`3o001L0?ooo`040?l0003oool0oooo0?l003L0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo
d03oool00`000?l0oooo0000o`350?ooo`040?l0003oool0oooo0?l005/0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000
003oool0oooo0780oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooom00oooo
00<0003o0?ooo`000?l0a@3oool0103o0000oooo0?ooo`3o001K0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo
0?ooo`1b0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oooo@0?ooo`030000
o`3oool0003o0<D0oooo00@0o`000?ooo`3oool0o`00F`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo03@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
LP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0ooood03oool00`000?l0oooo
0000o`350?ooo`040?l0003oool0oooo0?l005/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0d0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0780oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooom00oooo00<0003o0?ooo`000?l0
a03oool01@3o0000oooo0?ooo`3oool0o`0005/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0d0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0780oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooll0oooo00<0003o0?ooo`000?l0
a03oool01@3o0000oooo0?ooo`3oool0o`0005/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0d0?ooo`030000003oool0oooo01X0oooo000N0?ooo`800000103oool2000000<0oooo
1000000<0?ooo`030000003oool0oooo0780oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`3o0?oooll0oooo00<0003o0?ooo`000?l0a03oool01@3o0000oooo0?ooo`3oool0o`0005X0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo01X0
oooo000M0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1b0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3oooo?0?ooo`04
0000o`3oool0oooo0000ol<0oooo00D0o`000?ooo`3oool0oooo0?l0001J0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`007@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo1`00001]0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0o`3oooo?0?ooo`040000o`3oool0oooo0000ol<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0;P3oool7000001`0oooo000M0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0o`3oooo?0?ooo`040000o`3oool0oooo0000ol<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
=03oool00`000000oooo0?ooo`0J0?ooo`007@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo0?l0ooooc`3oool010000?l0oooo0?ooo`000?o30?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
03@0oooo00<000000?ooo`3oool06P3oool001h0oooo0P00000:0?ooo`8000003@3oool00`000000
oooo0?ooo`1a0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3oooo>0?ooo`04
0000o`3oool0oooo0000ol<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1G0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?oo
o`00>@3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0o`3oooo>0?ooo`040000o`3oool0oooo0000ol<0oooo00H0o`000?ooo`3oool00?l00?ooo`3o
001H0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0o`3oooo>0?ooo`040000o`3oool0oooo0000ol<0oooo00H0o`000?ooo`3oool00?l0
0?ooo`3o001H0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0P`3oool00`3o0000oooo0?ooo`3o0?ooodP0oooo00@0003o0?ooo`3oool0
003o``3oool01P3o0000oooo0?ooo`00o`00oooo0?l005P0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
0740oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`230?ooo`030?l0003oool0oooo
0?l0ooooA`3oool01@000?l0oooo0?ooo`3oool0003o0<80oooo00<0o`000?ooo`3oool00P00o`00
0`3oool0o`000?ooo`1G0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool0PP3oool00`3o0000oooo0?ooo`3o0?ooodL0oooo00D0003o0?oo
o`3oool0oooo0000o`320?ooo`030?l0003oool0oooo00800?l000<0oooo0?l0003oool0E`3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0840oooo0P3o003o0?ooodT0oooo00D0003o0?ooo`3oool0oooo0000o`320?ooo`070?l0003oool0
oooo003o003oool00?l00?l0001H0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0P@3oool00`3o0000oooo0?l0003o0?ooodP0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2o0?ooo`070?l0003oool0oooo003o003oool0
0?l00?l0001G0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0J0?ooo`00>@3oool5000006h0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`210?ooo`030?l0003oool0o`000?l0ooooB03oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0;l0oooo00<0o`000?ooo`00o`000P3oool00`00o`00o`000?ooo`1F0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool0;`3oool5000001`0oooo000i0?ooo`030000003o
ool0oooo0700oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`210?ooo`030?l0003o
ool0o`000?l0ooooB03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0;l0oooo00<0
o`000?ooo`00o`000P3oool00`00o`00o`000?ooo`1F0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`1`
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0P03oool00`3o0000oooo0?l0002:
0?ooo`030?l0003oool0oooo0;X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2o
0?ooo`030?l0003oool00?l00080oooo00<00?l00?l0003oool0EP3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool0O`3oool0103o0000oooo0?ooo`3o00290?ooo`80o`00_03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0;l0oooo00<0o`000?ooo`00o`000P3oool00`00o`00o`000?ooo`1F
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02h0oooo00<0o`000?oo
o`3oool0?`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo07l0oooo00@0o`000?oo
o`3oool0o`00R@3oool20?l00;`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`26
0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`00o`000P3oool00`00o`00o`000?ooo`1F
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02h0oooo00<0o`000?oo
o`3oool0?`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo07l0oooo00D0o`000?oo
o`3oool0oooo0?l000270?ooo`040?l0003oool0oooo0?l00;/0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`260?ooo`030000o`3oool0oooo03H0oooo00<0o`00003o003oool00P3o
ool00`00o`00o`000?ooo`1E0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo02h0oooo0P3o000o0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`0_0?ooo`050?l0003oool0oooo0?ooo`3o0000Q`3oool0103o0000oooo0?oo
o`3o002B0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1d0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0=P3oool00`3o00000?l0
0?ooo`030?ooo`03003o003oool0oooo01D0oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0o`0003l0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo02l0oooo00D0
o`000?ooo`3oool0oooo0?l000260?ooo`050?l0003oool0oooo0?ooo`3o0000TP3oool00`3o0000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0M03oool20?l00100
oooo0P000?lf0?ooo`030?l0003oool00?l000@0oooo00<00?l00?ooo`3oool0503oool20?l003h0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo01D0
oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0;@3oool0103o0000oooo
0?ooo`3o000n0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0^0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0Q03oool01@3o0000
oooo0?ooo`3oool0o`000980oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo05X0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?l0000?0?oo
o`80003o=P3oool00`3o0000oooo003o00040?ooo`03003o003oool0oooo01<0oooo00<0o`000?oo
o`3o0000?P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01X0oooo00<0o`000?oo
o`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0]0?ooo`04
0?l0003oool0oooo0?l003h0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1<0?oo
o`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`230?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`1L0?oo
o`80o`00:03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05T0oooo00<0o`000?oo
o`3oool05`3oool0103o0000oooo0?ooo`3o000=0?ooo`030000o`3oool0003o03H0oooo00<0o`00
003o003oool0103oool00`00o`00oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`3o0000?@3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0]0?ooo`040?l0003oool0
oooo0?l003h0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo02h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`220?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1L0?ooo`80o`00:03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05T0oooo00<0o`000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`000?l0=P3o
ool00`3o00000?l00?ooo`040?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0k0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo02d0oooo00D0o`000?ooo`3oool0oooo0?l0000m0?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`3oool0C03oool20000obl0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`210?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`1L0?ooo`030?l0003oool0o`000240oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo05T0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`000?l0=P3oool00`3o00000?l00?oo
o`040?ooo`03003o003o0000oooo0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0j0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000:P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo03/0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1;
0?ooo`030000o`3oool0003o02l0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`20
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0;`3oool20000oed0oooo00<0o`00
0?ooo`3o0000803oool20?l000@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1H
0?ooo`80o`00603oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00@0003o
0?ooo`3oool0003o=@3oool00`3o00000?l00?ooo`040?ooo`03003o003o0000oooo00l0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0B0?ooo`D00000703oool003T0oooo00<00000
0?ooo`3oool0;03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo03X0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`1;0?ooo`030000o`3oool0003o02h0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`200?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0;`3oool20000oe`0oooo00@0o`000?ooo`3oool0o`007`3oool00`3o0000oooo0?l0
00040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0F03oool00`3o0000oooo0?l0
000G0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo0?oo
o`000?le0?ooo`03003o003oool0oooo00@0oooo00<00?l00?l0003oool03P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01P0oooo00<0
o`000?ooo`3oool0<03oool00`000?l0oooo0000o`0^0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0O`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02h0oooo00<0
003o0?ooo`000?l0G03oool0103o0000oooo0?ooo`3o000N0?ooo`050?l0003oool0oooo0?ooo`3o
00000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05P0oooo00<0o`000?ooo`3o
00005`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3o
ool0003o=@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00`0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo02X0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo01H0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo0300oooo00<0003o0?ooo`000?l0;P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo07l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000o`3oool0003o03/0oooo00<0o`000?ooo`3oool07P3oool0103o0000oooo0?ooo`3o000M0?oo
o`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0
oooo05P0oooo00<0o`000?ooo`3o00005`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00D0oooo00@0003o0?ooo`3oool0003o=@3oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo00`0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo01P0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0<03oool0
0`000?l0oooo0000o`0^0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0OP3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0000o`0k0?ooo`030?l0003oool0oooo01h0oooo00@0o`000?ooo`3oool0o`00703o
ool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`000?l0oooo
0?ooo`1H0?ooo`030?l0003oool0o`0001H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l0=03oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
>03oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01H0oooo0P3o000b0?ooo`030000
o`3oool0003o02h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1m0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0003o03X0oooo0P3o000P0?ooo`040?l0003oool0oooo0?l001`0oooo00<0o`000?ooo`3o
ool00`3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool0F03oool00`3o
0000oooo0?l0000F0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0380oooo00<00?l00?ooo`3oool01@3oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`0;0?ooo`800?l0:`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
01L0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0[0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0=`3oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo01H0oooo0P3o000b0?ooo`030000o`3oool0003o02d0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1l0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0F0?ooo`040000o`3oool0oooo0000
ocT0oooo00<0o`000?ooo`3o00007P3oool01@3o0000oooo0?ooo`3oool0o`0001/0oooo00<0o`00
0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool0F03o
ool00`3o0000oooo0?l0000F0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0340oooo00<00?l00?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool00?l002X0oooo00<0o`000?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo03L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0
o`000340oooo00@0003o0?ooo`3oool0003o;03oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo07`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo01H0oooo00@0003o0?ooo`3oool0003o>@3oool00`3o0000oooo0?l0000N0?ooo`050?l0
003oool0oooo0?ooo`3o00006P3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?oo
o`000?l01P3oool00`000?l0oooo0?ooo`1G0?ooo`040?l0003oool0oooo0?l001H0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0<@3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<00?l0
0?ooo`00o`00:P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01L0oooo00<0o`00
0?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0[0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?l0000a0?oo
o`040000o`3oool0oooo0000ob`0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1l
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool04P3oool20?l001P0oooo00@0003o
0?ooo`3oool0003o>03oool0103o0000oooo0?ooo`3o000N0?ooo`050?l0003oool0oooo0?ooo`3o
00006@3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?oo
o`3oool0=@3oool00`3o0000oooo0?ooo`0N0?ooo`040?l0003oool0oooo0?l001H0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0<@3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<00?l0
0?ooo`00o`00:P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01L0oooo00<0o`00
0?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0[0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool05@3oool0103o0000oooo0?ooo`3o000a
0?ooo`040000o`3oool0oooo0000ob`0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`1l0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?l0
000G0?ooo`040000o`3oool0oooo0000ocP0oooo00@0o`000?ooo`3oool0o`007P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0203oool0103o0000
oooo0?ooo`000?l70?ooo`030000o`3oool0oooo03@0oooo0P3o000P0?ooo`040?l0003oool0oooo
0?l001H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0<03oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00X0oooo00<00?l00?ooo`00o`00:P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo01H0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool05@3oool0103o
0000oooo0?ooo`3o000`0?ooo`050000o`3oool0oooo0?ooo`000?l0;03oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo07/0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0B0?ooo`030?l0003oool0o`0001L0oooo00@0003o0?ooo`3oool0003o>03oool0103o0000oooo
0?ooo`3o000M0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3oool00`3o0000
oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool0<`3oool00`3o
0000oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00005@3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0_
0?ooo`03003o003o0000oooo00L0oooo00<0o`00003o003oool00P3oool20000o`H0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool00?l002X0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo01P0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0oooo0200oooo0P000?lC0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool05@3oool0103o0000oooo0?ooo`3o000`0?ooo`050000o`3oool0oooo0?ooo`000?l0;03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo07X0oooo00<0o`000?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0o`0001L0oooo00D0003o0?ooo`3oool0oooo
0000o`0f0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo
0?ooo`000?l70?ooo`030000o`3oool0oooo0380oooo00@0o`000?ooo`3oool00?l0803oool01@3o
0000oooo0?ooo`3oool0o`0001@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool00`00o`00o`000?ooo`07
0?ooo`030?l00000o`00oooo0080oooo0P000?l60?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`00o`00oooo003o000Z0?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo000i0?oo
o`D00000:03oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0200oooo00<0003o0?oo
o`000?l04@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01@0oooo00@0o`000?oo
o`3oool0o`00<03oool01@000?l0oooo0?ooo`3oool0003o0200oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo04l0oooo00<0003o0?ooo`3oool0803o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool04P3o
ool00`3o0000oooo0?l0000F0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=03o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o
1`3oool00`000?l0oooo0?ooo`0a0?ooo`060?l0003oool0oooo0?ooo`00o`00o`007`3oool01@3o
0000oooo0?ooo`3oool0o`0001@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool00`00o`00o`000?ooo`07
0?ooo`030?l00000o`00oooo0080oooo0P000?l60?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool02@3oool00`00o`00oooo003o000Z0?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0D0?ooo`D00000703oool003T0oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?oo
o`000?l04@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01<0oooo00D0o`000?oo
o`3oool0oooo0?l0000`0?ooo`050000o`3oool0oooo0?ooo`000?l0803oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo003o001=0?ooo`030000
o`3oool0oooo0200oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo0140oooo00<0o`000?ooo`3o00005P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo03@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0003o00L0oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`02003o00030?l0
003oool0oooo01d0oooo00D0o`000?ooo`3oool0oooo0?l0000D0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02l0
oooo00<00?l00?l0003oool01`3oool00`3o00000?l00?ooo`020?ooo`80003o1P3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo00@00?l00?ooo`3oool00?l0:P3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0603oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0000o`0A0?ooo`030?l0003oool0oooo00h0
oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo0?ooo`3oool0o`000300oooo00D0003o0?oo
o`3oool0oooo0000o`0P0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
103o0000oooo0?ooo`3oool2003o04`0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?l0
000F0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?oo
o`0`0?ooo`070?l0003oool0oooo0?ooo`00o`00oooo003o000O0?ooo`050?l0003oool0oooo0?oo
o`3o0000503oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0^0?ooo`03003o003o0000oooo00L0oooo00<0o`00003o
003oool00P3oool20000o`H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?oo
o`05003o003oool0oooo0?ooo`00o`00:03oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool07`3oool00`00
0?l0oooo0000o`0A0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool04`3oool01@3o
0000oooo0?ooo`3oool0o`000300oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0M
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o
ool2003o04`0oooo0P000?lQ0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0o`0001H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool02`3o
ool00`3o0000oooo0000o`070?ooo`030000o`3oool0oooo02l0oooo00<0o`000?ooo`3oool00P3o
ool00`00o`00oooo003o000N0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0o`0000P0oooo00<0o`00003o003oool00P3o
ool20000o`H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`05003o003o
ool0oooo0?ooo`00o`00:03oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01@0oooo
00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool07P3oool010000?l0oooo0?oo
o`000?lA0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo
0?ooo`3oool0o`000300oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool01`3o0000oooo0?ooo`3oool00?l0
0?ooo`00o`00B`3oool20000ob40oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0100oooo00@0o`000?ooo`3oool0o`005P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0H0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?oo
o`020?ooo`04003o003oool0oooo003o01h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo02d0oooo00<00?l00?ooo`3o0000203oool00`3o00000?l0
0?ooo`020?ooo`80003o1P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo
00D00?l00?ooo`3oool0oooo003o000X0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o
ool0203oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3o
ool06P3oool003T0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo01d0oooo00@0003o0?ooo`3oool0003o4@3oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0180oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0?0?ooo`80
003o203oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo003o0080oooo00<00?l00?oo
o`3oool0A`3oool00`000?l0oooo0000o`0Q0?ooo`80003o1@3oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0100oooo00@0o`000?ooo`3oool0o`005P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0H
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`03
0?ooo`04003o003oool0oooo003o01h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo02d0oooo00<00?l00?l0003oool0203oool00`3o00000?l00?oo
o`020?ooo`80003o1P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00D0
0?l00?ooo`3oool0oooo003o000P0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`060?ooo`<00?l02`3oool00`3o0000oooo0?ooo`0I0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0M0?ooo`050000o`3oool0oooo0?ooo`000?l0403oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0]0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo
003o000?0?ooo`030000o`3oool0003o00P0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo
0?ooo`00o`020?ooo`03003o003oool0oooo04L0oooo00<0003o0?ooo`000?l0803oool00`000?l0
oooo0000o`050?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool0103o0000
oooo0?ooo`3o000F0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0<@3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<0o`000000o`3oool0203oool00`00
0?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo00@0oooo00@00?l00?ooo`3oool00?l07P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0;@3oool0
0`00o`00o`000?ooo`080?ooo`070?l0003oool00?l00?ooo`000?l0oooo0000o`060?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool01`3oool01@00o`00oooo0?ooo`3oool00?l00200
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00D0
oooo00D00?l00?ooo`3oool0oooo003o000:0?ooo`030?l0003oool0oooo01T0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo01d0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00T0oooo00D00?l00?ooo`3oool0oooo003o000>0?ooo`030000o`3oool0003o00P0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo003o00040?ooo`03003o003oool0oooo04H0oooo00@0003o
0?ooo`3oool0003o7`3oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0o`0001D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0
103oool01P00o`00oooo0?ooo`3oool0o`00003o01d0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool05`3oool00`00
o`00oooo0?l000090?ooo`070?l0003oool00?l00?ooo`000?l0oooo0000o`060?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool01`3oool01@00o`00oooo0?ooo`3oool00?l00200oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo
0P00o`040?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00d0oooo00<0
o`000?ooo`3oool07@3oool01@000?l0oooo0?ooo`3oool0003o00l0oooo00<0o`000?ooo`3oool0
403oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
2`3oool00`000?l0oooo0000o`080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`00o`00
103oool00`00o`00oooo0?ooo`160?ooo`040000o`3oool0oooo0000oal0oooo00<0003o0?ooo`00
0?l01@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00D0o`000?ooo`3o
ool0oooo0?l0000>0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0103oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo01/0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool05`3oool00`00
o`00oooo0?l0000:0?ooo`060?l00000o`00oooo0000o`3oool0003o1P3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00L0oooo00D00?l00?ooo`3oool0oooo003o000P0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0L0?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool00`3o0000oooo
0?ooo`0@0?ooo`030?l0003oool0oooo0080oooo0P00o`0<0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool09@3oool2003o00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`070?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02P3oool00`000?l0oooo
0000o`080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`00o`001@3oool00`00o`00oooo
0?ooo`150?ooo`040000o`3oool0oooo0000oal0oooo00<0003o0?ooo`000?l01@3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?oo
o`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0`0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo01/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o0000603oool00`00o`00oooo0?l0000:0?oo
o`060?l00000o`00oooo0000o`3oool0003o1P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`02003o00L0oooo00<0
0?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0K
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`002`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo02D0oooo0P00o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00T0oooo00<0003o
0?ooo`000?l01`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool00?l000H0oooo00<00?l0
0?ooo`3oool0A03oool010000?l0oooo0?ooo`000?lO0?ooo`030000o`3oool0003o00D0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`3o0000
3@3oool2003o00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo02P0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo01X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3o0000603oool00`00o`00oooo0?l0000:0?ooo`060?l0
0000o`00oooo0000o`3oool0003o1@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00D0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0L0?ooo`80003o1`3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l00000o`00oooo00T0oooo00<00?l00?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D000009P3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo003o000;0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0903oool01000o`00
oooo0?ooo`00o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
o`00oooo0?ooo`090?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`000?l01`3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l00000o`00oooo00D0oooo00<00?l00?ooo`3oool0A03oool01000
0?l0oooo0?ooo`000?lG0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0;0?ooo`03003o003oool00?l000@0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool05@3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`030?ooo`030?l00000o`00oooo01X0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0003o2P3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0o`0001L0oooo00@00?l00?ooo`3oool0o`00
2P3oool0103o00000?l00?ooo`000?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0703oool20000o`L0oooo00<0o`000?ooo`3oool03P3oool00`3o00000?l00?ooo`090?ooo`03
003o003oool0oooo00H0oooo00<0o`000?ooo`3oool05P3oool5000001`0oooo000i0?ooo`030000
003oool0oooo02P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo0080oooo00<00?l00?ooo`00o`002`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo02@0oooo00@00?l00?ooo`3oool00?l0103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`070?ooo`03
0000o`3oool0003o00L0oooo00<0o`000?ooo`3oool0303oool00`3o00000?l00?ooo`060?ooo`03
003o003oool0oooo04<0oooo00D0003o0?ooo`3oool0oooo0000o`0E0?ooo`800?l01`3oool00`00
0?l0oooo0000o`040?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`00o`00103oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool09P3oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<0o`00003o003oool06P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool0103o
0000oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool01@3oool0
0`3o0000oooo0?l0000G0?ooo`04003o003oool0oooo0?l000X0oooo00@0o`00003o003oool0003o
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01`0oooo00<0003o0?ooo`000?l0
1P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l00000o`00oooo00T0oooo00<00?l00?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`050?l0003o
ool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool08`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3o
ool01P3oool010000?l0oooo0?ooo`000?l60?ooo`030?l0003oool0oooo00`0oooo00<0o`00003o
003oool01`3oool00`00o`00oooo0?ooo`110?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool04`3oool2003o00L0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00<00?l00?ooo`00o`00103oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`080?oo
o`03003o003oool0oooo00<0oooo00<0o`00003o003oool06P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l:
0?ooo`030000o`3oool0oooo00L0oooo0P00o`050?ooo`050?l0003oool0oooo0?ooo`3o00005P3o
ool01000o`00oooo0?ooo`3o000:0?ooo`040?l00000o`00oooo0000o`80oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`0L0?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o
ool03P3oool00`3o00000?l00?ooo`0:0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0W0?ooo`030?l0
003oool0oooo0100oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool00?l00080
oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02<0
oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo00D0oooo00@0003o0?oo
o`3oool0003o1P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l00000o`00oooo00L0oooo00<00?l0
0?ooo`3oool0>`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool04P3oool00`00o`00o`00003o00070?ooo`040000o`3oool0oooo0000o`<0oooo00<0
o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0
0?l00?ooo`3oool00?l0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02d0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o0000oooo00L0oooo
00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo
00<0o`00003o003oool06P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo
00<0o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo00H0
oooo00<00?l00?ooo`00o`001@3oool01@3o0000oooo0?ooo`3oool0o`0001H0oooo00@00?l00?oo
o`3oool0o`002P3oool0103o0000oooo003o00000?l20?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0703oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo00l0oooo00<0
o`00003o003oool02P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo01/0oooo00<0
00000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00/0oooo0P3o000<0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`050?l0003oool0oooo0?ooo`00o`000`3o
ool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool08@3o
ool00`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`000?l01P3oool01@000?l0oooo
0?ooo`3oool00?l00140oooo00<00?l00?ooo`3oool01@3oool010000?l0oooo0?ooo`000?l50?oo
o`030?l0003oool0oooo00d0oooo00<0o`00003o003oool0203oool00`00o`00oooo0?ooo`0i0?oo
o`800?l01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00@00?l00?l0
003oool00?l01P3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool01P3oool2003o00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool08P3oool30?l000L0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0
903oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo00@0oooo00<0o`00003o003oool0
6P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0
3@3oool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo00H0oooo00@00?l00?ooo`3o
ool00?l0103oool01@3o0000oooo0?ooo`3oool0o`0001D0oooo00D00?l00?ooo`3oool0oooo0?l0
000:0?ooo`040?l0003oool00?l00000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`0L0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool03`3oool00`3o00000?l0
0?ooo`0:0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0U0?ooo`03003o003oool0o`000180oooo00<0
o`000?ooo`3oool02`3oool0103o0000oooo0?l0003o000:0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo003o00@0
oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0200
oooo00<00?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0003o00H0oooo00D0003o0?oo
o`3oool0oooo003o000A0?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0003o1@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l00000o`00oooo00T0oooo00<00?l00?ooo`3oool0=`3o
ool00`00o`00oooo003o00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0403o
ool01@00o`00oooo0?l0003oool00?l000H0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`00o`001@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Q0?oo
o`040?l0003oool0oooo0?ooo`@0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo01<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`3o00000?l00?ooo`0I0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`040?l0003oool0
oooo0000o`/0oooo00<0003o0?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool00?l000@0oooo
00D0o`000?ooo`3oool0oooo0?l0000E0?ooo`04003o003oool0oooo0?l000/0oooo00@0o`000?oo
o`00o`00003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00<0o`00
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0000o`050?ooo`030?l00000o`000?l000l0oooo00<0o`00
003o003oool02`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo01/0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0903oool2003o00030?ooo`3o0000oooo
0140oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`80o`00203oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool04P3oool00`3o
0000oooo003o00040?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0P0?ooo`03003o003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`06
0?ooo`050000o`3oool0oooo0?ooo`00o`00403oool00`3o0000oooo003o00050?ooo`050000o`3o
ool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00P0oooo
00<00?l00?ooo`3oool0=`3oool01000o`00oooo0?ooo`00o`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0403oool01@00o`00oooo0?l0003oool00?l000H0oooo00@0003o0?oo
o`3oool0003o0`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00D00?l0
0?ooo`3oool0oooo003o00040?ooo`030?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo
0000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`050?ooo`<0o`003@3oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3o0000oooo00P0oooo00<0003o0?ooo`3oool08@3oool00`3o
0000oooo0?ooo`090?ooo`03003o003oool0oooo00H0oooo00<0o`00003o003oool0603oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool0103o
0000oooo0?ooo`000?l;0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0
1000o`00oooo0?ooo`3o00050?ooo`030?l0003oool0oooo0180oooo00@00?l00?ooo`3oool0o`00
2`3oool0103o0000oooo003o00000?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o
ool04`3oool20?l000L0oooo00<0003o0?ooo`000?l0103oool2003o00030?ooo`00o`00oooo00h0
oooo00<0o`00003o003oool02`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo01/0
oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0903oool2003o00030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`80o`00
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo003o00040?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0O0?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0
oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`00o`00403oool00`3o0000oooo003o00050?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003o0000
oooo00X0oooo00<00?l00?ooo`3oool0=@3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0o`000080oooo00<0
0?l00?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?oo
o`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0
oooo0200oooo00<0o`000?ooo`3oool05`3oool0103o0000oooo0?ooo`000?lA0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0o`0000P0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0:0?ooo`03003o003o
ool0oooo00H0oooo00<0o`00003o003oool0603oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l;0?ooo`030000
o`3oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00050?ooo`03
0?l0003oool0oooo0140oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool00?l0
0000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0B0?ooo`80o`001P3oool0
10000?l0oooo0?ooo`000?l20?ooo`800?l000@0oooo0?l0003oool00?l03`3oool00`3o00000?l0
0?ooo`0;0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool06`3oool00`000000oooo
0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0S0?ooo`04003o003oool00?l00?l001@0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`80o`00103oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
003o00040?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0O0?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool0003o1P3oool010000?l0
oooo0?ooo`00o`0A0?ooo`030?l0003oool00?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`05
0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?l0003oool02P3oool00`00o`00oooo0?ooo`0M
0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?l00002
0?ooo`03003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003o
ool0oooo0180oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`05003o003oool0oooo0?ooo`3o
00001P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0103oool00`00o`00oooo0?ooo`02
0?ooo`05003o003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo01L0oooo00@0o`000?ooo`3oool0003o4@3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?l000080?ooo`030000
o`3oool0oooo0200oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`060?ooo`030?l0
0000o`00oooo01P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00h0oooo00<0o`000?ooo`000?l0303oool00`000?l0oooo0?ooo`030?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3o00001@3oool00`3o0000oooo0?ooo`0A0?ooo`05003o
003oool0oooo0?ooo`3o00002`3oool0103o0000oooo003o00000?l20?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?l000060?ooo`040000o`3oool0oooo
0000o`800?l00`3oool00`3o0000oooo003o000?0?ooo`030?l00000o`00oooo00/0oooo00<00?l0
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000i0?oo
o`030000003oool0oooo02<0oooo00@00?l00?ooo`00o`00o`00503oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool04P3oool00`3o00000?l00?ooo`050?ooo`03003o003o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0N0?ooo`03003o003o
ool0oooo00L0oooo00<00?l00?ooo`000?l0203oool00`000?l0oooo003o000A0?ooo`030?l0003o
ool00?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00h0oooo
00<00?l00?l0003oool02`3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo01<0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool03P3oool01000o`00oooo0?ooo`3o00020?ooo`03003o003o0000oooo00<0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo0180oooo00D0o`000?oo
o`3oool0oooo003o00050?ooo`05003o003oool0oooo0?ooo`3o00001P3oool01`3o0000oooo0?oo
o`3oool0003o0?ooo`000?l0103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0003o00X0
oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0H0?ooo`040?l0003oool0oooo0000
oa00oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00l0oooo00@0003o0?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0
oooo00X0oooo00<00?l00?ooo`3oool01`3oool00`3o00000?l00?ooo`0H0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?l0000@0?ooo`030?l0003oool0
003o00`0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
o`0000D0oooo00<0o`000?ooo`3oool04@3oool01@00o`00oooo0?ooo`3oool0o`0000/0oooo00@0
o`000?ooo`00o`00003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0100oooo
00@0o`000?ooo`3oool0o`001P3oool010000?l0oooo003o00000?l50?ooo`030?l0003oool00?l0
00l0oooo00<00?l00?l0003oool0303oool01@00o`00oooo0?ooo`3oool0o`0001h0oooo00<00000
0?ooo`3oool06P3oool001h0oooo0P0000040?ooo`800000103oool2000000d0oooo00<000000?oo
o`3oool08P3oool01@00o`00oooo0?ooo`00o`00o`0001@0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l00000o`00oooo00D0oooo00<00?l00?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01h0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0000o`080?ooo`030000o`3oool00?l00140oooo00<0o`000?ooo`00o`001@3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000403oool00`00o`00o`00
0?ooo`0;0?ooo`03003o003oool0oooo01`0oooo0P3o000C0?ooo`03003o003oool0oooo00@0oooo
00D00?l00?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3o
00000`3oool00`00o`00o`000?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool00?l000H0oooo00D00?l00?ooo`3oool0oooo0?l00006
0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`000?l02P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo01P0oooo
00<0o`000?ooo`3oool00P000?l?0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
303oool00`3o0000oooo0?ooo`0@0?ooo`040000o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`00
o`000`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0o`000100oooo00<0o`000?ooo`00
0?l0303oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0@0?ooo`05003o003oool0oooo0?ooo`3o00002`3oool0103o
0000oooo003o00000?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0003o003o003oool0003o1@3o
ool00`3o0000oooo003o000?0?ooo`03003o003o0000oooo00`0oooo00D00?l00?ooo`3oool0oooo
0?l0000N0?ooo`030000003oool0oooo01X0oooo000M0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0
oooo00@0o`000?ooo`3oool0003o203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
01<0oooo00<0o`00003o003oool01@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00l0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0000o`080?ooo`030000o`00o`00oooo
0100oooo00D0o`000?ooo`3oool00?l00?l000040?ooo`030000o`3oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l0000@0?ooo`03003o003o0000oooo00`0oooo00<00?l00?ooo`3oool06P3o
ool00`3o0000oooo0?l0000B0?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo
0000o`070?ooo`030000o`3oool0oooo00`0oooo00@00?l00?ooo`3oool0o`00103oool00`00o`00
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`0C0?oo
o`030?l00000o`00oooo00L0oooo00@00?l00?ooo`3oool0o`001P3oool01`3o0000oooo0?ooo`3o
ool0003o0?ooo`000?l00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0003o00X0oooo
00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0080003o
1P3oool:0?l000`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`040000
o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool03@3oool5003o00/0oooo00<0o`000?ooo`3o
ool0303oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool00?l000<0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool2003o00030?ooo`3o0000oooo00l0oooo00<0o`000?ooo`000?l03@3oool01@000?l0
oooo0?ooo`3oool00?l000P0oooo00<0o`00003o003oool01@3oool00`3o0000oooo0?ooo`0?0?oo
o`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`000?l2
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo003o
000?0?ooo`03003o003o0000oooo00`0oooo00D00?l00?ooo`3oool0oooo0?l0000N0?ooo`030000
003oool0oooo01X0oooo000M0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
2`3oool7000001d0oooo00H00?l00?ooo`3oool0oooo0?l00000o`0E0?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool4003o00D0oooo00<00?l00?ooo`3oool02@3oool0
0`00o`00003o0?ooo`070?ooo`030000o`00o`00oooo0100oooo00D0o`000?ooo`3oool0oooo003o
00040?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`03003o
003oool0o`0000`0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo0?l000070?ooo`<00?l0
203oool00`00o`00oooo0?ooo`060?ooo`04003o003oool0oooo0000o`L0oooo00<0003o0?ooo`3o
ool0303oool01000o`00oooo0?ooo`3o00040?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?l0000E0?ooo`03003o003oool0oooo00L0oooo00@00?l00?oo
o`3oool0o`001P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0003o00X0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo
0?ooo`0J0?ooo`040?l000000?l0oooo0000o`D0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00D0003o0?ooo`3oool0oooo0?l000070?oo
o`030000o`3oool0oooo00P0oooo1@00o`050?ooo`<00?l0203oool00`3o0000oooo0?ooo`0;0?oo
o`03003o003oool0oooo00T0oooo00<0o`00003o003oool00P3oool20000o`L0oooo00<00?l00?oo
o`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool01@3oool2003o00030?ooo`3o0000oooo0100oooo00<0o`000000o`3oool0303oool01@00
0?l0oooo0?ooo`3oool00?l000P0oooo00<0o`00003o003oool01@3oool00`3o0000oooo0?ooo`0?
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`00
0?l30?ooo`040000o`3oool0oooo0?l001<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`00o`003`3oool00`00o`00
o`000?ooo`0=0?ooo`03003o003oool0o`0001T0oooo1`00000L0?ooo`007@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`00o`00
oooo0?ooo`020?ooo`030?l00000o`00oooo01@0oooo00@0o`000?ooo`3oool00?l0103oool00`3o
0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool0
0`3o0000oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`000?l0203oool20?l000H0oooo00<0
0?l00?ooo`3oool00P3oool5003o00`0oooo00<00?l00000o`3oool01`3oool00`000?l00?l00?oo
o`0@0?ooo`050?l0003oool0oooo0?ooo`00o`00103oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000403oool00`00o`00oooo0?l0000=0?ooo`03003o003oool0oooo00T0
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?l000060?ooo`04003o003oool0oooo0?oo
o`@00?l00`3oool00`00o`00oooo0?ooo`070?ooo`04003o003oool0oooo0000o`L0oooo00<0003o
0?ooo`3oool02`3oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo00<00?l00?l0003oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0001@0oooo00<00?l00?l0003oool0203o
ool01000o`00oooo0?ooo`3o00060?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool010000?l0
oooo0?ooo`00o`070?ooo`03003o00000?l0oooo00T0oooo00<0003o0?ooo`3oool0703oool00`3o
0000oooo0?ooo`0K0?ooo`040?l000000?l0oooo0000o`D0oooo00<0o`000?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0?l0
00070?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool02`3oool3003o00@0oooo00<0
o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`090?ooo`030?l00000o`00oooo0080oooo0P00
0?l70?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`020?ooo`80003o1@3oool01@00o`00oooo0?ooo`00o`00o`000140oooo00<0o`000000o`3oool0
303oool010000?l0oooo0?ooo`00o`090?ooo`030?l0003oool00?l000D0oooo00<0o`000?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3o
ool0003o0`3oool010000?l0oooo0?ooo`3o000D0?ooo`040?l0003oool0oooo003o00P0oooo00<0
0?l00?ooo`3oool03@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0
0?l00000o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool00?l000l0oooo00<0
0?l00?l0003oool03@3oool00`00o`00oooo0?l0000O0?ooo`030000003oool0oooo01X0oooo000M
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000303oool00`000000oooo
0?ooo`0O0?ooo`03003o003oool0oooo00<0oooo00<0o`00003o003oool0503oool0103o0000oooo
0?ooo`00o`040?ooo`030?l0003oool0oooo00`0oooo00<0o`000000o`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3oool01P3oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0oooo0P000?l60?oo
o`030?l0003oool0o`0000H0oooo00<00?l00?ooo`3oool04`3oool00`00o`00003o0?ooo`070?oo
o`030000o`00o`00oooo0100oooo00D0o`000?ooo`3oool0oooo003o00040?ooo`030000o`3oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`03003o003oool0o`0000d0oooo00<0
0?l00?ooo`3oool0203oool20?l000P0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?oo
o`3o00050?ooo`03003o003oool0oooo00D0oooo0`00o`0:0?ooo`04003o003oool0oooo0000o`P0
oooo00<0003o0?ooo`3oool02P3oool01000o`00oooo0?ooo`3o00050?ooo`03003o003o0000oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0o`000?ooo`0D0?ooo`03003o003o0000oooo
00P0oooo00@00?l00?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`000?l30?ooo`040000o`3o
ool0oooo003o00L0oooo00<00?l00000o`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`<00?l0
2@3oool00`3o0000oooo0?ooo`0K0?ooo`040?l000000?l0oooo0000o`@0oooo00<0o`000?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0140oooo00D0003o0?ooo`3o
ool0oooo0?l000070?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool03P3oool2003o
00030?ooo`3o0000oooo00d0oooo00<00?l00?ooo`3oool02P3oool00`3o00000?l00?ooo`020?oo
o`80003o1P3oool00`00o`00oooo003o00090?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool00P3oool20000o`D0oooo00D00?l00?ooo`3oool00?l00?l0000A0?ooo`030?l000000?l0
oooo00`0oooo00@0003o0?ooo`3oool00?l0203oool0103o0000oooo0?ooo`00o`060?ooo`030?l0
003oool0oooo00d0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`040?l0
003oool0oooo0000o`<0oooo00@0003o0?ooo`3oool0o`00503oool0103o0000oooo0?ooo`00o`08
0?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool01`3o0000oooo0?ooo`3o
ool00?l00?ooo`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo003o00L0
oooo00<0003o0?ooo`3oool0103oool00`00o`00o`000?ooo`0=0?ooo`03003o003oool0o`0001l0
oooo00<000000?ooo`3oool06P3oool001h0oooo0P00000:0?ooo`8000003@3oool00`000000oooo
0?ooo`0O0?ooo`03003o003oool0oooo00<0oooo00<0o`00003o003oool0503oool0103o0000oooo
0?ooo`00o`040?ooo`030?l0003oool0oooo00`0oooo00<0o`000000o`3oool02@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3o00001`3oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00H0o`000?ooo`3oool0003o0?ooo`000?l6
0?ooo`040?l0003oool0oooo0?l000@0oooo00<00?l00?ooo`3oool0503oool00`00o`00003o0?oo
o`070?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`004@3oool01000o`00oooo
0?ooo`3o000=0?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3o00001P3oool20000o`H0
oooo00@0o`000?ooo`3oool0o`00103oool00`00o`00oooo0?ooo`0C0?ooo`04003o003oool0oooo
0000o`P0oooo00<0003o0?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool0o`0000D0oooo00<0
0?l00?l0003oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo01@0oooo00<0
0?l00?ooo`3o0000203oool00`00o`00oooo0?l000070?ooo`040?l0003oool0oooo0000o`<0oooo
00<0003o0?ooo`00o`00203oool00`00o`00003o0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0103oool2003o00<0oooo1000o`040?ooo`030?l0003oool0oooo01`0oooo
00D0o`000000o`3oool0oooo0000o`020?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`00
0?l0oooo0?ooo`060?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool03@3oool00`00
o`00oooo0?ooo`0:0?ooo`030?l0003oool00?l00080oooo0P000?l60?ooo`03003o003oool00?l0
00T0oooo00<0o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00D0
0?l00?ooo`3oool0oooo003o000B0?ooo`030?l000000?l0oooo00`0oooo00@0003o0?ooo`3oool0
0?l0203oool01@3o0000oooo0?ooo`3oool00?l000D0oooo00<0o`000?ooo`3oool03@3oool00`00
o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o0`3oool0
10000?l0oooo0?ooo`3o000D0?ooo`040?l0003oool0oooo003o00T0oooo00<00?l00?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`050?ooo`060?l0003oool0oooo003o003oool0003o103oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`03003o003o0000oooo00h0oooo00<00?l00?l0003oool07P3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`0N0?ooo`03003o003oool0oooo00<0oooo00<0o`000?oo
o`00o`005P3oool0103o00000?l00?ooo`00o`020?ooo`030?l0003oool0oooo00d0oooo00<0o`00
0000o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool04@3oool00`00o`00oooo0?l000070?ooo`03003o003oool0oooo0080oooo00<0o`00
0?ooo`3oool02P3oool01P3o0000oooo0?ooo`000?l0oooo0000o`H0oooo00@0o`000?ooo`3oool0
o`00103oool00`00o`00oooo0?ooo`0E0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool010000?l0oooo0?ooo`3o000A0?ooo`05003o003oool0oooo0?ooo`3o0000303oool0
0`00o`00oooo0?ooo`060?ooo`040?l0003oool0oooo0?l000H0oooo0P000?l50?ooo`050?l0003o
ool0oooo0?ooo`3o0000103oool00`00o`00oooo0?ooo`0C0?ooo`04003o003oool0oooo0000o`P0
oooo00<0003o0?ooo`3oool01`3oool3003o00<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00
o`000?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003oool0503oool00`00o`00
oooo0?l000090?ooo`03003o003o0000oooo00L0oooo00<0o`000?ooo`000?l00`3oool00`000?l0
oooo003o00080?ooo`03003o00000?l0oooo00X0oooo00<0003o0?ooo`3oool01P3oool20?l000<0
oooo0P00o`090?ooo`<00?l000<0oooo0?l0003oool07P3oool010000?l0oooo0?ooo`000?l20?oo
o`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0A0?oo
o`050000o`3oool0oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo0180oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0
0?l00080oooo00<0003o0?ooo`000?l0103oool01@00o`00oooo0?ooo`3oool00?l000P0oooo00<0
o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00D00?l00?ooo`3o
ool0oooo003o000B0?ooo`030?l000000?l0oooo00`0oooo00<0003o0?ooo`00o`002@3oool01@3o
0000oooo0?ooo`3oool00?l000D0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`02
0?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3oool0003o0`3oool010000?l0oooo0?oo
o`3o000E0?ooo`030?l0003oool00?l000T0oooo00@00?l00?ooo`3oool0oooo2P3o00080?ooo`03
0?l0003oool00?l00080oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0o`00
00h0oooo00<00?l00?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0N0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`00o`005P3oool0103o0000
0?l00?ooo`00o`020?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool04@3oool00`00
o`00oooo0?l000070?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool01P3o
0000oooo0?ooo`000?l0oooo0000o`H0oooo00@0o`000?ooo`3oool0o`000`3oool00`00o`00oooo
0?ooo`0F0?ooo`030000o`3oool0oooo00H0oooo00<00?l00000o`3oool03`3oool00`3o0000oooo
0?ooo`020?ooo`05003o003o0000oooo0?ooo`000?l01@3oool010000?l0oooo0?ooo`3o000A0?oo
o`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`040?oo
o`050?l0003oool0oooo0?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l40?ooo`050?l0003o
ool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0003o00P0oooo
00<0003o0?ooo`3oool00`3oool4003o00D0oooo00<0o`000?ooo`3oool0103oool00`00o`00o`00
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003oool0503oool00`00o`00oooo
0?l000090?ooo`03003o003o0000oooo00L0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo
003o00080?ooo`03003o00000?l0oooo00X0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo
0?ooo`3o0002003o00d0oooo00<00?l00?l0003oool07`3oool01P000?l0oooo0?ooo`000?l0oooo
0?l001X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0B0?ooo`050000o`3oool0
oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`040?ooo`04003o003oool0oooo0?l00100oooo
00<0o`000?ooo`00o`00303oool00`00o`00oooo0?ooo`0<0?ooo`050?l0003oool00?l00?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`00203oool00`3o
0000oooo0?ooo`080?ooo`060?l0003oool0oooo0000o`3oool0003o0`3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool03@3oool00`000?l00?l00?oo
o`080?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0<0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?oo
o`000?l30?ooo`040000o`3oool0oooo0?l001H0oooo00<0o`00003o003oool0203oool01000o`00
oooo0?ooo`3o000B0?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`03003o003oool0o`0000h0oooo00<00?l00?ooo`3oool07P3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`00o`005P3oool0103o00000?l00?ooo`00o`020?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P00o`0C
0?ooo`03003o003oool0o`0000L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:
0?ooo`060?l0003oool0oooo0000o`3oool0003o1P3oool01@3o0000oooo0?ooo`3oool0o`000080
oooo00<00?l00?ooo`3oool05P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0003o0100
oooo00<0o`000?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l60?ooo`030000o`3oool0o`00
0100oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo
00@0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool00?l001P0oooo00<00?l00000o`3oool02@3o
ool00`000?l0oooo003o0002003o00T0oooo00<0o`000?ooo`3oool01@3oool01000o`00o`000?oo
o`000?l50?ooo`030000o`3o0000oooo01<0oooo00@00?l00?ooo`3oool0o`002@3oool00`00o`00
o`000?ooo`070?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`00o`002@3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`00o`000?l00?l0000?0?oo
o`03003o003oool0oooo01h0oooo00D0003o0?ooo`3oool0003o0?l0000K0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool20?l000d0oooo0P3o
00030?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0303oool01@3o0000oooo003o
003oool0003o0080oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`03003o003oool0oooo00D0
oooo00<0o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0@0?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0o`00
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`000?l00`3oool010000?l0oooo0?ooo`3o000G0?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3o00004`3oool00`3o00000?l00?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`00o`00oooo0?l0000>0?ooo`03003o003oool0oooo01h0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool0903oool00`3o0000oooo003o000F0?ooo`060?l00000
o`00oooo003o003oool0o`00403oool00`000?l0o`000?ooo`0:0?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool2003o0180oooo00@00?l00?ooo`3oool0o`001`3oool00`00o`00oooo0?ooo`02
0?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`00o`00603oool00`000?l00?l00?oo
o`060?ooo`03003o003oool0003o0100oooo00<0o`000?ooo`3oool00`3oool01000o`00oooo0?oo
o`000?l60?ooo`030000o`3oool0o`000100oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo
0?ooo`090?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool00?l001P0oooo00<00?l00000o`3oool02@3oool00`000?l0oooo003o000;0?ooo`03
0?l0003oool0oooo00D0oooo00@00?l00?l0003oool0003o1@3oool00`000?l0o`000?ooo`0C0?oo
o`05003o003oool0oooo0?ooo`3o0000203oool00`00o`00o`000?ooo`070?ooo`030?l0003oool0
003o00<0oooo00<0003o003o003oool0203oool00`000?l00?l00?ooo`0:0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`00o`000`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l00000o`00
oooo01l0oooo00D0003o0?ooo`3oool0003o0?l0000K0?ooo`040?l0003oool0oooo0000o`P0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`000080oooo0P3o000:0?ooo`03
0?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0=0?ooo`05
0?l0003oool00?l00?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<00?l0
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`80oooo00<0
003o0?ooo`00o`001@3oool00`3o00000?l00?ooo`0@0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000
3@3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`000?l0
0?l00P3oool01@000?l0oooo0?ooo`3o0000oooo00800?l0503oool00`00o`00o`000?ooo`070?oo
o`03003o003o0000oooo01<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0
003o00D0oooo00@00?l00?ooo`3oool0o`00303oool00`3o0000oooo003o000O0?ooo`030000003o
ool0oooo01X0oooo000i0?ooo`030000003oool0oooo02<0oooo00@0o`000?ooo`3oool00?l05P3o
ool01P3o00000?l00?ooo`00o`00oooo0?l00100oooo00<0003o0?l0003oool02P3oool010000?l0
oooo0?ooo`3o00050?ooo`03003o003oool00?l00180oooo00@00?l00?ooo`3oool0o`00203oool0
1000o`00oooo0?ooo`3o000=0?ooo`040?l0003oool0oooo0000o`80oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l00000o`00oooo01L0oooo00<0003o0?ooo`00o`00
1P3oool00`00o`00oooo0000o`0?0?ooo`030?l0003oool0oooo00@0oooo00@00?l00?ooo`3oool0
003o1P3oool00`000?l0o`000?ooo`0@0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3o
ool0203oool01@00o`00oooo0?ooo`3oool0o`0000H0oooo00@0o`000?ooo`3oool0003o103oool0
1@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`00003o003oool0603oool00`00o`00003o0?oo
o`090?ooo`030000o`00o`00oooo00/0oooo00<0o`000?ooo`3oool01@3oool01000o`00o`000?oo
o`000?l50?ooo`030000o`3o0000oooo01<0oooo00D00?l00?ooo`3oool0oooo0?l000080?ooo`03
003o003o0000oooo00L0oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?ooo`070?ooo`03
0000o`00o`00oooo00/0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo003o00040?ooo`03
0?l0003oool0oooo00P0oooo0P3o00000`3oool00?l00?ooo`0O0?ooo`040000o`3oool0oooo0000
oa`0oooo00@0o`000?ooo`3oool0003o1`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0
oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`050?ooo`80o`001`3oool00`00o`00oooo0?oo
o`060?ooo`03003o003oool0oooo00l0oooo00@0o`000?ooo`00o`00003o0`3oool00`000?l0oooo
003o00070?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo
0?ooo`000?l20?ooo`030000o`3oool00?l000D0oooo00<0o`00003o003oool0403oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool01000o`00
oooo0?ooo`3o000=0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool0103o
0000oooo0000o`00o`020?ooo`030000o`3oool00?l000800?l000<0oooo003o003oool04P3oool0
0`00o`00oooo0?l000070?ooo`030?l00000o`00oooo01<0oooo00<00?l00?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?oo
o`040?ooo`030000o`3oool0003o00D0oooo00@00?l00?ooo`3oool0o`00303oool00`3o0000oooo
003o000O0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02<0oooo00@0
o`000?ooo`3oool00?l05`3oool01000o`00oooo0?ooo`00o`0A0?ooo`030000o`3oool0o`0000X0
oooo00<0003o0?ooo`3o00001P3oool00`00o`00oooo003o000B0?ooo`04003o003oool0oooo0?l0
00P0oooo00@00?l00?ooo`3oool0o`003@3oool00`3o0000oooo0000o`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0G0?ooo`030000o`3oool0
0?l000H0oooo00<00?l00?ooo`000?l03`3oool00`3o0000oooo0?ooo`040?ooo`04003o003oool0
oooo0000o`H0oooo00<0003o0?l0003oool0403oool00`00o`00oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<00?l00?ooo`3o00001`3oool00`3o0000oooo0000o`050?ooo`050000o`3o
ool0oooo0?ooo`3o00001P3oool00`00o`00oooo0?ooo`0G0?ooo`03003o00000?l0oooo00T0oooo
00<0003o003o003oool02P3oool00`3o0000oooo0?ooo`060?ooo`04003o003o0000oooo0000o`D0
oooo00<0o`000000o`3oool04`3oool01@00o`00oooo0?ooo`3oool0o`0000T0oooo00<00?l00?oo
o`3oool01P3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0oooo00L0oooo00<0003o003o
003oool02`3oool00`000?l0oooo0?ooo`030?ooo`030?l00000o`00oooo00D0oooo00<0o`000?oo
o`3oool01@3oool20?l000@0oooo00<00?l00?ooo`3oool04`3oool3003o00L0oooo00D0003o0?l0
003o0000oooo0000o`0K0?ooo`030?l0003oool0oooo0080003o1P3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3o
ool00?l000<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00P0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0?0?ooo`040?l0003o
ool00?l00000o`<0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`03
0000o`3oool00?l000@0oooo00<0o`000?ooo`00o`004@3oool00`000?l0oooo0?ooo`0<0?ooo`03
003o00000?l0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?l0000:0?ooo`80
o`0000<00?l00?l0003o00001@3o000=0?ooo`0:0?l0003oool0003o003o003oool00?l00000o`00
o`00oooo0?l00080oooo00<00?l00?ooo`3oool04@3oool01000o`00oooo0?ooo`3o00050?ooo`03
0?l0003oool00?l001@0oooo00<00?l00?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o
00D0oooo00@00?l00?ooo`3oool0o`00303oool00`3o0000oooo003o000O0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo02<0oooo00D0o`000?ooo`3oool0oooo003o0006
0?ooo`030000o`3oool0oooo00`0oooo00D00?l00?l0003oool0oooo003o000A0?ooo`030000o`3o
ool0o`0000X0oooo00<0003o0?ooo`3o00001P3oool01000o`00oooo0?ooo`00o`0@0?ooo`05003o
003oool0oooo0?ooo`3o0000203oool01000o`00oooo0?ooo`3o000=0?ooo`030?l0003oool0003o
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
01L0oooo00<0003o0?ooo`00o`001@3oool01000o`00oooo0?ooo`000?l?0?ooo`030?l0003oool0
oooo00@0oooo00@00?l00?l0003oool0003o1P3oool00`000?l0o`000?ooo`0@0?ooo`03003o003o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?l000070?ooo`030?l0003o
ool0003o00D0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`03003o003o0000oooo01P0oooo
00<00?l00000o`3oool02@3oool00`000?l00?l00?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo
00@00?l00?l0003oool0003o1@3oool00`3o0000003o0?ooo`0C0?ooo`05003o003oool0oooo0?oo
o`3o00002@3oool00`00o`00oooo0?ooo`060?ooo`030?l000000?l0oooo00@0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo003o000;0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`00o`001`3oool00`3o0000oooo0?ooo`020?ooo`80o`001P3oool00`00o`00oooo0?ooo`0?0?oo
o`@00?l00P3oool00`00o`00oooo0?ooo`040?ooo`060000o`3oool0o`000?l0003oool0003o6`3o
ool00`3o0000oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`030?l0
003oool0oooo00D0oooo0P3o00000`3oool0o`000?l0000<0?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool0403oool0103o0000oooo003o00000?l30?ooo`030000o`00o`00oooo00P0
oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool00?l000<0
oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l00?l00?ooo`040?ooo`030?l0003oool00?l0
0140oooo00<0003o0?ooo`3oool0303oool00`00o`00003o0?ooo`070?ooo`030?l0003oool0oooo
00T0oooo00<00?l00?ooo`3o0000203oool0103o0000oooo0?ooo`00o`0D0?ooo`030?l0003oool0
003o00800?l000D0oooo0000o`3oool0oooo0?l000020?ooo`03003o003oool0oooo0140oooo00D0
0?l00?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo003o01<0oooo00@00?l00?ooo`3o
ool0o`000`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo0?l0
000;0?ooo`040?l0003oool0oooo003o01h0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool08`3oool01@3o0000oooo0?ooo`3oool00?l000H0oooo00<0003o0?ooo`3oool0
303oool01@00o`00o`000?ooo`3oool00?l00140oooo00<0003o0?ooo`3o00002P3oool00`000?l0
o`000?ooo`050?ooo`05003o003oool0oooo0?ooo`00o`00403oool01@00o`00oooo0?ooo`3oool0
o`0000P0oooo00@00?l00?ooo`3oool0o`003P3oool00`3o0000003o0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`00o`00oooo0?l0000H0?ooo`030000o`3oool00?l000D0oooo
00@00?l00?ooo`3oool0003o3`3oool00`3o0000oooo0?ooo`040?ooo`04003o003o0000oooo0000
o`H0oooo00<0003o0?l0003oool0403oool00`00o`00oooo0?ooo`090?ooo`80o`001`3oool00`00
o`00o`000?ooo`080?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103oool0
0`00o`00oooo0?l0000J0?ooo`030000o`3oool0oooo00P0oooo00<00?l00000o`3oool02P3oool0
0`3o0000oooo0?ooo`060?ooo`04003o003oool0o`000000o`D0oooo00<0o`000000o`3oool04`3o
ool01@00o`00oooo0?ooo`3oool0o`0000P0oooo00<0o`00003o003oool01`3oool00`3o0000003o
0?ooo`030?ooo`03003o00000?l0oooo00P0oooo00<0003o0?ooo`00o`002`3oool00`000?l0oooo
0?ooo`020?ooo`030?l00000o`00oooo00P0oooo00@0o`000?ooo`3o0000o`00203oool00`00o`00
oooo0?ooo`0<0?ooo`<00?l01P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0o`000080
oooo00<0003o0?ooo`3oool06P3oool01@3o0000oooo0000o`3oool0003o00@0oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00@0003o0?oo
o`3oool00?l00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0@0?ooo`040?l0003oool00?l00000o`@0oooo00<0
003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0
0?l00?ooo`3oool0oooo003o00020?ooo`040?l0003oool0oooo0000o`80oooo00<0003o003o003o
ool0103oool00`3o0000oooo003o000A0?ooo`030000o`3oool0oooo00/0oooo00@00?l00?ooo`3o
ool0003o1`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003o0000oooo00H0oooo00D0o`000?oo
o`3oool0oooo003o000D0?ooo`030?l000000?l0oooo00<0oooo00@0003o0?ooo`3oool0o`000P3o
ool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o0000103o
ool00`00o`00oooo0?ooo`0@0?ooo`04003o003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool0103oool00`000?l0
oooo0000o`050?ooo`05003o003oool0oooo0?ooo`3o00002P3oool01@3o0000oooo0?ooo`3oool0
0?l001h0oooo00<000000?ooo`3oool06P3oool003T0oooo1@00000P0?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool0103oool20000o`d0oooo00D00?l00?l0003oool0o`00003o000A
0?ooo`030000o`3oool0o`0000X0oooo00<0003o0?l0003oool01@3oool01@00o`00oooo0?ooo`3o
ool00?l00100oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`03003o003o
ool0o`0000l0oooo00<0o`000000o`3oool00`3oool010000?l0oooo0?ooo`3o00050?ooo`03003o
003oool0o`0001P0oooo00@0003o0?ooo`3oool00?l0103oool01000o`00oooo0?ooo`000?l?0?oo
o`030?l0003oool0oooo00D0oooo00<00?l00?ooo`000?l01P3oool00`000?l0o`000?ooo`0@0?oo
o`03003o003oool0oooo00/0oooo0P3o00050?ooo`03003o003oool0oooo00P0oooo00<0003o0?oo
o`3oool01@3oool010000?l0oooo0?ooo`3o00040?ooo`03003o003oool0o`0001X0oooo00<0003o
0?ooo`3oool0203oool00`00o`00003o0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00@00?l0
0?ooo`3o0000003o1@3oool00`3o0000003o0?ooo`0C0?ooo`03003o003oool0oooo0080oooo00<0
o`000?ooo`3oool01@3oool00`3o00000?l00?ooo`070?ooo`030?l000000?l0oooo00<0oooo00<0
0?l00000o`3oool0203oool00`000?l0oooo003o000;0?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo003o000:0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool02P3oool00`00o`00
oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0J0?ooo`050?l000000?l0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo003o00040?oo
o`030?l0003oool0oooo01P0oooo00D00?l00?ooo`3oool0oooo003o000C0?ooo`040?l0003oool0
oooo0000o`<0oooo00<00?l00000o`3oool02@3oool01@00o`00oooo0?ooo`3oool0o`0000<0oooo
00<00?l00?ooo`3oool00`3oool01P00o`00oooo0?ooo`3o0000oooo0000o`80oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo003o000A0?ooo`030000o`3oool0oooo00/0oooo00@00?l00?oo
o`3oool0003o1`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00D0oooo00@0o`00
0?ooo`3oool00?l05@3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00<0
0?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0403oool01000o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`00
0?l01@3oool01@00o`00oooo0?ooo`3oool0o`0000X0oooo00D0o`000?ooo`3oool0oooo003o000J
0?ooo`D00000703oool003T0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l03@3oool01@00o`00oooo0?l0003o0000
0?l00100oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030?l000000?l0oooo00@0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo0080oooo00<0
o`000?ooo`3oool01P3oool00`00o`00o`000?ooo`0>0?ooo`030?l000000?l0oooo00<0oooo00@0
003o0?ooo`3oool0o`00103oool01000o`00oooo0?ooo`3o000H0?ooo`040000o`3oool0oooo003o
00@0oooo00D00?l00?ooo`3oool0oooo0000o`0=0?ooo`030?l0003oool0oooo00H0oooo00<00?l0
0?ooo`000?l01P3oool00`000?l0o`000?ooo`0@0?ooo`03003o003oool0oooo00d0oooo0`3o0002
0?ooo`030?l00000o`00oooo00L0oooo00<0003o0?l0003oool01P3oool00`000?l0oooo0?l00004
0?ooo`05003o003oool0oooo0?ooo`3o00006@3oool00`000?l0oooo0?ooo`080?ooo`03003o0000
0?l0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`00o`00o`000000o`050?ooo`030?l00000
0?l0oooo01<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l00000
o`00oooo00L0oooo00<0o`000000o`3oool00`3oool00`00o`00003o0?ooo`080?ooo`030000o`3o
ool00?l000`0oooo00D0003o0?ooo`3oool0o`00003o000G0?ooo`03003o003oool0oooo00X0oooo
00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool06P3oool01@3o0000003o0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`00
o`000`3oool00`3o0000oooo0?ooo`0J0?ooo`03003o003oool00?l001@0oooo00@0o`000?ooo`3o
ool0003o0`3oool00`00o`00003o0?ooo`090?ooo`06003o003oool0oooo0?ooo`3o0000oooo0P00
o`070?ooo`800?l000<0o`000000o`3oool00P3oool00`00o`00003o0?ooo`040?ooo`030?l0003o
ool00?l00140oooo00<0003o0?l0003oool02P3oool01@00o`00oooo0?ooo`3oool0003o00L0oooo
00<0o`000?ooo`3oool02`3oool00`3o00000?l00?ooo`040?ooo`050?l0003oool0oooo0?ooo`00
o`005@3oool00`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo00<0oooo00<00?l00?ooo`3o
ool0403oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00l0oooo00D00?l00?ooo`3o
ool0oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0o`000`3oool0
0`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`00o`007P3oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool00`3oool00`000?l0oooo0000o`0=0?ooo`03003o003oool0o`000080oooo00<00?l0
0?ooo`3oool03@3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<0o`000000o`3oool0103o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`060?ooo`03003o003o0000oooo00h0oooo00<0o`000000o`3oool00`3o
ool010000?l0oooo0?ooo`3o00040?ooo`05003o003oool0oooo0?ooo`3o00005`3oool010000?l0
oooo0?ooo`00o`030?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`060?ooo`03003o003oool0003o00H0oooo00<0o`000000o`3oool0403oool00`00
o`00oooo0?ooo`0@0?ooo`80o`0000<0oooo003o003oool01P3oool010000?l0oooo0?ooo`3o0006
0?ooo`030000o`3oool0o`0000@0oooo00D00?l00?ooo`3oool0oooo0?l0000H0?ooo`030000o`00
o`00oooo00T0oooo00<00?l00000o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03003o003o
0000003o00D0oooo00<0o`000000o`3oool04P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`00o`00203oool00`000?l0oooo0?ooo`020?ooo`03003o0000
0?l0oooo00P0oooo00@0003o0?ooo`3oool00?l02`3oool01@000?l0oooo0?ooo`3o00000?l001L0
oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l000000?l0oooo0080
oooo00@0003o0?ooo`3oool0o`005P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`03003o003oool00?l0
01@0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00oooo0000o`0;0?ooo`05003o003oool0
oooo0?l00000o`002`3oool01`00o`00003o0?ooo`3oool00?l00?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool00?l000l0oooo00<0003o0?ooo`3o00002@3oool2003o00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`030?l00000o`000?l00080oooo00<0o`000?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0
003oool00`3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo00T0oooo00<00?l00?oo
o`3oool03`3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0103oool0
10000?l0oooo0?ooo`3o00030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`000?l01@3o
ool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo0280oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`040000o`3oool0
oooo0000o`/0oooo00@00?l00?ooo`3oool0o`000P3oool00`00o`00oooo0?ooo`0=0?ooo`050000
o`3oool0oooo0?ooo`3o00002@3oool00`3o0000003o0?ooo`040?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00H0
oooo00<00?l00?l0003oool03P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l0
00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`040000o`3oool0oooo
003o00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00H0oooo00<00?l00?l000000?l01P3oool00`3o0000003o0?ooo`0@0?ooo`03003o003oool0
oooo01<0oooo00<00?l00?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00060?ooo`030000o`3o
ool0o`0000<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`00
o`00oooo00P0oooo00@00?l00?ooo`3oool0003o2@3oool00`3o0000oooo0?ooo`080?ooo`03003o
003o0000003o00D0oooo00<0o`000000o`3oool04P3oool00`00o`00oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`00o`00203oool01@000?l0oooo0?ooo`3oool00?l00080
oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`00o`0;0?ooo`050000o`3oool0o`00
0?ooo`00o`00603oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00T0oooo00<00?l0
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo0P00o`04
0?ooo`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool0o`005P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000N0?ooo`03003o
003oool0oooo01<0oooo00@0o`000?ooo`3oool0003o0P3oool01000o`00oooo0?ooo`000?l:0?oo
o`04003o00000?l0oooo003o00`0oooo00L0o`000000o`3oool0oooo003o003oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo003o000?0?ooo`030000o`3oool0o`0000P0oooo00<00?l00?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o
ool00P00o`050?ooo`03003o003oool0oooo01<0oooo00<0o`000000o`3oool0103oool00`000?l0
o`000?ooo`030?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool02@3oool01000o`00
oooo0?ooo`000?l>0?ooo`05003o003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`00
0?l40?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00@0003o
0?ooo`3oool0003o2`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00d0oooo00D0
003o0?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0003o00@0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0>0?ooo`030000o`3oool0oooo00@00?l000<0003o0?ooo`3o0000
0`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo01@0oooo00D0003o0?ooo`3oool0
oooo003o00020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`060?ooo`03003o00000?l0oooo00H0oooo00<0o`000000o`3oool0403oool00`00o`00
oooo0?ooo`0C0?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000060?oo
o`030000o`3oool0o`000080oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool00?l000P0oooo00@00?l00?ooo`3oool0003o203oool00`3o0000oooo0?ooo`09
0?ooo`03003o003oool0003o00@0oooo00<0o`000?ooo`000?l04`3oool00`00o`00oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`00o`00203oool01@000?l0oooo0?ooo`3o
ool00?l00080oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`00o`0;0?ooo`040000
o`3oool0o`00003o01T0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0:0?ooo`03
003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`03
003o003oool0oooo00800?l00P3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0o`0001H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o0000=@3oool01@3o0000oooo0000o`3oool00?l000<0oooo00<0003o0?ooo`3oool0203oool2
0000o`03003o003oool0oooo00/0oooo00@0o`000000o`00o`000?l00P3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`00o`003`3oool00`000?l0oooo0?l000070?ooo`03003o
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`050?l0
003oool0oooo0?l0003oool00`00o`000`3oool00?l00?ooo`0E0?ooo`030?l000000?l0oooo00@0
oooo00<0003o0?l0003oool00`3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00X0
oooo00<00?l00?ooo`3oool00`000?l<0?ooo`05003o003oool0oooo0?ooo`3o00000P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool0103oool01000
0?l0oooo0?ooo`000?l30?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
00<0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`03003o003oool0oooo00<0oooo00<00?l0
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`000?l0103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00d0oooo00<00?l0
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo00h0oooo00@0003o
0?ooo`3oool00?l00`3oool00`000?l00?l0003o0003003o00H0oooo00<0o`000?ooo`3oool0503o
ool01`000?l0oooo0?ooo`3oool00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00H0oooo00<00?l00000o`3oool01P3oool00`3o0000003o0?ooo`0?0?ooo`03
003o003oool0oooo01D0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`00
00L0oooo00@0003o0?l0003oool00?l01`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
0?l000P0oooo00@00?l00?ooo`3oool0003o203oool00`3o0000oooo0?ooo`090?ooo`03003o003o
ool0003o00@0oooo00<0o`000?ooo`000?l04`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`00o`00203oool01@000?l0oooo0?ooo`3oool00?l00080oooo
00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000/0oooo00@0003o0?l0003o
ool00?l06P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00/0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo00<00?l00?oo
o`3oool00`3oool3003o00030000o`3oool0oooo0080oooo00<0003o0?l0003oool02`3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0oooo03<0oooo00<0o`000000o`3oool00P00o`030?ooo`030000o`3oool0
oooo00P0oooo0P000?l00`3o0000oooo0?ooo`0;0?ooo`040?l000000?l0oooo003o0080oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l000l0oooo00<0003o0?ooo`3o0000
1@3oool2003o00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`040?l0
003oool0oooo0?l000@0oooo0P00o`0F0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003o
ool00`3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3o
ool0003o0P3oool20000o`T0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0000o`060?oo
o`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
003o00<0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0003o00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`00
0?l40?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?oo
o`030?ooo`030?l0003oool0oooo00H0oooo00<0o`00003o003oool03P3oool00`000?l0oooo003o
00040?ooo`030000o`3o0000oooo00T0oooo00<0o`000?ooo`3oool03`3oool20?l00080oooo00<0
003o0?ooo`3oool00P3oool00`00o`00oooo003o00050?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00l0oooo00<0
0?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo003o00080?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo003o00070?ooo`05003o003oool0oooo0?ooo`000?l0
1`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o00000?l0o`0000@0oooo00<0o`000?ooo`000?l0
4`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0
0?l01P3oool00`000?l0o`000?ooo`020?ooo`04003o003oool0oooo0000o`L0oooo00D0003o0?oo
o`3oool0oooo003o000<0?ooo`030000o`00o`00oooo01X0oooo00<00?l00?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo00H0oooo00@0o`000000o`00o`000?l00P3o
ool00`000?l0o`000?ooo`0:0?ooo`80003o2P3oool00`000?l0oooo0?ooo`080?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`0d0?ooo`040?l000000?l0oooo003o00@0
oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0000o`3o000=0?ooo`030?l000000?l0oooo
00@0oooo00@0003o0?ooo`3oool0o`00103oool00`00o`00oooo0?ooo`0=0?ooo`030000o`3oool0
o`0000@0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00l0oooo0P3o000M0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003oool00`3oool0
0`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3oool0003o103o
ool20000o`L0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0000o`060?ooo`030000o`3o
ool0o`0000D0oooo00<00?l00?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo
00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`0M0?ooo`040000o`3oool0oooo0?l000H0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo
0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0=0?ooo`03
003o003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o00000?l00?ooo`0>0?ooo`03
0000o`3oool00?l000@0oooo00<0003o0?l0003oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`80
o`0000D0oooo0?l0003oool0oooo0000o`040?ooo`03003o003oool00?l000D0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`000?l0403oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`00o`00oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?l0000:0?ooo`030000o`3oool00?l000L0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00X0oooo00<00?l00000
o`3o0000103oool0103o0000oooo0?ooo`000?lB0?ooo`03003o003oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool00?l000H0oooo00D0003o0?l0003oool0oooo
003o00030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo
0?ooo`090?ooo`030000o`00o`00oooo01X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`0=0?ooo`05003o003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0>0?ooo`03
003o003oool0oooo00L0oooo00@0o`000000o`3oool0oooo0P00o`000`3oool0003o0?ooo`0:0?oo
o`80003o2P3oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0000o`80oooo00<0o`00
0?ooo`3oool0=03oool0103o0000003o0?ooo`00o`050?ooo`030000o`3oool0oooo00H0oooo00@0
003o0?ooo`000?l0o`003@3oool00`3o0000003o0?ooo`040?ooo`040000o`3oool0oooo0?l000@0
oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?l000040?ooo`03003o003oool0oooo00T0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01`0
oooo00<0o`000000o`3oool0103oool00`000?l0o`000?ooo`030?ooo`03003o003oool0oooo00l0
oooo00<00?l00?ooo`3oool02`3oool00`00o`00003o0?ooo`060?ooo`80003o1@3oool00`00o`00
oooo0?ooo`030?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3o00001@3oool00`00o`00
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01d0oooo00@0003o0?ooo`3o
ool0o`001P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo2P000?l60?oo
o`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`00o`003`3oool00`000?l0o`00003o00040?ooo`030000o`3o0000
oooo00X0oooo00<0o`000?ooo`3oool02P3oool20?l000<0oooo00@0o`000?ooo`3oool0003o1@3o
ool2003o00D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
0000oooo00@0oooo00<0o`000?ooo`000?l0403oool00`00o`00oooo0?ooo`0E0?ooo`05003o003o
ool0oooo0?ooo`000?l01P3oool00`3o0000oooo0?ooo`030?ooo`03003o00000?l0oooo00X0oooo
00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool20?l000P0oooo00<0003o0?ooo`00
o`001`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0o`000?ooo`030?ooo`040?l0003oool0oooo0000oa80oooo00<00?l00?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool0
1@000?l0o`000?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?oo
o`000?l40?ooo`03003o003oool0oooo00P0oooo00<0o`000000o`00o`00703oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00d0oooo00D00?l00?ooo`3oool0oooo0000o`070?ooo`03
0000o`3oool0oooo00d0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`03
003o00000?l0oooo00T0oooo00@0003o0?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`090?oo
o`060?l0003oool0oooo0000o`3oool0o`00=`3oool00`3o0000003o0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`0=0?ooo`030?l000000?l0oooo00@0oooo
00@0003o0?ooo`3oool0o`001@3oool00`00o`00oooo0?ooo`0<0?ooo`030000o`3oool0o`0000@0
oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo02h0
oooo00<0o`000000o`3oool0103oool00`000?l0o`000?ooo`040?ooo`03003o003oool0oooo00@0
oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o00000?l0oooo00P0
oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`030?l000000?l0oooo00H0oooo00<0003o0?oo
o`3o00001@3oool00`00o`00oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0
0`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`00o`00oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
01d0oooo00@0003o0?ooo`3oool0o`001`3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<0
003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`00o`00203oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo003o000>0?ooo`040000o`3oool0o`00003o00D0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`80o`001@3oool0103o0000oooo
0?ooo`000?l50?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`000?l0403oool00`00o`00
oooo0?ooo`0F0?ooo`04003o003oool0oooo0000o`H0oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo0000o`0;0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool00?l000H0oooo00<00?l00?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o00000`3oool0103o
0000oooo0?ooo`000?lB0?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool00?l000H0oooo00@0003o0?l0003oool00?l0103oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0oooo0000o`@0oooo00<00?l00?ooo`3oool0203oool00`3o0000
003o0?ooo`0L0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool03`3oool01000o`00
oooo0?ooo`000?l70?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`020?ooo`040?l000000?l00?l0003o00L0oooo00D0003o0?ooo`3oool0oooo0000
o`090?ooo`030000o`3oool0oooo00X0oooo00D0o`00003o003oool0003o0?l0000g0?ooo`030?l0
00000?l0oooo00H0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00h0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l000060?ooo`03003o003oool0oooo00`0
oooo00<0003o0?ooo`3o00000`3oool00`00o`00oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?oo
o`3o0000<@3oool00`3o0000003o0?ooo`040?ooo`030000o`3o0000oooo00@0oooo00<00?l00?oo
o`3oool0103oool20000o`P0oooo00<00?l00?ooo`3oool02`3oool00`00o`00003o0?ooo`080?oo
o`050000o`3oool0oooo0?ooo`00o`001P3oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0
o`0000D0oooo00<00?l00?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0
0?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0
0?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0N
0?ooo`030000o`3oool0o`0000L0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030000o`3o
ool0oooo00H0oooo00<00?l00?ooo`3oool01@3oool01@00o`00oooo0?ooo`3oool0003o0100oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool00?l000P0oooo
00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`00o`003P3oool00`000?l0oooo003o00050?ooo`030?l000000?l0oooo00/0oooo
2P3o00080?ooo`030?l0003oool0003o00D0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool0103oool0103o0000oooo
0?ooo`000?l?0?ooo`03003o003oool0oooo01H0oooo00@00?l00?ooo`3oool0003o1`3oool0103o
0000oooo0?ooo`00o`020?ooo`030?l000000?l0oooo00T0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o
00050?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`030000
o`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0000o`0A0?ooo`03003o003oool0oooo00H0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l000H0oooo00@0003o0?l0
003oool00?l01@3oool00`000?l0oooo0?ooo`020?l00080oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`070?ooo`040?l0003oool00?l00000oa`0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0?0?ooo`04003o003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool0
0`00o`080?ooo`03003o003oool0oooo00X0oooo00<0003o0?l0003oool00`3oool0103o0000oooo
0000o`3oool2003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo
00X0oooo00@0o`00003o003oool0003o>03oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3o00001P3oool00`00o`00oooo0?ooo`0;0?ooo`040000o`3oool0
oooo0?l000<0oooo00<00?l00?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0o`000340oooo
00<0o`000000o`3oool0103oool00`000?l0o`000?ooo`040?ooo`03003o003oool0oooo00@0oooo
00@0003o0?ooo`000?l0003o1P3oool00`00o`00oooo0?ooo`0;0?ooo`03003o00000?l0oooo00P0
oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`030?l000000?l0oooo00H0oooo00<0003o0?oo
o`3o00001@3oool00`00o`00oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0
0`00o`00oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`00o`00oooo0?oo
o`0J0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000703oool00`000?l0o`000?ooo`07
0?ooo`05003o003oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`050?ooo`03003o003o
ool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`0@0?ooo`050?l0003oool0oooo0?ooo`3o
00001@3oool00`000?l0oooo003o00080?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo003o00000?l0303oool00`00
0?l0oooo003o00050?ooo`030?l000000?l0oooo01d0oooo00<0o`000?ooo`000?l03@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?l0003oool0103oool01P3o
0000oooo0?ooo`000?l0oooo003o00d0oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0000
o`080?ooo`080?l0003oool0oooo003o003oool0o`000?ooo`000?l:0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool01`3oool20?l000<0oooo00D0003o0?ooo`3oool0oooo003o0005
0?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`003`3oool00`000?l0oooo0?l0
00020?ooo`050?l0003oool0oooo0?ooo`000?l04@3oool00`00o`00oooo0?ooo`060?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030000
o`3o00000?l000H0oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000oooo0000o`D0oooo00<00?l0
0?ooo`3oool01P3oool0103o00000?l00?ooo`000?lM0?ooo`04003o003oool0oooo003o0180oooo
00@00?l00?ooo`3oool0003o1`3oool010000?l0oooo0?ooo`00o`020?ooo`@00?l00`3oool00`00
o`00oooo0?ooo`0;0?ooo`030000o`3o0000oooo00<0oooo00<0o`000?ooo`000?l00P3oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0;0?ooo`03003o003oool0003o03T0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`030?ooo`060000o`3oool0oooo0?ooo`3o0000003o3@3oool00`000?l0o`000?oo
o`040?ooo`030000o`3oool0o`0000H0oooo00<00?l00?ooo`3oool02`3oool010000?l0oooo0?oo
o`3o00030?ooo`03003o003oool0oooo00/0oooo00@0003o0?ooo`3oool0o`00<@3oool00`3o0000
003o0?ooo`040?ooo`030000o`3o0000oooo00@0oooo00<00?l00?ooo`3oool0103oool01@000?l0
oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool02`3oool00`00o`00003o0?ooo`090?oo
o`030000o`3oool00?l000L0oooo00<0o`000000o`3oool01P3oool00`000?l0oooo0?l000050?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`08
0?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`00o`00oooo0?ooo`0F0?ooo`D00000703o
ool003T0oooo00<000000?ooo`3oool07P3oool00`000?l0o`000?ooo`070?ooo`05003o003oool0
oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`000?l04P3oool0103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00L0oooo
00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00@0o`000?ooo`3oool0oooo0P000?l<0?ooo`030000o`3oool00?l000D0oooo00<0o`000000o`3o
ool07@3oool00`3o0000oooo0000o`0=0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l00?l00?ooo`040?ooo`060?l0003oool0oooo0000o`3oool00?l03@3oool0
0`00o`00oooo0?ooo`0F0?ooo`03003o003oool0003o00P0oooo00<0o`000?ooo`00o`000P3oool0
0`3o0000oooo0000o`0;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool0
103o0000oooo0?ooo`000?l30?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3o
ool00`000?l0oooo0?l0000@0?ooo`030000o`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo
0000o`0A0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`00o`001P3oool020000?l0oooo
0?ooo`3o0000oooo0?l0003oool0003o1@3oool00`00o`00oooo0?ooo`060?ooo`040?l00000o`00
oooo0000oad0oooo00@00?l00?ooo`3oool00?l04P3oool01000o`00oooo0?ooo`000?l80?ooo`03
0000o`00o`00oooo00H0oooo0`00o`0>0?ooo`030000o`3o0000oooo0080oooo00L0o`000?ooo`3o
ool0oooo0000o`3oool00?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00/0oooo00<00?l00?l000000?l0>@3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`0<
0?ooo`030000o`3o0000oooo00D0oooo00<0003o0?l0003oool01@3oool00`00o`00oooo0?ooo`0;
0?ooo`040000o`3oool0oooo0?l000<0oooo00<00?l00?ooo`3oool02`3oool010000?l0oooo0?oo
o`3o000a0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o000>0?ooo`03
003o00000?l0oooo00T0oooo00<0003o0?ooo`00o`001`3oool00`3o0000003o0?ooo`060?ooo`03
0000o`3oool0o`0000D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`04
0000o`3oool0oooo003o00P0oooo00@0o`000?ooo`3oool0o`002@3oool00`00o`00oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01h0oooo00<0003o0?l0
003oool01`3oool01000o`00oooo0?ooo`000?l70?ooo`030000o`3oool0oooo00D0oooo00<00?l0
0?ooo`3oool01P3oool00`00o`00oooo0000o`0B0?ooo`040?l0003oool0oooo0?l000H0oooo00<0
003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00D0oooo00<0
o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`000?l00?l00?ooo`000?l02`3oool00`000?l0
0?l00?l000050?ooo`030?l000000?l0oooo01d0oooo00<0o`000?ooo`000?l03@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o003o003o00000`3oool01@3o0000
oooo0?ooo`3oool0003o00800?l03@3oool00`00o`00oooo0?ooo`0G0?ooo`030000o`3oool0oooo
00P0oooo00L0o`00003o003oool0oooo0?l0003oool0003o00/0oooo00D0o`000?ooo`3oool0oooo
0?l0000>0?ooo`030?l0003oool0003o00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`070?ooo`030000o`3o0000oooo00l0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00030?oo
o`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`000?l00?l00?l000060?oo
o`030000o`3oool0o`000080oooo00<0o`000?ooo`000?l01@3oool5003o00@0oooo00@00?l00?oo
o`3oool0003o7@3oool00`00o`00oooo003o000C0?ooo`04003o003oool0oooo0000o`P0oooo00<0
003o003o003oool05`3oool00`000?l0o`000?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool00`00o`00oooo0000o`070?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
2`3oool01000o`00o`000?ooo`000?lh0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00`0oooo00<0003o0?l0003o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00/0oooo00@0003o0?ooo`3o
ool0o`000P3oool00`00o`00oooo0?ooo`0<0?ooo`030000o`3oool0o`0001<0oooo00<0003o0?oo
o`3oool0703oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<00?l00?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003o00<0oooo003o003oool03@3oool00`00
o`00003o0?ooo`090?ooo`030000o`3oool00?l000L0oooo00<0o`000000o`3oool01`3oool00`00
0?l0o`000?ooo`040?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`00o`090?ooo`030?l0003oool0o`0000T0oooo00<00?l00?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3o0000oooo
00L0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`000?l04P3oool00`3o0000oooo0?l000060?ooo`03003o00000?l0
oooo00P0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00L0o`000?ooo`000?l0oooo003o003oool0003o00/0oooo00<0003o003o003o0000
1@3oool00`3o0000oooo0000o`0M0?ooo`030?l0003oool0003o00d0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`00o`00o`0000<0oooo00P0o`000?ooo`3oool0
oooo0000o`00o`00oooo003o00`0oooo00<00?l00?ooo`3oool05`3oool00`000?l0oooo0?ooo`08
0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0;0?ooo`040?l0003oool0oooo0?l000l0
oooo00<0o`000?ooo`000?l00`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00L0
oooo00<0003o0?ooo`3oool03`3oool01P000?l00?l00?ooo`3o0000oooo0?l000<0oooo00<0003o
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000D0oooo00<0
0?l00?ooo`3oool00P3oool010000?l0oooo003o003o00060?ooo`030000o`3oool0o`000080oooo
00<0o`000?ooo`000?l02P3oool5003o0080oooo00<0003o0?ooo`3oool0703oool2003o01@0oooo
00<00?l00?ooo`000?l0203oool00`000?l00?l00?ooo`0G0?ooo`030000o`3o0000oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`03003o003oool0003o00L0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0;0?ooo`04003o003oool0oooo0000ocP0oooo00<0003o0?oo
o`3oool01`3oool010000?l0oooo0?ooo`000?l20?ooo`@0o`0000<0003o0?ooo`3oool02`3oool0
0`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool02`3oool0
1`000?l0oooo0?ooo`3oool0o`000?ooo`00o`003P3oool00`000?l0oooo0?l0000C0?ooo`80003o
7@3oool00`3o0000003o0?ooo`040?ooo`030?l000000?l0oooo00@0oooo00<00?l00?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`00o`00oooo00d0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l00?l00?ooo`070?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0
103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0
0?l02@3oool00`3o0000oooo0?l000090?ooo`03003o003oool0oooo01X0oooo00<000000?ooo`3o
ool06P3oool003T0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`070?ooo`04003o
003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03
003o00000?l0oooo0180oooo00<0o`000?ooo`3o00001P3oool00`00o`00003o0?ooo`080?ooo`03
003o003oool0oooo00/0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`07
0?l000000?l0oooo0?ooo`00o`00oooo0000o`0:0?ooo`040000o`3oool00?l00?l000@0oooo00@0
o`000?ooo`3oool0003o7@3oool00`3o0000oooo0000o`0=0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool02@3oool010000?l0oooo003o003o00030?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo01L0oooo00<0003o003o
003oool02@3oool01000o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00T0oooo00@0o`00
0?ooo`3oool0o`00403oool00`3o0000003o0?ooo`030?ooo`04003o003oool0oooo003o00X0oooo
00<0003o0?ooo`3oool03`3oool01P000?l00?l00?ooo`3o0000oooo0?l000<0oooo00<0003o0?oo
o`3oool03`3oool00`00o`00oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000D0oooo00<00?l0
0?ooo`3oool00P3oool010000?l00?l00?ooo`3o00060?ooo`030000o`3oool0o`000080oooo00<0
o`000000o`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00<0
0?l00?ooo`3oool04`3oool00`00o`00oooo0000o`080?ooo`030000o`00o`00oooo01L0oooo00D0
003o0?l0003oool0oooo0?l000050?ooo`040000o`3oool00?l00000o`P0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0;0?ooo`04003o003oool0oooo0000ocP0oooo00<0003o0?oo
o`3oool01`3oool010000?l0o`000?l000000?l20?l000@0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool02P3oool0
1`000?l0oooo0?ooo`3oool0o`000?ooo`00o`003P3oool00`000?l0oooo0?l0000C0?ooo`030000
o`3oool0003o01d0oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`040?ooo`03003o
003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`00o`00oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`040000o`3oool0oooo003o
00T0oooo00<0o`000?ooo`3o00002@3oool00`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo01h0oooo00<0o`000000o`3oool01`3oool01000o`00
oooo0?ooo`000?l80?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00
o`00003o0?ooo`0C0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`000?l0203oool00`00
o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000003o0?ooo`030?ooo`03003o003oool0003o00T0oooo00@0003o003o003oool0o`00103oool0
103o0000oooo0?ooo`000?lN0?ooo`030?l000000?l0oooo00`0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`090?ooo`040000o`3oool00?l00?l000<0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool05`3oool00`000?l0
oooo003o00080?ooo`05003o003o0000oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`090?oo
o`80o`004@3oool00`3o0000003o0?ooo`030?ooo`04003o003oool0oooo003o00T0oooo00<0o`00
0?ooo`000?l0403oool01P000?l00?l00?ooo`3o0000oooo0?l000@0oooo00<0003o0?ooo`3oool0
3P3oool00`00o`00oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000H0oooo00P00?l00?ooo`3o
ool0oooo0000o`00o`00oooo0?l000L0oooo00H0003o0?ooo`3oool0oooo0?l000000?l>0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0<@3oool00`00o`00oooo0000o`080?ooo`03
0000o`3oool0oooo01L0oooo00D0003o0?l0003oool0oooo0?l000050?ooo`030000o`3oool0003o
00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`04003o003oool0oooo
0000ocP0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`080?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?l0003oool0103oool00`3o0000003o0?ooo`070?ooo`03003o003oool0
oooo00X0oooo00L0003o0?ooo`3oool0oooo0?l0003oool00?l000h0oooo00<0003o0?l0003oool0
4P3oool01@000?l0oooo0?ooo`3oool0003o01`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
003o0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`00o`00oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
o`000?ooo`070?ooo`030000o`3oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`050?oo
o`040000o`3oool0oooo003o00X0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01h0oooo00<0o`000000
o`3oool01`3oool01000o`00oooo0?ooo`000?l90?ooo`030000o`3oool0oooo0080oooo00<00?l0
0?ooo`3oool01`3oool00`000?l00?l00?ooo`0C0?ooo`030?l0003oool0oooo00@0oooo00@00?l0
0?ooo`3oool0003o203oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00H0oooo00D0
o`000?ooo`3oool0oooo0000o`050?ooo`03003o003oool0003o00T0oooo00@0003o003o003oool0
o`00103oool0103o0000oooo0?ooo`000?lN0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`040000o`3oool00?l00?l000<0oooo00D0o`00
0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool05`3o
ool00`000?l0oooo003o00080?ooo`05003o003oool0o`000?ooo`3o00000`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo
0?ooo`00o`090?ooo`030?l0003oool0003o00l0oooo00@0003o0?ooo`00o`00oooo0P3o00050?oo
o`040000o`3oool0oooo003o00d0oooo00<00?l00?ooo`3oool01`3oool0103o0000oooo0?ooo`3o
00060?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0340oooo00<00?l00000o`3oool0203oool00`000?l0oooo0?ooo`0G0?ooo`050000
o`3o0000oooo0?ooo`3o00001P3oool20000o`X0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`000?l0=P3oool00`000?l0o`000?ooo`080?oo
o`030000o`3oool0003o00P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`040?oo
o`030?l000000?l0oooo00L0oooo00<00?l00?ooo`3oool02P3oool01P000?l0oooo0?ooo`3oool0
o`00003o0100oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`020?ooo`80003o6P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l000000?l0oooo00D0oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0003o003o003oool02P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0103o
ool01@00o`00oooo0?ooo`3oool0003o00D0oooo00@0003o0?ooo`3oool00?l02P3oool00`3o0000
oooo0?ooo`090?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool07P3oool00`3o0000003o0?ooo`070?ooo`04003o003oool0oooo0000o`T0
oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`030000o`00o`00oooo01X0
oooo00@00?l00?ooo`3oool0003o2@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo
00H0oooo00D0o`000?ooo`3oool0003o0?l000050?ooo`04003o003oool0oooo0000o`P0oooo00D0
003o003o003oool0oooo0?l000030?ooo`040?l0003oool0oooo0000oah0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`3o
ool00?l00P3oool02@3o0000oooo0?ooo`3oool00?l00?ooo`000?l0oooo003o000;0?ooo`03003o
003oool0oooo01H0oooo00@0003o0?ooo`3oool00?l01`3oool01P00o`00oooo0?ooo`3o0000oooo
0?l000<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`0A0?ooo`030000o`3o0000
oooo00<0oooo00@00?l00?ooo`3oool00?l0203oool01@3o0000oooo0?ooo`3oool0003o00h0oooo
00<0003o0?ooo`00o`000P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo003o00d0
oooo00<00?l00?ooo`3oool01`3oool0103o0000oooo0000o`3o00060?ooo`05003o003oool0oooo
0?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0340oooo00<00?l0
0000o`3oool0203oool00`00o`00003o0?ooo`0G0?ooo`040000o`3oool0o`000?l000L0oooo00<0
003o0?ooo`00o`002@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo00D0
0?l00?ooo`3oool0oooo0000o`0f0?ooo`030000o`3o0000oooo00L0oooo00<0o`000?ooo`000?l0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`000?l0
1`3oool00`00o`00oooo0?ooo`0:0?ooo`060000o`3oool0oooo0?ooo`3o00000?l0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l000000?l0oooo00D0oooo00<00?l00?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`03003o00000?l0oooo00d0oooo00<0003o003o003oool02@3oool00`00
o`00003o0?ooo`070?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0103oool01@00
o`00oooo0?ooo`3oool0003o00D0oooo00@0003o0?ooo`3oool00?l05P3oool00`00o`00oooo0?oo
o`0I0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo01d0oooo00<0o`00
0?ooo`000?l0203oool00`00o`00oooo0000o`0;0?ooo`050000o`3oool0oooo0?ooo`00o`00203o
ool00`000?l0oooo003o000K0?ooo`04003o003oool0oooo0000o`T0oooo00<00?l00?ooo`3oool0
2@3oool00`00o`00oooo0?ooo`070?ooo`050?l0003oool0003o0?ooo`3o00001P3oool00`00o`00
oooo0000o`080?ooo`050000o`00o`00oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0
003o01d0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00T0oooo00L0003o0?ooo`3oool00?l00?l0003oool0o`0000<0oooo00D00?l00?ooo`000?l0
oooo003o000;0?ooo`03003o003oool0oooo01H0oooo00@0003o0?ooo`3oool00?l01`3oool01P00
o`00oooo0?ooo`3o0000oooo0?l000<0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?oo
o`000?l@0?ooo`030000o`3o0000oooo00<0oooo00<00?l00?ooo`00o`002@3oool01@3o0000oooo
0?ooo`3oool0003o00h0oooo00<0003o0?ooo`00o`000P3oool00`3o0000oooo0?ooo`030?ooo`04
0000o`3oool00?l0003o00`0oooo00<00?l00?ooo`3oool02@3oool00`3o0000003o0?l000060?oo
o`05003o003oool0oooo003o00000?l00P3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0
oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0380oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`0G0?ooo`040000o`3oool0
o`000?l000T0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00`0oooo00D00?l00?ooo`3oool0oooo0000o`0f0?ooo`030000o`3oool0o`0000L0oooo
00<0o`000?ooo`000?l02@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0o`0000<0oooo
00@0o`000?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo0080
oooo00<0o`00003o003oool03`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`030?ooo`030?l000000?l0oooo00D0
oooo00D00?l00?ooo`3oool0oooo0000o`090?ooo`03003o003oool0003o00d0oooo00<0003o003o
003oool02@3oool00`00o`00003o0?ooo`070?ooo`030000o`3o0000oooo00L0oooo00<0003o0?oo
o`3oool0103oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00@0003o0?ooo`3oool00?l05P3o
ool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0
oooo01d0oooo00<0o`000?ooo`000?l02@3oool00`00o`00003o0?ooo`0:0?ooo`040000o`3oool0
oooo003o00T0oooo00<0003o0?ooo`00o`006`3oool01@00o`00oooo0?ooo`3oool0003o00P0oooo
00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`070?ooo`040?l000000?l0oooo0?l000L0
oooo00<00?l00?ooo`000?l0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`070000o`3oool0oooo003o003o0000oooo0?l0
00030?ooo`03003o003oool0003o0080oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?oo
o`0E0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?oo
o`3oool20?l000@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3o00000`3oool00`00o`00oooo003o00080?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo003o00020?ooo`030?l0
003oool0oooo00<0oooo00D0003o0?ooo`00o`00oooo003o000;0?ooo`03003o003oool0oooo00T0
oooo00<0003o0?ooo`000?l01P3oool01@00o`00oooo0?ooo`00o`00003o0080oooo00<0o`000?oo
o`3oool0103oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?oo
o`000?l05`3oool00`000?l0oooo0?ooo`020?l000T0oooo00<00?l00?ooo`3oool0203oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00D00?l00?ooo`3oool0oooo0000o`0f
0?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0003o1`3oool00`00o`00oooo0?oo
o`090?ooo`030000o`3oool0oooo0080oooo00<0o`00003o003oool03P3oool00`3o0000003o0?oo
o`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?oo
o`030?ooo`030?l000000?l0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`090?ooo`03003o
003oool0003o00d0oooo00<0003o003o003oool02@3oool00`00o`00oooo0000o`070?ooo`030000
o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0003o00H0
oooo00<0003o0?ooo`00o`005P3oool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o
0?ooo`0:0?ooo`040000o`3oool0oooo003o00T0oooo00<0003o0?ooo`00o`006P3oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool02@3oool00`00o`00
oooo0?ooo`070?ooo`040?l000000?l0oooo0?l000P0oooo00<00?l00?ooo`000?l01P3oool00`00
0?l00?l00?ooo`020?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool0
1`000?l0oooo0?ooo`00o`00o`000?ooo`3o00000P3oool01000o`00oooo0?ooo`000?l20?ooo`03
003o003oool0oooo00P0oooo00<00?l00?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0o`0000@0oooo0P00o`080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool02`3oool010000?l0oooo0?ooo`00o`070?ooo`050000o`00o`00oooo0?ooo`00o`002`3oool0
0`00o`00oooo0?ooo`090?ooo`030000o`3oool0003o00L0oooo0P00o`001@3oool0003o0?ooo`3o
ool0o`0000H0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`060?ooo`03003o003o
ool0003o01L0oooo00@0003o0?ooo`3oool0o`002P3oool00`00o`00oooo0?ooo`080?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`030?ooo`030000
o`3oool0oooo03<0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0o`000`3oool0103o0000oooo0?ooo`000?l80?oo
o`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0>0?oo
o`030?l000000?l0oooo0140oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0E0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000000o`3oool01@3oool01@00o`00oooo0?ooo`3oool0
003o00T0oooo00<00?l00?ooo`000?l03@3oool00`000?l00?l00?ooo`080?ooo`04003o003oool0
oooo0000o`L0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`040?ooo`05003o003o
ool0oooo0?ooo`000?l01P3oool00`000?l0oooo003o000F0?ooo`03003o003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?oo
o`060?ooo`03003o00000?l0oooo00/0oooo00<0003o0?ooo`00o`00203oool01@000?l0oooo0?oo
o`3oool00?l001T0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`03003o
003oool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool0103o0000003o0?ooo`3o00090?ooo`03
003o00000?l0oooo00D0oooo00<0003o003o003oool00P3oool0103o0000oooo0?ooo`3o00040?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool03P3oool010000?l0oooo0?ooo`3oool4
0?l000`0oooo00L0003o0?ooo`3oool00?l00?l0003oool0o`000080oooo00@00?l00?ooo`3oool0
003o0P3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`00o`005`3oool00`00
0?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool00?l01`3oool0
1@000?l00?l00?ooo`3oool00?l000/0oooo00<00?l00?ooo`3oool02@3oool00`000?l0o`000000
o`070?ooo`800?l000<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0003o00@0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0340oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0000o`0G0?ooo`040000o`3o
ool0oooo0?l000X0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00/0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0c0?ooo`030000
o`3oool0o`0000D0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`040000
o`3oool0oooo0?l000<0oooo00@0o`000?ooo`3oool0003o203oool00`00o`00oooo0?ooo`080?oo
o`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool03P3oool00`3o0000003o0?ooo`0A0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?oo
o`030?l000000?l0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`090?ooo`03003o003oool0
003o00`0oooo00<0003o0?ooo`00o`002@3oool01000o`00oooo0?ooo`000?l70?ooo`030000o`3o
0000oooo00L0oooo00<0003o0?ooo`3oool01@3oool01000o`00oooo0?ooo`000?l60?ooo`030000
o`00o`00oooo01H0oooo00<00?l00?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool5000001h0oooo00<0003o0?ooo`3oool01P3oool00`00o`00003o0?ooo`0;0?ooo`030000o`3o
ool00?l000P0oooo00D0003o0?ooo`3oool0oooo003o000I0?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00L0oooo
00@0003o0?ooo`3oool0o`002@3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`0<0?ooo`@0003o2P3oool00`00
0?l0o`000?ooo`0=0?ooo`80o`0000<0003o0?l0003o0000403oool02@000?l0oooo0?ooo`00o`00
o`000?ooo`3o0000oooo003o00030?ooo`040000o`3oool0oooo003o00D0oooo0P000?l30?ooo`03
003o003oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`000`3oool00`00o`00oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`00o`07
0?ooo`050000o`3oool0oooo0?ooo`00o`001`3oool01@000?l0oooo0?ooo`3oool00?l000/0oooo
00@0003o0?l0003oool0003o1P3oool00`00o`00oooo0000o`040?ooo`030?l0003oool0oooo0080
oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0o`000?ooo`0;0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`060?ooo`04003o003oool0oooo
0000oaH0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0
oooo03<0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00T0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00D0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo00d0oooo00@0o`000?ooo`3oool0003o4@3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`050?ooo`05003o
003oool0oooo0?ooo`000?l02@3oool00`00o`00oooo0000o`0<0?ooo`040000o`3oool0oooo003o
00H0oooo0P00o`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool01`3oool00`00
0?l0oooo0?ooo`050?ooo`04003o003oool0oooo0000o`H0oooo00<0003o003o003oool05`3oool0
0`00o`00oooo0?ooo`0D0?ooo`D00000703oool003T0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`060?ooo`03003o00000?l0oooo00`0oooo00<0003o003o003oool01P3oool00`00
0?l0oooo0?ooo`020?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool00`00
0?l0oooo0?l0000;0?ooo`03003o00000?l0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00L0oooo1@000?l30?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?l0003oool03@3oool0103o0000oooo0?ooo`000?lA0?ooo`060000o`3o
ool0oooo0?ooo`00o`00o`000P3oool01@00o`00oooo0?ooo`3oool0003o0080oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0000o`030?ooo`03003o003oool0oooo01@0oooo00<0003o0?oo
o`3oool0103oool01000o`00oooo0?ooo`00o`0<0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?l000X0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo003o00L0oooo
00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`00
o`002P3oool01@000?l0oooo0?l0003oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?l0003oool02`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0340oooo00<0003o003o003oool01@3oool0
1@00o`00oooo0?ooo`3oool0003o00@0oooo1@000?l=0?ooo`030000o`3oool0oooo00`0oooo00<0
0?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0
0?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0o`0000@0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?l00080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00L0oooo
00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0=0?ooo`040?l0003oool0oooo0000oa40
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000000o`3oool01P3oool01000o`00oooo0?ooo`000?l80?ooo`04003o003oool0oooo
0000o``0oooo00@0003o0?ooo`3oool00?l0103oool2003o00H0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?l000080?ooo`030000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0003o
1P3oool00`000?l00?l00?ooo`0G0?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00`0oooo00<00?l00000o`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo01H0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?l0000<0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l000060?ooo`030000o`3o
ool0oooo00D0oooo0P000?l90?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0003oool03@3o
ool01@3o0000oooo0?ooo`3oool0003o0100oooo00H0003o0?ooo`3oool0oooo003o003o00020?oo
o`05003o003oool0oooo0?ooo`000?l00P3oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00@0
003o0?ooo`3oool00?l05@3oool00`000?l0oooo0?ooo`050?ooo`04003o003oool0oooo003o00`0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool010000?l0oooo0?ooo`00o`070?ooo`03003o00000?l0oooo0080oooo00<00?l0
0?ooo`3oool00`3oool00`000?l0oooo0000o`020?ooo`03003o003oool0oooo00P0oooo00<0003o
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3oool0o`0000/0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`00o`00oooo00D0oooo00@0
0?l00?ooo`3oool0oooo1@000?l40?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0
303oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
2`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3o0000
0`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0
o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000oooo00h0oooo00@0o`000?ooo`3o
ool0003o4@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo01@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0000o`070?ooo`04003o003oool0oooo0000o`P0oooo00D00?l0
0?ooo`3oool0oooo0000o`0;0?ooo`040000o`3oool0oooo003o0080oooo0P00o`080?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001`3oool00`000?l0oooo0?ooo`050?ooo`03
003o003oool0003o00L0oooo00<0003o003o003oool05`3oool00`00o`00oooo0?ooo`0H0?ooo`03
0000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0003o00H0oooo00<0003o0?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00L0oooo00<0003o0?l0003o0000
303oool00`000?l00?l00?ooo`020?ooo`03003o00000?l0oooo00<0oooo00<0o`000?ooo`3o0000
1P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0o`000?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`020?ooo`04003o003o0000oooo003o00D0oooo00@0003o0?ooo`3o
ool00?l00P000?l40?ooo`030000o`3oool00?l001H0oooo00<0003o0?ooo`3oool01@3oool00`00
o`00oooo003o000=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool20000
o`L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0
003o00<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0000o`020?ooo`03003o003oool0
oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`060000o`3oool0oooo0000o`3oool0
o`002`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`00
o`001P3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3o
00000P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00H0003o0?ooo`3o
ool0o`000?ooo`3o00050?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`03003o003o0000oooo00h0oooo00@0o`000?ooo`3oool0003o403o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0000o`070?ooo`03003o003oool0003o00T0oooo00D00?l00?ooo`3oool0oooo
0000o`0;0?ooo`030000o`3oool0oooo00<00?l02P3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0?l000H0oooo00<0o`000?ooo`000?l01P3oool00`00o`00oooo0000o`070?ooo`03
0000o`00o`00oooo01L0oooo00D00?l00?ooo`3oool0oooo0000o`0F0?ooo`030000003oool0oooo
01X0oooo000i0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0<0?ooo`03003o003oool0oooo0080003o0`3oool00`000?l0oooo0?ooo`040?ooo`03
003o003oool0oooo01D0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool00`000?l0o`000?l0000=0?ooo`05
0000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo
0080oooo0P000?l=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o00003@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool01000
o`00oooo0?ooo`00o`050?ooo`040000o`3oool0oooo0000o`H0oooo00<0003o0?ooo`00o`005P3o
ool00`000?l0oooo0?ooo`050?ooo`03003o003oool00?l000h0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0=0?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`040000o`3o
ool0oooo003o00H0oooo00<00?l00?ooo`000?l00`3oool00`00o`00oooo0?ooo`020?ooo`060000
o`3oool0oooo0000o`3oool00?l02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00H0003o
0?ooo`3oool0003o0?ooo`3o000;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
;`3oool00`000?l0oooo003o00050?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
<P3oool01P000?l0oooo0?ooo`3o0000oooo0?l00140oooo00<0003o0?ooo`3oool0203oool01000
0?l0oooo0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`06
0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3o00003@3oool01@3o0000oooo0?ooo`3o
ool0003o0100oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo0080oooo00@0o`000?ooo`3oool0003o1P3oool00`00o`00oooo0000o`090?ooo`05003o
003oool0oooo0?ooo`000?l02`3oool010000?l0oooo0?ooo`00o`0<0?ooo`030000o`3oool0oooo
00<0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0000o`060?ooo`03003o003oool0
003o00L0oooo00<0003o003o003oool05`3oool01000o`00oooo0?ooo`000?lG0?ooo`030000003o
ool0oooo01X0oooo000i0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool0003o1P3o
ool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3o00003P3o
ool01@000?l00?l00?ooo`3oool0003o00H0oooo0P3o00070?ooo`040000o`3oool0oooo0000o`l0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l0000=0?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo003o
00D0oooo00@0003o0?ooo`000?l00?l01P3oool00`000?l0oooo003o000E0?ooo`030000o`3oool0
oooo00L0oooo00<00?l00?ooo`3oool03@3oool01@000?l0oooo0?ooo`3oool0003o0180oooo0P00
0?l30?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`04003o
003oool0oooo0000o`@0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`030000o`3oool00?l0
00X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0000o`80oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo01T0oooo00<0
003o0?ooo`3oool04`3oool00`000?l0oooo003o00050?ooo`03003o003oool0oooo00`0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo00D0
003o0?ooo`3oool0oooo0000o`0=0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0
<@3oool00`000?l0oooo0?ooo`020?l00180oooo00<0003o0?ooo`3oool0203oool010000?l0oooo
0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<00?l00?ooo`3o00003@3oool01@3o0000oooo0?ooo`3oool0003o
0100oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o0000oooo
00<0oooo00@0o`000?ooo`3oool0003o1P3oool00`00o`00oooo0000o`090?ooo`05003o003oool0
oooo0?ooo`000?l02`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0o`001P3oool00`3o0000oooo0000o`060?ooo`03003o003oool0003o00P0oooo
00<0003o0?ooo`3oool05P3oool01000o`00oooo0?ooo`000?lG0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0<0?ooo`03003o003oool0oooo00<0oooo0P000?l70?ooo`03003o003oool0oooo00L0oooo
00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0o`0000h0oooo
00D0003o0?ooo`00o`00oooo0000o`060?ooo`80o`001`3oool30000oa40oooo00<0003o0?ooo`3o
ool0103oool010000?l0oooo0?ooo`3o000<0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool00?l000H0oooo0P000?l00`3o
ool00?l00?ooo`050?ooo`030000o`3oool00?l001D0oooo00<0003o0?ooo`3oool01`3oool00`00
o`00oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l0503oool20000o`030?ooo`000?l0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0
oooo0000o`@0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030000o`00o`00oooo00T0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00@0o`000?ooo`3oool0o`00103oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0003o
01@0oooo00@0003o0?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`080?ooo`050000o`3oool0
oooo003o00000?l03@3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0340oooo00<0
003o0?ooo`3oool00P3o000B0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo
0P3o00060?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`04003o003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
o`000?ooo`030?ooo`040?l0003oool0oooo0000o`H0oooo00<00?l00?ooo`000?l02@3oool01@00
o`00oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`02
0?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`000?l01P3oool00`00o`00oooo0000
o`080?ooo`030000o`3oool0oooo01H0oooo00<00?l00?ooo`000?l0603oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0303oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<00?l0
0?ooo`3oool01@3oool2003o00030?ooo`00o`00oooo00X0oooo00<00?l00?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`070?ooo`030000o`3oool0o`0000l0oooo00@0003o003o0000o`00003o1P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0103o
ool010000?l0oooo0?ooo`3o000;0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`030?ooo`800?l01P3oool010000?l0oooo0?ooo`00o`070?ooo`03
0000o`00o`00oooo01<0oooo00<0003o0?ooo`3oool0603oool010000?l0oooo0?ooo`000?lG0?oo
o`80003o1@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool0
0`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo0000o`@0oooo00<0003o003o003oool02@3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo01H0oooo00@0003o0?ooo`3oool0
003o503oool010000?l0oooo0?ooo`00o`040?ooo`03003o003oool0oooo00`0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00P0oooo00D0003o0?oo
o`3oool00?l00000o`0=0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool0
1@000?l0oooo0?ooo`3oool0o`0001<0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?oo
o`3oool0o`0000L0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00@00?l00?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?ooo`03
0000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o1P3oool00`00o`00oooo0000o`080?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0000o`06
0?ooo`03003o003oool0003o00P0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0G
0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0240oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo003o000<0?ooo`03003o003oool0oooo00d0oooo00<00?l00?oo
o`3oool00`3oool2003o00<0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0oooo0P000?l40?ooo`03003o003oool0
oooo00L0oooo00<0003o0?ooo`3oool03`3oool010000?l0oooo003o00000?l60?ooo`030?l0003o
ool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o000;0?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`03003o
003oool0oooo00P0oooo00<00?l00?ooo`3oool01@3oool00`000?l00?l00?ooo`0C0?ooo`030000
o`3oool0oooo01P0oooo00@0003o0?ooo`3oool0003o7`3oool0103o0000oooo0?ooo`3o000@0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`000?l40?ooo`030000o`00
o`00oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0000o`020?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool010000?l0oooo0?ooo`00o`030?ooo`03
003o003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03
003o003oool0oooo00P0oooo00D0003o0?ooo`00o`000?l00000o`0=0?ooo`03003o003oool0oooo
00D0oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`04003o003oool0oooo
0?l000`0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool04@3oool00`000?l0o`000?ooo`030?ooo`040?l0003oool0
oooo0000o`H0oooo00<00?l00?ooo`000?l0203oool00`00o`00oooo0?ooo`020?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3o
ool0oooo0?l000H0oooo00<0o`000?ooo`000?l01P3oool00`00o`00oooo0000o`080?ooo`030000
o`3oool0oooo01H0oooo00<0003o003o003oool0603oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`00o`00303o
ool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo00800?l01P3oool00`00o`00oooo0?oo
o`070?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool01000o`00oooo0?oo
o`3oool20000o`@0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0003o00H0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0?l000/0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`040?ooo`03
0000o`00o`00oooo0180oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0000o`0P0?ooo`03
0?l0003oool0o`000140oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo
0000o`D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo00<0003o0?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool2
0000o`H0oooo00<0003o0?ooo`3oool0403oool010000?l0oooo0?ooo`00o`030?ooo`03003o003o
ool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003o
ool0oooo00T0oooo00@0003o003o0000o`00003o3@3oool00`00o`00oooo0?ooo`060?ooo`030000
o`3oool0oooo02l0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0A0?ooo`03
0000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o1`3oool00`00o`00003o0?ooo`070?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
003o00H0oooo00<00?l00?ooo`000?l0203oool00`000?l0oooo0?ooo`0F0?ooo`030000o`00o`00
oooo01P0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool00?l000`0oooo00<00?l00?ooo`3oool03P3oool3003o
00P0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0oooo
00@0oooo00@00?l00?ooo`3oool0003o0P3oool01@000?l0oooo0?ooo`3oool00?l000T0oooo00<0
003o0?ooo`3oool0403oool20000obD0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?oo
o`3o000;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`0?0?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool04P3oool00`000?l0oooo
0?ooo`0J0?ooo`80003o8@3oool20?l00140oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`020?ooo`04003o003oool0oooo003o00@0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
003o0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool01@000?l0
oooo0?ooo`3oool0003o00H0oooo0P3o00060?ooo`030000o`3oool0003o0080oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo10000?l80?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool01@000?l0oooo0?ooo`3oool0
0?l00080oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0203oool00`000?l00?l00000o`0=0?ooo`03003o003oool0
oooo00L0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`05003o003oool0
oooo0?ooo`000?l01`3oool01@00o`00oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
403oool00`000?l0o`000?ooo`030?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0403oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`000?l01P3oool00`00o`00oooo0000o`080?ooo`030000o`3oool0oooo01D0oooo00<0003o0?oo
o`00o`006@3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`00303oool00`00o`00oooo0?ooo`0>0?ooo`03
003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`080?ooo`03
0000o`3oool0oooo00@0oooo00@00?l00?ooo`3oool0003o0P3oool01@000?l0oooo0?ooo`3oool0
0?l000P0oooo00<0003o0?ooo`3oool04@3oool20000obH0oooo00<0003o0?ooo`3oool00P3oool0
10000?l0oooo0?ooo`3o000;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool04@3o
ool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00@00?l00?ooo`3oool00?l0
1@3oool00`000?l0oooo0?ooo`020?ooo`03003o00000?l0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool20?l000H0
oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool00P3oool30000o`@0oooo10000?l30?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo0?ooo`3oool00?l00080oooo00<00?l00?oo
o`3oool03P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<00?l00?oo
o`3oool0203oool00`000?l0oooo0000o`0=0?ooo`03003o003oool0oooo00L0oooo00<0003o0?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0003o00P0oooo00D00?l00?oo
o`3oool0oooo0?l0000;0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0100oooo00<0003o0?l0003oool00`3oool0
103o0000oooo0?ooo`000?l70?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00@0003o0?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0003o00H0oooo00<00?l00?ooo`000?l0
203oool00`000?l0oooo0?ooo`0D0?ooo`040000o`3oool0oooo003o01T0oooo00<000000?ooo`3o
ool06P3oool003T0oooo1@00000P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`00
303oool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
203oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0003o00<0oooo00D0003o0?ooo`3oool0
oooo003o00080?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0903oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P00o`060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01@3oool00`00o`00003o0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00D0oooo0P000?l4
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0000o`02
0000o`/0oooo0`000?l<0?ooo`030000o`3oool0oooo00h0oooo00L0003o0?ooo`3oool0oooo003o
003oool00?l00140oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`03003o
003oool0oooo00P0oooo00@0003o0?ooo`000?l00?l0303oool00`00o`00oooo0?ooo`070?ooo`03
0000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0000o`080?ooo`05
003o003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o0000oooo
00<0oooo00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`040000o`3oool0
oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`060?ooo`03003o0000
0?l0oooo00P0oooo00<0003o0?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool00?l001D0oooo
1@00000L0?ooo`00>@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`00o`002`3oool00`00o`00oooo0?ooo`0L0?ooo`03003o003oool0oooo00@0oooo00<0
0?l00?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`03003o00000?l0oooo00<0oooo00D0
003o0?ooo`3oool0oooo003o00080?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0
9@3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00`00o`00
oooo0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0DP3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P00o`060?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0000o`070?ooo`030000o`3oool0oooo00T0
oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`050?ooo`80003o103oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo0P000?lN0?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o000A0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?ooo`080?ooo`04003o00000?l0003o
003o00`0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`80003o9P3oool0
0`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00P0oooo00D00?l00?ooo`3oool0oooo0?l0
000;0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?oo
o`000?l70?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0140oooo00@0003o0?ooo`3oool0003o103oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0003o00H0oooo00<00?l00000o`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`D0003o1@3oool01@000?l0oooo0?ooo`3oool00?l001T0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`04
0000o`3oool0oooo003o00/0oooo00<00?l00?ooo`3oool0703oool00`00o`00oooo0?ooo`040?oo
o`03003o003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool00`00o`00003o0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`00o`00203oool00`000?l0oooo0?ooo`0j0?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo00@0oooo00<0
0?l00000o`3oool0403oool00`000?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0
003o003o003oool0103oool00`00o`00oooo0000o`070?ooo`030000o`3oool0oooo00T0oooo00@0
003o0?ooo`3oool0003o3`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo
00<00?l00?ooo`00o`004@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo
00<00?l00?ooo`3oool01`3oool01@00o`00oooo0000o`000?l00?l000`0oooo00<00?l00?ooo`3o
ool0203oool00`000?l0oooo0?ooo`040?ooo`80003o0P3oool30000ob<0oooo00<0003o0?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo10000?l40?ooo`03
003o00000?l0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0003o
00L0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`000?l01P3oool00`00o`00003o0?ooo`080?ooo`03003o00000?l0
oooo00T0oooo00<0003o0?ooo`3oool00P3oool50000o`D0oooo00<00?l00?ooo`3oool05P3oool0
0`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo
0?ooo`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo01d0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool010000?l0oooo0?ooo`00o`080?ooo`030000o`3oool0oooo03/0oooo00<0
003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00000o`3oool0403oool00`000?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`070000o`3oool0oooo0?ooo`000?l0
oooo003o00050?ooo`03003o003oool0003o00H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0000o`0@0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0[0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool2003o0180
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo00H0
oooo00D00?l00?ooo`000?l0003o003o000<0?ooo`03003o003oool0oooo00P0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`<0003o1P3oool50000oaD0oooo00<0003o0?oo
o`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00l0oooo1@000?l2003o
00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00l0oooo00<0003o0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0003o
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo00<00?l00000o`3oool0203o
ool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo01H0oooo00<000000?ooo`3oool06P3o
ool003T0oooo00<000000?ooo`3oool08`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0N0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`00o`00oooo00@0oooo00<0
003o0?ooo`00o`00203oool00`000?l0oooo0?ooo`0l0?ooo`030000o`3oool0003o00@0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool04@3oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo00l0oooo00<0
003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo00L0
003o0?ooo`3oool0oooo0000o`3oool00?l000D0oooo00@00?l00?ooo`3oool0003o1@3oool00`00
0?l0oooo0?ooo`0;0?ooo`80003o403oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0140oooo00<00?l00?ooo`3oool01P3oool01@00o`00oooo0000o`000?l00?l000`0oooo00<00?l0
0?ooo`3oool0203oool010000?l0oooo0?ooo`3oool20000o`/0oooo1P000?l40?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo01H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?l000020?ooo`050?l0003o
ool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0003o00@0oooo
00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3o
ool01`3oool00`00o`00003o0?ooo`080?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3o
ool05P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0S0?ooo`050000
o`3oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo01h0
oooo00D00?l00?ooo`3oool0oooo003o000>0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo003o
00050?ooo`030000o`3oool00?l000P0oooo00<0003o0?ooo`3oool0?@3oool20000o`@0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool04@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0003o00l0oooo00<0
003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo00L0
003o0?ooo`3oool0oooo0000o`3oool00?l000D0oooo00@00?l00?ooo`3oool0003o1@3oool00`00
0?l0oooo0?ooo`0;0?ooo`80003o403oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0140oooo00<00?l00?ooo`3oool01@3oool01P00o`00oooo0?ooo`3oool0003o003o00`0oooo00<0
0?l00?ooo`3oool02@3oool30000oaP0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0G0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05`3oool2003o00@0oooo00<0
0?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool04P3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00H0oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`070?ooo`030000
o`3oool0oooo00h0oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo0200oooo00@00?l00?ooo`3oool00?l03P3oool010000?l0
oooo0?ooo`000?l20?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`00o`00203oool00`00
0?l0oooo0?ooo`0m0?ooo`80003o103oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`000?l03P3oool00`000?l0oooo0?ooo`1F0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`000?l30?ooo`03003o003oool0
oooo0080oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0140oooo00<00?l00?ooo`3oool01@3oool01P00o`00oooo0?ooo`3oool0003o003o00`0
oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01X0
oooo00@00?l00?ooo`3oool00?l01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00h0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool04P3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0000o`08
0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0
0`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo0200oooo00@00?l00?ooo`3oool00?l03P3o
ool010000?l0oooo0?ooo`000?l20?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool0
1`3oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0003o00h0oooo00<0003o0?ooo`3oool0
EP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3oool0
003o0`3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0903oool00`00
0?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0K0?ooo`<00?l01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00h0oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`00o`001P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00H0oooo00<00?l0
0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0oooo01H0oooo00<00000
0?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l4
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool08@3oool00`00o`00oooo003o000>
0?ooo`030000o`3oool0003o00<0oooo00<00?l00?ooo`3oool0103oool00`000?l00?l00?ooo`07
0?ooo`030000o`3oool0oooo03h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`000?l03@3oool00`000?l0oooo0?ooo`1G
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool20000o`@0oooo00<00?l0
0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0903o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3o
ool00`00o`00oooo0?ooo`0U0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0603o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01d0oooo00<00?l00?ooo`3oool0103o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o00000P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`001P3o
ool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`060?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`000?l01`3oool00`000?l0oooo
0?ooo`0@0?ooo`03003o003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool001h0oooo0P00
00040?ooo`8000001@3oool3000000/0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000
o`040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool08@3oool2003o0100oooo0P00
0?l30?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool01P3oool00`000?l0oooo0?oo
o`150?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0000
o`0=0?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0=0?ooo`80003o103oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D0003o0?ooo`3oool0
oooo0000o`0V0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`0:0?ooo`03003o003oool0oooo02D0oooo00<0003o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0903oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o00000P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`001P3oool00`00o`00
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0
oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00H0oooo00<00?l00?ooo`000?l01`3oool00`000?l0oooo0?ooo`0@0?oo
o`03003o003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool001d0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo
o`000?l0103oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo0280oooo00<00?l00?oo
o`3oool03P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00<0003o003o
003oool01P3oool00`000?l0oooo0?ooo`150?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<00?l00?oo
o`3oool00P3oool01000o`00oooo0?ooo`000?l<0?ooo`030000o`3oool0oooo05P0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0=0?ooo`80003o103oool01@00o`00oooo0?ooo`3o
ool00?l000D0oooo00<0003o0?ooo`000?l0:03oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo02l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo02@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3o
ool0o`000080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool00?l000H0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo01/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo
00<0003o003o003oool01`3oool01000o`00oooo0?ooo`000?l50?ooo`030000o`3oool0oooo0140
oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`007@3oool010000000oooo
0?ooo`0000080?ooo`D000002`3oool700000200oooo00<0003o0?ooo`000?l0103oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo03P0oooo00<00?l00?ooo`3oool0103oool00`000?l0
0?l00?ooo`060?ooo`030000o`3oool0oooo04D0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`00o`00
oooo0?ooo`020?ooo`04003o003oool0oooo0000o`/0oooo00<0003o0?ooo`3oool0F@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool01000
o`00oooo0?ooo`00o`050?ooo`030000o`3oool0003o02P0oooo00D0o`000?ooo`3oool0oooo0?l0
000c0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`050?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0T0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o
00060?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0K0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`00o`00oooo00L0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0A0?ooo`03
003o003oool0oooo00l0oooo1`00000L0?ooo`007@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000o`040?oo
o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0>@3oool00`00o`00oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0A@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?oo
o`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`1I
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`04
0?ooo`04003o003oool0oooo003o00D0oooo00<0003o0?ooo`000?l0:03oool01@3o0000oooo0?oo
o`3oool0o`0003<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0I0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0W0?ooo`030000
o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo02@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0o`000080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040000
o`3oool0oooo003o00H0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo
00<0oooo00<0003o003o003oool01`3oool01000o`00oooo0?ooo`000?l40?ooo`030000o`3oool0
oooo0180oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`007@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0903oool0
0`000?l0oooo0000o`040?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0>@3oool0
0`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0A@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0C0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo05X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0D0?ooo`04003o003oool0oooo003o00D0oooo00<0003o0?ooo`000?l0:03oool01@3o0000oooo
0?ooo`3oool0o`0003<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0I0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool01000o`00oooo0?ooo`00o`080?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool09`3oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0T0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?l000020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
0?l000@0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0
003o003o003oool01`3oool01000o`00oooo0?ooo`000?l40?ooo`030000o`3oool0oooo0180oooo
00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`007P3oool2000000/0oooo0P00
000<0?ooo`030000003oool0oooo02@0oooo0P000?l50?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool0>P3oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo00H0oooo00<0
003o0?ooo`3oool0AP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`05003o003oool0oooo0?ooo`00o`00
103oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo05X0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0D0?ooo`04003o003oool0oooo003o00H0oooo00<0003o0?ooo`3o
ool09`3oool01@3o0000oooo0?ooo`3oool0o`0003@0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool01000
o`00oooo0?ooo`00o`080?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?l000020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo01/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000
o`3oool0oooo00<0oooo00<0003o003o003oool01`3oool01000o`00oooo0?ooo`000?l30?ooo`03
0000o`3oool0oooo01<0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0j0?ooo`03003o003oool0oooo00<0oooo00<00?l00000o`3oool0
1@3oool00`000?l0oooo0?ooo`170?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00@00?l00?ooo`3oool0
0?l0103oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo05/0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0E0?ooo`03003o003oool00?l000H0oooo00<0003o0?ooo`3o
ool09`3oool01@3o0000oooo0?ooo`3oool0o`0003@0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool01000
o`00oooo0?ooo`00o`080?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool0
1@000?l0oooo0?ooo`3oool0003o01P0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?l0
003oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l000@0
oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01`0
oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`00o`00oooo
00L0oooo00@00?l00?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0
oooo01@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0>P3oool00`00
o`00oooo0?ooo`030?ooo`03003o00000?l0oooo00D0oooo00<0003o0?ooo`3oool0A`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0000o`0F
0?ooo`04003o003oool0oooo003o00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`1L0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`00o`00oooo003o
000a0?ooo`030?l0003oool0o`0003D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`00o`00oooo003o
00090?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0U0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool01@000?l0oooo0?oo
o`3oool0003o01P0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?l0003oool0o`0000D0
oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?oo
o`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01`0oooo00@0o`000?oo
o`3oool0o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`00o`00oooo00L0oooo00@00?l0
0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`03
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0>`3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0003o00D0oooo00<0003o0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0000o`0F0?ooo`04003o003o
ool0oooo003o00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1L0?ooo`050000
o`3oool0oooo0?ooo`000?l0603oool2003o0380oooo00<0o`000?ooo`3o0000=P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0D0?ooo`03003o003oool00?l000T0oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool06@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0@0?ooo`040000o`3oool0oooo0000oaP0oooo00<0003o0?ooo`3oool02`3oool01@00
0?l0oooo0?l0003oool0o`0000H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0003o01h0oooo
00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`00o`00oooo00L0
oooo00@00?l00?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo
01@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0;03oool00`00o`00
oooo0?ooo`040?ooo`03003o003oool0oooo03/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0000o`050?ooo`030000o`3oool0oooo04L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000?l05P3oool01000o`00oooo0?ooo`00o`04
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0G@3oool01@000?l0oooo0?ooo`3o
ool0003o01P0oooo0P00o`0b0?ooo`030?l0003oool0o`0003H0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3o
ool2003o00T0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo02H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0A0?ooo`040000o`3o
ool0oooo0000oaP0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?l0003oool0o`0000H0
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool02@3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<0o`000?ooo`3o00001@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`00o`00oooo00L0oooo00L00?l00?ooo`3oool0oooo0000
o`3oool0003o01L0oooo00<00?l00?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0>`3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0003o00D0oooo00<0003o0?ooo`3oool0A`3o
ool01@3o0000oooo0?ooo`3oool0o`0001@0oooo00D0003o0?ooo`3oool0oooo0000o`0F0?ooo`04
003o003oool0oooo003o00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1M0?oo
o`050000o`3oool0oooo0?ooo`000?l06@3oool00`00o`00oooo0?ooo`0`0?ooo`030?l0003oool0
o`0003H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool05@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0
oooo00P0oooo00<00?l00?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo01X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0000o`0H0?ooo`030000o`3oool0
oooo00/0oooo00D0003o0?ooo`3o0000oooo0?l000060?ooo`040000o`3oool0oooo0000o`@0oooo
00D00?l00?ooo`3oool0oooo003o000<0?ooo`050000o`3oool0oooo0?ooo`000?l07`3oool00`3o
0000oooo0?l000050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`00o`001`3oool01000
o`00oooo0?ooo`3oool20000obl0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?oo
o`3oool0;03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo03/0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0000o`040?ooo`030000o`3oool0oooo04P0oooo00D0o`000?oo
o`3oool0oooo0?l0000E0?ooo`040000o`3oool0oooo0000oaH0oooo00@00?l00?ooo`3oool00?l0
1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05h0oooo00D0003o0?ooo`3oool0
oooo0000o`0I0?ooo`03003o003oool0oooo0300oooo00<0o`000?ooo`3o0000=P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0E0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool06P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0B0?ooo`80003o6@3oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0o`000?oo
o`3o00001P3oool010000?l0oooo0?ooo`000?l40?ooo`05003o003oool0oooo0?ooo`00o`00303o
ool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<0o`000?ooo`3o00001@3oool01@000?l0oooo
0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`3oool20000
obl0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0;03oool00`00o`00
oooo0?ooo`040?ooo`03003o003oool0oooo03/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0000o`040?ooo`030000o`3oool0oooo04T0oooo00@0o`000?ooo`3oool0o`005@3oool01000
0?l0oooo0?ooo`000?lG0?ooo`03003o003oool00?l000D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`1O0?ooo`040000o`3oool0oooo0000oaT0oooo00<00?l00?ooo`3oool0<03o
ool00`3o0000oooo0?l0000g0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0703o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0240oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool06`3o
ool01@000?l0oooo0?ooo`3oool0003o02P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool02P3oool01P000?l0oooo
0?ooo`3o0000oooo0?l000H0oooo00@0003o0?ooo`3oool0003o1@3oool01000o`00oooo0?ooo`00
o`0<0?ooo`050000o`3oool0oooo0?ooo`000?l07`3oool00`3o0000oooo0?l000050?ooo`050000
o`3oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?oo
o`000?l0<03oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0/0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`030?ooo`04
003o003oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0B@3oool0103o0000oooo0?ooo`3o000E
0?ooo`040000o`3oool0oooo0000oaL0oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo05l0oooo00@0003o0?ooo`3oool0003oC@3oool00`3o0000oooo
0?ooo`0f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0240oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?ooo`0[0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool06`3oool01@000?l0oooo
0?ooo`3oool0003o02P0oooo00D0o`000?ooo`3oool0oooo0?l0000F0?ooo`030000o`3oool0oooo
01L0oooo00<0003o0?ooo`3oool02P3oool01P000?l0oooo0?ooo`3o0000oooo0?l000H0oooo00@0
003o0?ooo`3oool0003o1@3oool01000o`00oooo0?ooo`00o`0<0?ooo`050000o`3oool0oooo0?oo
o`000?l07`3oool00`3o0000oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`000?l0<03oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool5000002X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0l
0?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0003o0`3oool00`000?l0oooo0?oo
o`190?ooo`030?l0003oool0o`0001H0oooo00@0003o0?ooo`3oool0003o5`3oool00`00o`00oooo
003o00050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0H03oool010000?l0oooo
0?ooo`000?m=0?ooo`030?l0003oool0oooo03H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0L0?ooo`050000o`3oool0oooo0?ooo`000?l0903oool00`00o`00oooo0?ooo`060?oo
o`03003o003oool0oooo02`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0K0?oo
o`050000o`3oool0oooo0?ooo`000?l0:03oool01@3o0000oooo0?ooo`3oool0o`000300oooo00<0
003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`3oool20?l000H0oooo00@0003o0?ooo`3oool0
003o1@3oool01000o`00oooo0?ooo`00o`0<0?ooo`040000o`3oool0oooo0000ob00oooo00<0o`00
0?ooo`3o00001@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0^0?ooo`D00000703oool003T0oooo00<000000?ooo`3oool0;03oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo03d0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`050000o`3oool0oooo0?ooo`000?l0B`3oool00`3o0000oooo0?l0000G0?ooo`80003o
603oool2003o00L0oooo00D0003o0?ooo`3oool0oooo0000o`1R0?ooo`040000o`3oool0oooo0000
odd0oooo00<0o`000?ooo`3oool0=`3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00@0003o
0?ooo`3oool0003o903oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo02`0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0K0?ooo`050000o`3oool0oooo0?ooo`000?l0
:03oool01@3o0000oooo0?ooo`3oool0o`000340oooo00<0003o0?ooo`3oool02@3oool010000?l0
oooo0?ooo`3oool20?l000H0oooo00@0003o0?ooo`3oool0003o1@3oool01000o`00oooo0?ooo`00
o`0=0?ooo`030000o`3oool0003o0200oooo00<0o`000?ooo`3o00001@3oool01@000?l0oooo0?oo
o`3oool0003o0080oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0b0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02`0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0m0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool010000?l0oooo
0?ooo`000?m<0?ooo`030?l0003oool0o`0001L0oooo0P000?lH0?ooo`800?l01`3oool010000?l0
oooo0?ooo`000?mS0?ooo`040000o`3oool0oooo0000ohL0oooo00D0003o0?ooo`3oool0oooo0000
o`0O0?ooo`040000o`3oool0oooo0000ob@0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo
0?ooo`0]0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool06`3oool01@000?l0oooo
0?ooo`3oool0003o02P0oooo00D0o`000?ooo`3oool0oooo0?l0000a0?ooo`030000o`3oool0oooo
00T0oooo00@0003o0?ooo`3oool0oooo0P3o00060?ooo`040000o`3oool0oooo0000o`D0oooo00<0
0?l00?ooo`00o`003P3oool00`000?l0oooo0000o`0P0?ooo`030?l0003oool0o`0000D0oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0
<`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0/0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0?@3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo
00<0003o0?ooo`000?l0C03oool00`3o0000oooo0?l0000G0?ooo`80003o603oool2003o00L0oooo
00@0003o0?ooo`3oool0003oI03oool00`000?l0oooo0000o`270?ooo`050000o`3oool0oooo0?oo
o`000?l07`3oool010000?l0oooo0?ooo`000?lT0?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo01/0oooo00@0003o
0?ooo`3oool0003o:@3oool0103o0000oooo0?ooo`3o000b0?ooo`030000o`3oool0oooo00T0oooo
00@0003o0?ooo`3oool0oooo0P3o00060?ooo`030000o`3oool0003o00H0oooo00<00?l00?ooo`00
o`003P3oool00`000?l0oooo0000o`0P0?ooo`030?l0003oool0o`0000D0oooo00D0003o0?ooo`3o
ool0oooo0000o`020?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool0?P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<0003o0?oo
o`000?l0C@3oool20?l001L0oooo0P000?lI0?ooo`03003o003oool0oooo00D0oooo00@0003o0?oo
o`3oool0003oI03oool00`000?l0oooo0000o`280?ooo`040000o`3oool0oooo0000oal0oooo00@0
003o0?ooo`3oool0003o903oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo02d0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0K0?ooo`040000o`3oool0oooo0000obT0
oooo00@0o`000?ooo`3oool0o`00<P3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo
0?ooo`3o00001`3oool00`000?l0oooo0000o`060?ooo`03003o003oool00?l000h0oooo00<0003o
0?ooo`000?l0803oool20?l000L0oooo00@0003o0?ooo`3oool0003o0P3oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0;03oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo03h0oooo00D00?l0
0?ooo`3oool0oooo003o00040?ooo`030000o`3oool0003o04d0oooo00<0o`000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0G0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`000?l0I@3o
ool00`000?l0oooo0000o`280?ooo`040000o`3oool0oooo0000oal0oooo00@0003o0?ooo`3oool0
003o903oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo02h0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0K0?ooo`040000o`3oool0oooo0000obT0oooo00@0o`000?oo
o`3oool0o`00<P3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o00001`3o
ool00`000?l0oooo0000o`060?ooo`03003o003oool00?l000h0oooo00<0003o0?ooo`000?l08@3o
ool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0000o`80oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02d0oooo00D00?l00?ooo`3oool0oooo003o00100?ooo`05003o003oool0oooo0?ooo`00
o`00103oool00`000?l0oooo0000o`1=0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3o
ool05`3oool00`00o`00oooo0?ooo`060?ooo`80003oI@3oool20000ohT0oooo00@0003o0?ooo`3o
ool0003o7`3oool010000?l0oooo0?ooo`000?lT0?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo01`0oooo00<0003o
0?ooo`000?l0:@3oool0103o0000oooo0?ooo`3o000b0?ooo`030000o`3oool0oooo00T0oooo00D0
003o0?ooo`3oool0oooo0?l000070?ooo`030000o`3oool0003o00L0oooo0P00o`0>0?ooo`030000
o`3oool0003o0240oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`000?l20?ooo`03
003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`00
>@3oool00`000000oooo0?ooo`0]0?ooo`05003o003oool0oooo0?ooo`00o`00@03oool01@00o`00
oooo0?ooo`3oool00?l000@0oooo00<0003o0?ooo`000?l0C@3oool00`3o0000oooo0?ooo`0j0?oo
o`030000o`3oool0oooo06@0oooo0P000?n:0?ooo`80003o8@3oool00`000?l0oooo0000o`0T0?oo
o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo01`0oooo00<0003o0?ooo`000?l0:P3oool20?l003<0oooo00<0003o0?oo
o`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo0P000?l70?ooo`800?l03`3oool0
0`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l00`3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0;@3oool01@00o`00oooo0?ooo`3oool00?l00400oooo00D00?l0
0?ooo`3oool0oooo003o00050?ooo`030000o`3oool0oooo08T0oooo00<0003o0?ooo`3oool0I03o
ool20000ohX0oooo0P000?lQ0?ooo`030000o`3oool0003o02D0oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0^0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0703o
ool00`000?l0oooo0000o`0Z0?ooo`80o`00<`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3o
ool0oooo0?ooo`3o0000203oool20000o`L0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l00`3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0
00000?ooo`3oool0;@3oool01000o`00oooo0?ooo`00o`110?ooo`05003o003oool0oooo0?ooo`00
o`001@3oool00`000?l0oooo0?ooo`3a0?ooo`030000o`3oool0oooo08P0oooo0P000?lQ0?ooo`03
0000o`3oool0003o02D0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0000o`0Z0?ooo`80
o`00<`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o0000203oool20000
o`L0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`000?l00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0;@3oool01000o`00
oooo0?ooo`00o`110?ooo`05003o003oool0oooo0?ooo`00o`001@3oool00`000?l0oooo0?ooo`3a
0?ooo`030000o`3oool0oooo08T0oooo00<0003o0?ooo`3oool07`3oool20000obH0oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0_0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool07@3oool00`000?l0oooo0000o`0Z0?ooo`80o`00<`3oool00`000?l0oooo0?ooo`09
0?ooo`050000o`3oool0oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`060?ooo`03003o003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0000o`030?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool0<`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool5
000002/0oooo00@00?l00?ooo`3oool00?l0@P3oool00`00o`00oooo003o003j0?ooo`030000o`3o
ool0oooo08T0oooo00<0003o0?ooo`3oool07`3oool20000obH0oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0_0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3o
ool00`000?l0oooo0000o`0Z0?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`000?l00`3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo02l0oooo1@00000L0?ooo`00>@3oool0
0`000000oooo0?ooo`0]0?ooo`04003o003oool0oooo003o0480oooo00<00?l00?ooo`00o`00o`3o
oonZ0?ooo`030000o`3oool0oooo02@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`0`0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0000
o`0Z0?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0;@3oool01000o`00oooo0?ooo`00o`120?ooo`03003o003oool00?l00?l0ooooZP3o
ool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo0P000?l[0?ooo`030?l0003o
ool0oooo0380oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0480oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0;@3oool0
1000o`00oooo0?ooo`00o`120?ooo`03003o003oool00?l00?l0ooooZP3oool00`000?l0oooo0?oo
o`0T0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`000?l0103oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0;@3oool00`00o`00oooo003o00130?ooo`03003o003oool00?l00?l0ooood@3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`1?0?ooo`030000o`3oool0003o00@0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
02d0oooo00<00?l00?ooo`00o`00@`3oool00`00o`00oooo003o003o0?ooom40oooo00<00?l00?oo
o`3oool0103oool00`00o`00oooo0?ooo`0a0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool07P3oool00`000?l0oooo0?ooo`1O0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool0D03oool20000o`@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0c0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo02h0oooo0P00o`130?ooo`03
003o003oool00?l00?l0ooood@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0380
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo05l0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo00<0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo02h0oooo0P00o`130?ooo`03003o003oool00?l00?l0oooo
d@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0380oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003o
ool0oooo02h0oooo0P00o`130?ooo`03003o003oool00?l00?l0oooodP3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo0380oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`200?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0D03oool00`000?l0oooo0?oo
o`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0<`3oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`0^0?ooo`03003o003oool0oooo0480oooo00<00?l0
0?ooo`00o`00o`3ooooB0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0<P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0800oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
02h0oooo00<00?l00?ooo`3oool0@`3oool00`00o`00oooo0?ooo`3o0?ooom40oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`0c0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0P@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0500oooo00<0003o0?oo
o`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo03@0oooo00<000000?oo
o`3oool06P3oool003T0oooo00<000000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`130?ooo`03
003o003oool0oooo0?l0ooood@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo03<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`210?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool0D03oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`00>@3oool500000780oooo
00<00?l00?ooo`3oool0o`3ooooA0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0840oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`1F0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
<03oool5000001`0oooo000i0?ooo`030000003oool0oooo07@0oooo00<00?l00?ooo`3oool0o`3o
oooA0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0840oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`1F0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?oo
o`0J0?ooo`00>@3oool00`000000oooo0?ooo`1d0?ooo`03003o003oool0oooo0?l0ooood@3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo03D0oooo00D0003o0?ooo`3oool0oooo0000
o`230?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0EP3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0M03oool00`00o`00oooo0?ooo`3o0?ooom40oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0e0?ooo`050000o`3oool0oooo0?ooo`000?l0P`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo05H0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0d0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom9
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0=@3oool01@000?l0oooo0?ooo`3o
ool0003o08<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1G0?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooB@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo03D0oooo00D0003o0?ooo`3oool0oooo0000o`230?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0F03oool01@00o`00oooo0?ooo`3oool00?l003H0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodX0oooo00D00?l00?ooo`3oool0oooo
003o000h0?ooo`040000o`3oool0oooo0000oh<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`1H0?ooo`05003o003oool0oooo0?ooo`00o`00=P3oool00`000000oooo0?ooo`0J0?oo
o`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooBP3oool01@00o`00oooo0?ooo`3oool00?l0
03P0oooo00@0003o0?ooo`3oool0003oP`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo05P0oooo00D00?l00?ooo`3oool0oooo003o000f0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo0?l0ooooo`3ooom:0?ooo`05003o003oool0oooo0?ooo`00o`00>03o
ool010000?l0oooo0?ooo`000?n30?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
F03oool01@00o`00oooo0?ooo`3oool00?l003H0oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodX0oooo00D00?l00?ooo`3oool0oooo003o000h0?ooo`04
0000o`3oool0oooo0000oh@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1H0?oo
o`05003o003oool0oooo0?ooo`00o`00=P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooBP3oool01@00o`00oooo0?ooo`3oool00?l003T0oooo0P000?n5
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0F03oool01@00o`00oooo0?ooo`3o
ool00?l003H0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodX0oooo00D00?l00?ooo`3oool0oooo003o000i0?ooo`80003oQ@3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo05P0oooo00D00?l00?ooo`3oool0oooo003o000f0?ooo`030000
003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?ooodP0oooo00D00?l00?ooo`3oool0oooo
003o000i0?ooo`80003oQ@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05P0oooo
00D00?l00?ooo`3oool0oooo003o000b0?ooo`D00000703oool003T0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodX0oooo00D00?l00?ooo`3oool0oooo003o000i0?ooo`80003oQ@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo05P0oooo00D00?l00?ooo`3oool0oooo003o000f0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom:0?ooo`04
003o003oool0oooo003o03/0oooo00<0003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo05P0oooo00D00?l00?ooo`3oool0oooo003o000f0?ooo`030000003oool0
oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom:0?ooo`04003o003oool0oooo
003o03/0oooo00<0003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo05P0oooo00D00?l00?ooo`3oool0oooo003o000f0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo0?l0ooooo`3ooom:0?ooo`04003o003oool0oooo003o03/0oooo00<0
003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05P0oooo00@0
0?l00?ooo`3oool00?l0=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`3o0?ooool0ooooB`3oool00`00o`00oooo003o00310?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0F03oool01000o`00oooo0?ooo`00o`0g0?ooo`030000003oool0oooo01X0oooo
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`03003o003oool00?l00<40oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1H0?ooo`04003o003oool0oooo003o03L0oooo
00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo00<0
0?l00?ooo`00o`00`@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05P0oooo00@0
0?l00?ooo`3oool00?l0=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?oo
o`3o0?ooool0ooooB`3oool00`00o`00oooo003o00310?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0F03oool01000o`00oooo0?ooo`00o`0g0?ooo`030000003oool0oooo01X0oooo
000N0?ooo`800000103oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo0?l0ooooo`3o
oom;0?ooo`03003o003oool00?l00<40oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`1I0?ooo`03003o003oool00?l003L0oooo00<000000?ooo`3oool06P3oool001d0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0?l0oooo
o`3ooom;0?ooo`03003o003oool00?l00<40oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`1I0?ooo`03003o003oool00?l003L0oooo00<000000?ooo`3oool06P3oool001d0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0:0?ooo`L00000o`3ooooo0?ooodL0oooo
00<00?l00?ooo`00o`00`@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05T0oooo
00<00?l00?ooo`00o`00<@3oool7000001`0oooo000M0?ooo`040000003oool0oooo000000T0oooo
0P00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`03003o003oool00?l00<80oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?ooo`03003o003oool00?l003L0oooo
00<000000?ooo`3oool06P3oool001d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`03003o003oool00?l00<80oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?ooo`03003o003oool00?l003L0oooo
00<000000?ooo`3oool06P3oool001h0oooo0P00000:0?ooo`<00000303oool00`000000oooo0?oo
o`3o0?ooool0ooooB`3oool2003o0<<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`1I0?ooo`03003o003oool00?l003L0oooo00<000000?ooo`3oool06P3oool003T0oooo00<00000
0?ooo`3oool0o`3ooooo0?oood`0oooo00<00?l00?ooo`3oool0`@3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo05T0oooo00<00?l00?ooo`00o`00=`3oool00`000000oooo0?ooo`0J
0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooC03oool00`00o`00oooo0?ooo`310?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0F@3oool00`00o`00oooo003o000g0?oo
o`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`03
003o003oool0oooo0<40oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?ooo`03
003o003oool00?l003L0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0
o`3ooooo0?oood`0oooo00<00?l00?ooo`3oool0`@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo05T0oooo00<00?l00?ooo`00o`00=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooC03oool00`00o`00oooo0?ooo`310?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0F@3oool00`00o`00oooo003o000g0?ooo`030000003o
ool0oooo01X0oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`03003o003oool0
oooo0<40oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1J0?ooo`03003o003oool0
0?l003L0oooo00<000000?ooo`3oool06P3oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo4@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05X0oooo00<00?l00?oo
o`00o`00=`3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooolA0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0FP3oool00`00o`00
oooo003o000g0?ooo`030000003oool0oooo01X0oooo000i0?ooo`D00000o`3ooooo0?ooool0oooo
3`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05X0oooo0P00o`0d0?ooo`D00000
703oool003T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo05X0oooo0P00o`0h0?ooo`030000003oool0oooo01X0oooo000i
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa40oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`1K0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool06P3oool0
03T0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo05/0oooo00<00?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0J0?oo
o`00>@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0F`3oool00`00o`00oooo0?ooo`0f0?ooo`030000003oool0oooo01X0
oooo000i0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1K0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0
6P3oool003T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo03l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1K0?ooo`03003o003o
ool0oooo00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05/0oooo00<00?l00?ooo`3oool01@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01X0oooo000i0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`050?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool01@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool003T0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`00>@3ooooo00000?l00000o`00
000E000000030000o`000000000000<0000000<0003o000000000000U@00000L0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {566.438, 361.563}} -> {-13.067, \
0.876267, 0.114894, 0.00171894}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Raw Tapping Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions2b];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.137123 0.810999 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02508 -18 -4.5 ]
[-0.0125 .02508 0 4.5 ]
[-0.0125 .06563 -24 -4.5 ]
[-0.0125 .06563 0 4.5 ]
[-0.0125 .10618 -18 -4.5 ]
[-0.0125 .10618 0 4.5 ]
[-0.0125 .14673 -24 -4.5 ]
[-0.0125 .14673 0 4.5 ]
[-0.0125 .18728 -18 -4.5 ]
[-0.0125 .18728 0 4.5 ]
[-0.0125 .22783 -24 -4.5 ]
[-0.0125 .22783 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02508 m
.00625 .02508 L
s
[(0.2)] -0.0125 .02508 1 0 Mshowa
0 .06563 m
.00625 .06563 L
s
[(0.25)] -0.0125 .06563 1 0 Mshowa
0 .10618 m
.00625 .10618 L
s
[(0.3)] -0.0125 .10618 1 0 Mshowa
0 .14673 m
.00625 .14673 L
s
[(0.35)] -0.0125 .14673 1 0 Mshowa
0 .18728 m
.00625 .18728 L
s
[(0.4)] -0.0125 .18728 1 0 Mshowa
0 .22783 m
.00625 .22783 L
s
[(0.45)] -0.0125 .22783 1 0 Mshowa
.125 Mabswid
0 .03319 m
.00375 .03319 L
s
0 .0413 m
.00375 .0413 L
s
0 .04941 m
.00375 .04941 L
s
0 .05752 m
.00375 .05752 L
s
0 .07374 m
.00375 .07374 L
s
0 .08185 m
.00375 .08185 L
s
0 .08996 m
.00375 .08996 L
s
0 .09807 m
.00375 .09807 L
s
0 .11429 m
.00375 .11429 L
s
0 .1224 m
.00375 .1224 L
s
0 .13051 m
.00375 .13051 L
s
0 .13862 m
.00375 .13862 L
s
0 .15484 m
.00375 .15484 L
s
0 .16295 m
.00375 .16295 L
s
0 .17106 m
.00375 .17106 L
s
0 .17917 m
.00375 .17917 L
s
0 .19539 m
.00375 .19539 L
s
0 .2035 m
.00375 .2035 L
s
0 .21161 m
.00375 .21161 L
s
0 .21972 m
.00375 .21972 L
s
0 .01697 m
.00375 .01697 L
s
0 .00886 m
.00375 .00886 L
s
0 .00075 m
.00375 .00075 L
s
0 .23594 m
.00375 .23594 L
s
0 .24405 m
.00375 .24405 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .02508 m
1 .02508 L
s
.99375 .06563 m
1 .06563 L
s
.99375 .10618 m
1 .10618 L
s
.99375 .14673 m
1 .14673 L
s
.99375 .18728 m
1 .18728 L
s
.99375 .22783 m
1 .22783 L
s
.125 Mabswid
.99625 .03319 m
1 .03319 L
s
.99625 .0413 m
1 .0413 L
s
.99625 .04941 m
1 .04941 L
s
.99625 .05752 m
1 .05752 L
s
.99625 .07374 m
1 .07374 L
s
.99625 .08185 m
1 .08185 L
s
.99625 .08996 m
1 .08996 L
s
.99625 .09807 m
1 .09807 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .1224 m
1 .1224 L
s
.99625 .13051 m
1 .13051 L
s
.99625 .13862 m
1 .13862 L
s
.99625 .15484 m
1 .15484 L
s
.99625 .16295 m
1 .16295 L
s
.99625 .17106 m
1 .17106 L
s
.99625 .17917 m
1 .17917 L
s
.99625 .19539 m
1 .19539 L
s
.99625 .2035 m
1 .2035 L
s
.99625 .21161 m
1 .21161 L
s
.99625 .21972 m
1 .21972 L
s
.99625 .01697 m
1 .01697 L
s
.99625 .00886 m
1 .00886 L
s
.99625 .00075 m
1 .00075 L
s
.99625 .23594 m
1 .23594 L
s
.99625 .24405 m
1 .24405 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .16764 m
.0423 .15061 L
.05155 .16091 L
.0608 .10149 L
.07004 .14847 L
.07929 .13598 L
.08853 .13856 L
.09778 .0927 L
.10703 .09441 L
.11627 .175 L
.12552 .16936 L
.13477 .08198 L
.14401 .22036 L
.15326 .08254 L
.16251 .15965 L
.17175 .09282 L
.181 .13365 L
.19025 .16288 L
.19949 .15773 L
.20874 .14239 L
.21798 .16912 L
.22723 .1625 L
.23648 .14561 L
.24572 .09356 L
.25497 .1421 L
.26422 .13135 L
.27346 .13885 L
.28271 .1132 L
.29196 .17113 L
.3012 .12024 L
.31045 .1575 L
.31969 .11238 L
.32894 .14346 L
.33819 .16844 L
.34743 .14366 L
.35668 .14356 L
.36593 .15908 L
.37517 .13067 L
.38442 .15503 L
.39367 .07333 L
.40291 .18079 L
.41216 .14911 L
.42141 .18537 L
.43065 .13464 L
.4399 .1844 L
.44914 .07417 L
.45839 .11023 L
.46764 .16321 L
.47688 .14838 L
.48613 .12812 L
Mistroke
.49538 .14271 L
.50462 .15432 L
.51387 .13779 L
.52312 .15496 L
.53236 .16193 L
.54161 .14561 L
.55086 .20291 L
.5601 .14426 L
.56935 .13423 L
.57859 .11023 L
.58784 .14729 L
.59709 .13294 L
.60633 .07994 L
.61558 .0636 L
.62483 .13495 L
.63407 .11568 L
.64332 .14037 L
.65257 .14549 L
.66181 .13212 L
.67106 .14892 L
.68031 .14616 L
.68955 .1319 L
.6988 .1847 L
.70804 .15971 L
.71729 .14108 L
.72654 .1042 L
.73578 .16562 L
.74503 .15024 L
.75428 .07426 L
.76352 .05266 L
.77277 .15967 L
.78202 .15444 L
.79126 .13106 L
.80051 .16597 L
.80975 .11747 L
.819 .15945 L
.82825 .11475 L
.83749 .01134 L
.84674 .18008 L
.85599 .15902 L
.86523 .17745 L
.87448 .10692 L
.88373 .15252 L
.89297 .16327 L
.90222 .13764 L
.91147 .08386 L
.92071 .14767 L
.92996 .15193 L
.9392 .15819 L
.94845 .12114 L
Mistroke
.9577 .15576 L
.96694 .09627 L
.97619 .10494 L
Mfstroke
0 1 0 r
.03306 .11246 m
.0423 .09268 L
.05155 .11649 L
.0608 .10618 L
.07004 .0794 L
.07929 .11615 L
.08853 .14124 L
.09778 .15743 L
.10703 .16269 L
.11627 .08517 L
.12552 .12171 L
.13477 .11568 L
.14401 .07496 L
.15326 .14032 L
.16251 .10623 L
.17175 .19252 L
.181 .10638 L
.19025 .10686 L
.19949 .10911 L
.20874 .12742 L
.21798 .12808 L
.22723 .11734 L
.23648 .13588 L
.24572 .0846 L
.25497 .19541 L
.26422 .09911 L
.27346 .12501 L
.28271 .15004 L
.29196 .08342 L
.3012 .15145 L
.31045 .12853 L
.31969 .18083 L
.32894 .10643 L
.33819 .10261 L
.34743 .10673 L
.35668 .11648 L
.36593 .09331 L
.37517 .13477 L
.38442 .10624 L
.39367 .10054 L
.40291 .14997 L
.41216 .06708 L
.42141 .12618 L
.43065 .10151 L
.4399 .08703 L
.44914 .11957 L
.45839 .20763 L
.46764 .11647 L
.47688 .21879 L
.48613 .15242 L
Mistroke
.49538 .12344 L
.50462 .11291 L
.51387 .12 L
.52312 .10084 L
.53236 .10111 L
.54161 .06972 L
.55086 .1052 L
.5601 .09655 L
.56935 .13958 L
.57859 .04626 L
.58784 .13039 L
.59709 .11242 L
.60633 .18466 L
.61558 .13798 L
.62483 .14897 L
.63407 .14551 L
.64332 .13376 L
.65257 .11586 L
.66181 .11417 L
.67106 .1026 L
.68031 .09517 L
.68955 .09077 L
.6988 .12853 L
.70804 .10898 L
.71729 .14403 L
.72654 .06325 L
.73578 .12631 L
.74503 .10713 L
.75428 .18101 L
.76352 .19198 L
.77277 .22028 L
.78202 .15506 L
.79126 .12056 L
.80051 .10816 L
.80975 .12867 L
.819 .10538 L
.82825 .1015 L
.83749 .00595 L
.84674 .1475 L
.85599 .07966 L
.86523 .10583 L
.87448 .10349 L
.88373 .10946 L
.89297 .11115 L
.90222 .15094 L
.91147 .17278 L
.92071 .20712 L
.92996 .09782 L
.9392 .11887 L
.94845 .13207 L
Mistroke
.9577 .1157 L
.96694 .1406 L
.97619 .13943 L
Mfstroke
0 0 1 r
.03306 .11952 m
.0423 .15634 L
.05155 .12222 L
.0608 .19197 L
.07004 .17176 L
.07929 .14749 L
.08853 .11983 L
.09778 .1495 L
.10703 .14253 L
.11627 .13946 L
.12552 .10856 L
.13477 .20197 L
.14401 .10431 L
.15326 .17676 L
.16251 .13375 L
.17175 .11429 L
.181 .1596 L
.19025 .12989 L
.19949 .13279 L
.20874 .12982 L
.21798 .10243 L
.22723 .11979 L
.23648 .11814 L
.24572 .22147 L
.25497 .06212 L
.26422 .16917 L
.27346 .13577 L
.28271 .13639 L
.29196 .14507 L
.3012 .12794 L
.31045 .1136 L
.31969 .10642 L
.32894 .14974 L
.33819 .12858 L
.34743 .14924 L
.35668 .13959 L
.36593 .14725 L
.37517 .13419 L
.38442 .13837 L
.39367 .22577 L
.40291 .06887 L
.41216 .18344 L
.42141 .08808 L
.43065 .16347 L
.4399 .1282 L
.44914 .20589 L
.45839 .08177 L
.46764 .11995 L
.47688 .03246 L
.48613 .11909 L
Mistroke
.49538 .13349 L
.50462 .1324 L
.51387 .14184 L
.52312 .14382 L
.53236 .13659 L
.54161 .1843 L
.55086 .09152 L
.5601 .15882 L
.56935 .12582 L
.57859 .24314 L
.58784 .12195 L
.59709 .15428 L
.60633 .13503 L
.61558 .19805 L
.62483 .11571 L
.63407 .13844 L
.64332 .1255 L
.65257 .13828 L
.66181 .15334 L
.67106 .14811 L
.68031 .1583 L
.68955 .17696 L
.6988 .0864 L
.70804 .13094 L
.71729 .11452 L
.72654 .23218 L
.73578 .10769 L
.74503 .14226 L
.75428 .14436 L
.76352 .15499 L
.77277 .01967 L
.78202 .09013 L
.79126 .14802 L
.80051 .1255 L
.80975 .15349 L
.819 .1348 L
.82825 .18338 L
Mfstroke
.82825 .18338 m
.83134 .25 L
s
.84144 .25 m
.84674 .07206 L
.85599 .16095 L
.86523 .11636 L
.87448 .18922 L
.88373 .13765 L
.89297 .12521 L
.90222 .11105 L
.91147 .14299 L
.92071 .04484 L
.92996 .14988 L
.9392 .12258 L
.94845 .14642 L
.9577 .12818 L
.96694 .16276 L
.97619 .15525 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00DP3oool200000:P0oooo100000030?ooo`800000Y`3oool30000
0080oooo0P00002V0?ooo`<00000103oool200000:H0oooo0P0000040?ooo`800000XP3oool50000
0080oooo0P0000040?ooo`800000A03oool00540oooo00@000000?ooo`3oool00000Y`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000Y03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
@@3oool00540oooo00@000000?ooo`3oool00000Z03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:@0oooo1@0000001@3oool000000?ooo`3oool000000:D0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3oool010000000oooo0?ooo`00002Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool3000000<0oooo00@000000?ooo`3o
ool00000Y@3oool2000000<0oooo00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3o
ool010000000oooo0?ooo`00002W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000:H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00DP3oool200000:T0oooo0P0000040?oo
o`800000Y`3oool2000000<0oooo0P00002W0?ooo`<000000`3oool200000:H0oooo0P0000040?oo
o`800000X`3oool2000000@0oooo0P0000040?ooo`800000A03oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03`0ooooo`00003o00000?l00000/`00000I0?ooo`00?03oool500000180oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo1P00000I0?ooo`00
?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0@`3oool00`00o`00
oooo0?ooo`1U0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool00`00o`00oooo0?ooo`2F0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`D00000o`3ooooo0?ooool0oooo503oool00`00o`00oooo0?oo
o`2B0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo5P3oool0
0`00o`00oooo0?ooo`2F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooaH0oooo00<00?l00?ooo`3oool0UP3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`800?l0V03oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`800?l0
V03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolE0?ooo`800?l0V03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooolE0?ooo`800?l0V03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`03003o003o00000?l009L0oooo00<000000?oo
o`3oool05`3oool003`0oooo1@00003o0?ooool0ooooo`3ooolC0?ooo`03003o003o00000?l009<0
oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolE0?ooo`03003o
003o00000?l009L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooomP0oooo00<0003o0?ooo`3oool0>@3oool00`00o`00o`00003o002G0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooH0?ooo`030000o`3oool0
oooo03T0oooo00<00?l00?l00000o`00U`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0oooof03oool00`000?l0oooo0?ooo`0i0?ooo`03003o003o00000?l0
09L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooomP0
oooo00<0003o0?ooo`3oool0>03oool01000o`00o`000?ooo`00o`2G0?ooo`030000003oool0oooo
01L0oooo000Q0?ooo`800000103oool2000000<0oooo1000000<0?ooo`030000003oool0oooo0?l0
ooooo`3ooooH0?ooo`030000o`3oool0oooo03P0oooo00@00?l00?l0003oool00?l0U`3oool00`00
0000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooomP0oooo0P000?li0?ooo`04003o003o0000oooo
003o09L0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0<0?ooo`L00000o`3ooooo0?ooom@0oooo0P000?li0?ooo`04003o003o0000
oooo003o0940oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooomP0oooo0P000?li0?ooo`04003o003o
0000oooo003o09L0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0?l0ooooo`3ooooG0?ooo`03
0000o`3oool0003o03T0oooo00@00?l00?l0003oool00?l0U`3oool00`000000oooo0?ooo`0G0?oo
o`008@3oool2000000X0oooo0P00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooooG0?ooo`03
0000o`3oool0003o03T0oooo00@00?l00?l0003oool00?l0U`3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooe`3oool00`000?l0oooo0000o`0i0?ooo`04
003o003oool0oooo003o09L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooomL0oooo00<0003o0?ooo`000?l0>@3oool01000o`00oooo0?ooo`00o`2G0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo`03oool00`000?l0
oooo0?ooo`3o0?oooa@0oooo00<0003o0?ooo`000?l0>@3oool01000o`00oooo0?ooo`00o`2G0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`D00000o`3ooonn0?ooo`030000o`3oool0oooo0?l0
oooo503oool010000?l0oooo0?ooo`000?lg0?ooo`06003o003o0000oooo0?ooo`3o00000?l0TP3o
ool5000001T0oooo000l0?ooo`030000003oool0oooo0?l0oooo`03oool00`000?l0oooo0?ooo`3o
0?oooa@0oooo00@0003o0?ooo`3oool0003o=`3oool01P00o`00o`000?ooo`3oool0o`00003o09H0
oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3oooo00?ooo`030000
o`3oool0oooo0?l0oooo503oool010000?l0oooo0?ooo`000?lg0?ooo`06003o003o0000oooo0?oo
o`3o00000?l0UP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?oo
ol00oooo00<0003o0?ooo`3oool0o`3ooolD0?ooo`040000o`3oool0oooo0000ocL0oooo00H00?l0
0?l0003oool0oooo0?l00000o`2F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0?l0oooo_`3oool00`000?l0oooo0000o`3o0?oooaD0oooo00@0003o0?ooo`3oool0003o
=`3oool01P00o`00o`000?ooo`3oool0o`00003o09H0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0o`3ooono0?ooo`030000o`3oool0003o0?l0oooo5@3oool010000?l0
oooo0?ooo`000?lg0?ooo`06003o003o0000oooo0?ooo`3o00000?l0UP3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?oookl0oooo00<0003o0?ooo`000?l0o`3ooolE
0?ooo`040000o`3oool0oooo0000ocL0oooo00H00?l00?l0003oool0oooo0?l00000o`2F0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo_`3oool00`000?l0oooo
0000o`3o0?oooaD0oooo00@0003o0?ooo`3oool0003o=`3oool01P00o`00oooo0?ooo`3oool0o`00
003o09H0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00003o0?oookd0oooo00<0003o0?oo
o`000?l0o`3ooolE0?ooo`050000o`3oool0oooo0?ooo`000?l0=P3oool01P00o`00oooo0?ooo`3o
ool0o`00003o0980oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?oookl0oooo00<0
003o0?ooo`000?l0o`3ooolD0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=03o
ool01P00o`00oooo0?ooo`3oool0o`00003o09H0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0o`3ooono0?ooo`030000o`3oool0003o0?l0oooo503oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo03<0oooo00<00?l00?l0003oool00`3oool00`00o`00oooo
0?ooo`2D0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo_`3o
ool00`000?l0oooo0000o`3o0?oooa@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0c0?ooo`03003o003o0000oooo00<0oooo00<00?l00?ooo`3oool0B@3oool00`000?l0oooo0?oo
o`180?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo_`3oool0
0`000?l0oooo0000o`1N0?ooo`03003o003oool0oooo0;80oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0c0?ooo`03003o003o0000oooo00<0oooo00<00?l00?ooo`3oool0B@3oool0
0`000?l0oooo0?ooo`180?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0?l0oooo_P3oool01@000?l0oooo0?ooo`3oool0003o05d0oooo00<00?l00?ooo`3oool0/P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03<0oooo00<00?l00?l0003oool00`3oool0
0`00o`00oooo0?ooo`190?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`050000o`3oool0oooo0?ooo`000?l0G@3oool0
0`00o`00oooo0?ooo`2b0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool0
0`00o`00o`000?ooo`030?ooo`03003o003oool0oooo04T0oooo00<0003o0?ooo`3oool0B03oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool500000?l0oooo_03oool01@000?l0oooo0?ooo`3oool0
003o05d0oooo00<00?l00?ooo`3oool0/P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo03<0oooo00<00?l00?l0003oool00`3oool00`00o`00oooo0?ooo`190?ooo`030000o`3oool0
oooo04@0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?oookh0oooo00D0003o0?oo
o`3oool0oooo0000o`1M0?ooo`03003o003oool0oooo0;80oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0c0?ooo`03003o003o0000oooo00<0oooo00<00?l00?ooo`3oool0B@3oool0
0`000?l0oooo0?ooo`180?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0?l0oooo_P3oool01@000?l0oooo0?ooo`3oool0003o05`0oooo0P00o`2d0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0<P3oool00`00o`00o`000?ooo`030?ooo`030?l00000o`00
oooo04P0oooo00<0003o0?ooo`000?l0B@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?oookh0oooo00D0003o0?ooo`3oool0oooo0000o`1L0?ooo`03003o003oool0
0?l00;<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0b0?ooo`03003o003oool0
oooo00<0oooo00<0o`00003o003oool0B03oool00`000?l0oooo0000o`190?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0oooo_P3oool01@000?l0oooo0?ooo`3oool0
003o05`0oooo00<00?l00?ooo`00o`00[03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0<P3oool00`00o`00oooo0?ooo`030?ooo`030?l00000o`00
oooo04P0oooo00<0003o0?ooo`000?l0B@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?oookh0oooo00D0003o0?ooo`3oool0oooo0000o`1L0?ooo`03003o003oool0
0?l00:`0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0340oooo00<00?l00?l0003oool0103oool00`3o00000?l00?ooo`180?ooo`030000o`3oool0
003o04T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`050000o`3oool0oooo0?ooo`000?l0G03oool00`00o`00oooo003o002[0?ooo`80o`001P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0340oooo00<00?l00?l0003oool0103oool0
0`3o00000?l00?ooo`180?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0F@3oool00`00o`00oooo003o002[0?ooo`80o`001P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0340oooo00<00?l00?l0003oool0103oool00`3o00000?l00?ooo`180?oo
o`030000o`3oool0003o04T0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00003o0?oook/0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1I0?ooo`03003o003oool00?l00:X0
oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0340
oooo00<00?l00?l0003oool0103oool00`3o00000?l00?ooo`180?ooo`030000o`3oool0003o04D0
oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`3o0?oookd0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1I0?ooo`03003o003oool00?l00:X0oooo00<0o`000?ooo`3o0000
1@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0340oooo00<00?l00?l0003oool0
103oool00`3o00000?l00?ooo`180?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0F@3oool00`00o`00oooo003o002Y0?ooo`050?l0003oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0300oooo00<00?l00?l0003oool0
103oool00`3o00000?l00?ooo`180?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0F@3oool00`00o`00oooo003o002Y0?ooo`050?l0003oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0300oooo00<00?l00?l0003oool0
103oool00`3o00000?l00?ooo`180?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0kP3oool00`000?l0oooo0?ooo`3;0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0F03oool01000o`00oooo0?ooo`00o`2X0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0300oooo00<00?l00?l0003oool0103oool00`3o00000?l00?ooo`170?ooo`040000
o`3oool0oooo0000odT0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
kP3oool00`000?l0oooo0?ooo`3;0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
F03oool01@00o`00oooo0?ooo`3oool00?l00:L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool00`00o`00
o`000?ooo`040?ooo`030?l00000o`00oooo04L0oooo00D0003o0?ooo`3oool0oooo0000o`180?oo
o`030000003oool0oooo01L0oooo000K0?ooo`800000103oool2000000<0oooo100000030?ooo`80
00003@3oool00`000000oooo0?ooo`3^0?ooo`030000o`3oool0oooo0</0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1H0?ooo`05003o003oool0oooo0?ooo`00o`00803oool00`3o
0000oooo0?ooo`1U0?ooo`03003o003oool0oooo01/0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool00`00
o`00oooo0?ooo`040?ooo`030?l00000o`00oooo04L0oooo00D0003o0?ooo`3oool0oooo0000o`18
0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0>h0oooo00<0
003o0?ooo`3oool0b`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05P0oooo00D0
0?l00?ooo`3oool0oooo003o000O0?ooo`80o`00I`3oool00`00o`00oooo0?ooo`0K0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo02l0oooo00<00?l00?l0003oool01P3oool00`00o`00oooo0?ooo`160?ooo`050000
o`3oool0oooo0?ooo`000?l0B03oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool700000>X0
oooo00<0003o0?ooo`3oool0b`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05L0
oooo00D00?l00?ooo`3oool0oooo003o000O0?ooo`80o`00I`3oool00`00o`00oooo0?ooo`0K0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo02l0oooo00<00?l00?l0003oool01P3oool00`00o`00oooo0?ooo`160?oo
o`050000o`3oool0oooo0?ooo`000?l0@P3oool7000001T0oooo000J0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000d0oooo00<000000?ooo`3oool0kP3oool0
0`000?l0oooo0?ooo`2A0?ooo`03003o003oool0oooo03H0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1G0?ooo`05003o003oool0oooo0?ooo`00o`007P3oool00`3o0000oooo0?l0
001W0?ooo`03003o003oool0oooo01X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0;`3oool00`00o`00o`000?oo
o`060?ooo`03003o003oool0oooo04H0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`030000
003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0>h0oooo00<0003o0?ooo`3o
ool0T@3oool00`00o`00oooo0?ooo`0f0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0E`3oool01@00o`00oooo0?ooo`3oool00?l001h0oooo00<0o`000?ooo`3o0000I`3oool2003o
01/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0;`3oool00`00o`00o`000?ooo`060?ooo`03003o003oool0oooo
04H0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`030000003oool0oooo01L0oooo000K0?oo
o`8000002P3oool2000000@0oooo0`00000<0?ooo`030000003oool0oooo0>h0oooo0P000?n90?oo
o`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0=P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo05L0oooo00D00?l00?ooo`3oool0oooo003o000M0?ooo`050?l0003oool0
oooo0?ooo`3o0000I@3oool00`00o`00oooo003o000J0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02h0oooo00<0
0?l00?l0003oool01P3oool00`3o00000?l00?ooo`160?ooo`050000o`3oool0oooo0?ooo`000?l0
B03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3^0?ooo`80003oR@3o
ool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo03H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0f0?ooo`03003o003oool0oooo01h0oooo00D00?l00?ooo`3oool0oooo
003o000L0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0H`3oool00`00o`00oooo
003o000J0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo02h0oooo00<00?l00?l0003oool01P3oool00`3o00000?l0
0?ooo`160?ooo`050000o`3oool0oooo0?ooo`000?l0B03oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`3]0?ooo`030000o`3oool0003o08T0oooo00<0003o0?ooo`3oool0
1P3oool2003o03L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0f0?ooo`03003o
003oool0oooo01h0oooo00D00?l00?ooo`3oool0oooo003o000L0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0H`3oool00`00o`00oooo003o000I0?ooo`030?l0003oool0oooo00L0
oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo02h0oooo00<00?l00?l0
003oool01P3oool00`3o00000?l00?ooo`160?ooo`050000o`3oool0oooo0?ooo`000?l0B03oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3]0?ooo`030000o`3oool0003o
08T0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo003o000g0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0=@3oool00`00o`00oooo003o000N0?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
06<0oooo00<00?l00?ooo`00o`006@3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo
0000o`T0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00o`000?ooo`060?ooo`030?l00000o`00
oooo0080oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo04H0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00003[0?ooo`030000o`3oool0003o
0800oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool00?l0
03L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0e0?ooo`03003o003oool00?l0
01h0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0H`3oool00`00o`00oooo003o000H0?ooo`030?l0003oool0oooo
00P0oooo00@0o`000?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`0^0?ooo`03003o003o0000
oooo00H0oooo00<0o`00003o003oool00P3oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0@P3oool5000001T0oooo000l0?ooo`030000003oool0oooo
0>d0oooo00<0003o0?ooo`000?l0P03oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<00?l00?ooo`00o`008@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0=@3oool00`00o`00oooo003o000N0?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool05`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
06<0oooo00@00?l00?ooo`3oool00?l05`3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0
oooo0000o`T0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00o`000?ooo`060?ooo`030?l00000
o`00oooo0080oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo04D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0Q@3oool0
0`00o`00oooo0?ooo`1U0?ooo`030000o`3oool0003o0800oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`03003o003oool00?l00240oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03@0oooo00@00?l00?ooo`3oool00?l07P3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01H0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`1S0?ooo`04003o003oool0oooo003o01L0oooo00<0o`000?ooo`3oool0
203oool0103o0000oooo0?ooo`000?l90?ooo`030000o`3oool0oooo02d0oooo00<00?l00?l0003o
ool01`3oool00`3o00000?l00?ooo`020?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo08D0oooo00<00?l00?ooo`3oool0I@3oool00`000?l0oooo0000o`200?ooo`030?l0
003oool0oooo00H0oooo0P000?l60?ooo`03003o003oool00?l00240oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03<0oooo00D00?l00?ooo`3oool0
oooo003o000M0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool05P3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo06<0oooo00@00?l00?ooo`3oool00?l05`3oool00`3o
0000oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool0;@3oool0
0`00o`00o`000?ooo`070?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`3oool0@03oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0Q@3oool00`00o`00oooo0?ooo`1U0?ooo`030000o`3oool0003o
0800oooo00<0o`000?ooo`3oool01P3oool20000o`H0oooo00@00?l00?ooo`3oool00?l0803oool2
0?l001<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0c0?ooo`05003o003oool0
oooo0?ooo`00o`007@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01D0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`1Q0?ooo`05003o003oool0oooo0?ooo`00o`00
5`3oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`X0oooo00<0003o0?ooo`3o
ool0;03oool00`00o`00o`000?ooo`070?ooo`030?l00000o`00oooo0080oooo0P000?m10?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`240?ooo`800?l0I`3oool00`000?l0oooo0000o`1o0?ooo`80o`00
1`3oool00`000?l0oooo0000o`060?ooo`04003o003oool0oooo003o0200oooo0P3o000C0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0<`3oool01@00o`00oooo0?ooo`3oool00?l0
01d0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool0H@3oool01@00o`00oooo0?ooo`3oool00?l001L0oooo00<0o`00
0?ooo`3oool0203oool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo02`0oooo00<0
0?l00?l0003oool01`3oool00`3o00000?l00?ooo`020?ooo`80003o@@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<00000
0?ooo`3oool0?`3oool00`00o`00oooo0?ooo`120?ooo`03003o003oool00?l006H0oooo00<0003o
0?ooo`000?l0O`3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0003o00H0oooo00@00?l0
0?ooo`3oool00?l0803oool20?l001<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0b0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`1Q0?ooo`05003o003oool0oooo0?ooo`00o`005P3oool00`3o0000oooo0?ooo`090?ooo`040?l0
003oool0oooo0000o`X0oooo00<0003o0?ooo`3oool0;03oool00`00o`00o`000?ooo`070?ooo`03
0?l00000o`00oooo0080oooo0P000?l70?ooo`03003o003oool0oooo03L0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo03l0oooo00<00?l00?ooo`3oool0@P3oool00`00o`00oooo003o001V0?ooo`030000
o`3oool0003o07l0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0000o`050?ooo`05003o
003oool0oooo0?ooo`00o`007`3oool00`3o0000oooo0?l0000C0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0<P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01X0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0H@3oool01@00o`00oooo0?ooo`3oool00?l001H0oooo00<0o`000?oo
o`3oool02@3oool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo02`0oooo00<00?l0
0?l0003oool01`3oool00`3o00000?l00?ooo`020?ooo`80003o1`3oool00`00o`00oooo0?ooo`0g
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool5000003`0oooo00<00?l00?ooo`00o`00>`3oool00`3o0000oooo0?ooo`050?oo
o`03003o003oool00?l006H0oooo00@0003o0?ooo`3oool0003oOP3oool00`3o0000oooo0?l00006
0?ooo`030000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo003o000O0?ooo`040?l0003o
ool0oooo0?l000D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0380oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0J0?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`3oool0503oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0640oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`030?l0
003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l0oooo0?ooo`0/0?ooo`03
003o003o0000oooo00L0oooo00<0o`00003o003oool00P3oool20000o`L0oooo0P00o`0h0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0@@3oool5000001T0oooo000l0?ooo`030000
003oool0oooo03h0oooo00<00?l00?ooo`00o`00>`3oool00`3o0000oooo0?ooo`040?ooo`04003o
003oool0oooo003o00L0oooo00<0o`000?ooo`3oool0G03oool010000?l0oooo0?ooo`000?mn0?oo
o`030?l0003oool0o`0000H0oooo00<0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3oool0
0?l001l0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0<@3oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo01T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0H@3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo01<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0000o`0:0?ooo`030000o`3o
ool0oooo02`0oooo00<00?l00?l0003oool01`3oool00`3o00000?l00?ooo`020?ooo`80003o1`3o
ool2003o03P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`150?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`00o`00>`3oool0
0`3o0000oooo0?ooo`040?ooo`04003o003oool0oooo003o00L0oooo00<0o`000?ooo`3oool0G03o
ool010000?l0oooo0?ooo`000?lP0?ooo`03003o003oool0oooo05/0oooo00<0o`000?ooo`3o0000
1P3oool00`000?l0oooo0000o`050?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
703oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0a0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool0603oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`1Q0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0003o00X0oooo00<0003o0?ooo`3o
ool0;03oool00`00o`00o`000?ooo`070?ooo`030?l00000o`00oooo0080oooo0P000?l60?ooo`03
003o003oool00?l00380oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo04D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
?@3oool01000o`00oooo0?ooo`00o`0Z0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0103oool01000o`00oooo0?ooo`00o`070?ooo`030?l0003oool0oooo05@0oooo00<00?l00?oo
o`3oool01@3oool010000?l0oooo0?ooo`000?lP0?ooo`03003o003oool0oooo05/0oooo00<0o`00
0?ooo`3o00001P3oool00`000?l0oooo0000o`050?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool0703oool0103o0000oooo0?ooo`3o00050?ooo`80003o2`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0340oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0H0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo0640oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0C0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`000?l02P3oool00`000?l0oooo0?oo
o`0/0?ooo`03003o003o0000oooo00L0oooo00<0o`00003o003oool00P3oool20000o`H0oooo00@0
0?l00?ooo`3oool00?l0<@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`0m0?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00@0oooo00@00?l00?ooo`3oool00?l01`3oool00`3o0000oooo0?ooo`1D0?ooo`03
003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0003o803oool00`00o`00oooo0?ooo`1K0?oo
o`030?l0003oool0o`0000H0oooo00<0003o0?ooo`000?l01@3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`80003o2P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02l0oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo04P0oooo00<0003o0?ooo`3oool05@3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0000o`0;0?ooo`030000o`3oool0oooo02X0oooo00<00?l00?ooo`3o00002@3oool0
103o00000?l00?ooo`3oool20000o`H0oooo00@00?l00?ooo`3oool00?l0<@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0m0?ooo`05003o003oool0oooo0?ooo`00o`00
:@3oool2003o00l0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00@0oooo00<0o`000?ooo`3oool0E03oool00`00o`00oooo0?ooo`050?ooo`040000
o`3oool0oooo0000ob00oooo00<00?l00?ooo`3oool0F`3oool00`3o0000oooo0?l000060?ooo`03
0000o`3oool0003o00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0D0?ooo`03
003o003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`80003o2P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02l0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo04P0oooo00<0003o0?ooo`3oool0503oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000003o0?ooo`0;0?ooo`030000o`3oool0oooo02X0oooo00<00?l00?l0003oool02@3oool0103o
00000?l00?ooo`3oool20000o`H0oooo00D00?l00?ooo`3oool0oooo003o000`0?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`140?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo03`0oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0W0?ooo`800?l03P3oool20?l000D0oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`040?ooo`80o`00E03oool2003o00L0oooo00@0003o0?ooo`3oool0003o7`3o
ool2003o05d0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0000o`050?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0=0?ooo`800?l01`3o
ool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P000?l:0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0;`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l000000?l0oooo00/0oooo
00<0003o0?ooo`3oool0:P3oool00`00o`00o`000?ooo`090?ooo`070?l00000o`00oooo0?ooo`00
0?l0oooo0000o`050?ooo`05003o003oool0oooo0?ooo`00o`00;`3oool00`3o0000oooo0?l00003
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool09`3oool2003o00h0oooo0P3o00050?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool0103oool20?l005@0oooo0P00o`060?ooo`050000o`3oool0oooo0?ooo`000?l07`3oool0
0`00o`00oooo003o001K0?ooo`040?l0003oool0oooo0?l000H0oooo00@0003o0?ooo`3oool0003o
103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
3@3oool00`00o`00oooo003o00060?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0000o`090?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00
oooo0?ooo`080?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0B03oool20000oaD0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0
oooo00<0o`000000o`3oool02`3oool00`000?l0oooo0?ooo`0Z0?ooo`03003o003o0000oooo00T0
oooo00L0o`00003o003oool0oooo0000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo003o
000_0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000>P3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo02D0oooo00<00?l00?ooo`00o`003P3oool00`3o0000oooo0?l00004
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool20?l005@0oooo0P00o`06
0?ooo`050000o`3oool0oooo0?ooo`000?l07`3oool00`00o`00oooo003o001K0?ooo`040?l0003o
ool0oooo0?l000H0oooo00@0003o0?ooo`3oool0003o0`3oool00`00o`00oooo0?ooo`040?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool0303oool01000o`00oooo0?ooo`00o`060?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0A
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0?`3oool00`00o`00oooo0?ooo`06
0?ooo`80003o5@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0140oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000003o0?ooo`0;0?ooo`030000o`3oool0oooo02X0oooo00<00?l0
0?l0003oool02@3oool0103o00000?l00?ooo`000?l20?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0o`0000<0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`100?ooo`D000006@3oool003`0oooo00<00000
0?ooo`3oool0>`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo02D0oooo00@00?l0
0?ooo`3oool00?l03@3oool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool00`3o0000oooo0?l0001D0?ooo`03003o003oool00?l000D0oooo00D0
003o0?ooo`3oool0oooo0000o`0O0?ooo`03003o003oool00?l005/0oooo00D0o`000?ooo`3oool0
oooo0?l000050?ooo`040000o`3oool0oooo0000o`<0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o0006
0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;P3oool00`00o`00oooo0?oo
o`080?ooo`05003o003oool0oooo0?ooo`000?l05@3oool00`00o`00oooo0?ooo`050?ooo`03003o
003oool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0m0?ooo`<00?l0
1`3oool00`000?l0oooo0000o`0E0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l000000?l0oooo00/0oooo00<0003o0?ooo`3oool0
:P3oool00`00o`00o`000?ooo`090?ooo`040?l00000o`00oooo0000o`80oooo00<0003o0?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3o
00000`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool09@3oool00`00o`00oooo0?ooo`0C0?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool05@3oool20?l000h0oooo00@00?l00?ooo`3oool0
0?l03@3oool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool00`3oool00`3o0000oooo0?l0000?0?ooo`030?l0003oool0oooo0480oooo00<00?l00?ooo`00
o`001@3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<00?l00?ooo`00o`00F`3oool01@3o
0000oooo0?ooo`3oool0o`0000D0oooo00@0003o0?ooo`3oool0003o0`3oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool01@00o`00oooo0?oo
o`3oool00?l000H0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0]0?ooo`03
003o003oool0oooo00X0oooo00@00?l00?ooo`3oool0003o503oool00`00o`00oooo0?ooo`060?oo
o`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0l0?oo
o`04003o003oool0oooo003o00L0oooo00<0003o0?ooo`000?l05@3oool00`00o`00oooo0?ooo`04
0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`3o0000003o0?ooo`0;
0?ooo`030000o`3oool0oooo02X0oooo00<00?l00?l0003oool02@3oool0103o00000?l00?ooo`00
0?l20?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0/0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02D0oooo00<00?l0
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01D0oooo00<0o`00
0?ooo`3o00000`3o000:0?ooo`04003o003oool0oooo003o00d0oooo00<0o`000?ooo`3o00000`3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o00003`3o
ool00`3o0000oooo0?ooo`110?ooo`04003o003oool0o`00003o00D0oooo00D0003o0?ooo`3oool0
oooo0000o`0O0?ooo`03003o003oool00?l004<0oooo00<00?l00?ooo`3oool05@3oool01@3o0000
oooo0?ooo`3oool0o`0000D0oooo00@0003o0?ooo`3oool0003o0`3oool00`00o`00oooo0?ooo`04
0?ooo`07003o003oool0oooo0?ooo`000?l0oooo0000o`0;0?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`<0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02d0
oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`000?lD0?ooo`03003o003oool0oooo
00H0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
03X0oooo0P00o`040?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`000?l05@3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`3o
0000003o0?ooo`0;0?ooo`030000o`3oool0oooo02X0oooo00<00?l00?l0003oool02@3oool0103o
00000?l00?ooo`000?l20?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0103oool0
0`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`140?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
02@0oooo00<00?l00?ooo`00o`00503oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
01@0oooo00<0o`000?ooo`3oool00`3oool30?l000L0oooo00@00?l00?ooo`3oool00?l03@3oool0
0`3o0000oooo0?l000030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo0?l0000?0?ooo`030?l0003oool0oooo0440oooo00@00?l00?ooo`3o00000?l01@3o
ool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<00?l00?ooo`00o`00@`3oool00`00o`00oooo
0?ooo`0E0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l30?oo
o`03003o003oool0oooo00@0oooo00L00?l00?ooo`3oool0oooo0000o`3oool0003o00X0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0
o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0;@3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo0000oa@0
oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool0>03oool2003o00H0oooo00<00?l00?ooo`3oool0103oool010000?l0
oooo0?ooo`000?lD0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0:@3oool00`00
o`00o`000?ooo`090?ooo`040?l00000o`00oooo0000o`80oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo02X0oooo00@0o`000?ooo`3oool0o`000P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0903oool00`00o`00oooo003o000C0?ooo`03003o003oool0
oooo00H0oooo00<00?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00D00?l00?ooo`3oool0oooo003o000<0?ooo`030?l0003oool0o`000080oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0o`0000l0oooo0P3o
00120?ooo`04003o003oool0o`00003o00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0K0?ooo`04003o003oool0oooo003o0480oooo0P00o`0G0?ooo`050?l0003oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0103oool0
1`00o`00oooo0?ooo`3oool0003o0?ooo`000?l02P3oool00`00o`00oooo0?ooo`040?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0000o`030?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0/0?ooo`03003o
003oool0oooo00/0oooo00<00?l00?ooo`000?l0503oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0f0?ooo`03003o
003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`000?lC0?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0:@3oool00`00o`00o`000?ooo`090?ooo`04
0?l00000o`00oooo0000o`80oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?oo
o`03003o003oool0oooo02X0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00P0oooo00<0
003o0?ooo`3oool0A03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0S
0?ooo`05003o003oool0oooo0?ooo`00o`004P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o
ool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`05003o003o
ool0oooo0?ooo`00o`00303oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00D0oooo
00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`3o000=0?ooo`030?l0003oool0o`000480
oooo00@00?l00?l0003oool00?l01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01/0oooo00@00?l00?ooo`3oool00?l0@P3oool00`00o`00oooo003o000F0?ooo`050?l0003oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0
103oool01`00o`00oooo0?ooo`3oool0003o0?ooo`000?l02@3oool00`00o`00oooo0?ooo`060?oo
o`05003o003oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0000o`030?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0[0?ooo`03003o003oool0
oooo00`0oooo00@00?l00000o`3oool0003o1P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003o
ool0oooo00L0oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo03D0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`040000o`3o
ool0oooo0000oa<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0X0?ooo`03003o
003oool0o`0000X0oooo00@0o`00003o003oool0003o0P3oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0:@3oool01`3o0000oooo0?ooo`3oool0o`00
0?ooo`000?l0203oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo01`0oooo00<00000
0?ooo`3oool05`3oool003`0oooo1@00000Q0?ooo`05003o003oool0oooo0?ooo`00o`004P3oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`00o`00303oool00`3o0000oooo0?l0
00020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?oo
o`3o000=0?ooo`030?l0003oool0o`000480oooo00@00?l00?l0003oool00?l01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00D00?l00?ooo`3oool0oooo003o00110?oo
o`03003o003oool00?l001H0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`050?ooo`06003o003oool0oooo0000o`3oool0
003o2@3oool00`00o`00oooo0?ooo`060?ooo`05003o003oool0oooo0?ooo`3o00001P3oool00`3o
0000oooo0000o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0[0?ooo`03003o003oool0oooo00`0oooo00@00?l00000o`3oool0003o1@3oool2
003o00`0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00d0oooo00<0o`000?ooo`3oool0<`3oool2003o00/0oooo00<00?l00?ooo`3oool00`3oool0
10000?l0oooo0?ooo`000?lC0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0:03o
ool00`00o`00o`000?ooo`0:0?ooo`040?l00000o`00oooo0000o`<0oooo00D0003o0?ooo`3oool0
oooo003o00070?ooo`03003o003oool0oooo02T0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0
003o00T0oooo00D0003o0?ooo`3oool0oooo003o000R0?ooo`80o`006@3oool5000001T0oooo000l
0?ooo`030000003oool0oooo0280oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0?
0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`09
0?ooo`040?l0003oool0oooo0?l00080oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`020?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3o0000@P3oool01000o`00o`00
0?ooo`00o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0F0?ooo`05003o003oool0oooo0?ooo`00o`00@03oool01000o`00oooo0?ooo`00o`0F
0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo
00<00?l00?ooo`3oool01@3oool01P00o`00oooo0?ooo`000?l0oooo0000o`P0oooo00<00?l00?oo
o`3oool01`3oool01@00o`00oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`000?l0103oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0:`3oool0
0`00o`00oooo0?ooo`0<0?ooo`04003o00000?l0oooo0000o`@0oooo00<00?l00?ooo`00o`00303o
ool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0b0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0003o0180oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0X0?ooo`03003o003o0000oooo00X0oooo00@0o`00003o003oool0003o0`3oool010000?l0
oooo0?ooo`00o`080?ooo`03003o003oool0oooo02T0oooo00L0o`000?ooo`3oool0oooo0?l0003o
ool0003o00T0oooo00D0003o0?ooo`3oool0oooo003o000R0?ooo`030?l0003oool0o`0001`0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00P0oooo00@0o`000?ooo`3oool0o`000P3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo0080oooo00@0o`000?ooo`3oool0o`003@3oool0103o0000
oooo0?ooo`3o00100?ooo`05003o003oool0o`000?ooo`00o`001@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool05P3oool01@00o`00oooo0?ooo`3o
ool00?l00400oooo00@00?l00?ooo`3oool00?l05@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo00H0
oooo00H00?l00?ooo`3oool0003o0?ooo`000?l70?ooo`03003o003oool0oooo00P0oooo00D00?l0
0?ooo`3oool0oooo0?l000070?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo02X0oooo00<00?l00?ooo`3oool03P3o
ool00`000?l0oooo0000o`030?ooo`05003o003oool0oooo0?ooo`00o`002`3oool00`00o`00oooo
0?ooo`070?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0a0?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0003o0180oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0X0?ooo`03
003o003o0000oooo00X0oooo00@0o`00003o003oool0003o0`3oool010000?l0oooo0?ooo`00o`09
0?ooo`03003o003oool0oooo02P0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00T0oooo
00@0003o0?ooo`3oool0oooo0P00o`0Q0?ooo`040?l0003oool0oooo0?l001/0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00h0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00P0oooo00H0o`000?ooo`3oool0o`000?ooo`00o`090?ooo`05003o003oool0
oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l00400oooo
00D00?l00?ooo`3o0000oooo003o00050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool2003o01L0oooo00D00?l00?ooo`3oool0oooo003o000o0?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool04P3oool01P3o0000oooo0?ooo`00o`00oooo0?l000@0oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo00H0oooo00H00?l00?ooo`3oool0
003o0?ooo`000?l70?ooo`03003o003oool0oooo00T0oooo00@00?l00?ooo`3oool0o`001`3oool0
0`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0Q0?ooo`X00?l0403oool00`000?l0oooo0000o`020?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0_0?ooo`800?l03`3oool0
0`00o`00oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool00`00o`00oooo0?oo
o`060?ooo`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo02L0oooo00<00?l00?l0003oool02P3oool0103o00000?l00?oo
o`000?l30?ooo`040000o`3oool0oooo003o00T0oooo00<00?l00?ooo`3oool09`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0003o00T0oooo00@0003o0?ooo`3oool0oooo0P00o`0P0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool02`3oool00`3o00000?l00?ooo`0;0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0203oool01P3o0000oooo0?ooo`3o0000oooo003o00T0oooo00D00?l00?ooo`3oool0oooo0?l0
00020?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00:@3oool00`000?l0oooo
0?ooo`0D0?ooo`06003o003oool0o`000?ooo`00o`00o`00103oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo0P00o`0G0?ooo`05003o003oool0oooo0?ooo`00o`00?`3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0180oooo00H0o`00003o0000o`000?l00?oo
o`3o00040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`00o`00203oool01P00o`00oooo
0?ooo`000?l0oooo0000o`H0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`3o0007
0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0240oooo00<00?l00?ooo`3oool05`3oool01@000?l0oooo0000o`3o
ool00?l000D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0^0?ooo`03003o003o
ool0oooo0100oooo00D00?l00?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0100oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0V0?ooo`800?l000<0o`000?ooo`3oool0
2@3oool0103o00000?l00?ooo`000?l30?ooo`040000o`3oool0oooo003o00X0oooo00<00?l00?oo
o`3oool09P3oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo00P0oooo00L0003o0?oo
o`3oool0oooo003o003oool00?l001l0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0240oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`030?l00000o`00oooo00/0oooo00<00?l0
0?ooo`3oool0403oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`060?l0003oool0oooo0?l0003oool00?l0
2@3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool02`3oool0103o0000
oooo0?ooo`3o000Y0?ooo`80003o5@3oool01P00o`00o`000?ooo`3oool00?l00?l000@0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`800?l05P3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo02D0oooo0`00o`0E0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool04P3oool01P00o`00oooo0?ooo`00o`00oooo0?l000@0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo003o00080?ooo`04003o003oool0oooo0000o`80oooo00<0003o0?oo
o`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo0?l000L0oooo00<0o`00
0000o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool0803oool00`00o`00oooo0?ooo`0H0?ooo`040000o`3oool0003o003o00H0oooo00<0
0?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00h0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo0140oooo00D0
0?l00?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?l0003oool0
3@3oool00`000?l0oooo0?ooo`0S0?ooo`<00?l00P3oool00`3o0000oooo0?ooo`090?ooo`040?l0
0000o`00oooo0000o`<0oooo00@0003o0?ooo`3oool00?l02P3oool00`00o`00oooo0?ooo`060?oo
o`800?l07P3oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo00P0oooo00L0003o0?oo
o`3oool0oooo003o003oool00?l001l0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`800000103oool2000000@0oooo0P00000=
0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0;
0?ooo`030?l00000o`00oooo00/0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`07
0?ooo`060?l0003oool0oooo0?l0003oool00?l01@3oool01@000?l0oooo0?ooo`3oool00?l000<0
oooo00@0o`000?ooo`3oool0o`003@3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o
0?ooo`000?l05@3oool00`00o`00o`000?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool00?l001D0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0R0?ooo`<00?l00`3oool3003o0140oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0@0?ooo`800?l000L0o`000?ooo`3oool0oooo003o
003oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo003o00090?ooo`03003o
00000?l0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o
003oool0o`0000P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0803oool00`00o`00oooo0?ooo`0H0?ooo`030000
o`00o`00003o00P0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`03003o
003oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0[0?ooo`03003o
003oool0oooo0180oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00h0
oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00h0
oooo00<0o`000?ooo`3oool0303oool00`000?l0o`000?ooo`0=0?ooo`030000o`3oool0oooo0200
oooo0`00o`050?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`00o`00003o0`3oool01000
0?l0oooo0?ooo`00o`0:0?ooo`03003o003oool0oooo00<0oooo0`00o`020?ooo`03003o003oool0
oooo01/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000003o0?ooo`080?ooo`040000o`3oool0
oooo003o00<0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01D0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003o0000oooo00/0oooo00<00?l00?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool01@000?l0
oooo0?ooo`3oool00?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool09@3oool010000?l0oooo0?ooo`000?lC0?ooo`03003o003o
ool0o`0000<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool07`3oool3003o00T0oooo0`00o`0>0?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool03@3oool2003o0080oooo00L0o`000?ooo`3oool0oooo003o003oool0o`00
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo003o00090?ooo`03003o00000?l0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o003o0000oooo
00L0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0I0?ooo`040000o`00o`00oooo
0000o`L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0
oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0
oooo01<0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00h0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00h0oooo00<0
o`000?ooo`3oool0303oool00`000?l0o`000?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo0P00
o`080?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`00o`00003o0`3oool010000?l0oooo
0?ooo`00o`0;0?ooo`03003o003oool00?l000800?l01P3oool2003o01/0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo003o00<0oooo00<00?l00?oo
o`3oool0703oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01@0oooo00<000000?oo
o`3oool05`3oool00200oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;0?oo
o`L00000703oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00T0oooo00<0o`00003o
003o00003@3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00D0o`000?oo
o`3oool0oooo003o00060?ooo`050000o`3oool0oooo0?ooo`00o`000P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo1@00o`0M0?ooo`040000o`3oool0oooo0000oa<0oooo
00<00?l00?ooo`3o00000`3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00D0003o0?ooo`3o
ool0oooo003o00030?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0D0?ooo`030000o`3oool0oooo00D0oooo0P00o`0?0?ooo`800?l0303oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3oool01`3o
0000oooo0?ooo`3oool00?l00?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool00?l000T0oooo00<00?l00000o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003o
ool0oooo00`0oooo00<00?l00?l0003oool01`3oool00`000?l0o`000?ooo`050?ooo`050000o`3o
ool0oooo0?ooo`000?l03`3oool00`000?l0oooo0?ooo`0N0?ooo`03003o003oool0oooo01T0oooo
00@0003o0?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02T0
oooo00<00?l00?ooo`3oool05@3oool01000o`00oooo0?ooo`000?l50?ooo`030000o`3oool0oooo
00h0oooo00@00?l00?ooo`3oool0oooo0P3o00050?ooo`03003o003oool0oooo00h0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0o`000?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo00<00?l0
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool00?l00000o`<0oooo00<0
003o0?ooo`00o`00303oool2003o00/0oooo00<00?l00?ooo`3oool0603oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool00?l0103oool00`00o`00oooo
0?ooo`0K0?ooo`030?l0003oool0oooo01L0oooo1`00000I0?ooo`00803oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3o00003@3oool00`00o`00oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`05
0000o`3oool0oooo0?ooo`00o`000P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<00?l00?ooo`3oool00P3oool6003o01H0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0@0?ooo`03003o003oool0o`0000<0oooo00D00?l00?l0003oool0oooo0000o`05
0?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0B0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool04`3oool20000o`L0oooo00<00?l00?ooo`3oool0403o
ool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0303o
ool00`00o`00oooo0?ooo`020?ooo`070?l0003oool0oooo0?ooo`00o`00oooo0?l000030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`00o`002@3oool00`00o`00003o0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`00o`00403oool00`00o`00oooo0?ooo`060?ooo`030000o`3o0000oooo
00D0oooo00D0003o0?ooo`3oool0oooo0000o`0?0?ooo`030000o`3oool0oooo01d0oooo00<00?l0
0?ooo`3oool06@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo01H0oooo00@00?l00?ooo`3oool0003o
1@3oool00`000?l0oooo0?ooo`0>0?ooo`04003o003oool0oooo0?ooo`80o`001@3oool01000o`00
oooo0?ooo`000?l80?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?l0000>0?ooo`030000o`3oool0oooo01`0oooo00<00?l00?ooo`3oool0203oool00`3o
0000oooo0?ooo`0:0?ooo`030?l00000o`00003o00@0oooo00<0003o003o003oool0503oool00`3o
0000oooo0?ooo`020?ooo`03003o003oool0oooo01L0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`080?ooo`040000o`3oool0oooo003o00@0oooo00<00?l00?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0O0?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool01000o`00o`000?ooo`3o000=0?ooo`03003o
003oool0oooo00h0oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool00?l000P0
oooo00@00?l00?ooo`3oool0003o1@3oool01@3o0000oooo0?ooo`3oool00?l000H0oooo0P000?l3
0?ooo`03003o003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool2003o00D0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00P0oooo1000o`0B
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`00o`00o`000?ooo`03
0?ooo`05003o003o0000oooo0?ooo`000?l01@3oool01@000?l0oooo0?ooo`3oool00?l000<0oooo
00<00?l00?ooo`3oool04P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0140oooo
0P000?l00`3oool0003o0?ooo`060?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0
0`3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`00o`00oooo00T0oooo00<00?l00000o`3oool00P3oool01@000?l0oooo0?ooo`3oool0
0?l00100oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?l000050?ooo`050000o`3oool0
oooo0?ooo`000?l03`3oool00`000?l0oooo0?ooo`0M0?ooo`03003o003oool0oooo01T0oooo00D0
003o0?ooo`3oool0oooo0000o`070?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0
2@3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0
9`3oool00`00o`00oooo0?ooo`0G0?ooo`04003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3o
ool03P3oool01`00o`00oooo0?ooo`3oool0o`000?ooo`3o0000103oool01000o`00oooo0?ooo`00
0?l70?ooo`800?l00`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0o`0000h0oooo00<0
003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo00<0
o`000?ooo`3oool02P3oool00`3o00000?l00000o`040?ooo`030000o`00o`00oooo01@0oooo00<0
o`000?ooo`3oool00`3oool2003o01H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`080?ooo`040000o`3oool0oooo003o00@0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo
0?ooo`0N0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000002P3oool2000000d0oooo00<0
00000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00H0oooo00D0
0?l00?ooo`3o0000oooo0?l0000=0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0
2P3oool01@3o0000oooo0?ooo`3oool00?l000P0oooo00@00?l00?ooo`3oool0003o103oool01P3o
0000oooo0?ooo`3oool00?l00?l000H0oooo0P000?l30?ooo`03003o003oool0o`0000@0oooo00<0
o`000?ooo`3oool00P3oool2003o00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`03003o003oool0oooo00`0oooo0`00o`0?0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool03`3oool00`00o`00o`000?ooo`030?ooo`05003o003o0000oooo0?ooo`000?l0
1P3oool010000?l0oooo0?ooo`00o`040?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool00`00o`00oooo0?ooo`0B0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`00o`00o`000?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o003o003o
ool02@3oool00`00o`00003o0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00o`00403oool00`00
o`00oooo0?ooo`060?ooo`030000o`3oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000o`0?
0?ooo`030000o`3oool0oooo01`0oooo00<00?l00?ooo`3oool06P3oool01@000?l0oooo0?ooo`3o
ool0003o00P0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`090?ooo`03003o003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0W0?ooo`03003o003o
ool0oooo01L0oooo00@00?l00?ooo`3oool0003o1P3oool01@000?l0oooo0?ooo`3oool00?l000/0
oooo00L00?l00?ooo`3oool0oooo0?l0003oool0o`0000D0oooo00@00?l00?ooo`000?l0003o1P3o
ool2003o00<0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?l0000>0?ooo`030000o`3o
ool0oooo00/0oooo0P00o`0?0?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool02`3o
ool00`3o00000?l00000o`040?ooo`030000o`00o`00oooo01@0oooo00<0o`000?ooo`3oool01@3o
ool3003o01<0oooo00<0o`000?ooo`3oool0103oool00`000?l0o`000?ooo`090?ooo`030000o`3o
ool00?l000D0oooo00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool02`3oool0
0`00o`00oooo0?ooo`040?ooo`06003o003oool0oooo0?l0003oool0o`003P3oool00`00o`00oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo003o00080?ooo`04
003o003oool0003o0000o`@0oooo00H0o`000?ooo`3oool0oooo003o003o00050?ooo`030000o`3o
ool0003o00<0oooo00<00?l00?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`800?l01@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool03`3o
ool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03P3o
ool00`00o`00oooo0?l000040?ooo`05003o003o0000oooo0?ooo`000?l01P3oool010000?l0oooo
0?ooo`00o`040?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00o`00
oooo0?ooo`0C0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`0:0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00o`00
o`000?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o003o003oool02P3oool01@000?l0
oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`060?oo
o`030000o`3oool0o`0000H0oooo00@0003o0?ooo`3oool0003o3`3oool00`000?l0oooo0?ooo`0L
0?ooo`03003o003oool0oooo01X0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`03003o003o
ool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003o
ool0oooo01T0oooo00<00?l00?ooo`000?l01P3oool00`000?l0oooo0?ooo`02003o00/0oooo00@0
0?l00?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0003o0000o`D0
oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0o`0000h0
oooo00<0003o0?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo
00P0oooo00<0o`000?ooo`3oool02`3oool00`3o00000?l00000o`040?ooo`030000o`00o`00oooo
01@0oooo0P3o00090?ooo`@00?l03`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo
00T0oooo00<0003o0?ooo`00o`001@3oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003oool0oooo
01h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`00o`00
oooo0?ooo`0<0?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l000020?oo
o`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`050?l0003oool0oooo0?ooo`00o`00203oool01000o`00oooo0000o`000?l40?ooo`060?l0003o
ool0oooo0?ooo`00o`00o`001@3oool00`000?l0oooo0000o`030?ooo`03003o003oool0o`0000@0
oooo00<0o`000?ooo`3oool00P3oool2003o00D0oooo00<0o`000?ooo`3oool00`3oool01@3o0000
oooo0?ooo`3oool00?l00180oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3o0000103oool01@00o`00o`000?ooo`3oool0
003o00H0oooo00@0003o0?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`0@0?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool03@3oool20000o`H0oooo00<0003o0?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`00o`00o`000?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o003o003oool02P3o
ool01@000?l0oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool03`3oool00`3o00000?l0
0?ooo`060?ooo`030000o`3oool0o`0000H0oooo00@0003o0?ooo`3oool0003o3`3oool00`000?l0
oooo0?ooo`0L0?ooo`03003o003oool0oooo01X0oooo00D0003o0?ooo`3oool0oooo0000o`080?oo
o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0U0?oo
o`03003o003oool0oooo01X0oooo00<00?l00000o`3oool01P3oool00`000?l0oooo0?ooo`02003o
00/0oooo00@00?l00?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0
003o0000o`D0oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0o`0000h0oooo00<0003o0?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=0?ooo`03003o
003oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`3o00000?l00000o`040?ooo`030000
o`00o`00oooo01<0oooo00<0o`000?ooo`3o00003@3oool3003o00P0oooo00D0003o0?ooo`3oool0
oooo0?l000060?ooo`030000o`3o0000oooo00T0oooo00<0003o0?ooo`00o`001P3oool00`00o`00
oooo0?ooo`0H0?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool07@3oool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo00<0oooo
00@00?l00?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool00?l000T0oooo00<00?l00000
o`000?l0103oool01P3o0000oooo0?ooo`3oool00?l00?l000D0oooo00<0003o0?ooo`000?l00`3o
ool00`00o`00oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o000C0?ooo`03
003o003oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`03
003o003oool0o`0000@0oooo00D00?l00?ooo`3o0000oooo0000o`060?ooo`040000o`3oool0oooo
003o00D0oooo00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
oooo00`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`040?ooo`03003o003oool0
oooo01D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003o0000
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l00?l00?ooo`0:0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`00o`004@3oool00`3o00000?l00?ooo`060?ooo`030000o`3oool0
o`0000H0oooo00@0003o0?ooo`3oool0003o3`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool06`3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`80o`001@3oool00`00o`00oooo
0?ooo`080?ooo`04003o003oool0oooo0?l001<0oooo00<0o`000?ooo`3oool0903oool00`00o`00
oooo0?ooo`0K0?ooo`03003o00000?l0oooo00H0oooo00<0003o0?ooo`00o`000P3oool00`00o`00
oooo0?ooo`080?ooo`04003o003oool0oooo0?l00080oooo00<0o`000?ooo`3oool00`3oool01000
o`00oooo0000o`000?l40?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0o`0000h0oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l00000o`00003o00@0oooo00<0003o003o003oool04`3oool00`3o0000oooo0?l0
000?0?ooo`03003o003oool0oooo00D0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?l0003oool02@3oool00`000?l0oooo003o00060?ooo`03003o003oool0oooo01P0oooo00<0
o`000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0]
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo
00<00?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`00
o`002@3oool00`000?l0oooo0000o`040?ooo`060?l0003oool0oooo003o003oool0o`001@3oool0
0`000?l0oooo0000o`030?ooo`03003o003oool0o`0000D0oooo00@0o`000?ooo`3oool00?l00P3o
ool01@00o`00oooo0?ooo`3oool0o`0000L0oooo00@0o`000?ooo`3oool00?l04`3oool00`00o`00
oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`00o`00
oooo0?l000040?ooo`05003o003oool0o`000?ooo`000?l01P3oool010000?l0oooo0?ooo`00o`05
0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`04
0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`04
0?ooo`03003o003oool0oooo01H0oooo00D00?l00?ooo`3oool0oooo003o000:0?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`05003o003o
0000oooo0?ooo`000?l01@3oool00`000?l00?l00?ooo`0:0?ooo`030000o`3oool0oooo0080oooo
00<0003o003o003oool04@3oool00`3o00000?l00?ooo`060?ooo`040000o`3oool0oooo0?l000D0
oooo00@0003o0?ooo`3oool0003o3`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool00?l0
00X0oooo00<00?l00?ooo`3oool06`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0o`00
00@0oooo00<00?l00?ooo`3oool01`3oool2003o0080oooo00<0o`000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0P0?ooo`<00?l07P3oool00`00o`00003o0?ooo`070?ooo`050000o`00o`00oooo
0?ooo`00o`002@3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool00`3o
ool01@00o`00oooo0000o`3oool0003o00<0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3o00003`3oool00`000?l0oooo0?ooo`070?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`090?ooo`03
0?l0003oool0oooo00/0oooo00<0o`00003o00000?l0103oool00`000?l0oooo0?ooo`0C0?ooo`03
0?l0003oool0o`0000l0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0000o`020?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?l0003oool02@3oool00`000?l0oooo003o00070?ooo`03
003o003oool0oooo01H0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool5000002/0oooo00@00?l00?ooo`3oool00?l0103oool01@3o0000oooo0?ooo`3oool0o`00
00h0oooo00<00?l00?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`050?l0003oool0oooo
0?ooo`00o`002@3oool010000?l0oooo0?ooo`000?l30?ooo`060?l0003oool0oooo003o003oool0
o`001@3oool00`000?l0oooo0000o`030?ooo`03003o003oool0o`0000D0oooo00@0o`000?ooo`3o
ool00?l00P3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0?ooo`00o`0D0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0<0?ooo`03003o003o0000oooo00@0oooo00D00?l00?ooo`3o0000oooo
0000o`060?ooo`040000o`3oool0oooo003o00D0oooo00<00?l00?ooo`3oool02P3oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool00`000?l0
oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0G0?ooo`04
003o003oool0oooo003o00/0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00@00?l00?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`00o`00oooo00<0oooo00<0003o003o003oool04@3oool00`3o0000oooo003o0006
0?ooo`040000o`3oool0oooo0?l000H0oooo00<0003o0?ooo`000?l0403oool00`000?l0oooo0?oo
o`0<0?ooo`04003o003oool0oooo0?ooo`800?l01`3oool00`00o`00oooo0?ooo`0L0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`03003o
003oool0oooo0080oooo00@0o`000?ooo`3oool0o`00103oool00`00o`00oooo0?ooo`070?ooo`80
0?l00P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01`0oooo1000o`0R0?ooo`03
0000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`040000o`3oool0oooo
003o0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`05003o00000?l0
oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0?l000l0oooo
00<0003o0?ooo`3o00003`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00D0oooo
00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo
00<0o`00003o00000?l0103oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0o`000100oooo
00<00?l00?ooo`3oool00`3oool01P000?l0oooo0?ooo`000?l0oooo0?l000L0oooo00<0003o0?l0
003oool02@3oool00`000?l0oooo003o00070?ooo`03003o003oool0oooo01H0oooo00<0o`000?oo
o`3oool06`3oool5000001T0oooo000l0?ooo`030000003oool0oooo02h0oooo0P00o`050?ooo`05
0?l0003oool0oooo0?ooo`3o00003P3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00`0oooo00@0o`000?ooo`3oool00?l02P3oool010000?l0oooo0?ooo`000?l30?ooo`060?l0003o
ool0oooo003o003oool0o`001@3oool00`000?l0oooo0000o`040?ooo`03003o003o0000oooo00@0
oooo00<0o`000?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0?ooo`00o`0D0?ooo`03003o003oool0oooo00L0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003o0000oooo00D0oooo00@00?l0
0?l0003oool0003o1P3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0oooo00P0oooo
0P3o00040?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`040?l0003oool0o`000000o`@0oooo00<00?l00?ooo`3oool0603oool2003o00`0
oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00@00?l00?l0003oool0003o1P3oool00`000?l0oooo0?ooo`080?ooo`030000o`00o`00oooo
00<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo003o00060?ooo`040000o`3oool0oooo
0?l000H0oooo0P000?lA0?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool0103oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01`0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0
103o0000oooo0?ooo`3o00050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`00o`000P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0003o00P0oooo00<0o`000?ooo`3oool03P3o
ool3003o02H0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo
0P000?l20?ooo`04003o003oool0oooo0?l000@0oooo00<0o`000?ooo`3oool00P3oool01@00o`00
003o0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o000?
0?ooo`030000o`3oool0o`0000l0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`05
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l00000o`00003o00@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?l0000@
0?ooo`03003o003oool0oooo0080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0o`0000L0oooo
00<0003o0?l0003oool02@3oool00`000?l0oooo003o00080?ooo`03003o003oool0oooo00l0oooo
00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo02h0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0<0?ooo`040?l0003oool0oooo003o00X0oooo00@0003o003o003oool0003o0`3oool00`3o0000
oooo003o00020?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0003o0`3oool00`00
o`00o`000?ooo`040?ooo`030?l0003oool00?l000<0oooo00H00?l00?ooo`3oool0oooo0?l0003o
ool20000o`@0oooo00@0o`000?ooo`3oool00?l05@3oool00`00o`00oooo0?ooo`060?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`00o`002P3oool00`00o`00oooo0?l000060?ooo`04003o
003o0000oooo0000o`H0oooo00@0003o0?ooo`3oool00?l01P3oool00`00o`00oooo0?ooo`080?oo
o`80o`000`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool0103o0000oooo0?l000000?l40?ooo`03003o003oool0oooo01T0oooo00<00?l0
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool01000o`00o`000?ooo`000?l60?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool00?l000H0oooo00@0
003o0?ooo`3oool0o`001P3oool20000oa40oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool07@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`020?ooo`040?l0003oool0oooo0?l000D0oooo00<00?l00?ooo`3oool01@3oool01P00o`00
oooo0?ooo`00o`00oooo0?l001@0oooo00<0o`000?ooo`000?l01`3oool20?l00100oooo00<00?l0
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00<0oooo00<00?l0
0?ooo`3oool00P3oool20000o`80oooo00@00?l00?ooo`3oool0o`00103oool00`3o0000oooo0?oo
o`030?ooo`060000o`3oool0oooo0000o`3oool00?l01@3oool00`00o`00oooo0?l0000@0?ooo`03
0000o`3oool0o`0000l0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`070?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0?l00000o`00003o00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?l000l0oooo00<00?l00?ooo`3oool00P3oool01`000?l0oooo0?ooo`3oool0
003o0?ooo`3o00001P3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`00o`00oooo00P0oooo
00<00?l00?ooo`3oool03P3oool2003o00D0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00d0oooo00<0
o`000?ooo`00o`002@3oool01@000?l0oooo003o003oool0003o00<0oooo0P00o`030?ooo`030?l0
003oool0oooo00<0oooo00@0003o0?ooo`3oool0003o0`3oool00`00o`00o`000?ooo`040?ooo`03
0?l0003oool00?l000<0oooo00T00?l00?ooo`3oool0oooo0?l0003oool0003o0?ooo`000?l0103o
ool00`3o0000oooo003o000E0?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l00?l00?ooo`050?ooo`80003o0P3oool00`00o`00oooo0?l000060?ooo`04003o003o
0000oooo0000o`H0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`070?ooo`040?l0
003oool0oooo0?l00080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00@0o`000?ooo`3o0000003o103oool00`00o`00oooo0?ooo`0V0?oo
o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`04003o003o0000oooo0000o`D0oooo00<00?l00000o`3oool02@3oool00`000?l0oooo003o0003
0?ooo`030000o`3oool0oooo0100oooo00@0o`000?ooo`3oool00?l01P3oool010000?l0oooo0?oo
o`3o00060?ooo`80003o4@3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo00P0oooo
0P00o`020?ooo`03003o003oool0oooo01`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`060?ooo`03003o003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`03
0?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool01`00o`00oooo0?ooo`3oool00?l0
0?ooo`3o0000503oool0103o0000oooo0000o`000?l60?ooo`030?l0003oool0o`0000h0oooo00<0
0?l00?ooo`3oool09`3oool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00<0oooo00L0
0?l00?ooo`3oool0oooo0000o`3oool0003o0080oooo00@00?l00?ooo`3oool0o`00103oool00`3o
0000oooo0?ooo`030?ooo`060000o`3oool0oooo0?ooo`000?l00?l01@3oool00`00o`00oooo0?l0
000?0?ooo`040000o`3oool0oooo0?l000l0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo003o000;0?ooo`03
0?l0003oool0oooo00`0oooo00<0o`00003o00000?l0103oool00`00o`00003o0?ooo`0;0?ooo`03
0000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0o`003`3oool01@00o`00oooo0?ooo`3oool0
003o00D0oooo00<0003o0?l0003oool01@3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`00
o`00oooo00T0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo003o00040?ooo`030?l0003o
ool0oooo01l0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0=03oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030?l0003oool00?l000T0oooo00D0003o0?ooo`00o`00oooo0000
o`020?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?oo
o`000?l30?ooo`03003o003o0000oooo00@0oooo00<0o`000?ooo`00o`000`3oool01P00o`00oooo
0?ooo`3oool0o`000000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo003o000F0?oo
o`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool01@00o`00003o0?ooo`00o`00
oooo00@0003o00L0oooo0000o`3oool0oooo003o003oool0o`0000H0oooo00@00?l00?ooo`3o0000
003o1P3oool00`000?l0oooo003o00080?ooo`03003o003oool0oooo00H0oooo00@0o`000?ooo`3o
ool0o`000P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool0103o0000oooo0?ooo`000?l40?ooo`03003o003oool0oooo02L0oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00@00?l0
0?l0003oool0003o1@3oool00`00o`00003o0?ooo`090?ooo`030000o`3oool00?l00080oooo00<0
0?l00000o`3oool04@3oool01@3o0000oooo0?ooo`3oool00?l000D0oooo00@0003o0?ooo`3oool0
o`001`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3o
ool02P3oool2003o01l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`03
003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool0103oool01P00o`00oooo0?ooo`3oool00?l00?l001D0oooo00@0
o`000?ooo`000?l0003o1@3oool0103o0000oooo0?ooo`3o000>0?ooo`03003o003oool0oooo02L0
oooo00<0003o003o003oool0103oool01000o`00oooo0?ooo`000?l30?ooo`07003o003oool0oooo
0?ooo`000?l0oooo0000o`020?ooo`03003o003oool0o`0000D0oooo00<0o`000?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<00?l00?ooo`3o00003`3oool01@000?l0oooo
0?ooo`3oool0o`0000h0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`05
003o003oool0oooo0?ooo`3o00000P3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00`0oooo00<0o`00003o00000?l0103oool00`00o`00003o0?ooo`0;0?ooo`030000o`3oool0oooo
00@0oooo00D0o`000?ooo`3oool0oooo0?l0000@0?ooo`03003o003oool0003o00H0oooo00<0003o
0?l0003oool01@3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`00o`00oooo00T0oooo00<0
0?l00?ooo`3oool0303oool01000o`00oooo0?ooo`00o`040?ooo`030?l0003oool0oooo01l0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?oo
o`050?ooo`050000o`3oool0oooo0?ooo`3o00003`3oool00`3o0000oooo003o00090?ooo`090000
o`3oool00?l00?ooo`000?l0oooo003o003oool0o`0000@0oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`000?l30?ooo`03003o003o0000oooo00@0oooo00<0o`00003o003oool00`3o
ool01P00o`00oooo0?ooo`3oool0o`000000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo003o000F0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`00o`00
oooo0000o`020000o`D0oooo00D0003o0?ooo`3oool00?l00?l000070?ooo`04003o003oool0o`00
0000o`H0oooo00<0003o0?ooo`00o`00203oool00`00o`00oooo0?ooo`060?ooo`040?l0003oool0
oooo0?l00080oooo00<00?l00?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool0203oool01P3o0000oooo0?ooo`3oool0o`000000o`<0oooo00<00?l00?oo
o`3oool09`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool01P3oool00`00o`00oooo0000o`050?ooo`03003o00000?l0oooo00T0oooo00<0003o0?oo
o`00o`000P3oool00`00o`00003o0?ooo`0A0?ooo`050?l0003oool0oooo0?ooo`00o`001@3oool0
1@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`070?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool07@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?oo
o`3o00050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`020?ooo`03003o003o0000oooo01@0oooo00D0o`000?ooo`000?l0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`3o0000303oool00`00o`00oooo0?ooo`0X0?ooo`030000o`00o`00oooo
00@0oooo00@00?l00?ooo`3oool0003o0`3oool01000o`00oooo0?ooo`000?l20?ooo`060000o`3o
ool0oooo003o003oool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`000?l01P3oool00`00o`00oooo0?l0000?0?ooo`050000o`3oool0oooo0?ooo`3o00003`3oool0
0`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00D00?l00?ooo`3oool0oooo0?l0
00020?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`3o00000?l00000
o`040?ooo`03003o00000?l0oooo00X0oooo0P000?l60?ooo`050?l0003oool0oooo0?ooo`3o0000
403oool00`00o`00003o0?ooo`060?ooo`030000o`3o0000oooo00D0oooo00@0003o0?ooo`3oool0
o`002@3oool00`000?l00?l00?ooo`0:0?ooo`03003o003oool0oooo00/0oooo00D00?l00?ooo`3o
ool0oooo003o00020?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`040?ooo`040000o`3oool0oooo0?l0
0100oooo00<0o`000?ooo`00o`00203oool02@000?l0oooo0?ooo`3oool00?l00000o`00o`00oooo
0?l000060?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01P000?l0oooo0?ooo`3oool00?l0
0?l000D0oooo00<0o`00003o003oool00`3oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o00000?l00?ooo`0G0?ooo`03003o003oool0oooo00<0oooo00<0
003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00D0
003o0?ooo`3oool00?l00?l000070?ooo`04003o003oool0o`000000o`H0oooo00<0003o0?ooo`00
o`002@3oool00`00o`00oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`00
o`00oooo0?ooo`060?ooo`05003o003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`09
0?ooo`060?l0003oool0oooo0?ooo`3o0000003o0P3oool00`00o`00oooo0?ooo`0X0?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03003o
003oool0003o00D0oooo00<00?l00000o`3oool02@3oool00`000?l0oooo003o00020?ooo`03003o
00000?l0oooo0140oooo00D0o`000?ooo`3oool0oooo003o00040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0@0?ooo`030000o`3oool0oooo00H0
oooo00<00?l00?ooo`3oool0;@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0
oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3o00050?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03003o003o0000oooo
01@0oooo00D0o`000000o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0X0?ooo`030000o`00o`00oooo00<0oooo00D00?l0
0?ooo`3oool0oooo0000o`040?ooo`03003o003oool0003o0080oooo00H0003o0?ooo`3oool00?l0
0?ooo`3o00050?ooo`030?l0003oool0oooo00<0oooo00H0003o0?ooo`3oool00?l00?ooo`000?l6
0?ooo`03003o003o0000oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`050000o`3o
ool0oooo0?ooo`00o`003P3oool01`00o`00oooo0?l0003oool0o`000?ooo`00o`00303oool00`3o
0000oooo0?ooo`0<0?ooo`030?l00000o`00003o00@0oooo00<00?l00000o`3oool02P3oool00`00
0?l0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o0000403oool00`00o`00003o0?ooo`06
0?ooo`030000o`3o0000oooo00D0oooo00@0003o0?ooo`3oool0o`002P3oool00`000?l0oooo0?oo
o`090?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?oo
o`020?ooo`04003o003oool0oooo0?l00280oooo00<000000?ooo`3oool05`3oool003`0oooo1@00
000K0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0000
o`3oool0o`000100oooo00<0o`000?ooo`00o`00203oool01P000?l0oooo0?ooo`3oool00?l00000
o`80oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0003o
0?ooo`3oool0oooo003o00070?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0o`00
0000o`030?ooo`030000o`3oool0oooo0080oooo00<0o`00003o003oool05`3oool00`00o`00oooo
0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`030?ooo`050000o`3oool00?l00?ooo`3o00001`3oool01000o`00oooo0?l000000?l70?oo
o`030000o`00o`00oooo00P0oooo00<00?l00?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
o`000080oooo00<00?l00?ooo`3oool01P3oool01000o`00oooo0?ooo`3oool20?l000030?ooo`00
0?l0oooo00/0oooo00H0o`000?ooo`3oool0oooo0?l000000?l20?ooo`03003o003oool0oooo02P0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<00?l00?ooo`000?l01@3oool00`00o`00003o0?ooo`090?ooo`050000o`3oool00?l00?oo
o`00o`000P3oool00`000?l0oooo0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`00o`00103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P00o`0C0?ooo`030000o`3oool0
oooo00@0oooo00<00?l00?ooo`3oool0;P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?l000070?ooo`060?l0003oool0
oooo0?ooo`00o`00003o0`3oool00`00o`00oooo0?ooo`030?ooo`03003o003o0000oooo01D0oooo
00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool02@3oool00`00o`00oooo0?ooo`0X0?ooo`030000o`3oool00?l000@0oooo00D00?l00?ooo`3o
ool0oooo0000o`040?ooo`03003o00000?l0oooo00<0oooo00D0003o003o003oool0oooo0?l00006
0?ooo`030?l0003oool0oooo0080oooo00H0003o0?ooo`3oool00?l00?ooo`000?l60?ooo`03003o
003o0000oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`050000o`3oool0oooo0?oo
o`00o`003P3oool01P00o`00oooo0?l0003oool0o`00003o00`0oooo00<0o`000?ooo`3oool03@3o
ool00`3o0000oooo0000o`030?ooo`03003o003oool0003o00/0oooo00<0003o0?ooo`000?l01@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000003o0?ooo`050?ooo`040000o`3oool0oooo0?l000X0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo003o00050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
0`3oool01000o`00oooo0?ooo`3o000N0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0080oooo00D0003o0?ooo`000?l0
oooo0?l0000@0?ooo`030?l0003oool00?l000P0oooo00<0003o0?ooo`3oool00P3oool010000?l0
oooo0?ooo`3o00060?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01P000?l0oooo0?ooo`3o
ool0o`00003o00D0oooo00<00?l00?l0003oool0103oool00`00o`00oooo0000o`050?ooo`030000
o`3oool0oooo0080oooo00<00?l00?ooo`3oool05`3oool01@00o`00oooo0?ooo`3oool0003o00X0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`050000o`3oool00?l00?oo
o`3o00001`3oool01000o`00oooo0?l000000?l70?ooo`030000o`00o`00oooo00P0oooo00<00?l0
0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<00?l00?ooo`3oool01`3o
ool01`00o`00oooo0?l0003oool0o`000?ooo`000?l0303oool00`3o0000oooo0?ooo`020?ooo`04
0000o`3oool0oooo003o02X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<00?l00?ooo`000?l01@3oool00`00o`00003o0?ooo`090?oo
o`030000o`3oool0oooo00800?l00P3oool00`000?l0oooo0?ooo`0?0?ooo`050?l0003oool0oooo
0?ooo`00o`00103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`00o`004P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo02l0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3o00001`3oool01P3o0000oooo0?ooo`3oool00?l00000o`<0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00o`000?ooo`0E0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000060?oo
o`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool0:03oool010000?l0oooo0?ooo`00o`02
0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00003o0?ooo`03
0?ooo`040000o`00o`00oooo0?l000L0oooo00<0o`000?ooo`3oool00P3oool00`000?l00?l0003o
00020?ooo`030000o`3oool0oooo00@0oooo00<00?l00?l0003oool03P3oool01@000?l0oooo0?oo
o`3oool0o`0000l0oooo00@0003o0?ooo`3oool00?l0403oool01@00o`00o`000?ooo`3o00000?l0
00`0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0000o`030?ooo`03003o003oool0003o
00/0oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`00o`001`3oool00`3o0000003o0?ooo`050?ooo`050000o`3oool0oooo
0?ooo`3o00002@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo003o00@0oooo0P3o
00030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o00008P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00`0oooo0P000?l5
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`02
0?ooo`050000o`3oool0003o0?ooo`3o0000403oool00`3o00000?l00?ooo`070?ooo`030000o`3o
ool0oooo00<0oooo00@0003o0?ooo`3oool0o`001P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0003o0?ooo`3oool0o`00003o00050?ooo`03003o003o0000oooo00@0oooo00<00?l00?oo
o`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo01L0oooo00D00?l00?oo
o`3oool0oooo0000o`090?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool0
10000?l00?l00?ooo`3o00070?ooo`04003o003oool0003o0?l000L0oooo00<0003o003o003oool0
2@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`00003o003oool0
2@3oool01P00o`00oooo0?l0003oool0o`000000o`d0oooo00<0o`000?ooo`3oool00P3oool01000
0?l0oooo0?ooo`00o`0[0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`03003o003oool0003o00D0oooo00<00?l00000o`3oool02@3oool0
0`000?l0oooo0?ooo`02003o0080oooo00<0003o0?ooo`3oool03`3oool01@3o0000oooo0?ooo`3o
ool00?l000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03003o003o
ool00?l001<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0_0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool01@00o`00oooo0?ooo`3oool00?l00080oooo
00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool00?l00080003o00<0oooo003o003o
ool01@3oool00`00o`00oooo0?ooo`0E0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l00006
0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0:@3oool010000?l0oooo0?ooo`00
o`020?ooo`03003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`040000
o`00o`00oooo0?l000L0oooo00<0o`000?ooo`3oool00P3oool00`000?l00?l0003o00020?ooo`03
0000o`3oool0oooo00@0oooo00<00?l00?l0003oool03P3oool01@000?l0oooo0?ooo`3oool0o`00
00l0oooo00@0003o0?ooo`3oool00?l0403oool01000o`00o`000?ooo`00o`0=0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`000?l00`3oool00`00o`00oooo0000o`0:0?ooo`040000o`3o
ool0oooo0000o`D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool00?l000L0oooo00<0o`000000o`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`0000T0
oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0000o`3oool00?l000<0oooo00<0o`000?oo
o`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0o`000280oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0<0?ooo`80
003o103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00d0oooo00D00?l00?ooo`3o
ool0oooo0000o`030?ooo`030000o`3o0000oooo00l0oooo00<0o`00003o003oool01`3oool00`00
0?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050000o`3oool0oooo0?l00000o`001@3oool00`00o`00o`000?ooo`040?ooo`03003o
003oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0H0?ooo`03003o
003oool0003o00T0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`020?ooo`030000
o`00o`00o`0000P0oooo00@00?l00?ooo`000?l0o`001`3oool00`000?l00?l00?ooo`090?ooo`03
003o003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?ooo`090?ooo`05
003o003oool0o`000?ooo`000?l03@3oool00`3o0000oooo0?ooo`030?ooo`040?l000000?l0oooo
003o02/0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<00?l00?ooo`000?l01@3oool00`00o`00003o0?ooo`080?ooo`050000o`3oool0
oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`00o`00
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`00
4`3oool01@000?l0oooo0?ooo`3oool00?l00380oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`070?ooo`07003o003oool0oooo0000o`00o`00oooo0?l000080?ooo`050?l0003oool0
oooo0?ooo`00o`000P000?l00`3oool00?l00?ooo`050?ooo`030?l00000o`00oooo01D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo003o000[0?ooo`060000o`3oool0oooo003o003oool00?l01P3oool01P00
0?l0oooo0?ooo`3oool0003o003o00@0oooo00@0003o003o003oool0o`001`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`00o`00oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00o`00
0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`3o00003`3oool010000?l0oooo0?ooo`00o`090?oo
o`030000o`3oool0oooo00D0oooo00<00?l00?ooo`00o`003@3oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0003o00<0oooo00<00?l00?ooo`000?l02P3oool010000?l0oooo0?ooo`000?l5
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool010000?l0oooo0?ooo`00
o`070?ooo`030?l000000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`000?l00P3oool01P00o`00oooo0?ooo`3o0000oooo0?l0
0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00o`000?ooo`0Q0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0000o`030?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03P3oool01000o`00
oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000H0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050000o`3oool0oooo0?l00000o`001@3oool00`00o`00o`000?ooo`040?ooo`03003o0000
0?l0o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0H0?ooo`03003o003o
ool0003o00T0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`020?ooo`030000o`00
o`00o`0000P0oooo00@00?l00?ooo`000?l0o`001`3oool00`000?l00?l00?ooo`090?ooo`05003o
003oool0oooo0?ooo`3o00001P3oool00`3o00000?l00?ooo`090?ooo`06003o003oool0o`000?oo
o`000?l0o`00303oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool00?l002/0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`00
003o00000?l01@3oool00`00o`00003o0?ooo`080?ooo`050000o`3oool0oooo0?ooo`00o`000`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo
0000o`050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`00503oool010000?l0oooo
0?ooo`00o`0b0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool01`00o`00
oooo0?ooo`000?l00?l00?ooo`3o0000203oool00`3o0000oooo0?ooo`020?ooo`80003o00<00?l0
0?ooo`3oool01@3oool00`3o00000?l00?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo003o000/0?ooo`06
0000o`3oool0oooo003o003oool00?l01P3oool01P000?l0oooo0?ooo`000?l0oooo003o00@0oooo
00@0003o003o003oool0o`001`3oool00`3o0000oooo0?ooo`020?ooo`030000o`00o`00oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?oo
o`3o0000403oool00`000?l0oooo003o00090?ooo`030000o`3oool0oooo00@0oooo00D0o`00003o
003oool00?l00?l0000<0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`00o`000`3oool0
0`00o`00oooo0000o`0:0?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`00o`001`3oool00`3o0000oooo
0000o`050?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0003o00<0oooo00L00?l00?ooo`3o0000oooo0?l0003oool00?l000T0oooo00<00?l0
0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00h0oooo00@00?l00?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0@
0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l00006
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3o00000?l000@0oooo
00<00?l00?ooo`3o00001@3oool00`00o`00003o0?l000060?ooo`060000o`3oool0oooo0?ooo`00
o`00o`006P3oool00`00o`00003o003o0002003o00D0oooo00<00?l00?ooo`3oool02@3oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0o`0000P0oooo00@00?l00?ooo`000?l0o`001`3oool0
0`000?l00?l00?ooo`0:0?ooo`04003o003oool0oooo0?l000H0oooo00<0o`00003o003oool02@3o
ool01P00o`00oooo0?l000000?l0oooo0?l000`0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo003o000[0?ooo`05003o003oool0oooo0?ooo`00o`002@3oool00`3o0000oooo0?ooo`070?oo
o`03003o00000?l0oooo00<0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo003o000E0?ooo`030000o`3o
ool00?l00380oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`05003o0000
0?l0003o003o003o00002P3oool0103o0000oooo0?ooo`3oool20000o`03003o003oool0oooo00D0
oooo00<0o`00003o003oool05@3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l01`3oool0
103o0000oooo0?ooo`000?l20?ooo`030000o`3oool00?l002`0oooo00D0003o0?ooo`3oool0oooo
003o00070?ooo`060000o`3oool0oooo0000o`3oool00?l0103oool00`000?l00?l00?l000080?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`03003o003oool0oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`030000o`00o`00
oooo00P0oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo003o003oool0o`0000/0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000003o003o00030?ooo`04003o003oool0oooo0000o`T0oooo
00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0003o00@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0o`000080oooo00<00?l00?oo
o`3oool0203oool00`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo01l0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`000?l30?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0000o`040?oo
o`030?l000000?l0oooo0100oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0o`0000H0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0
oooo0?l00000o`00103oool00`00o`00oooo0?l000050?ooo`030000o`3oool0o`0000H0oooo00H0
003o0?ooo`3oool0oooo003o003o000J0?ooo`030000o`3oool0oooo0080oooo1@00o`0=0?ooo`07
003o003oool0oooo0?ooo`000?l0oooo0?l000090?ooo`03003o00000?l0o`0000L0oooo00<0003o
003o003oool02P3oool01000o`00oooo0?ooo`3o00060?ooo`030?l00000o`00oooo00T0oooo00H0
0?l00?ooo`3o0000003o0?ooo`3o00060?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo003o000:0?ooo`030000o`3oool0oooo01l0oooo00@00?l00?ooo`3o
ool00?l02@3oool00`3o0000oooo0?ooo`070?ooo`03003o00000?l0oooo00<0oooo00@00?l00?oo
o`3oool0003o203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`000?l01@3o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l00100oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo003o000a0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203o
ool01@00o`00003o0000o`00o`00o`0000X0oooo00L0o`000?ooo`3oool0oooo0000o`00o`00003o
00L0oooo00<0o`00003o003oool05@3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l0203o
ool00`3o0000oooo0000o`030?ooo`030000o`3oool0oooo02/0oooo00D0003o0?ooo`3oool0oooo
003o00080?ooo`80003o0P3oool00`00o`00oooo0?ooo`020?ooo`030000o`00o`00o`0000T0oooo
00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00h0
oooo00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`030000o`00o`00oooo00P0oooo00<0003o0?oo
o`000?l01@3oool01@3o0000oooo003o003oool0o`0000/0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l00?l00?ooo`020?ooo`04003o003oool0oooo0000o`T0oooo00@0003o0?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`060?ooo`03003o00000?l0oooo00L0oooo00D0003o0?ooo`3o
ool0oooo0000o`030?ooo`05003o003oool0oooo0?ooo`00o`001P3oool01P000?l0oooo0?ooo`3o
ool0o`00003o0280oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07`3o
ool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000o`<0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o00000?l0oooo00<0oooo00<0o`000000o`3oool0
403oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o0000
1P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00H0003o0?ooo`3oool0o`000?ooo`00o`03
0?ooo`03003o003oool0o`0000D0oooo00<0003o0?ooo`3o00001P3oool01P000?l0oooo0?ooo`3o
ool00?l00?l000T0oooo0P000?l>0?ooo`80003o5P3oool01`00o`00oooo0?ooo`3oool0003o0?oo
o`3o00002@3oool01000o`00003o0?ooo`3o00060?ooo`030000o`3oool0oooo00/0oooo00<00?l0
0?l0003oool01P3oool00`3o00000?l00?ooo`090?ooo`03003o003o0000003o0080oooo00<0o`00
0?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
003o003oool02P3oool00`000?l0oooo0?ooo`0O0?ooo`04003o003oool0oooo003o00P0oooo00<0
o`000?ooo`3oool0203oool00`00o`00003o0?ooo`030?ooo`04003o003oool0oooo0000o`P0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`3o
00001@3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo003o000@0?ooo`80o`00103oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0203oool01@00o`00003o0000o`00o`00o`0000X0oooo00L0o`00
0?ooo`3oool0oooo0000o`00o`00003o00L0oooo00<0o`00003o003oool05@3oool010000?l0oooo
0?ooo`3o00030?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`3oool00`3oool00`00o`00
003o0?ooo`0[0?ooo`030000o`3oool0oooo00X0oooo0P000?l30?ooo`07003o003oool0oooo0?oo
o`000?l00?l00?l000090?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`3o0000403oool00`000?l00?l0
0?ooo`070?ooo`040000o`3oool0oooo0000o`D0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?oo
o`030?l0003oool0oooo00l0oooo00D0003o003o003oool0oooo003o00030?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
1P3oool00`00o`00003o0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01@3o0000
0?l00?ooo`00o`00o`0000D0oooo0P000?l30?ooo`030?l00000o`00oooo0240oooo00<000000?oo
o`3oool05`3oool003`0oooo1@00000M0?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3o
ool0003o0`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<00?l00000
o`3oool00P3oool00`3o0000oooo0000o`0A0?ooo`03003o003oool0oooo00@0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?l000060?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1P000?l0oooo0?ooo`3o0000oooo003o00<0oooo00@00?l00?ooo`3oool0o`000`3oool00`000?l0
0?l00?l000070?ooo`060000o`3oool0oooo003o003oool0o`002@3oool010000?l0oooo0000o`00
0?l90?ooo`<0003o6@3oool01P00o`00oooo0?ooo`000?l0oooo0?l000T0oooo00@00?l00000o`3o
ool0o`001P3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003o0000oooo00L0oooo00<00?l00?oo
o`3oool0203oool00`00o`00o`000000o`030?ooo`030?l0003oool0oooo0080oooo0P00o`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o003o003oool02@3oool00`000?l0oooo0000o`0P0?oo
o`03003o003o00000?l000T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?oo
o`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`08
0?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`000?l01@3o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l000l0oooo00<0o`000?ooo`3o0000103o
ool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool01000o`00003o0000o`00o`0;0?ooo`070?l0003oool0oooo0000o`00o`00oooo0000o`060?oo
o`030?l0003oool00?l001H0oooo00@0003o0?l0003oool0o`000`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`000?l0;03oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0080oooo00L00?l00?ooo`3oool0oooo0000o`00o`00o`0000T0oooo
00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`020?ooo`030?l00000o`00oooo00h0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`040000o`3oool0oooo0?l0
00H0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o00002`3o
ool00`3o0000oooo0?ooo`0?0?ooo`050000o`00o`00oooo0?ooo`00o`000`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00D0oooo00<00?l00000o`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`080000o`3oool0oooo
0?l00000o`00oooo003o003o00050?ooo`030000o`3oool0003o0080oooo00<0o`00003o003oool0
7@3oool5000001T0oooo000l0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0203o
ool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`00o`00oooo0080oooo00@0o`000?ooo`3oool0003o403oool00`00o`00
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool01P3oool0103o0000
oooo0?ooo`000?l50?ooo`060000o`3oool0oooo0?l0003oool00?l00P3oool01@00o`00oooo0?oo
o`3oool0o`0000<0oooo00<0003o003o003o00001`3oool010000?l0oooo0?ooo`00o`020?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool30000o`<0oooo0`000?lL0?ooo`05
003o003oool0oooo0000o`3o00002P3oool01000o`00003o0?ooo`3o00060?ooo`040000o`3oool0
oooo0?l000X0oooo00<00?l00?l0003oool01P3oool00`00o`00o`000?ooo`0:0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo003o00030?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`0P0?ooo`03003o003o
00000?l000T0oooo00<0o`000?ooo`3oool0203oool00`000?l00?l00?ooo`030?ooo`04003o003o
ool0oooo0000o`P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`80003o
0`3oool00`3o0000oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`000?l01P3oool01`3o0000
oooo0?ooo`3oool00?l00?ooo`00o`003`3oool0103o0000oooo0?ooo`3o00030?ooo`03003o0000
0?l0oooo0300oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`040000o`3o
ool0003o003o00`0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool00?l001D0oooo00@0003o0?ooo`3o0000o`00103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0o`0000<0oooo00@00?l00?ooo`3oool0003o303oool00`3o0000oooo0?ooo`0G0?oo
o`050?l0003oool0oooo0?ooo`000?l04P3oool01P00o`00oooo0?ooo`3oool0003o0?l000X0oooo
00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`020?ooo`030?l00000o`00oooo00h0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`040000o`3oool0oooo0?l0
00D0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`050000o`00o`00oooo0?ooo`00o`000`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00D0oooo00<00?l00000o`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`06
0000o`3oool0oooo0?l0003oool00?l00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00H0
003o0?ooo`3oool0o`000?ooo`00o`0Q0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo0200oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`00o`00oooo0080
oooo00@0o`000?ooo`3oool0003o3`3oool00`00o`00o`000?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?l0003oool01P3oool0103o0000oooo0?ooo`000?l60?ooo`050000o`3oool0
o`000?ooo`00o`000P3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`00o`00
o`00203oool00`000?l0oooo003o00020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool30000ob00oooo00@00?l00?ooo`000?l0o`002P3oool01000o`00003o0?ooo`3o0006
0?ooo`050000o`3oool0o`000?ooo`3o00002@3oool00`3o00000?l00?ooo`060?ooo`03003o003o
0000oooo00X0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l00080oooo
00D00?l00?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3o
ool0oooo0000o`0O0?ooo`030?l00000o`000?l000T0oooo00<0o`000?ooo`3oool0203oool00`00
0?l00?l00?ooo`030?ooo`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?ooo`05003o003oool0
oooo0?ooo`000?l01P3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0oooo00`0oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`03003o003oool0003o00D0oooo1@000?lW0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool010000?l00?l00?l000000?l<0?oo
o`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`00o`0D
0?ooo`040000o`3oool0o`000?l000D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l0
00020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?l0
000G0?ooo`80o`000`3oool00`000?l0oooo0?ooo`0@0?ooo`06003o003oool0oooo0?ooo`000?l0
o`002P3oool0103o0000oooo0?ooo`000?l80?ooo`060000o`3oool0oooo0?ooo`3o00000?l03P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00D00?l00000o`3o0000oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool01@000?l00?l00?ooo`3oool00?l0
00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o00001P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<00?l0
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`050?ooo`03003o003oool0003o00H0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01P000?l0oooo
0?ooo`3o0000oooo003o0240oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0803oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`00o`000`3oool0103o
0000oooo0?ooo`000?l?0?ooo`03003o003o0000oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0o`000?ooo`060?ooo`040?l0003oool0oooo0000o`H0oooo00D0003o0?ooo`3o0000oooo
003o00020?ooo`05003o003oool0oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`00o`080?oo
o`030000o`3oool00?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0X0?oo
o`800?l000<0003o0?l0003oool02@3oool01000o`00003o0?ooo`3o00060?ooo`030000o`3o0000
oooo0080oooo0P3o00070?ooo`030?l00000o`00oooo00H0oooo00<00?l00?l0003oool02@3oool0
0`000?l00?l00?ooo`030?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool01@00o`00oooo0?oo
o`3oool0o`0000P0oooo00<0003o0?l0003oool01`3oool01@000?l0oooo0?ooo`3oool0003o01l0
oooo00<0o`000000o`000?l02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`00o`00oooo00<0
oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`05003o003oool0oooo
0?ooo`000?l01P3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0oooo00`0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo003o00020?ooo`D0003o1@3oool00`000?l0oooo0?oo
o`0T0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool010000?l00?l00?l0
00000?l<0?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool00?l001@0oooo00<0003o0?ooo`3o00001P3oool00`000?l0oooo0?ooo`020?ooo`07
0000o`3oool0oooo0?ooo`3o0000oooo003o00040?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3o00005`3oool20?l000<0oooo00<0003o0?ooo`3oool04@3oool01@00o`00oooo0?ooo`00
0?l0o`0000X0oooo00@0o`000?ooo`3oool0003o203oool01P000?l0oooo0?ooo`3oool0o`00003o
00h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`05003o00000?l0o`00
0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000D0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0@0?ooo`050000o`00o`00oooo0?ooo`00o`00
0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000070?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o1@3oool00`3o
0000oooo0?ooo`050?ooo`03003o003oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0o`000?ooo`040?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3o00000`3oool0
0`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0200oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`00
00X0oooo00<0o`000?ooo`3oool0303oool010000?l0oooo0?ooo`00o`020?ooo`040?l0003oool0
oooo0000o`l0oooo00<00?l00?l0003oool0103oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
0000oooo00H0oooo00@0o`000?ooo`3oool0003o1P3oool01`000?l0oooo0?l0003oool00?l00?oo
o`00o`00103oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0oooo00H0oooo00<0003o
0?ooo`00o`000P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo02X0oooo00<00?l0
0000o`3o00002P3oool01@00o`00003o0?ooo`3oool0o`0000D0oooo00<0003o0?l0003oool0103o
ool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo003o00H0oooo00<00?l00?l0003oool0
2@3oool00`000?l00?l00?ooo`040?ooo`040?l0003oool0oooo003o0080oooo00@00?l00?ooo`3o
ool0o`002@3oool00`000?l0o`000?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0703oool00`000?l00?l00?ooo`020000o`L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l00?l00?ooo`030?ooo`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool01P3oool0
10000?l0oooo0?ooo`3o00060?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool0
0`3oool01@00o`00oooo0?ooo`3oool0003o00H0oooo00@0o`000?ooo`3oool00?l00`3oool00`00
o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`00003o003oool0303oool00`00
0?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool01@00
0?l0oooo003o0000o`00003o00`0oooo00<0o`000?ooo`000?l0103oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0o`0000L0oooo00@0003o0?ooo`3oool0003o103oool00`3o00000?l00?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0?l0000E0?ooo`040?l0003oool0oooo0?l0
0080oooo00<0003o0?ooo`3oool04@3oool01@00o`00oooo0?ooo`00o`00003o00X0oooo00@0o`00
0?ooo`3oool0003o203oool01P000?l0oooo0?ooo`3oool0o`00003o00h0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0003o0080oooo00D0o`000?ooo`3o
ool0oooo0000o`060?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00D0003o003o003oool0oooo003o
00030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?oo
o`3o00080?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool01@00o`00oooo
0?ooo`3oool0o`0000D0oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`050?oo
o`03003o003oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`050?oo
o`030?l0003oool0003o00@0oooo00<0003o0?l0003oool00P3oool00`00o`00oooo0?ooo`0N0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000X0oooo00<0o`000?ooo`3o
ool0203oool30?l000070?ooo`000?l0oooo0?ooo`00o`00oooo0?l000040?ooo`030000o`3oool0
oooo00`0oooo00<00?l00?ooo`3o0000103oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000
oooo00L0oooo00<0o`000?ooo`000?l01P3oool01`000?l0oooo0?l0003oool00?l00?ooo`00o`00
103oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`00
o`000`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo02X0oooo00<00?l00?ooo`00
0?l02P3oool01@00o`00003o0?ooo`3oool0o`0000D0oooo00<00?l00000o`3oool01@3oool0103o
0000oooo0?ooo`3oool:0000o`030?ooo`00o`00o`0000T0oooo00<0003o0?l00000o`001@3oool0
0`3o0000oooo003o00030?ooo`04003o003oool0oooo0?l000T0oooo00<0003o0?l0003oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01/0oooo00H0o`000000o`3oool0oooo
0?l0003oool20000o`D0oooo00<0o`000?ooo`3oool0203oool00`000?l00?l00?ooo`020?ooo`05
003o003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo
0?l000H0oooo00@0003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`030?ooo`05003o003o
ool0oooo0?ooo`000?l01P3oool0103o0000oooo0?ooo`00o`030?ooo`03003o003oool0oooo00X0
oooo00<0o`000?ooo`3oool0103oool00`3o00000?l00?ooo`0=0?ooo`030000o`3oool0oooo0280
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3o00000?l0003o
00000?l0303oool00`3o0000oooo0000o`040?ooo`040000o`3oool0oooo0?l000@0oooo00<00?l0
0?ooo`3oool00P3oool20000o`h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`05
0?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo01<0oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?oo
o`0A0?ooo`05003o003oool0oooo003o00000?l02`3oool00`3o0000oooo0000o`080?ooo`060000
o`3oool0oooo0?l0003oool00?l03P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00`0oooo00<00?l00?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00@0003o
0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0403oool01@000?l00?l00?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3o
ool0oooo0000o`0=0?ooo`04003o003oool0oooo0?l000D0oooo00@0003o0?ooo`3oool0003o1@3o
ool00`3o0000oooo0?ooo`050?ooo`03003o003oool0003o00@0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003oool00P3o
ool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
o`0000X0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00<0o`0000<0
0?l00?ooo`3o0000103oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0o`0000@0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`070?ooo`030?l0003oool0003o00H0oooo00<0
003o0?l0003oool00P3oool2003o00@0oooo00<0o`000?ooo`000?l00`3oool00`00o`00oooo0?oo
o`060?ooo`030000o`3oool00?l000<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0[0?ooo`030?l000000?l0oooo00T0oooo00D00?l00000o`3oool0oooo0?l000040?ooo`030?l0
0000o`00003o00L0oooo0P3o00000`3oool0003o0?l000020?ooo`03003o003oool0oooo00<0oooo
00@0003o003o003oool0o`00203oool00`000?l0o`00003o00050?ooo`030?l0003oool00?l000<0
oooo00@00?l00?ooo`3oool0o`002@3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool06P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo0P000?l3
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`00o`000P3oool01@00o`00oooo0?ooo`3o
ool0003o00L0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00060?ooo`040000
o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0000o`070?ooo`04
0?l0003oool0oooo003o00<0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?oo
o`03003o003o0000oooo00h0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`00o`00
003o00d0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?l000050?ooo`03003o003oool0
oooo0080oooo0P000?l>0?ooo`030000o`3oool0oooo00P0oooo0P000?l50?ooo`03003o003o0000
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0140oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo0140oooo00D0
0?l00?ooo`3oool00?l00000o`0;0?ooo`030?l0003oool0003o00T0oooo00D0003o0?ooo`3o0000
oooo003o000>0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0303oool00`00o`00
oooo0000o`030?ooo`030?l0003oool0003o00P0oooo00<0003o0?l0003oool01P3oool00`3o0000
oooo0?ooo`020000o`<0oooo00<0o`000?ooo`3oool04@3oool010000?l00?l00?ooo`00o`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000080?oo
o`050?l0003oool0oooo0?ooo`000?l03@3oool01000o`00oooo0?ooo`3o00050?ooo`040000o`3o
ool0oooo0000o`D0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0000o`040?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?ooo`040?ooo`030000
o`3o0000oooo00<0oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?l0000:0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool01`000?l0oooo0?ooo`3oool0o`00003o003o0000103oool00`000?l0oooo0?ooo`0<0?ooo`03
003o003oool0o`0000<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0003o00H0oooo00<0003o0?l0003oool00P3oool2003o00@0oooo00<0o`000?ooo`00
0?l00`3oool00`00o`00oooo0?ooo`070?ooo`030000o`00o`00oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0/0?ooo`030?l000000?l0oooo00T0oooo00D00?l00000o`3o
ool0oooo0?l000030?ooo`040?l0003oool00?l00000o`T0oooo00<0003o0?l0003oool00`3oool0
0`00o`00oooo0?ooo`030?ooo`030000o`3oool0o`0000L0oooo00@0003o0?ooo`3o00000?l01@3o
ool00`3o00000?l00?ooo`040?ooo`03003o003oool0o`0000T0oooo00<00?l00000o`3o00001@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01T0oooo00<0003o0?l0003oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`80003o00<0oooo0?l0003oool02@3oool00`000?l0oooo003o
00020?ooo`05003o003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`070?ooo`050000
o`3oool0o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo
00@0oooo00<00?l00?ooo`000?l0203oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo
00T0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?l0000?0?ooo`050000o`3oool0oooo
0?ooo`3o00003P3oool30000o``0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`05
0?ooo`060?l000000?l0oooo0?ooo`00o`00003o3@3oool00`3o0000003o0?ooo`030?ooo`030000
o`3oool0o`0000D0oooo00L00?l00?ooo`3oool0oooo0000o`3oool0003o00P0oooo00<00?l00?oo
o`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<00?l00?oo
o`3o0000203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool04@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool04P3oool0
1000o`00oooo003o00000?l;0?ooo`030?l0003oool0003o00T0oooo00D0003o0?ooo`3o0000oooo
003o000>0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool01000o`00oooo
0?l000000?l30?ooo`030?l0003oool0003o00P0oooo00<0003o0?l0003oool01P3oool01P3o0000
oooo0?ooo`000?l0oooo0000o`80oooo00<0o`000?ooo`3oool04@3oool010000?l00?l00?ooo`00
o`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l0
00080?ooo`040?l0003oool0oooo0000o`h0oooo00@00?l00?ooo`3oool0o`001P3oool20000o`L0
oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0000o`040?ooo`030000o`3oool0oooo00H0
oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5000001l0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00X0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0o`000080oooo
0P000?l;0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`00
0?ooo`020?ooo`03003o003oool0oooo00@0oooo00H0o`000000o`3oool0oooo0?l00000o`090?oo
o`030000o`00o`00oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0^0?ooo`030?l000000?l0
oooo00T0oooo00D00?l00000o`3oool0oooo0?l000020?ooo`050?l0003oool0oooo003o00000?l0
2@3oool00`000?l0o`000?ooo`030?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`000?l0
o`001`3oool010000?l0oooo0?l00000o`060?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3o0000203oool01000o`00oooo0000o`3o00040?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?l0000:0?ooo`030000o`3o00000?l00080oooo00D00?l0
0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3o0000oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`040?ooo`03
003o003oool0003o00P0oooo00<0o`000?ooo`00o`000`3oool00`00o`00oooo0?ooo`080?ooo`03
0?l0003oool0oooo00H0oooo00<00?l00?ooo`3o0000403oool010000?l0oooo0?l0003o000=0?oo
o`040000o`3oool0oooo0000o``0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`03
0?ooo`030?l000000?l0oooo0080oooo00<00?l00000o`3oool0303oool00`3o0000003o0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`030000o`3o
ool0oooo00D0oooo0P00o`040?ooo`030000o`3oool0oooo00d0oooo00D00?l00?ooo`3oool0oooo
0?l000080?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool03`3oool00`3o0000
oooo0?ooo`020?ooo`040?l0003oool0oooo0000oa@0oooo00@00?l00?ooo`00o`00003o2`3oool0
0`3o0000oooo0000o`090?ooo`050000o`3oool0o`000?ooo`00o`003P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00/0oooo00D00?l00?ooo`3o0000oooo0000o`020?ooo`030?l0
00000?l0oooo00P0oooo00<0003o0?l0003oool01P3oool00`3o0000oooo0000o`020?ooo`040000
o`3oool0oooo0?l001<0oooo00@0003o0?ooo`00o`000?l01@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o00002@3oool00`3o0000oooo0000o`0>0?oo
o`04003o003oool0oooo0?l000H0oooo0P000?l70?ooo`030?l0003oool0oooo00@0oooo00<00?l0
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0003o00D0oooo00<0003o
0?l0003oool01@3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo1000o`0B
0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool02`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`030?oo
o`030000o`3oool0oooo00/0oooo00<00?l00?ooo`000?l00P000?l=0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`000?ooo`020?ooo`03003o003oool0oooo
00@0oooo00H0o`000000o`3oool0oooo0?l00000o`090?ooo`030000o`3oool0oooo00<0oooo00D0
o`000?ooo`3oool0oooo0000o`0^0?ooo`030?l000000?l0oooo00T0oooo00<00?l00000o`3oool0
0P3oool00`3o0000oooo0?l000020?ooo`03003o00000?l0oooo00P0oooo00<0003o0?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0000o`H0oooo00H0003o0?ooo`3o
ool0o`000?ooo`00o`040?ooo`03003o003o0000oooo00@0oooo00<00?l00?l0003oool0203oool0
1000o`00oooo0000o`3o00040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0000o`0;0?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0o`000?ooo`0:0?ooo`030000o`3o00000?l00080oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00@0003o0?l0003oool0o`00
103oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0103oool00`00o`00
oooo0000o`080?ooo`030?l0003oool00?l000<0oooo00<00?l00?ooo`3oool0203oool00`3o0000
oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000403oool010000?l0o`000?ooo`3o000:
0?ooo`80003o103oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0000o`3oool00`3oool00`3o0000003o0?ooo`050?ooo`04003o003oool0oooo0000o`<0oooo00<0
003o0?ooo`3oool01@3oool00`00o`00oooo003o00030?ooo`030000o`3oool0oooo00`0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0o`0000T0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000oa@0oooo
0P00o`000`3oool0003o0?ooo`0:0?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`3o0000
0P3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
2`3oool01@00o`00o`000?ooo`3oool0003o0080oooo00<0o`000000o`3oool02@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0003o0080oooo00@0003o0?ooo`3oool0o`004`3oool01000
0?l0oooo003o0000o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?l000090?ooo`030?l0003oool0003o00l0oooo00<00?l00?l0003oool01P3oool2
0000o`L0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0000o`030?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?l000050?ooo`030?l000000?l0
oooo00@0oooo1@00o`0J0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo
00/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`<0003o00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0003o00L0oooo00<0003o0?oo
o`3oool0203oool01P000?l0oooo0?ooo`3oool0o`00003o00T0oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?ooo`000?l_0?ooo`030?l000000?l0oooo00X0oooo00@0003o0?ooo`3oool0
oooo0P3o00020?ooo`03003o003oool0003o00T0oooo00<0003o0?ooo`3oool0103oool01@00o`00
oooo0?ooo`3oool00?l00080oooo00<0o`000000o`3oool0103oool01P000?l0oooo0?ooo`3o0000
oooo003o00@0oooo00<00?l00?l0003oool0103oool00`00o`00o`000?ooo`080?ooo`04003o003o
ool0003o0?l000@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`050000
o`3oool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0oooo0080
oooo00<0003o0?l0003oool02P3oool00`000?l0o`00003o00020?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`040000o`3o0000oooo0?l0
00@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo00@0oooo00<00?l0
0?ooo`000?l0203oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0o`000100oooo00@0o`000000o`3oool0o`00
2@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00H0oooo00<00?l00?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`040?ooo`04003o003oool0oooo003o00<0oooo00<0003o0?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`040?ooo`80o`001`3oool00`000?l0o`000?ooo`090?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0000o`0D0?ooo`80
0?l000<0oooo0000o`3oool02P3oool00`3o0000oooo0000o`0:0?ooo`050000o`3o0000oooo0?oo
o`00o`003@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00D00?l00?l0
003oool0oooo0000o`030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool04@3oool010000?l0oooo003o
0000o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?l000090?ooo`030?l000000?l0oooo00l0oooo00<00?l00?l0003oool01P3oool20000o`L0oooo
00<0o`000?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l30?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?l000050?ooo`030?l000000?l0oooo02<0
oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo
0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P000?l01000o`00oooo0?ooo`3o000?0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000000o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`06
0000o`3oool0oooo0?ooo`3o00000?l02@3oool00`00o`00003o0?ooo`040?ooo`030?l0003oool0
003o01@0oooo00<0o`000?ooo`3oool0603oool00`3o0000003o0?ooo`090?ooo`030000o`00o`00
oooo0080oooo00L0o`000?ooo`3oool0oooo003o003oool0003o00P0oooo00<0003o0?ooo`3oool0
1@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0o`000?ooo`000?l00`3oool010000?l0
oooo0?ooo`3o00020?ooo`03003o003oool0oooo0080oooo00<00?l00?l0003oool0103oool00`00
o`00o`000?ooo`080?ooo`05003o003oool0oooo0000o`3o00000P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`0:
0?ooo`060000o`3o0000oooo003o003oool00?l0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00P0oooo00@0003o0?l0003oool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3o0000oooo00H0oooo00<00?l00?ooo`000?l0203oool00`3o00000?l00?ooo`030?ooo`03
003o003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`000?l00`000?l50?ooo`80003o1`3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0
003o00D0oooo00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0
003o0?ooo`3oool0103oool00`00o`00003o0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00L0
0?l00?ooo`3oool0oooo003o003oool0003o00d0oooo00<00?l00?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`050?ooo`030?l000000?l0oooo01D0oooo00<00?l00?ooo`000?l0303oool00`000?l0
oooo0?ooo`090?ooo`80003o0P3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool02@3oool00`00o`00o`000?ooo`020?ooo`050000o`3oool0oooo0000
o`3o00002@3oool00`3o0000003o0?ooo`070?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l0
000D0?ooo`040000o`3oool00?l0003o00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3o0000oooo00T0oooo00<0o`000000o`3oool03`3oool00`00o`00oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool01000o`00oooo
0?ooo`000?l20?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`000?l08`3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00<0oooo00<0003o0?oo
o`3oool01P3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0000o`3oool01`3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00H0003o
0?ooo`3oool0oooo0?l00000o`090?ooo`03003o00000?l0oooo00@0oooo00<0o`000?ooo`000?l0
4`3oool20?l001T0oooo00<0o`000?ooo`000?l02P3oool00`000?l00?l00?ooo`060?ooo`03003o
003oool0003o00P0oooo00<0003o0?ooo`3oool01P3oool01000o`00oooo0?ooo`00o`030?ooo`03
0?l0003oool0003o0080oooo00@0003o0?ooo`3oool0o`000P3oool01@00o`00oooo0?ooo`3oool0
0?l00080oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`05003o003oool0
oooo0000o`3o00000P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0o`0000<0
003o0?l0003o00000P3o00030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o0000203o
ool01P3o0000oooo0?ooo`3oool0003o0?l000/0oooo00H0003o0?l0003oool00?l00?ooo`00o`04
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool01@000?l0o`000?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`060?ooo`03003o003o
ool0003o00T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`000?l010000?l90?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3o
ool0103oool00`00o`00003o0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00003o0?ooo`0<0?ooo`03003o003oool0oooo00P0oooo0P3o00030?ooo`03
0?l0003oool0003o00/0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`03
0?l000000?l0oooo01@0oooo00@0o`00003o003oool0003o303oool00`000?l0oooo0?ooo`0:0?oo
o`030?l000000?l0003o0080003o303oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00T0oooo00<00?l00?l0003oool00P3oool01@000?l0oooo0?ooo`000?l0o`0000T0oooo00<0o`00
0?ooo`000?l01P3oool00`000?l0o`000?ooo`030?ooo`030000o`3o0000oooo01<0oooo00@0003o
0?ooo`00o`000?l01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?l0003oool02@3oool00`3o0000003o0?ooo`0?0?ooo`03003o003oool0oooo00L0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0oooo0000o`80oooo
00<0003o0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030?l0003oool0003o02<0oooo00<000000?ooo`3oool05`3oool001/0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo0280
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0
oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00L0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l000000?l0oooo00L0oooo00<0o`000000o`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`3o0000oooo003o00080?ooo`03003o
00000?l0oooo00@0oooo00<0o`000000o`3oool04`3oool00`3o0000oooo0?l0000H0?ooo`030?l0
003oool0003o00X0oooo00<0003o003o003oool01P3oool00`00o`00oooo0000o`080?ooo`030000
o`3oool0oooo00H0oooo00@00?l00?ooo`3oool00?l00`3oool00`3o0000oooo0?ooo`020000o`<0
oooo00@0o`000?ooo`3oool00?l00`3oool01000o`00oooo0?ooo`3o00050?ooo`03003o003oool0
oooo00L0oooo00L00?l00?ooo`3oool0003o0?l0003oool0003o00d0oooo00<0003o0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool010000?l0
oooo0?ooo`3o00080?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool01P00
0?l0o`000?ooo`00o`00oooo003o00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`080?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3o0000oooo00H0oooo00<00?l00?ooo`000?l02@3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?l000030?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00030?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
003o003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0;0?ooo`80
o`0000D0oooo0?l0003oool0oooo0000o`0;0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000003o0?ooo`0D0?ooo`040?l00000o`00oooo0000o``0oooo00<0003o
0?ooo`3oool02P3oool01@3o0000oooo0?ooo`00o`00oooo00<0003o2@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00T0oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0000
o`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`000?l01P3oool00`000?l0o`000?oo
o`030?ooo`030000o`3o0000oooo01<0oooo00<0003o0?ooo`00o`001P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool02P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l00000o`00oooo0100oooo00<0o`000?ooo`3oool00P3oool01`00o`00oooo0?oo
o`3oool0003o0?ooo`000?l02@3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o02<0oooo00<000000?ooo`3oool05`3oool0
01X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000`0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00<0o`000000o`3oool02`3oool0103o0000oooo0?ooo`3o00070?ooo`03
0000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l0000=0?ooo`030?l000000?l0oooo
00L0oooo00<0o`000000o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo003o00080?ooo`03003o00000?l0oooo00D0oooo00<0003o0?ooo`3oool04@3o
ool0103o0000oooo0?ooo`3o000H0?ooo`030?l0003oool0003o00X0oooo00<0003o003o003oool0
1P3oool00`00o`00oooo0000o`070?ooo`030000o`3oool0oooo00L0oooo00@00?l00?ooo`3oool0
0?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool00?l00P3oool0
1@00o`00oooo0?ooo`3oool0o`0000@0oooo00<0o`00003o003oool0203oool01`00o`00oooo0?oo
o`000?l0oooo0?l000000?l03@3oool00`000?l0o`000?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000oooo
00800?l01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00D0003o0?oo
o`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool01P3oool0
0`00o`00oooo0000o`090?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool0
0`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool0
1@3o0000oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3o00000`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3o0000o`001@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo
0?ooo`030?ooo`030000o`00o`00oooo00P0oooo0P00o`0@0?ooo`050?l0003oool0oooo0?ooo`00
0?l02`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3o
ool04`3oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00<0003o0?ooo`3oool02@3oool01@3o
0000oooo0?ooo`3oool00?l000@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool20000o`80oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0000o`060?ooo`030000o`3o0000oooo00<0oooo00<0003o
0?l0003oool04`3oool00`000?l0oooo003o00060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`00o`004@3oool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo0?ooo`80003o2P3o
ool00`3o0000oooo0?ooo`020?ooo`80003o103oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0003o02<0oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo1`00000O0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`0<0?ooo`80o`001`3o
ool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo
0P000?l50?ooo`05003o003oool0oooo0?ooo`3o00003@3oool00`3o0000003o0?ooo`070?ooo`03
0?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`020?ooo`03
0?l0003oool00?l000P0oooo00<00?l00000o`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`04
0?l0003oool0oooo0?l001L0oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l00?l00?ooo`06
0?ooo`03003o003oool0003o00L0oooo00<0003o0?ooo`3oool0203oool2003o00@0oooo00<0o`00
0?ooo`3oool01@3oool0103o0000oooo0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`3o0000
103oool00`3o00000?l00?ooo`080?ooo`06003o003oool0oooo0000o`3oool0003o3`3oool01@00
0?l0oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`02
0?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`0;0?ooo`030000o`3o
0000oooo00800?l01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00L0
003o0?ooo`3oool0oooo0?l0003oool0003o00H0oooo00<0003o0?l0003oool01P3oool00`00o`00
oooo0000o`090?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`3o0000
oooo0?ooo`070?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool20?l000<0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?l000020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?l0003o00050?ooo`030000o`3oool0oooo
0080oooo00<0003o003o003oool01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo
00@0oooo00<0003o003o003oool01@3oool3003o01L0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`050?ooo`<0o`002P3oool00`000?l0oooo0?ooo`0B0?ooo`050?l0003oool0oooo
0?ooo`000?l0303oool00`000?l0oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`00o`001@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0203o
ool00`00o`00o`000?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o0000203oool0103o0000oooo
0?ooo`000?l40?ooo`040000o`3oool0oooo0?l000<0oooo00<0003o0?l0003oool04`3oool00`00
0?l0oooo003o00060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`00o`004@3oool00`3o
0000oooo0?ooo`020?ooo`04003o003oool0oooo0?ooo`80003o2P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?oo
o`0J0?ooo`L000006@3oool001X0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?oo
o`3oool2000000d0oooo00<000000?ooo`3oool08`3oool01@000?l0oooo0?ooo`3oool0003o00P0
oooo00<0o`000000o`3oool0303oool20?l000L0oooo00<0003o0?ooo`3oool02P3oool01@00o`00
oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool01@3oool01@00o`00oooo0?ooo`3oool0
o`0000d0oooo00<0o`000000o`3oool01`3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00D0003o0?ooo`3o0000oooo0?l000020?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`000?l01@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0503oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0003o003o003oool0
1P3oool00`00o`00oooo0000o`070?ooo`030000o`3oool0oooo00P0oooo0P00o`040?ooo`030?l0
003oool0oooo00D0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`020?ooo`06
0?l0003oool0oooo0?ooo`3o00000?l02@3oool01000o`00oooo0?ooo`3oool20000o`h0oooo00D0
o`000000o`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0?l0000:0?ooo`050?l0003oool0oooo0?ooo`000?l02P3oool00`000?l0oooo0?l000020?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?oo
o`070000o`3oool0oooo0?ooo`3o0000oooo0000o`060?ooo`030000o`3o0000oooo00L0oooo00<0
0?l00000o`3oool0203oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0
o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo0P3o
00030?ooo`030000o`3oool0oooo00T0oooo00D0003o0?l0003oool0oooo0000o`070?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3o00001P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`00o`00oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030000
o`3oool00?l00080oooo0`00o`0K0?ooo`030000o`3oool0oooo00P0oooo00@0o`000000o`3oool0
oooo103o000=0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo003o00060?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?oo
o`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo01<0oooo
00<0003o0?ooo`00o`001`3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0o`000?ooo`0>0?ooo`030?l0003oool00?l00140oooo0P3o00030?ooo`04
003o003oool0oooo0?ooo`80003o2@3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo
0?l000<0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`006P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`3o0000003o
0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo
0?ooo`020?ooo`80003o203oool01@00o`00oooo0?ooo`3oool0o`0000d0oooo00<0o`000000o`3o
ool01`3oool00`3o0000003o0?ooo`070?ooo`030?l000000?l0oooo00L0oooo00D0003o0?ooo`3o
0000oooo0?l000020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`000?l0103oool00`00
0?l0oooo0?l0000@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o003o003oool01P3oool00`00
o`00oooo0000o`070?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P00o`050?ooo`060?l0003oool0oooo
0?ooo`3o00000?l0203oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0o`0000d0oooo00@0
o`000?ooo`000?l0003o2P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo
00@0o`000?ooo`3oool0003o2P3oool00`000?l0oooo0?l000020?ooo`03003o003oool0oooo00<0
oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`090?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo0000o`060?ooo`030000o`3o0000oooo00L0oooo00<00?l00000o`3oool0203o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00000P3o
ool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00L0003o0?ooo`3oool0oooo0000o`3oool00?l0
00H0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo
00800?l07P3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0o`000000o`3o00004@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0o`000?ooo`090?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`00
o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000003o0?ooo`0C0?ooo`030000o`3o
ool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?l0003oool03@3oool01@3o0000oooo0?ooo`3oool00?l00180oooo0P3o00000`3oool0
0?l00?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool0103o0000
oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool05`3oool001/0
oooo0P00000:0?ooo`800000103oool3000000`0oooo00<000000?ooo`3oool0903oool010000?l0
oooo0?ooo`000?l80?ooo`030?l0003oool0003o01@0oooo00<0003o0?ooo`3oool0303oool01@00
o`00oooo0?ooo`3oool0003o00P0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0003o00L0oooo00<0o`000000o`3oool01`3oool00`3o0000003o0?ooo`07
0?ooo`050000o`3oool0o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo0000o`@0oooo00<0003o0?ooo`3o0000403oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000
o`00o`00oooo00H0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0:0?ooo`03
003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80
0?l01@3oool0103o0000oooo0?ooo`3o00020?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?l0000=0?ooo`030?l0003oool0003o00/0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000o`X0oooo00<0003o
0?ooo`3o00000P3oool00`00o`00oooo0?ooo`030?ooo`040000o`3oool0oooo0?l00080oooo00<0
003o0?ooo`3oool02@3oool00`3o0000003o0?ooo`020?ooo`030?l000000?l0oooo00D0oooo00<0
003o0?l0003oool01`3oool00`00o`00003o0?ooo`080?ooo`03003o003o0000oooo00<0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo00X0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool00P3oool01P3o0000oooo0?ooo`3o0000oooo0000o``0oooo00D0003o0?ooo`3o
ool0oooo0000o`070?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool01000
0?l0oooo0?ooo`000?l20?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0103oool2
0000o`@0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`090?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`00o`00o`000?ooo`0:0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l30?ooo`060?l0003o
ool0oooo0?ooo`3o0000003o503oool00`000?l0o`000?ooo`070?ooo`040000o`3oool0oooo0000
o`X0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`0=0?ooo`050?l0003oool0oooo
0?ooo`00o`00503oool00`3o00000?l00?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02P3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0oooo01l0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0903oool00`000?l0o`000000o`09
0?ooo`030?l0003oool0003o01@0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0:
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0000o`07
0?ooo`030?l000000?l0oooo00L0oooo00<0o`000000o`3oool01P3oool01P000?l0oooo0?ooo`3o
0000oooo0?l00080oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`000?l40?ooo`03
0000o`3oool0o`0000l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l00?l00?ooo`060?ooo`04
003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?ooo`3o0002
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:
0?ooo`040?l0003oool0o`000000o`X0oooo00@0003o0?ooo`3oool0o`001`3oool01`000?l0oooo
0?l0003oool0o`000?ooo`000?l02P3oool00`3o0000oooo0000o`030?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`00o`00003o0?ooo`080?ooo`03003o003o0000oooo
00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo
00/0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00@0003o
0?ooo`3oool0o`000`3oool00`3o0000oooo0000o`0<0?ooo`040000o`3oool0oooo0000o`P0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0003o00<0oooo
00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo
00<0003o0?ooo`3oool08P3oool010000?l0oooo0?ooo`3oool20000o`L0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0o`000?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool01@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3oool01`3oool00`00
o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0000o`040?ooo`060?l0003oool0oooo0?ooo`3o0000003o503oool00`000?l0o`000?oo
o`070?ooo`040000o`3oool0oooo0000o`T0oooo00<0o`000000o`3oool02@3oool00`000?l0oooo
0?l0000<0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool04`3oool00`00o`00o`00
0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo
0?ooo`0O0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02@0oooo00<0
003o0?ooo`000?l0203oool0103o0000oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo00h0oooo
00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo
00<0o`000?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o00L0oooo
00H0003o0?ooo`3oool0o`000?ooo`3o00020?ooo`03003o003oool0oooo00D0oooo00@00?l00?oo
o`3oool0003o0`3oool01@000?l0oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l00?l00?ooo`060?ooo`04003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
1@3oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0<0?ooo`80o`0000<0003o0?ooo`3oool0203oool010000?l0oooo
0?ooo`3o00070?ooo`070000o`3oool0o`000?ooo`3o0000oooo0000o`0:0?ooo`030?l0003oool0
003o00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00P0oooo00<00?l00?l0003oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000X0oooo00<0
0?l00?ooo`3oool0303oool0103o0000oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo00/0oooo
00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0000o`0<0?ooo`040000o`3oool0oooo0000
o`P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0003o
00<0oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00<0003o
0?ooo`3oool08P3oool010000?l0oooo0000o`000?l:0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?l0003oool0203oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00H0oooo00@0
003o0?ooo`3oool0003o1`3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00X0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00D0oooo
00D0o`000?ooo`3o0000oooo0000o`0D0?ooo`030000o`3o0000oooo00L0oooo00@0003o0?ooo`3o
ool0003o2@3oool00`3o0000003o0?ooo`090?ooo`030000o`3oool0o`0000`0oooo00<0o`000?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo0080o`002@3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0003o0?l0
00L0oooo00@0o`000?ooo`3oool0003o4`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0
oooo00P0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
003o00L0oooo00<0003o0?l0003oool01P3oool00`3o0000oooo0000o`070?ooo`060000o`3oool0
oooo0?l0003oool0o`000P3oool00`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`00
0?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo003o00060?ooo`04003o003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o00000P3oool0
0`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool2
0?l000030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`00203oool01P000?l0o`000?oo
o`3o0000oooo0000o`X0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?l000040?ooo`04
003o003oool0oooo0?l000/0oooo00<00?l00?ooo`3oool03@3oool00`3o0000oooo0?l0000>0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0000o`0<0?oo
o`040000o`3oool0oooo0000o`P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`00
o`060?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0o`000100oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3o0000oooo00L0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?oo
o`070?ooo`030000o`3oool0003o00L0oooo00<0o`000?ooo`3oool01P3oool00`3o00000?l00?oo
o`0<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`050?l0003oool0o`000?ooo`000?l0503oool00`000?l0o`000?ooo`070?ooo`040000
o`3oool0oooo0000o`T0oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?l0000<0?ooo`03
0?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`030?ooo`80
o`001`3oool00`3o0000oooo0?ooo`0<0?ooo`80o`001@3oool00`000?l0oooo0?ooo`0O0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02<0oooo00H0o`000?ooo`000?l0
003o0?ooo`3o00060?ooo`040?l0003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool0
103o0000oooo0?ooo`000?l70?ooo`030000o`3o0000oooo00H0oooo00<0o`000?ooo`000?l01`3o
ool01P000?l0oooo0?ooo`3o0000oooo0?l00080oooo00<00?l00?ooo`3oool01@3oool01@00o`00
oooo0?ooo`3oool0003o0080oooo00D0003o0?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`00o`001@3oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool03@3oool00`3o0000003o0?ooo`090?ooo`040000o`3oool0oooo0?l000P0oooo
00H0003o0?ooo`3oool0o`000?ooo`000?l:0?ooo`030?l0003oool0003o0080oooo00<0003o0?l0
003oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<00?l00?oo
o`3o0000103oool01000o`00oooo0?ooo`3o000;0?ooo`03003o003oool0oooo00h0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o0000oooo00@0oooo00<0o`00
0?ooo`000?l0303oool00`000?l0oooo0000o`090?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00@0003o
0?ooo`3oool00?l01P3oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3o00003`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?l0003oool01`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo0P00
0?l80?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?l0
00020?ooo`030000o`3oool0oooo0140oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0000
o`0:0?ooo`030?l0003oool0003o00P0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030?l0
003oool0oooo00@0oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool20?l000H0oooo00<0003o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000240oooo00<0o`000?ooo`000?l00`3o
ool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000oa80oooo00<0003o0?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0
2@3oool0103o0000oooo0?ooo`000?l70?ooo`030000o`3o0000oooo00H0oooo00<0o`000?ooo`00
0?l01P3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`04
0?ooo`07003o003oool0oooo0?ooo`000?l0oooo0000o`050?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo003o00050?ooo`05003o003oool0oooo0?ooo`00
0?l0103oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool02`3oool20?l000@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool0103o0000oooo0?ooo`3o000@0?oo
o`030?l0003oool0003o00T0oooo00@0003o0?ooo`3oool0o`00203oool01P000?l0oooo0?ooo`3o
ool0o`000000o`X0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?l000060?ooo`030?l0
00000?l0oooo00L0oooo00<0003o0?ooo`3oool01`3oool01000o`00oooo0?ooo`3o00030?ooo`03
003o003oool0o`0000`0oooo00<00?l00?ooo`3oool07`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3o0000oooo00@0oooo00<0o`000?ooo`000?l0303oool00`000?l0oooo0000o`090?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`040?ooo`04
0000o`3oool0oooo003o00H0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0o`0000l0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3o0000oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`090?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool20?l00003003o003oool0oooo
00`0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`00
0080oooo00<0003o0?ooo`3oool04@3oool00`000?l0o`000?ooo`070?ooo`030000o`3oool0003o
00X0oooo00<0o`000?ooo`000?l0203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo
00H0oooo0P3o00040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo1@00000I0?ooo`00?03oool00`000000
oooo0?ooo`0R0?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool00`3oool0103o
0000oooo0?ooo`000?lB0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o1`3o
ool00`000?l0o`000?ooo`060?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00L00?l00?ooo`3oool0oooo
0000o`3oool0003o00D0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool00?l000D0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
01<0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool04@3oool0103o0000oooo0?ooo`3o000B0?ooo`030000o`3oool0oooo00L0oooo00@0
003o0?ooo`3oool0o`00203oool01P000?l0oooo0?ooo`3oool0o`000000o`X0oooo00<0o`000?oo
o`000?l00P3oool00`000?l0oooo0?l000060?ooo`030?l000000?l0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool01000o`00oooo0?ooo`3o00030?ooo`03003o003o0000oooo00`0oooo00<00?l0
0?ooo`3oool0803oool00`3o0000oooo0?ooo`080?ooo`030?l000000?l0oooo00D0oooo00<0o`00
0000o`3oool02P3oool0103o0000oooo0000o`000?l90?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`040?ooo`040000o`3oool0oooo003o00H0oooo
00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000h0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?l000D0
oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo0080
oooo00@0o`000?ooo`3oool00?l03`3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo00<0o`00
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o0000oooo00L0oooo00<0003o
0?ooo`000?l02P3oool00`3o0000oooo0000o`080?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo0100oooo00<00?l0
0?ooo`3oool0203oool0103o0000oooo0?ooo`3o000@0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`02
0?ooo`040?l0003oool0oooo0000oa40oooo00<0003o0?ooo`3oool04`3oool00`00o`00oooo0?oo
o`060?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?oo
o`000?l70?ooo`030000o`3o0000oooo00H0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`020?ooo`80003o1@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`00o`001@3oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<0003o0?oo
o`3oool04`3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0o`000180oooo00<0003o0?ooo`3oool01`3oool0
10000?l0oooo0?ooo`3o00080?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool0103o0000oooo
0?ooo`000?l20?ooo`030000o`3oool0o`0000H0oooo00<0o`000000o`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`04003o003oool0oooo0?l000@0oooo00<00?l00?ooo`3oool02P3oool00`00
o`00oooo0?ooo`0R0?ooo`80o`00203oool00`3o0000003o0?ooo`050?ooo`030?l000000?l0oooo
00X0oooo00@0o`000?ooo`000?l0003o2@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo003o00070?ooo`030000o`3oool0
oooo03D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?l0000>0?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`020?l000<0oooo00<0
0?l00?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00D0o`000?ooo`3oool0
oooo0000o`0C0?ooo`030000o`3o0000oooo00P0oooo0P000?l:0?ooo`030?l0003oool0003o00P0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0
oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`090?ooo`<0o`00603oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000@0
oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0D0?ooo`800?l01@3oool00`00o`00
oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o1`3oool00`00
0?l0o`000?ooo`060?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo003o00050?ooo`05003o003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0C0?ooo`050?l0003oool0oooo0?ooo`3o00004`3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?ooo`80o`00
4`3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000000o`3o
ool00P3oool00`000?l0oooo0?ooo`080?ooo`060?l0003oool0oooo0000o`3oool0003o0P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
1000o`00oooo0?ooo`3o00030?ooo`030?l00000o`00oooo00/0oooo00<00?l00?ooo`3oool0903o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0003o00H0oooo00<0o`000000o`3oool02P3o
ool00`3o0000oooo0000o`0;0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool00?l000L0oooo00<0003o0?ooo`3oool0=P3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0o`0000d0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool0
203oool00`00o`00oooo0?ooo`0A0?ooo`<0o`001@3oool00`00o`00oooo0?ooo`0=0?ooo`040?l0
003oool0oooo0?l000l0oooo00D0o`000?ooo`3oool0oooo0000o`0C0?ooo`030000o`3o0000oooo
00P0oooo0P000?l90?ooo`040?l0003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0240oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l000040?ooo`030000o`3oool0oooo
00h0oooo00<0003o0?ooo`3oool05P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00@0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`000?l70?ooo`030000o`3o0000
oooo00H0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool20?l000l0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`00o`001@3o
ool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool04`3oool01@3o0000oooo
0?ooo`3oool0o`0001<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000003o0?ooo`020?oo
o`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3oool0oooo0P000?l20?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`000?l01`3oool00`000?l00?l00?ooo`070?ooo`04003o003oool0
oooo0?l000<0oooo00<0o`00003o003oool02`3oool00`00o`00oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0003o00/0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003o
ool0oooo00<0oooo00<0003o0?ooo`00o`001`3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3o
ool0oooo00L0oooo00@0003o0?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`080?ooo`03
003o003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0>0?ooo`04
0?l0003oool0oooo0?l000l0oooo00D0o`000?ooo`3oool0oooo0000o`0C0?ooo`030000o`3o0000
oooo00P0oooo00<0003o0?ooo`3oool0203oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`03003o003o
ool0oooo00l0oooo00<00?l00?ooo`3oool0903oool010000?l0oooo0?ooo`3oool20000oaX0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?oo
o`0:0?ooo`80o`00103oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo01P0oooo0P00
o`020?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?oo
o`000?l70?ooo`030000o`3o0000oooo00H0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0
oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02`3oool00`3o0000
oooo0?ooo`020?ooo`80o`004@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`050?ooo`05003o003oool0oooo
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0D0?ooo`050?l0003oool0oooo0?ooo`3o0000503o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`00
1`3oool00`3o0000003o0?ooo`020?ooo`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3oool0
oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l01`3oool00`000?l0
0?l00?ooo`070?ooo`04003o003oool0oooo0?l00080oooo00<0o`000?ooo`00o`00303oool00`00
o`00oooo0?ooo`0V0?ooo`80o`000P3oool0103o0000oooo0?ooo`000?l60?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0103oool00`000?l00?l00?ooo`060?ooo`030000o`3oool0
oooo03L0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o000<0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00030?ooo`030?l0
003oool0oooo00T0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`0?0?ooo`030?l0
003oool0o`0001@0oooo00<0003o0?ooo`3oool0403oool00`000?l0o`000?ooo`080?ooo`030000
o`3o0000oooo00P0oooo00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`070?ooo`05
0?l0003oool0oooo0?ooo`3o00002P3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo
02@0oooo00@0003o0?ooo`3oool0003o703oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo01X0oooo0`00o`060?ooo`030?l0003oool0oooo
00T0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3o0000oooo00H0oooo00@0o`00
0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0303oool0103o0000oooo0?l0003o000C0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo003o00D0
oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo01@0oooo00@0o`000?oo
o`3oool0o`005@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00L0oooo00@0003o
0?ooo`3oool0o`001P3oool00`3o0000oooo0000o`030?ooo`030000o`3o0000oooo00P0oooo00@0
o`000?ooo`3oool0oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l0
1`3oool00`000?l00?l00?ooo`070?ooo`04003o003oool0oooo0?ooo`80o`000P3oool00`00o`00
oooo0?ooo`0:0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo03L0oooo00<0003o0?ooo`3oool01P3oool010000?l0
oooo0?ooo`3o000;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0603oool0
0`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0o`0001@0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?l000080?ooo`030?l000000?l0o`0000T0oooo00D0o`000?ooo`3oool0oooo0000
o`060?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0o`002`3oool00`00o`00oooo
0?ooo`0>0?ooo`03003o003oool0oooo02D0oooo0P000?lM0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`D000007@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool0703oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00D0
o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3o0000oooo00H0oooo00@0o`000?ooo`3oool0
003o103oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0303oool20?l001H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`020?oo
o`030000o`3oool0003o01L0oooo00<0o`000?ooo`3o00005@3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo0?l0000[0?ooo`030000o`3oool0
oooo00L0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0000o`030?ooo`030000o`3o
0000oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`000?l01`3oool00`000?l00?l00?ooo`060?ooo`03003o003oool0oooo0080oooo
0P3o00020?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo
0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00L0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000`0oooo00<00?l0
0?ooo`3oool0603oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0o`0001@0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?l000080?ooo`040?l0003oool0oooo0?l000P0oooo00D0
o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00T0oooo0P3o000<0?ooo`03003o
003oool0oooo00h0oooo00<00?l00?ooo`3oool09@3oool00`000?l0oooo0?ooo`0H0?ooo`D00000
6@3oool003`0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`080?ooo`050?l0003o
ool0oooo0?ooo`000?l01P3oool00`000?l0o`000?ooo`060?ooo`040?l0003oool0oooo0000o`@0
oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo02@0
oooo00<0o`000?ooo`3oool01P3oool20?l000`0oooo00<0003o0?ooo`3oool01@3oool010000?l0
oooo0?ooo`00o`050?ooo`03003o003oool0oooo0080oooo0P000?lH0?ooo`030?l0003oool0o`00
01D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0:0?ooo`050?l0003oool0oooo
0?ooo`3o0000:`3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool00`3o0000oooo0000o`030?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l01`3o
ool00`000?l00?l00?ooo`060?ooo`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
003o000<0?ooo`03003o003oool0oooo02h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`00
0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`0?0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0i0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool20?l0
00d0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`0?0?ooo`80o`005@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030000o`3oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo0?l00008
0?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`140?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00001`3oool0
1@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo02D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo
0?ooo`020?ooo`80003o603oool00`3o0000oooo0?l0000E0?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool02P3oool0103o0000oooo0?ooo`3o000/0?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o
0?ooo`3o00001`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`000?l01`3oool00`000?l00?l00?ooo`060?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0_0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?l0003oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo00@0003o
0?ooo`3oool0oooo0P3o000=0?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3o00001`3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo
0000o`060?ooo`030000o`3oool0oooo01P0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo
0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3o00001`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0
2P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo02D0oooo00<0o`000?ooo`3oool0
0P3oool20?l000l0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000<0
oooo00<00?l00?ooo`3oool00`3oool20000oaP0oooo00<0o`000?ooo`3o00005@3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<0o`000?ooo`3o0000;@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l01`3oool00`000?l00?l00?ooo`060?oo
o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0_0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool02@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0403oool00`00o`00oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l0000>0?ooo`03003o003oool0
oooo01P0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo01P0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`150?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00001`3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo0?ooo`02
0?ooo`03003o003oool0oooo02D0oooo00D0o`000?ooo`3oool0oooo0?l0000A0?ooo`030000o`3o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo00<0oooo
0P000?lH0?ooo`030?l0003oool0o`0001H0oooo00@00?l00?ooo`3oool00?l03P3oool00`3o0000
oooo0?l0000]0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?l000070?oo
o`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0
oooo00D0oooo00<0003o003o003oool01P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000
oooo00T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo0100oooo00<00?l00?ooo`3oool00P3oool00`00o`00003o0?ooo`060?ooo`030000o`3oool0
oooo03/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0100oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`0W0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01X0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`150?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001@3oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o``0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0V0?ooo`<0o`004P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3o
ool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo01L0oooo
0P3o000G0?ooo`04003o003oool0oooo003o00l0oooo00<0o`000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01`3o0000
oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00T0oooo00<0
0?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo00T0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0000o`060?ooo`030000o`3oool0oooo03/0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0140oooo00<0
0?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`0X0?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo00<0
0?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0W
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`000?l<0?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo
00<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?ooo`04003o003oool0oooo
003o00l0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0003o00<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool00?l000L0oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0300oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?l000090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`000?l0
1P3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3oool0
:03oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0J0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0
A@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0d0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`000?l03@3oool01@00o`00oooo0?ooo`3oool00?l003h0
oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l000<0oooo00<00?l00?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0E0?ooo`04003o003oool0oooo003o03h0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo
0?ooo`00o`060?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`0`0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0@0?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`000?l01P3oool00`000?l0oooo0?ooo`0l0?oo
o`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0
oooo01H0oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
o`0000@0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`03003o003oool0
oooo00X0oooo00<00?l00?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool50000
0380oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo
00@0oooo0P3o00050?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00d0oooo00D00?l00?ooo`3oool0oooo003o
000o0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03003o
003oool0oooo01h0oooo00<0o`000?ooo`3oool05@3oool01000o`00oooo0?ooo`00o`0n0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00X0oooo00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0
oooo003o00H0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`03003o003o
ool0oooo0300oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0000o`060?ooo`030000o`3oool0oooo03`0oooo
00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3o
ool05P3oool00`00o`00oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00d0oooo00@0003o0?ooo`3o
ool0o`000`3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`110?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool00P3oool20?l0
00L0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`000?l03@3oool01@00o`00oooo0?ooo`3oool00?l003l0oooo00<0
003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0
=`3oool00`00o`00oooo003o000n0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0oooo00L0oooo00<00?l0
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0b0?ooo`040000o`3oool0oooo0000o`80oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0403oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0m0?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04P3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo02T0oooo00<0003o0?ooo`3o
ool03@3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo00P0oooo00D0o`000?oo
o`3oool0oooo0?l000050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0703oool0
0`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
02T0oooo00<0o`000?ooo`3oool00P3o000:0?ooo`030000o`3oool0oooo0080oooo00@0003o0?oo
o`3oool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`80003o3@3oool01@00o`00oooo0?ooo`3o
ool00?l003l0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool00?l000<0oooo
00<00?l00?ooo`3oool0=`3oool00`00o`00oooo003o000n0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0003o00@0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?l0
00<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003oool0
oooo00P0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0b0?ooo`040000o`3oool0
oooo0000o`80oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool01000o`00oooo0?ooo`00o`020?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo0000o`060?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0180oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo00d0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0:0?ooo`04
0?l0003oool0oooo0?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`0O0?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool0A@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0:P3oool30?l0
00`0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0303oool01@00o`00oooo0?ooo`3oool00?l003l0oooo00<0
003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0
=`3oool00`00o`00oooo003o000n0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0b0?ooo`040000o`3oool0oooo0000o`80oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool04@3oool01000o`00oooo0?ooo`00o`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0?`3oool20000o`H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`00o`00oooo
0?ooo`0F0?ooo`03003o003oool0oooo02T0oooo00<0003o0?ooo`3oool03@3oool010000?l0oooo
0?ooo`3o00020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o00001P3oool01@000?l0
oooo0?ooo`3oool0003o01l0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`150?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00`0oooo00D0003o0?ooo`3o
ool0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`00o`00?`3oool00`000?l0oooo0?ooo`04
0?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0g0?ooo`03003o003o
ool00?l003h0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`80o`001P3o
ool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3o
ool0103o0000oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0
0?l01@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3o
ool0<P3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00@00?l00?oo
o`3oool00?l00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03l0oooo0P000?l6
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`0Y
0?ooo`030000o`3oool0oooo00d0oooo00H0003o0?ooo`3oool0o`000?ooo`3o000>0?ooo`80o`00
1P3oool01@000?l0oooo0?ooo`3oool0003o0200oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo03D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0j0?ooo`050000o`3oool0oooo0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool03@3oool01000o`00oooo0?ooo`00o`0o0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo003o00030?ooo`03003o003oool0oooo03L0oooo0P00o`0o0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo00<0003o0?ooo`000?l01@3oool0
103o0000oooo0?ooo`3o000=0?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0
0P3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`0b0?ooo`040000o`3oool0oooo0000o`<0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04P3oool01000o`00oooo0?ooo`00o`030?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o00004P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01<0oooo00<00?l00?ooo`3oool0503o
ool00`00o`00oooo0?ooo`0[0?ooo`030000o`3oool0oooo00`0oooo00H0003o0?ooo`3oool0o`00
0?ooo`3o000>0?ooo`80o`001P3oool01@000?l0oooo0?ooo`3oool0003o0200oooo00<00?l00?oo
o`3oool0203oool00`00o`00oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo03D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0j0?ooo`05
0000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
01<0oooo00@00?l00?ooo`3oool00?l0?`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00<00?l00?ooo`00o`00>P3oool2003o0400oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo0000o`050?ooo`040?l0003oool0
oooo0?l000h0oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`040000o`3o
ool0oooo003o00D0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo03<0oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`03003o
003oool00?l000@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`100?ooo`030000
o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0000B0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool04`3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo02/0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`020?l00100oooo00<0o`000?ooo`3o
ool01@3oool010000?l0oooo0?ooo`000?lP0?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool0AP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>`3oool01@000?l0oooo0?ooo`3oool0003o
00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool00?l0
0400oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool00?l0
03/0oooo00<00?l00?ooo`3oool0?P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo0P3o00070?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`003P3oool0
0`3o0000oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool00?l01@3o
ool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0<`3o
ool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`00o`00103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04P0oooo00@0o`000?ooo`3oool0o`00
4`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01<0oooo00<00?l00?ooo`3oool0
503oool00`00o`00oooo0?ooo`0[0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0
0P3o000H0?ooo`040000o`3oool0oooo0000ob00oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`160?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000<`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o00100?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo003o000k0?ooo`03
003o003oool0oooo03h0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o000>0?oo
o`80o`001@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo003o00D0oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo03@0oooo00<0003o
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool00?l000@0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`180?ooo`040?l0003oool0oooo0?l001<0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo01@0oooo00<0
0?l00?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l001T0oooo
00<0003o0?ooo`000?l08P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0480oooo
1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0>`3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool00?l00400oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool00?l003/0oooo00<00?l00?ooo`3oool0
?P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000h0oooo0P3o00050?ooo`030000
o`3oool0oooo0080oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`090?ooo`03
003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0=03oool20000o`@0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04P3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0B03oool00`3o0000oooo0?l0000D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool04`3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo02/0oooo00<0003o0?ooo`3o
ool0303oool010000?l0oooo0?ooo`3o000I0?ooo`030000o`3oool0003o0280oooo00<00?l00?oo
o`3oool01P3oool00`00o`00oooo0?ooo`160?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`05
0000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`00o`00@@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`00o`00O03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l0000>0?ooo`80o`001@3oool00`00
0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00o`00103oool00`00o`00oooo0?ooo`09
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0=03oool20000o`D0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool04`3oool2003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`1:0?ooo`030?l0003o
ool0o`0001@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0D0?ooo`03003o003o
ool0oooo01<0oooo00<00?l00?ooo`3oool0;03oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo01X0oooo00<0003o0?ooo`000?l08P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o
ool0oooo04H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0=P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03`0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`3o00005P3oool00`00o`00oooo003o00110?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo003o001l0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`050?ooo`80o`00
403oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo003o00040?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0e0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool00`00o`00
oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0B`3oool20?l001@0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo0180oooo00<00?l00?oo
o`3oool0;03oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?oo
o`000?l08`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo04H0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0=P3oool01@000?l0oooo0?ooo`3oool0003o
03l0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o00005P3o
ool00`00o`00oooo003o00110?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`00o`00oooo003o001l0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`050?ooo`80o`00403oool00`3o0000oooo0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool01@00o`00oooo0?ooo`3oool00?l000`0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`0e0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04`3oool00`00o`00oooo0?ooo`040?ooo`040000o`3oool0oooo0000od`0oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo00<00?l00?oo
o`3oool04@3oool00`00o`00oooo0?ooo`0]0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool06P3oool00`000?l0oooo0000o`0S0?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool0AP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000@0oooo0P0000050?ooo`<0
00002`3oool00`000000oooo0?ooo`0f0?ooo`050000o`3oool0oooo0?ooo`000?l0@03oool01000
0?l0oooo0?ooo`000?l40?ooo`050?l0003oool0oooo0?ooo`3o00005P3oool00`00o`00oooo003o
00110?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo003o
001l0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o103oool01@00o`00oooo
0?ooo`3oool00?l000`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`00o`00oooo0?ooo`040?ooo`04
0000o`3oool0oooo0000od`0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01L0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0]0?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0000o`0S0?oo
o`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0AP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0=P3oool01@000?l0oooo0?ooo`3oool0003o0400oooo00<0003o0?ooo`000?l01@3oool0
1@3o0000oooo0?ooo`3oool0o`0001H0oooo00<00?l00?ooo`00o`00@@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`00o`00O03oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo0?oo
o`000?l40?ooo`05003o003oool0oooo0?ooo`00o`00303oool00`00o`00oooo0?ooo`040?ooo`03
003o003oool0oooo03`0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool06P3oool010000?l0oooo0?ooo`000?mR0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0603oool00`00o`00oooo0?ooo`0?0?oo
o`03003o003oool0oooo02d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0K0?oo
o`030000o`3oool0oooo0280oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`160?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000P0oooo1@00000;0?oo
o`L00000<P3oool010000?l0oooo0?ooo`000?m10?ooo`030000o`3oool0003o00D0oooo00D0o`00
0?ooo`3oool0oooo0?l0000G0?ooo`800?l0@@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<00?l00?ooo`00o`00O03oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo02h0oooo00@0003o0?ooo`3oool0003o103oool01@00o`00oooo0?ooo`3oool00?l000`0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0l0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01X0
oooo00@0003o0?ooo`3oool0003oH`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
01T0oooo00<00?l00?ooo`3oool03P3oool00`00o`00oooo0?ooo`0]0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool0@03oool7000001T0oooo000P0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0f0?ooo`040000o`3oool0
oooo0000od40oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`0001L0oooo
00<00?l00?ooo`3oool0@03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<00?l00?ooo`00o`00O@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02h0oooo
00@0003o0?ooo`3oool0003o103oool01@00o`00oooo0?ooo`3oool00?l000`0oooo00<00?l00?oo
o`3oool0103oool00`00o`00oooo0?ooo`0m0?ooo`050?l0003oool0oooo0?ooo`3o00004`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01X0oooo00@0003o0?ooo`3oool0003oH`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo00<00?l00?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`0]0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool0=`3oool20000od80oooo00<0003o0?ooo`000?l01@3o
ool01@3o0000oooo0?ooo`3oool0o`0001L0oooo00<00?l00?ooo`3oool0@03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`00o`00O@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo02h0oooo00@0003o0?ooo`3oool0003o103oool01@00o`00
oooo0?ooo`3oool00?l000`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0m0?oo
o`050?l0003oool0oooo0?ooo`3o00004`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo01/0oooo00<0003o0?ooo`000?l0H`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01/0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`0]0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool0A`3oool00`000000oooo0?ooo`0G0?ooo`008@3oool20000
00/0oooo0P00000<0?ooo`030000003oool0oooo03L0oooo0P000?m20?ooo`030000o`3oool0003o
00D0oooo00D0o`000?ooo`3oool0oooo0?l0000G0?ooo`03003o003oool0oooo0400oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo07`0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0^0?ooo`040000o`3oool0oooo0000o`@0oooo00D0
0?l00?ooo`3oool0oooo003o000<0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0
?@3oool01@3o0000oooo0?ooo`3oool0o`0001<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0K0?ooo`030000o`3oool0003o06<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0K0?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool0;@3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0440oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`170?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo03L0oooo
00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o
00005`3oool00`00o`00oooo0?ooo`100?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool00`00o`00oooo0?ooo`1l0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0;P3oool010000?l0oooo0?ooo`000?l40?ooo`05003o003oool0oooo0?ooo`00o`003@3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo03d0oooo00D0o`000?ooo`3oool0oooo0?l0
000C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0000
o`1S0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0703oool00`00o`00oooo0?oo
o`0;0?ooo`03003o003oool0oooo02d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`120?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0A`3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0440oooo00<0003o
0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`0001L0oooo00<00?l00?ooo`3oool0@03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0O03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02h0oooo00@0003o0?ooo`3oool0003o
1@3oool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0?@3oool0103o0000oooo0?ooo`3o000D0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0703oool00`000?l0oooo0000o`1S0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool07@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo02h0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`120?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool0A`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1k0?ooo`03
0000o`3oool0003o00D0oooo00D0o`000?ooo`3oool0oooo0?l0001K0?ooo`050000o`3oool0oooo
0?ooo`000?l01P3oool00`00o`00oooo0?ooo`1l0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0;`3oool00`000?l0oooo0000o`050?ooo`03003o003oool00?l000h0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0n0?ooo`040?l0003oool0oooo0?l001@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0003o06<0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0M0?ooo`03003o003oool0oooo00T0oooo00<0
0?l00?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0480oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`170?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo07/0oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3o
ool0o`0005/0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`03003o003oool0oooo07`0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0003o00D0oooo
00<00?l00?ooo`00o`003P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo03l0oooo
00<0o`000?ooo`3o0000503oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01`0oooo
0P000?mT0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool07P3oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo02h0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`130?ooo`05003o003oool0oooo0?ooo`00o`00B@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool5000007T0oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`0005/0
oooo00@0003o0?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`1l0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0000o`050?ooo`03003o003oool00?l0
00h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0o0?ooo`030?l0003oool0o`00
01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo
0680oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0N0?ooo`03003o003oool0oooo
00P0oooo00<00?l00?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo
04<0oooo00D00?l00?ooo`3oool0oooo003o00150?ooo`D000006@3oool003`0oooo00<000000?oo
o`3oool0O03oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`3o0000F`3oool0
10000?l0oooo0?ooo`000?n60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;`3o
ool00`000?l0oooo0000o`050?ooo`03003o003oool00?l000h0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0o0?ooo`030?l0003oool0o`0001@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo0680oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0N0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0;`3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo04@0oooo00D00?l00?ooo`3oool0oooo
003o00190?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo07`0oooo00<0
003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0005/0oooo00@0003o0?ooo`3oool0
003oQP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`00
0?l01@3oool00`00o`00oooo003o000>0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool0?`3oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool07@3oool00`000?l0oooo0?ooo`1R0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool07`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo02l0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`140?ooo`05003o003oool0oooo0?ooo`00o`00B@3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3o0000G03oool010000?l0oooo0?ooo`000?n60?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0;`3oool20000o`H0oooo00<00?l00?ooo`00o`003P3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo03l0oooo00<0o`000?ooo`3o00005@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0HP3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0200oooo00<00?l00?ooo`3oool01`3oool00`00
o`00oooo0?ooo`0_0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0A@3oool01000
o`00oooo0?ooo`00o`190?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
07`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l0001L0?ooo`040000o`3oool0oooo
0000ohL0oooo00D0003o0?ooo`3oool0oooo0000o`0a0?ooo`80003o1P3oool00`00o`00oooo003o
000>0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0?`3oool20?l001H0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`220?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0803oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0300oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`150?ooo`04003o003oool0oooo003o04T0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0O03oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0o`0005`0oooo00@0003o0?ooo`3oool0003oQ`3oool010000?l0oooo
0?ooo`000?lb0?ooo`80003o1P3oool00`00o`00oooo003o000>0?ooo`05003o003oool0oooo0?oo
o`00o`00@`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0P`3oool01@000?l0oooo0?ooo`3oool0003o02<0oooo00<00?l00?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0`0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0A@3oool0
1000o`00oooo0?ooo`00o`190?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo07`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l0001L0?ooo`040000o`3oool0
oooo0000ohL0oooo00@0003o0?ooo`3oool0003o<`3oool00`000?l0oooo0?ooo`040?ooo`03003o
003oool00?l000h0oooo00D00?l00?ooo`3oool0oooo003o00130?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`230?ooo`050000o`3oool0oooo0?oo
o`000?l08`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0300oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`160?ooo`800?l0BP3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`240?ooo`030?l0003oool0o`0005`0oooo00@0003o0?ooo`3o
ool0003oQ`3oool010000?l0oooo0?ooo`000?lc0?ooo`030000o`3oool0oooo00D0oooo0P00o`0?
0?ooo`04003o003oool0oooo003o04<0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo08<0oooo00D0003o0?ooo`3oool0oooo0000o`0S0?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo04H0oooo0P00o`1:0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000PP3o
ool00`3o0000oooo0?l0001L0?ooo`040000o`3oool0oooo0000ohL0oooo00@0003o0?ooo`3oool0
003o<`3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00h0oooo00@00?l00?ooo`3o
ool00?l0FP3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo08<0oooo00D0003o0?oo
o`3oool0oooo0000o`0T0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0<03oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo04H0oooo0P00o`160?ooo`D000006@3oool0
03`0oooo00<000000?ooo`3oool0Q03oool00`3o0000oooo0?l0001M0?ooo`030000o`3oool0003o
08L0oooo00@0003o0?ooo`3oool0003o<`3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0
oooo00h0oooo00@00?l00?ooo`3oool00?l0FP3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo08<0oooo00D0003o0?ooo`3oool0oooo0000o`0T0?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo04H0oooo
0P00o`1:0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo08@0oooo00<0
o`000?ooo`3o0000G@3oool00`000?l0oooo0000o`270?ooo`040000o`3oool0oooo0000oc<0oooo
00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0>0?ooo`04003o003oool0oooo003o05X0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`240?ooo`050000o`3oool0oooo0?oo
o`000?l0903oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0300oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`170?ooo`03003o003oool0oooo04P0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0Q03oool00`3o0000oooo0?l0001M0?ooo`03
0000o`3oool0003o08L0oooo00@0003o0?ooo`3oool0003o>`3oool00`00o`00oooo0?ooo`0>0?oo
o`04003o003oool0oooo003o05X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`24
0?ooo`050000o`3oool0oooo0?ooo`000?l09@3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo0300oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`170?ooo`03003o003o
ool0oooo04P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0Q03oool0
0`3o0000oooo0?l0001M0?ooo`030000o`3oool0003o08L0oooo00@0003o0?ooo`3oool0003o>`3o
ool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool00?l005/0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`240?ooo`050000o`3oool0oooo0?ooo`000?l09@3oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo0340oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`2B0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo08@0oooo00<0
o`000?ooo`3o0000G@3oool00`000?l0oooo0000o`270?ooo`040000o`3oool0oooo0000od`0oooo
00<00?l00?ooo`00o`00F`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo08@0oooo
00D0003o0?ooo`3oool0oooo0000o`0V0?ooo`05003o003oool0oooo0?ooo`00o`00<`3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0980oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0Q03oool00`3o0000oooo0?l0001M0?ooo`030000o`3oool0003o08P0
oooo00<0003o0?ooo`000?l0C03oool00`00o`00oooo003o001K0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0Q03oool01@000?l0oooo0?ooo`3oool0003o02H0oooo00D00?l00?oo
o`3oool0oooo003o000c0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool500000880oooo00<0o`000?ooo`3o0000G@3oool00`00
0?l0oooo0000o`280?ooo`030000o`3oool0003o04`0oooo00<00?l00?ooo`00o`00G03oool01@00
0?l0oooo0?ooo`3oool0003o08H0oooo00D0003o0?ooo`3oool0oooo0000o`0V0?ooo`05003o003o
ool0oooo0?ooo`00o`00<`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo08h0oooo
1@00000I0?ooo`00?03oool00`000000oooo0?ooo`240?ooo`030?l0003oool0o`0005d0oooo00<0
003o0?ooo`000?l0R03oool00`000?l0oooo0000o`1<0?ooo`03003o003oool00?l005`0oooo00D0
003o0?ooo`3oool0oooo0000o`260?ooo`040000o`3oool0oooo0000obP0oooo00@00?l00?ooo`3o
ool00?l0<`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0980oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0Q@3oool00`3o0000oooo0?ooo`1L0?ooo`80
003oR@3oool00`000?l0oooo0000o`1=0?ooo`800?l0G03oool01@000?l0oooo0?ooo`3oool0003o
08L0oooo00<0003o0?ooo`000?l0:03oool01000o`00oooo0?ooo`00o`0c0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool0TP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`250?ooo`030?l0003oool0oooo05`0oooo0P000?n90?ooo`030000o`3oool0003o
04d0oooo0P00o`1L0?ooo`050000o`3oool0oooo0?ooo`000?l0Q`3oool00`000?l0oooo0000o`0X
0?ooo`04003o003oool0oooo003o03<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`2B0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo08D0oooo00<0o`00
0?ooo`3oool0G03oool20000ohT0oooo00<0003o0?ooo`000?l0C@3oool00`00o`00oooo0?ooo`1K
0?ooo`050000o`3oool0oooo0?ooo`000?l0Q`3oool00`000?l0oooo0000o`0Y0?ooo`03003o003o
ool00?l003<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`2B0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo08D0oooo00<0o`000?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`270?ooo`030000o`3oool0003o04d0oooo00<00?l00?ooo`3oool0F`3oool0
1@000?l0oooo0?ooo`3oool0003o08L0oooo00<0003o0?ooo`000?l0:@3oool2003o03@0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo08D0oooo00<0o`000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`27
0?ooo`80003oCP3oool00`00o`00oooo0?ooo`1K0?ooo`050000o`3oool0oooo0?ooo`000?l0Q`3o
ool00`000?l0oooo0000o`0Y0?ooo`800?l0=@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0980oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0Q@3oool0
0`3o0000oooo0?ooo`1M0?ooo`030000o`3oool0oooo08L0oooo0P000?m>0?ooo`03003o003oool0
oooo05/0oooo00D0003o0?ooo`3oool0oooo0000o`270?ooo`030000o`3oool0003o02X0oooo00<0
0?l00?ooo`3oool0<`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0980oooo00<0
00000?ooo`3oool05`3oool003`0oooo1@0000230?ooo`030?l0003oool0oooo05d0oooo00<0003o
0?ooo`3oool0Q`3oool20000oj`0oooo00D0003o0?ooo`3oool0oooo0000o`270?ooo`030000o`3o
ool0003o02X0oooo00<00?l00?ooo`3oool0<`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo08h0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`250?ooo`030?l0003oool0
oooo05d0oooo00<0003o0?ooo`3oool0R03oool00`000?l0oooo0?ooo`2Z0?ooo`040000o`3oool0
oooo0000ohP0oooo00<0003o0?ooo`000?l0H03oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0980oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0i@3oool0
0`000?l0oooo0?ooo`280?ooo`030000o`3oool0oooo0:X0oooo00@0003o0?ooo`3oool0003oR03o
ool00`000?l0oooo0000o`1P0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooog40oooo00<0003o
0?ooo`3oool0ZP3oool010000?l0oooo0?ooo`000?n80?ooo`030000o`3oool0003o0600oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0?l0ooooL@3oool00`000?l0oooo0?ooo`2[0?ooo`030000o`3oool0
003o08P0oooo00<0003o0?ooo`000?l0H03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo0980oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3oooma0?oo
o`030000o`3oool0oooo0:/0oooo00<0003o0?ooo`000?l0R03oool00`000?l0oooo0000o`1P0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0TP3oool00`000000oooo0?ooo`0G0?oo
o`006`3oool2000000@0oooo0P0000050?ooo`<000000P3oool2000000d0oooo00<000000?ooo`3o
ool0o`3oooma0?ooo`030000o`3oool0oooo0:/0oooo00<0003o0?ooo`000?l0R@3oool00`000?l0
oooo0?ooo`1O0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0TP3oool00`000000
oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo803oool00`00
0?l0oooo0000o`290?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`2B0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo0000
00P0oooo1@0000040?ooo`030000003oool0oooo00X0oooo1`00003o0?ooool0oooo703oool00`00
0?l0oooo0000o`290?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`2<0?ooo`L000006@3oool001X0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`8000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo803oool0
0`000?l0oooo0000o`290?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0ooooo`3ooolP0?ooo`030000o`3oool0003o08T0oooo00<0003o0?ooo`3oool0G`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0980oooo00<000000?ooo`3oool05`3oool0
01/0oooo0P00000;0?ooo`8000000`3oool3000000`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob00oooo00<0003o0?ooo`000?l0R@3oool00`000?l0oooo0?ooo`1O0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool0TP3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`3o0?ooool0oooo803oool00`000?l0oooo0000o`290?ooo`030000o`3oool0oooo05l0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`030000o`3oool0003o0>/0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`030000o`3oool0003o0>/0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`D00000o`3ooooo0?oooah0oooo0P000?o/0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0S`3oool5000001T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?oo
o`030000o`3oool0oooo0>X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2C0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`03
0000o`3oool0oooo0>X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2C0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000
o`3oool0oooo0>/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2C0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000o`3o
ool0oooo0>/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2C0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000o`3oool0
oooo0>/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000o`3oool0oooo
0>/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`030000o`3oool0oooo0>/0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`D000004P3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo03d0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo02X0oooo
1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0680oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00
?03ooooo00000?l00000o`00000C000000030000o`000000000000H0000000<0003o000000000000
U000000I0?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {253.313, 48.4375}} -> {-13.4117, \
0.221188, 0.114894, 0.00130994}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3 performed by Friedman 1930", \
"Subsection"],

Cell[CellGroupData[{

Cell["Manually Corrected Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.105237 0.587828 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01233 -18 -4.5 ]
[-0.0125 .01233 0 4.5 ]
[-0.0125 .07111 -18 -4.5 ]
[-0.0125 .07111 0 4.5 ]
[-0.0125 .12989 -18 -4.5 ]
[-0.0125 .12989 0 4.5 ]
[-0.0125 .18868 -18 -4.5 ]
[-0.0125 .18868 0 4.5 ]
[-0.0125 .24746 -18 -4.5 ]
[-0.0125 .24746 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01233 m
.00625 .01233 L
s
[(0.2)] -0.0125 .01233 1 0 Mshowa
0 .07111 m
.00625 .07111 L
s
[(0.3)] -0.0125 .07111 1 0 Mshowa
0 .12989 m
.00625 .12989 L
s
[(0.4)] -0.0125 .12989 1 0 Mshowa
0 .18868 m
.00625 .18868 L
s
[(0.5)] -0.0125 .18868 1 0 Mshowa
0 .24746 m
.00625 .24746 L
s
[(0.6)] -0.0125 .24746 1 0 Mshowa
.125 Mabswid
0 .02408 m
.00375 .02408 L
s
0 .03584 m
.00375 .03584 L
s
0 .0476 m
.00375 .0476 L
s
0 .05935 m
.00375 .05935 L
s
0 .08287 m
.00375 .08287 L
s
0 .09462 m
.00375 .09462 L
s
0 .10638 m
.00375 .10638 L
s
0 .11814 m
.00375 .11814 L
s
0 .14165 m
.00375 .14165 L
s
0 .15341 m
.00375 .15341 L
s
0 .16516 m
.00375 .16516 L
s
0 .17692 m
.00375 .17692 L
s
0 .20043 m
.00375 .20043 L
s
0 .21219 m
.00375 .21219 L
s
0 .22395 m
.00375 .22395 L
s
0 .2357 m
.00375 .2357 L
s
0 .00057 m
.00375 .00057 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .01233 m
1 .01233 L
s
.99375 .07111 m
1 .07111 L
s
.99375 .12989 m
1 .12989 L
s
.99375 .18868 m
1 .18868 L
s
.99375 .24746 m
1 .24746 L
s
.125 Mabswid
.99625 .02408 m
1 .02408 L
s
.99625 .03584 m
1 .03584 L
s
.99625 .0476 m
1 .0476 L
s
.99625 .05935 m
1 .05935 L
s
.99625 .08287 m
1 .08287 L
s
.99625 .09462 m
1 .09462 L
s
.99625 .10638 m
1 .10638 L
s
.99625 .11814 m
1 .11814 L
s
.99625 .14165 m
1 .14165 L
s
.99625 .15341 m
1 .15341 L
s
.99625 .16516 m
1 .16516 L
s
.99625 .17692 m
1 .17692 L
s
.99625 .20043 m
1 .20043 L
s
.99625 .21219 m
1 .21219 L
s
.99625 .22395 m
1 .22395 L
s
.99625 .2357 m
1 .2357 L
s
.99625 .00057 m
1 .00057 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .16534 m
.0423 .09032 L
.05155 .10841 L
.0608 .08654 L
.07004 .12347 L
.07929 .10867 L
.08853 .04332 L
.09778 .04301 L
.10703 .21722 L
.11627 .06093 L
.12552 .08686 L
.13477 .07033 L
.14401 .10068 L
.15326 .03766 L
.16251 .13016 L
.17175 .01571 L
.181 .15931 L
.19025 .05657 L
.19949 .08107 L
.20874 .02942 L
.21798 .06923 L
.22723 .06794 L
.23648 .08994 L
.24572 .1173 L
.25497 .08886 L
.26422 .04682 L
.27346 .09979 L
.28271 .09047 L
.29196 .12787 L
.3012 .05587 L
.31045 .12372 L
.31969 .05887 L
.32894 .05249 L
.33819 .08745 L
.34743 .07008 L
.35668 .10586 L
.36593 .10841 L
.37517 .05229 L
.38442 .04606 L
.39367 .03792 L
.40291 .0917 L
.41216 .101 L
.42141 .07069 L
.43065 .0747 L
.4399 .09259 L
.44914 .08257 L
.45839 .09815 L
.46764 .069 L
.47688 .10187 L
.48613 .10544 L
Mistroke
.49538 .08123 L
.50462 .05697 L
.51387 .09994 L
.52312 .10404 L
.53236 .08336 L
.54161 .05588 L
.55086 .11598 L
.5601 .02404 L
.56935 .0909 L
.57859 .06667 L
.58784 .09576 L
.59709 .05424 L
.60633 .09183 L
.61558 .1032 L
.62483 .10125 L
.63407 .05782 L
.64332 .09598 L
.65257 .05867 L
.66181 .11045 L
.67106 .09239 L
.68031 .08256 L
.68955 .07375 L
.6988 .0506 L
.70804 .12131 L
.71729 .11965 L
.72654 .12041 L
.73578 .13651 L
.74503 .12884 L
.75428 .19854 L
.76352 .08628 L
.77277 .11928 L
.78202 .12288 L
.79126 .09031 L
.80051 .02868 L
.80975 .22608 L
.819 .05323 L
.82825 .06586 L
.83749 .0216 L
.84674 .06828 L
.85599 .04307 L
.86523 .09522 L
.87448 .00695 L
.88373 .20298 L
.89297 .05579 L
.90222 .04119 L
.91147 .02378 L
.92071 .07367 L
.92996 .04661 L
.9392 .11627 L
.94845 .02026 L
Mistroke
.9577 .08467 L
.96694 .00596 L
.97619 .05377 L
Mfstroke
0 1 0 r
.03306 .07197 m
.0423 .07296 L
.05155 .09557 L
.0608 .09143 L
.07004 .0785 L
.07929 .10016 L
.08853 .11148 L
.09778 .04937 L
.10703 .03448 L
.11627 .14566 L
.12552 .07598 L
.13477 .07488 L
.14401 .0622 L
.15326 .11431 L
.16251 .04609 L
.17175 .01848 L
.181 .07501 L
.19025 .13595 L
.19949 .07098 L
.20874 .12329 L
.21798 .09963 L
.22723 .1321 L
.23648 .10684 L
.24572 .03404 L
.25497 .07474 L
.26422 .13341 L
.27346 .07971 L
.28271 .06547 L
.29196 .1076 L
.3012 .14151 L
.31045 .09214 L
.31969 .14588 L
.32894 .16019 L
.33819 .12375 L
.34743 .17797 L
.35668 .05903 L
.36593 .12955 L
.37517 .15799 L
.38442 .1532 L
.39367 .13473 L
.40291 .08932 L
.41216 .101 L
.42141 .10708 L
.43065 .10649 L
.4399 .10578 L
.44914 .11151 L
.45839 .11565 L
.46764 .12295 L
.47688 .08574 L
.48613 .10027 L
Mistroke
.49538 .10491 L
.50462 .12534 L
.51387 .10245 L
.52312 .11512 L
.53236 .10638 L
.54161 .05553 L
.55086 .15019 L
.5601 .18149 L
.56935 .0909 L
.57859 .11381 L
.58784 .11553 L
.59709 .14255 L
.60633 .08285 L
.61558 .04696 L
.62483 .12956 L
.63407 .12426 L
.64332 .09315 L
.65257 .12312 L
.66181 .13039 L
.67106 .09947 L
.68031 .06867 L
.68955 .05894 L
.6988 .14494 L
.70804 .07159 L
.71729 .06794 L
.72654 .09672 L
.73578 .0755 L
.74503 .09557 L
.75428 .05257 L
.76352 .09352 L
.77277 .10499 L
.78202 .04818 L
.79126 .08913 L
.80051 .05997 L
.80975 .03288 L
.819 .13542 L
.82825 .08855 L
.83749 .14007 L
.84674 .10369 L
.85599 .11486 L
.86523 .09522 L
.87448 .02112 L
.88373 .04737 L
.89297 .1351 L
.90222 .11193 L
.91147 .1607 L
.92071 .10298 L
.92996 .13367 L
.9392 .06538 L
.94845 .13926 L
Mistroke
.9577 .07379 L
.96694 .08349 L
.97619 .06051 L
Mfstroke
0 0 1 r
.03306 .03481 m
.0423 .10883 L
.05155 .06813 L
.0608 .09415 L
.07004 .07015 L
.07929 .06328 L
.08853 .11731 L
.09778 .17973 L
.10703 .02042 L
.11627 .06553 L
.12552 .10928 L
.13477 .1269 L
.14401 .10923 L
.15326 .12015 L
.16251 .09586 L
.17175 .23792 L
.181 .0378 L
.19025 .0796 L
.19949 .12007 L
.20874 .11941 L
.21798 .10325 L
.22723 .07208 L
.23648 .07534 L
.24572 .12077 L
.25497 .10852 L
.26422 .09188 L
.27346 .09262 L
.28271 .11618 L
.29196 .03665 L
.3012 .07474 L
.31045 .05625 L
.31969 .06736 L
.32894 .05944 L
.33819 .06092 L
.34743 .02407 L
.35668 .10722 L
.36593 .03415 L
.37517 .06184 L
.38442 .07285 L
.39367 .09947 L
.40291 .0911 L
.41216 .07012 L
.42141 .09435 L
.43065 .09093 L
.4399 .07375 L
.44914 .07803 L
.45839 .05832 L
.46764 .08016 L
.47688 .0845 L
.48613 .0664 L
Mistroke
.49538 .08597 L
.50462 .08981 L
.51387 .06973 L
.52312 .05295 L
.53236 .08238 L
.54161 .16071 L
.55086 .00595 L
.5601 .06658 L
.56935 .09032 L
.57859 .09163 L
.58784 .06083 L
.59709 .07533 L
.60633 .09744 L
.61558 .12195 L
.62483 .0413 L
.63407 .09003 L
.64332 .08298 L
.65257 .09033 L
.66181 .03128 L
.67106 .08026 L
.68031 .12089 L
.68955 .13942 L
.6988 .07657 L
.70804 .07921 L
.71729 .08453 L
.72654 .05499 L
.73578 .06011 L
.74503 .0477 L
.75428 .02101 L
.76352 .09232 L
.77277 .04784 L
.78202 .10105 L
.79126 .09267 L
.80051 .18346 L
.80975 .01315 L
.819 .08347 L
.82825 .11771 L
.83749 .11045 L
.84674 .10015 L
.85599 .11418 L
.86523 .08168 L
.87448 .24405 L
.88373 .02177 L
.89297 .08122 L
.90222 .119 L
.91147 .08763 L
.92071 .09547 L
.92996 .09183 L
.9392 .09047 L
.94845 .1126 L
Mistroke
.9577 .11366 L
.96694 .18267 L
.97619 .15784 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00D`3oool200000:H0oooo100000030?ooo`800000YP3oool30000
0080oooo0P00002T0?ooo`<00000103oool200000:D0oooo0P0000040?ooo`800000X@3oool50000
0080oooo0P0000040?ooo`800000BP3oool00580oooo00@000000?ooo`3oool00000Y@3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2Q0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000X`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:80oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
A`3oool00580oooo00@000000?ooo`3oool00000YP3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:<0oooo1@0000001@3oool000000?ooo`3oool000000:<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002S0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000XP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`170?ooo`00DP3oool010000000oooo0?ooo`00002W
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2Q0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000X`3oool3000000<0oooo00@000000?ooo`3o
ool00000Y03oool2000000<0oooo00@000000?ooo`3oool00000XP3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`170?ooo`00DP3o
ool010000000oooo0?ooo`00002U0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y03oool00`000000oooo000000020?ooo`040000003oool0oooo00000:@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002S0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000XP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`170?ooo`00D`3oool200000:L0oooo0P0000040?oo
o`800000YP3oool2000000<0oooo0P00002U0?ooo`<000000`3oool200000:D0oooo0P0000040?oo
o`800000XP3oool2000000@0oooo0P0000040?ooo`800000BP3oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03d0ooooo`00003o00000?l00000Z`00000P0?ooo`00?@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0900oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0:X0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo
01h0oooo000m0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo0900oooo00<0003o0?ooo`3oool05`3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo06@0oooo00<0o`000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<0003o0?ooo`3oool0o`3oool/0?ooo`030?l0
003oool0oooo05@0oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`000?l0oooo0?ooo`3o0?ooob`0oooo00<0
o`000?ooo`3oool0E03oool20?l001d0oooo00<000000?ooo`3oool07P3oool00280oooo0P000004
0?ooo`8000000`3oool4000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P000?oo
0?ooobd0oooo00<0o`000?ooo`3oool0E03oool20?l001d0oooo00<000000?ooo`3oool07P3oool0
0240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooo`3oool20?ooo`80003oo`3oool]0?ooo`030?l0003oool0oooo05<0oooo00<0o`00
0?ooo`3o00007@3oool00`000000oooo0?ooo`0N0?ooo`008@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00`0oooo1`00003o0?ooood0oooo0P000?oo0?ooobd0oooo00<0o`00
0?ooo`3oool0D`3oool00`3o0000oooo0?l0000G0?ooo`L00000803oool00240oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3oool2
0?ooo`80003ol03oool00`000?l0oooo0?ooo`0h0?ooo`80o`00E@3oool00`3o0000oooo0?l0000M
0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000303oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool20000oo00oooo00<0
003o0?ooo`3oool0>03oool20?l005D0oooo00<0o`000?ooo`3o00007@3oool00`000000oooo0?oo
o`0N0?ooo`008P3oool2000000X0oooo0P00000=0?ooo`030000003oool0oooo09h0oooo00<0o`00
0?ooo`3oool0o`3ooomO0?ooo`030000o`3oool0003o0?00oooo00<0003o0?ooo`3oool0>03oool2
0?l005D0oooo00@0o`000?ooo`3oool0o`00703oool00`000000oooo0?ooo`0N0?ooo`00?@3oool0
0`000000oooo0?ooo`2N0?ooo`030?l0003oool0oooo0?l0ooooG`3oool010000?l0oooo0?ooo`00
0?o_0?ooo`030000o`3oool0oooo03P0oooo0P3o001E0?ooo`040?l0003oool0oooo0?l001`0oooo
00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0WP3oool00`3o0000oooo0?oo
o`3o0?oooel0oooo00@0003o0?ooo`3oool0003ok`3oool20000ocT0oooo0P3o001E0?ooo`040?l0
003oool0oooo0?l001`0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0
WP3oool00`00o`00oooo0?ooo`3o0?oooel0oooo00@0003o0?ooo`3oool0003ok`3oool20000ocT0
oooo00<0o`000?ooo`3o0000E03oool0103o0000oooo0?ooo`3o000L0?ooo`030000003oool0oooo
01h0oooo000m0?ooo`030000003oool0oooo09h0oooo00<00?l00?ooo`3oool0o`3ooomO0?ooo`04
0000o`3oool0oooo0000onl0oooo0P000?li0?ooo`030?l0003oool0o`0005<0oooo00D0o`000?oo
o`3oool0oooo0?l0000L0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo
0640oooo00<0003o0?ooo`3oool0>@3oool2003o0?l0ooooH@3oool010000?l0oooo0?ooo`000?nk
0?ooo`030000o`3oool0oooo0340oooo0P000?li0?ooo`030?l0003oool0o`0004@0oooo00<0o`00
0?ooo`3oool0303oool01@3o0000oooo0?ooo`3oool0o`0001`0oooo00<000000?ooo`3oool07P3o
ool003d0oooo00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0i0?ooo`03003o003o0000
0?l00?l0ooooH03oool010000?l0oooo0?ooo`000?nk0?ooo`030000o`3oool0oooo0340oooo0P00
0?lH0?ooo`030?l0003oool0oooo01h0oooo00<0o`00003o003o00001`3oool00`000?l0oooo0?oo
o`0j0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0I0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0640oooo00<0003o
0?ooo`3oool0>@3oool00`00o`00o`00003o003o0?ooof00oooo00D0003o0?ooo`3oool0oooo0000
o`2i0?ooo`80003o<P3oool00`000?l0oooo0000o`0H0?ooo`030?l0003oool0oooo01h0oooo00<0
o`00003o003o00001`3oool00`000?l0oooo0?ooo`0j0?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`D00000G`3oool20000ocT0oooo00@00?l00?l0003oool00?l0XP3oool00`000?l0oooo0?oo
o`2j0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`2a0?ooo`80003o
<P3oool00`000?l0oooo0000o`0H0?ooo`030?l0003oool0oooo01d0oooo00@0o`000?ooo`00o`00
0?l01`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01D0oooo1@00000P0?ooo`00
?@3oool00`000000oooo0?ooo`1Q0?ooo`80003o>@3oool01000o`00o`000?ooo`00o`2R0?ooo`03
0000o`3oool0oooo0;X0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo
0;40oooo00<0003o0?ooo`000?l0<@3oool00`000?l0oooo0000o`0G0?ooo`030?l0003oool0o`00
01h0oooo00@0o`000?ooo`00o`000?l01`3oool00`000?l0oooo0?ooo`0F0?ooo`80o`008P3oool2
0?l000d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0
oooo01h0oooo000m0?ooo`030000003oool0oooo0640oooo0P000?li0?ooo`04003o003o0000oooo
003o0:40oooo0P000?nl0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?oo
o`2`0?ooo`040000o`3oool0oooo0000oc40oooo00@0003o0?ooo`3oool0003o5P3oool00`3o0000
oooo0?l0000N0?ooo`040?l0003oool00?l0003o00L0oooo0P000?lG0?ooo`80o`008@3oool00`3o
0000oooo0?l0000=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`1Q0?ooo`80003o>03oool01@00o`00
oooo0?l0003oool00?l00:40oooo0P000?nl0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
0`3o0000oooo0?ooo`2`0?ooo`040000o`3oool0oooo0000oc40oooo00@0003o0?ooo`3oool0003o
5P3oool00`3o0000oooo0?l0000N0?ooo`050?l00000o`00oooo0?l00000o`001P3oool20000oaH0
oooo00@0o`000?ooo`3oool0o`00803oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000
oooo0?ooo`1Q0?ooo`80003o>03oool01P00o`00oooo0?l0003oool0o`00003o0:00oooo0P000?nl
0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool20?l00;40oooo00@0003o0?ooo`3oool0003o
<@3oool010000?l0oooo0?ooo`000?lF0?ooo`030?l0003oool0o`0001h0oooo00D0o`00003o003o
ool0o`00003o00060?ooo`80003o5P3oool0103o0000oooo0?ooo`3o000P0?ooo`030?l0003oool0
o`0000`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0
oooo01h0oooo000m0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`000?l0=`3oool01P00
o`00oooo0?l0003oool0o`00003o01l0oooo00<0o`000?ooo`3oool0OP3oool00`000?l0oooo0000
o`2k0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?l0002`0?ooo`050000
o`3oool0oooo0?ooo`000?l0:@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0000
oaD0oooo00@0o`000?ooo`3oool0o`007P3oool01P3o00000?l00?ooo`3o0000oooo003o00D0oooo
0P000?lE0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool00`3o0000oooo0?l0000<0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?ooo`00
?@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0003o03H0oooo00L00?l00?ooo`3oool0
o`000?ooo`3o00000?l001l0oooo00<0o`000?ooo`3oool0O@3oool010000?l0oooo0?ooo`000?nk
0?ooo`030000o`3oool0oooo0080oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`000;00oooo
00D0003o0?ooo`3oool0oooo0000o`0Y0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3o
ool0003o5@3oool01@3o0000oooo0?ooo`3oool0o`0001d0oooo00H0o`00003o003oool0o`000?oo
o`00o`050?ooo`80003o5@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00<0o`000?ooo`3o
0000303oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3o
ool07P3oool003d0oooo00<000000?ooo`3oool0H03oool010000?l0oooo0?ooo`000?lf0?ooo`07
003o003oool0oooo0?l0003oool0o`00003o000O0?ooo`030?l0003oool0oooo07d0oooo00@0003o
0?ooo`3oool0003o^`3oool00`000?l0oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0?l0001M0?ooo`030000o`3oool0oooo0500oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?oo
o`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0003o5@3oool01@3o0000oooo0?ooo`3o
ool0o`0001d0oooo00H0o`00003o003oool0o`000?ooo`00o`050?ooo`80003o503oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3o0000303oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool0H03oool010000?l0oooo0?ooo`000?le0?ooo`08003o003oool0oooo0?oo
o`3o0000oooo0?l00000o`0O0?ooo`80o`00OP3oool010000?l0oooo0?ooo`000?nj0?ooo`030000
o`3oool0oooo00<0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0005d0oooo00<0003o0?oo
o`3oool0C`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02L0oooo00<0o`000?oo
o`3oool01@3oool010000?l0oooo0?ooo`000?lE0?ooo`050?l0003oool0oooo0?ooo`3o00007@3o
ool0103o00000?l00?ooo`3o00020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`000?l0
4P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3o0000
303oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0
7P3oool003d0oooo00<000000?ooo`3oool0H03oool01@000?l0oooo0?ooo`3oool0003o03@0oooo
00P00?l00?ooo`3oool0oooo0?l0003oool0o`00003o01h0oooo00<0o`000?ooo`3o0000OP3oool0
10000?l0oooo0?ooo`000?nj0?ooo`030000o`3oool0oooo00<0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0o`0005d0oooo00<0003o0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo02D0oooo0P3o00070?ooo`050000o`00o`00oooo0?ooo`000?l0503oool01@3o
0000oooo0?ooo`3oool0o`0001d0oooo00@0o`00003o003oool0o`000P3oool00`00o`00oooo0?oo
o`020?ooo`030000o`3oool0003o0180oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0M0?ooo`040?l0003oool0oooo0?l000/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0G0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo01`0oooo00<0
003o0?ooo`3oool0@@3oool01@000?l00?l00?ooo`3oool0003o03@0oooo00@00?l00?ooo`3oool0
o`000P3oool00`3o0000oooo003o000M0?ooo`030?l0003oool0o`000240oooo00<00?l00?ooo`3o
ool0F@3oool01@000?l0oooo0?ooo`3oool0003o00l0oooo00<0003o0?ooo`3oool0Z03oool00`00
0?l0oooo0?ooo`030?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0001M0?ooo`80003oD03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02D0oooo0P3o00070?ooo`050000o`00
o`00oooo0?ooo`000?l04`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01X0oooo
00D0o`000?ooo`00o`00oooo0?l000020?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool07@3oool0103o
0000oooo0?ooo`3o000;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool5000001X0oooo00<0003o0?ooo`3oool0@@3oool01@00
0?l00?l00?ooo`3oool0003o03<0oooo00D00?l00?ooo`3oool0oooo0?l000020?ooo`030?l0003o
ool00?l001d0oooo00<0o`000?ooo`3o00008@3oool00`00o`00oooo0?ooo`1I0?ooo`050000o`3o
ool0oooo0?ooo`000?l03`3oool00`000?l0oooo0?ooo`2X0?ooo`030000o`3oool0oooo00<0oooo
00L0003o0?ooo`3oool0oooo0?l0003oool0o`0005`0oooo00<0003o0?ooo`000?l0D03oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02D0oooo0P3o00070?ooo`050000o`00o`00oooo
0?ooo`000?l04`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01T0oooo00D0o`00
003o003oool0oooo0?l000030?ooo`04003o003oool0oooo0000o`80oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01d0oooo00@0o`000?ooo`3oool0
o`002`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01<0oooo1@00000P0?ooo`00
?@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0440oooo00D0003o003o003oool0
oooo0000o`0c0?ooo`05003o003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo003o000M0?oo
o`040?l0003oool0oooo0?l00200oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?ooo`0^
0?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool20000ojT0oooo00<0003o0?ooo`3oool0103o
ool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo05T0oooo00<0003o0?ooo`000?l0
C`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02D0oooo0P3o00070?ooo`050000
o`00o`00oooo0?ooo`000?l04`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01T0
oooo00D0o`00003o003oool0oooo0?l000030?ooo`04003o003oool0oooo0000o`80oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01`0oooo00D0o`00
0?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0
oooo0400oooo00<00?l00000o`00o`000P3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0
oooo00P0oooo00D00?l00?ooo`3oool0oooo0?l000020?ooo`030?l0003oool00?l000D0oooo00<0
003o0?ooo`3oool05@3oool0103o0000oooo0?ooo`3o000P0?ooo`800?l0:@3oool00`000?l0oooo
0?ooo`0^0?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool20000oaP0oooo00<0o`000?ooo`3o
ool0SP3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?oo
o`3oool0F@3oool00`000?l0oooo0000o`1?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool09@3oool20?l000L0oooo00D0003o003o003oool0oooo0000o`0C0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool06@3oool01@3o00000?l00?ooo`3oool0o`0000@0oooo00<0
0?l00?ooo`000?l00P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0?`3oool00`00o`00003o003o00030?ooo`030000o`3o
ool0oooo02D0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`060?l0003o
ool0oooo0?l0003oool00?l01@3oool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l0
01l0oooo00<00?l00?ooo`00o`00:@3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0303oool20000oaL0oooo0P3o002@0?ooo`030000o`3oool0oooo
00@0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`1I0?ooo`030000o`3oool0
003o04l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`80o`001P3oool0
0`00o`00003o003o00020?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0I0?ooo`050?l00000o`00oooo0?ooo`3o0000103oool00`00o`00oooo0000
o`030?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0K0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0n0?ooo`04003o003oool0003o003o00<0oooo00<0003o0?ooo`3oool0
9@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00H0o`000?ooo`3oool0
oooo0?l00000o`050?ooo`030000o`3oool0oooo01@0oooo00D0o`000?ooo`3oool0oooo0?l0000O
0?ooo`03003o003oool00?l002T0oooo0P000?l^0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool02`3oool010000?l0oooo0?ooo`000?lE0?ooo`030?l0003oool0o`000900oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo05T0oooo00<0
003o0?ooo`000?l0CP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02D0oooo0P3o
00060?ooo`06003o00000?l0oooo003o003oool0003o4P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo01T0oooo00<0o`00003o003oool00P3oool01`3o0000oooo0?ooo`3oool00?l0
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0
oooo01d0oooo00<0003o0?ooo`3oool0?P3oool01@00o`00oooo0000o`3oool00?l00080oooo00<0
003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00L0
o`000?ooo`3oool0oooo0?l0003oool00?l000@0oooo0P000?lE0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0703oool00`00o`00oooo003o000Y0?ooo`80003o;P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0003o503oool01@3o
0000oooo0?ooo`3oool0o`0008l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l00003
0?ooo`030?l0003oool0oooo03L0oooo00<0003o0?ooo`3oool07`3oool010000?l0oooo0?ooo`00
0?m=0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool08`3oool0103o0000oooo0?oo
o`3o00040?ooo`05003o003oool0003o0?ooo`00o`000P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0603oool00`3o00000?l00?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<00?l00000o`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0
?@3oool01P00o`00oooo0?ooo`000?l0oooo003o0080oooo00<0003o0?ooo`3oool0903oool20?l0
00P0oooo00<00?l00?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00o`00103o
ool20000oaD0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L0?ooo`04003o003o
ool0oooo003o02L0oooo00<0003o0?ooo`000?l0;P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0003o4`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo08d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000030?ooo`03
0?l0003oool0oooo03L0oooo00<0003o0?ooo`3oool07P3oool01@000?l0oooo0?ooo`3oool0003o
04d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0S0?ooo`040?l0003oool0oooo
0?l000@0oooo00D00?l00000o`3oool0oooo003o00020?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l00000o`00oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`00o`00003o0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo00<0
00000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0`
0?ooo`X0o`000P3oool01`00o`00oooo0?ooo`3oool0003o0?ooo`00o`000P3oool00`000?l0oooo
0?ooo`0T0?ooo`80o`00203oool00`00o`00oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`3o
0000oooo003o00040?ooo`80003o5@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
01`0oooo00@00?l00?ooo`3oool00?l09`3oool00`000?l0oooo0000o`0]0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o0140oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2=0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?l0003oool00P3oool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo01h0oooo00D0
003o0?ooo`3oool0oooo0000o`1<0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
8`3oool0103o0000oooo0?ooo`3o00040?ooo`05003o00000?l0oooo0?ooo`00o`000P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0;0?ooo`030?l00000o`00oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
o`00003o0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool003d0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00H0
oooo00@0o`000?ooo`3oool00?l00`3oool00`000?l0oooo003o00030?ooo`030000o`3oool0oooo
02<0oooo00<0o`000?ooo`3o00001`3oool00`00o`00oooo0?ooo`030?ooo`070?l0003oool0oooo
0?ooo`3o0000oooo003o00040?ooo`80003o5@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo01`0oooo00@00?l00?ooo`3oool00?l09`3oool010000?l0oooo0?ooo`000?l/0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o
0100oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`2=0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?l0003oool00P3oool00`3o0000oooo0?ooo`0g0?ooo`80003o7`3oool01@00
0?l0oooo0?ooo`3oool0003o04`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0S
0?ooo`040?l0003oool0oooo0?l000<0oooo00<00?l00?ooo`000?l00P3oool01000o`00oooo0?oo
o`000?l@0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030?l00000o`00oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0003o00/0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`00o`00
103oool00`000?l0oooo003o00030?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3o0000
1P3oool00`00o`00oooo0?ooo`040?ooo`070?l0003oool0oooo0?ooo`3o0000oooo003o00040?oo
o`80003o5@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01/0oooo00@00?l00?oo
o`3oool00?l09`3oool010000?l0oooo0?ooo`000?l/0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o00l0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`2=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool0
0`3oool00`3o0000oooo0?ooo`0f0?ooo`80003o7`3oool01@000?l0oooo0?ooo`3oool0003o04`0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0S0?ooo`040?l0003oool0oooo0?l0
00<0oooo00<00?l00?ooo`000?l00P3oool01000o`00oooo0?ooo`000?l@0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool02@3oool20?l000d0oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
0300oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo003o00040?ooo`030000o`3oool00?l0
00<0oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?l000060?ooo`03003o003oool0oooo
00@0oooo00L0o`000?ooo`3oool0oooo0?l0003oool00?l000@0oooo00<0003o0?ooo`000?l04`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01/0oooo00D00?l00?ooo`3oool0oooo
003o000V0?ooo`040000o`3oool0oooo0000ob`0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo08d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
o`000?ooo`030?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`000?l07`3oool01@000?l0
oooo0?ooo`3oool0003o04/0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0S0?oo
o`040?l0003oool0oooo0?l000<0oooo00<00?l00?ooo`000?l00P3oool01000o`00oooo0?ooo`00
0?l@0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l0
000;0?ooo`030?l00000o`00oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l00?l00?oo
o`020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?oo
o`0N0?ooo`00?@3oool5000001`0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l00000o`00oooo00@0oooo00<0003o0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0S
0?ooo`030?l0003oool0o`0000H0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`040?l0003oool0oooo003o00<0oooo00<0003o0?ooo`000?l04`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0;0?ooo`030?l0003oool0oooo01H0oooo00@0003o0?ooo`3oool0003o:`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`090?ooo`80o`002P3oool00`3o0000oooo0?ooo`2<0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?l0003oool00`3oool00`3o0000oooo0?ooo`0^0?ooo`03003o003oool0oooo00@0oooo
00<0003o0?ooo`000?l07`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04P0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01D0oooo
00@0o`000?ooo`3oool0o`000P3oool01000o`00oooo0?ooo`000?l20?ooo`04003o003oool0oooo
0000oa00oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
o`0000/0oooo00<0o`00003o003oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`00
oooo0080oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0A0?ooo`D00000803oool0
03d0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo
00L0oooo00<0o`00003o003oool0103oool00`000?l0oooo003o00040?ooo`030000o`3oool0oooo
0240oooo00@0o`000?ooo`3oool0o`001P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00@0o`000?ooo`3oool00?l00`3oool00`000?l0oooo0000o`0C0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool06P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00/0oooo00<0o`000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o02X0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo08`0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo02h0oooo
00<00?l00?ooo`3oool0103oool00`000?l0oooo0000o`0N0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o
00000P3oool01000o`00oooo0?ooo`000?l20?ooo`04003o003oool0oooo0000oa00oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000/0oooo00<0
o`00003o003oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`00oooo0080oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo0P3o
000>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool003d0oooo00<00000
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo00<00?l0
0?ooo`3oool0103oool00`000?l0oooo003o00040?ooo`030000o`3oool0oooo0240oooo00@0o`00
0?ooo`3oool0o`001P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00@0
o`000?ooo`3oool00?l00P3oool010000?l0oooo0?ooo`000?lC0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool06@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00/0
oooo00<0o`000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o02X0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool20?l000d0oooo00<0o`000?ooo`3oool0R`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0;@3oool2003o00H0oooo00@0003o0?oo
o`3oool0003o7@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04H0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<00?l0
0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@00?l00?ooo`3oool0003o
0P3oool01@00o`00oooo0?ooo`3oool0003o00h0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000/0oooo00<0o`00003o003oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`00o`00oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo0P3o000>0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
01D0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07P3oool00`000?l0
oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool010000?l0
oooo0?ooo`00o`040?ooo`030000o`3oool0oooo0240oooo00@0o`000?ooo`3oool0o`001@3oool0
0`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool00?l00P3o
ool010000?l0oooo0?ooo`000?lC0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
6@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3o0000
5`3oool01@000?l0oooo0?ooo`3oool0003o02X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo08/0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
003o0?ooo`030?ooo`030?l0003oool0oooo02d0oooo0P00o`060?ooo`040000o`3oool0oooo0000
oad0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
02L0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0003o
00L0oooo00<00?l00?ooo`3oool02`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00o`000`3o
ool01@000?l0oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0o`002`3oool00`3o0000
0?l00?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o003o003oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?l0000=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo00L0oooo
00<00?l00?ooo`3oool00`3oool010000?l0oooo0?ooo`00o`040?ooo`030000o`3oool0oooo0240
oooo00@0o`000?ooo`3oool0o`001@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo00@0o`000?ooo`3oool00?l00P3oool01@000?l0oooo0?ooo`3oool0003o0180oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0I0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool02@3oool00`3o0000oooo0?l0000F0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20?l00100oooo00<0o`000?ooo`3oool0
R`3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo00<0o`000?ooo`3oool0
;@3oool2003o00H0oooo00@0003o0?ooo`3oool0003o7@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`000?l01P3oool00`00o`00oooo003o000<0?ooo`07
0?l0003oool0oooo0?ooo`3o0000oooo003o00030?ooo`050000o`3oool0oooo0?ooo`00o`000P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01@3o
ool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`00003o003oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`00o`00oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0o`003@3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo
00@0003o0?ooo`3oool00?l0103oool00`000?l0oooo0?ooo`0Q0?ooo`040?l0003oool0oooo0?l0
00D0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo
003o0080oooo00D0003o0?ooo`3oool0oooo0000o`0A0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool06@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<0
o`000?ooo`3o00005P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01`0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o000C0?ooo`030?l0003oool0oooo07<0oooo
00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo
00<0o`000?ooo`3oool0;@3oool00`00o`00oooo003o00050?ooo`040000o`3oool0oooo0000oad0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0K0?ooo`80o`009`3oool00`000?l0
oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`000?l02`3oool00`000?l0oooo0000o`060?oo
o`03003o003oool00?l000`0oooo00L0o`000?ooo`3oool0oooo0?l0003oool00?l000<0oooo00D0
003o0?ooo`3oool0oooo003o00020?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
203oool00`3o00000?l00?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`00o`00
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
1`3oool0103o0000oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3o
ool07P3oool003d0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0
003oool0oooo00H0oooo00<00?l00?l0003oool0103oool01@000?l0oooo0?ooo`3oool00?l000@0
oooo00<0003o0?ooo`3oool0803oool0103o0000oooo0?ooo`3o00050?ooo`03003o003oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0603o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3o00005P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo0`3o00090?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?l001<0oooo00<0o`000?ooo`3oool0LP3oool20000oaH0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000003o0?ooo`040?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
3@3oool01000o`00oooo0?ooo`00o`050?ooo`040000o`3oool0oooo0000oad0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0J0?ooo`80o`009P3oool00`000?l0oooo0?ooo`0:0?oo
o`05003o003oool0oooo0?ooo`000?l02`3oool00`000?l0oooo0000o`060?ooo`03003o003oool0
0?l000`0oooo00H0o`000?ooo`3oool0oooo0?l00000o`040?ooo`050000o`3oool0oooo0?ooo`00
o`000P3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`3o
00000?l00?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`00o`000`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool01`3oool0103o
0000oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool0
03d0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo
00H0oooo00<00?l00?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<0003o
0?ooo`3oool0803oool0103o0000oooo0?ooo`3o00050?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`000?l00`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool05`3oool00`00o`00
oooo0?ooo`040?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3o00005P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo01T0oooo00@0o`000?ooo`3oool0o`002@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?l0000C0?ooo`030?l0003oool0oooo0780oooo00<0003o0?ooo`000?l05@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`3oool06`3oool00`3o
0000oooo0?ooo`0=0?ooo`04003o003oool0oooo003o00D0oooo00D0003o0?ooo`3oool0oooo0000
o`0K0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?l0
000H0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool01@00o`00oooo0?oo
o`3oool0003o00/0oooo00<0003o0?ooo`000?l01P3oool00`00o`00oooo003o000<0?ooo`060?l0
003oool0oooo0?ooo`3o00000?l0103oool01@000?l0oooo0?ooo`3oool00?l00080oooo00@0003o
0?ooo`3oool0oooo0P3o00080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool00?l000<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0o`00
3@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo02`0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`00o`00103oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00H0o`000?ooo`3oool00?l00?ooo`000?l30?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool01`3oool0103o0000oooo0?ooo`3o000F0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo0P3o0004
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool04`3oool00`3o0000oooo0?ooo`1a
0?ooo`040000o`3oool0oooo0000o`l0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0=0?ooo`04003o003oool0oooo003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`0K0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool06@3oool0103o0000oooo0?ooo`3o000H0?oo
o`<0003o2@3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool00?l00080oooo00<0003o0?oo
o`3oool0203oool010000?l0oooo0?ooo`000?l60?ooo`04003o003oool0oooo003o00X0oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`00o`00
0P3oool010000?l0oooo0?ooo`3oool20?l000P0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`00o`000`3oool01@000?l0
oooo0?ooo`3oool0o`0001H0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
o`0000d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0280oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool00?l000@0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`060?l0003oool0oooo003o003oool0003o103oool01@000?l0oooo0?ooo`3oool0o`0000`0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0001D0oooo00<0003o0?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool04`3oool0
0`3o0000oooo0?ooo`1R0?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`3oool0003o3`3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`000?l0103o
ool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0o`0000h0oooo00@00?l00?ooo`3oool00?l0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0I0?ooo`040?l0003oool0oooo0?l001L0oooo00@0003o0?ooo`3o
ool0oooo0P000?l60?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`00o`000`3oool00`00
0?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool01000o`00oooo0?ooo`00
o`0:0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool00?l000<0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00070?ooo`030?l0003oool0oooo
00/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00L0oooo00<0o`00003o003oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool00?l0
00<0oooo00D0003o0?ooo`3oool0oooo0?l0000F0?ooo`030?l0003oool0oooo00D0oooo00D0o`00
0?ooo`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0
oooo01l0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`030000o`3oool0oooo01l0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool01P3o0000oooo0?ooo`00o`00oooo0000o`@0oooo00D0003o0?ooo`3o
ool0oooo0?l0000<0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool05P3oool00`00
o`00oooo0?ooo`050?ooo`03003o003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000E
0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`030000o`3o
ool0003o00L0oooo0P3o00070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0o`00003o003oool0103o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0003o00@0oooo00<0o`000?ooo`3oool06P3o
ool00`3o0000oooo0?l0000=0?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l0000G0?ooo`03
0000o`3oool0oooo00<0oooo0P000?l30?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`00
o`000`3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@00
o`00oooo0?ooo`3oool00?l000X0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`03
0?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o00000?l00?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`00o`000`3oool01@000?l0oooo0?ooo`3oool0o`0001H0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0280
oooo00<000000?ooo`3oool07P3oool003d0oooo1@00000M0?ooo`030000o`3oool0oooo02`0oooo
00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`00
o`001@3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo003o00070?ooo`030?l0003oool0oooo00<0oooo00H0o`000?ooo`3oool00?l00?ooo`00
0?l40?ooo`040000o`3oool0oooo0?ooo`80o`002P3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo01H0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`070?ooo`050?l0
003oool0oooo0?ooo`3o00005@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01P3oool2
0000o`L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo03H0oooo00<0003o0?ooo`3oool09`3oool20?l000d0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0;0?ooo`800?l01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
003o00@0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?l0000=0?ooo`05003o003oool0
oooo0?ooo`00o`00103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool04P3oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000
5`3oool00`000?l0oooo0?ooo`050?ooo`80003o00<0oooo0000o`3oool03@3oool00`00o`00oooo
003o00030?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`05
003o003oool0oooo0?ooo`00o`002P3oool01P3o0000oooo0?ooo`3oool00?l00?l000D0oooo00D0
003o0?ooo`3oool0oooo003o00030?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030?l00000o`00oooo00@0oooo00<0o`000?ooo`3o
ool00P3oool010000?l0oooo0?ooo`00o`040?ooo`040000o`3oool0oooo0?l001H0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01h0oooo1@00000P
0?ooo`00?@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?oo
o`3oool01P3oool01000o`00oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`00o`001@3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
003o00060?ooo`030?l0003oool0oooo00@0oooo00H0o`000?ooo`3oool0oooo003o00000?l40?oo
o`040000o`3oool0oooo0?ooo`80o`002P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo01H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`060?ooo`050?l0003oool0
oooo0?ooo`3o00005@3oool00`000?l0oooo0?ooo`040?ooo`060000o`3oool0oooo0?l0003oool0
o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040000o`80oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`000?l0:03oool00`3o0000
oooo0?l0000;0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool2003o0003
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l40?oo
o`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3o00003@3oool01@00o`00oooo0?ooo`3oool0
0?l000@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0140oooo0P00o`040?ooo`050?l0003oool0oooo0?ooo`3o00005`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00d0oooo00@00?l00?ooo`3oool00?l00P3oool00`000?l0oooo
0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00L0oooo00H0o`000?ooo`3oool0oooo003o003o00050?ooo`050000o`3oool0
oooo0?ooo`00o`000`3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`3o00000?l00?ooo`040?ooo`030?l0003oool0oooo0080oooo
00@0003o0?ooo`3oool00?l0103oool010000?l0oooo0?ooo`3o000G0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo
01@0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07`3oool00`000?l0
oooo0?ooo`0/0?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`3oool0o`00103oool01@00
0?l0oooo0?ooo`3oool00?l000D0oooo00<0003o0?l0003oool07P3oool00`3o0000oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool00`3o0000oooo0?ooo`040?ooo`060?l0003o
ool0oooo0?ooo`00o`00003o1@3oool01P000?l0oooo0?ooo`3o0000oooo0?l000T0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool01@3oool01@000?l0oooo0?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool0103o
ool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`<0
003o303oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3o
ool0203oool00`3o0000003o0?ooo`0C0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`00
0?l09`3oool0103o0000oooo0?ooo`3o000;0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool02@3oool0103o00000?l00?ooo`00o`040?ooo`030000o`3oool0oooo00D0oooo00@0o`00
0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00@0
o`000?ooo`3oool0o`002`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00003P3oool20?l0
00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool00?l0
00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
01L0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`030000o`3oool0oooo00L0oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01`3o
ool01P3o0000oooo0?ooo`3oool00?l00?l000@0oooo00<0003o0?ooo`3oool00P3oool01@00o`00
oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000l0oooo00@0o`000?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`060?ooo`030?l00000
o`00oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo0080oooo
00@0003o0?ooo`3oool0o`005`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo
0?ooo`060?ooo`04003o003oool0oooo0?l000@0oooo00D0003o0?ooo`3oool0oooo003o00050?oo
o`030000o`3o0000oooo01P0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`050?l0003oool0oooo0?ooo`00o`001P3oool00`3o0000oooo0?ooo`040?ooo`060?l0003oool0
oooo0?ooo`00o`00003o1@3oool01P000?l0oooo0?ooo`3o0000oooo0?l000T0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool01@000?l0oooo0?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool0103oool0
1@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0003o01@0oooo00<0o`000?ooo`3oool0=03oool01@000?l0oooo0?oo
o`3oool0003o02H0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00T0oooo00@0o`00003o003oool00?l0103oool00`000?l0oooo0?ooo`050?oo
o`040?l0003oool0oooo0000o`D0oooo00<0o`000?ooo`3oool04P3oool20000o`@0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0000>0?ooo`03
0?l0003oool0o`000080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`04
003o003oool0oooo003o00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo01L0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<0
0?l00?ooo`3oool01`3oool0103o0000oooo0?ooo`00o`020?ooo`050?l0003oool0oooo0?ooo`00
0?l01@3oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00<0oooo00@0o`000?oo
o`3oool0o`003`3oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo00H0oooo00<0
o`00003o003oool01@3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D00?l00?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool05@3oool00`000000
oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo02D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`04003o003oool0oooo0?l000@0
oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`030000o`3o0000oooo01H0oooo0P00o`040?oo
o`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`030?l0003oool0
oooo00@0oooo00H0o`000?ooo`3oool0oooo003o00000?l50?ooo`030000o`3oool0o`000080oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo
00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0o`000?ooo`3o
00000`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000@0oooo0P000?l50?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0003o4`3oool00`3o0000oooo0?ooo`0d0?oo
o`050000o`3oool0oooo0?ooo`000?l09P3oool0103o0000oooo0?ooo`3o000:0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool0103o00000?l00?ooo`00o`040?ooo`030000
o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<00?l00?oo
o`3oool00`3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00L0003o0?ooo`3oool0oooo0?l0
003oool0o`0000h0oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00h0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0G0?ooo`05003o003oool0oooo0?oo
o`00o`000P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00D0003o0?oo
o`3oool0oooo003o00040?ooo`03003o003oool0oooo00L0oooo00@0o`000?ooo`3oool00?l00P3o
ool01@3o0000oooo0?ooo`3oool0003o00D0oooo00H00?l00?ooo`3oool0003o0?ooo`3o00070?oo
o`80o`00403oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo00H0oooo00<00?l0
0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D00?l00?ooo`3oool0oooo
0000o`020?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo
0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo02<0oooo0`00
0?l40?ooo`030?l0003oool0oooo00L0oooo00@00?l00?ooo`3oool0o`00103oool01@000?l0oooo
0?ooo`3oool00?l000H0oooo00<0003o0?l0003oool05@3oool00`00o`00oooo003o00040?ooo`03
0?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`030?l0003oool0oooo
00@0oooo00H0o`000?ooo`3oool0oooo003o00000?l50?ooo`030000o`3oool0o`0000<0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01@0oooo00<0
0?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0o`000?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000oooo0080oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo0P00o`030?ooo`030000
o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`0B0?ooo`030?l0003oool0oooo03<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00@0o`00003o003oool00?l0103oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`0A0?ooo`040000o`3oool0oooo0000o`<0oooo00D0
o`000?ooo`3oool0oooo0?l0000;0?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0
oooo0000o`050?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0000>0?ooo`030?l0003oool0
o`000080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0
oooo0080oooo00@00?l00?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo01P0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`000?l70?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool00?l01P3oool00`00o`00oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`00o`000P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00H00?l0
0?ooo`3oool0oooo0000o`3o00070?ooo`80o`00403oool00`3o0000oooo0?l0000:0?ooo`030?l0
003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00L00?l00?ooo`3oool0oooo0000o`3oool0o`0001P0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool05@3oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo
0280oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`070?ooo`04003o003oool0
oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3o
0000oooo01D0oooo00@00?l00?ooo`3oool00?l00`3oool00`3o0000oooo0?ooo`030?ooo`050?l0
003oool0oooo0?ooo`00o`001P3oool00`3o0000oooo0?ooo`040?ooo`060?l0003oool0oooo0?oo
o`00o`00003o1@3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<00?l0
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`040000o`3o0000oooo0?l00080oooo00<0
003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`000?l90?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool00P3oool2003o00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool01@3o00000?l0
0?ooo`3oool00?l000@0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00<0o`000?ooo`3oool04@3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0
oooo0?ooo`000?l01@3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0oooo00X0oooo
00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00/0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?l000060?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool0603oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0000
o`L0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0
oooo00D0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`050?l0003oool0oooo0?ooo`000?l0
1@3oool01P00o`00oooo0?ooo`3oool0003o0?l000P0oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?l0000:0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0o`000?ooo`0G
0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`040?ooo`03003o003o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo
00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo0200oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool01`3oool01000o`00oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo
00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?l0000D0?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo003o00H0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0
003oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool04`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`800?l0103oool00`000?l0oooo0?ooo`070?oo
o`040000o`3o0000oooo0?l00080oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0000o`0:
0?ooo`030?l0003oool0oooo0100oooo00H0003o0?ooo`3oool00?l00?ooo`00o`020?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0340oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0D0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool01P3o00000?l00?ooo`3oool00?l00?l0
0080oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00@0
0?l00?ooo`3oool0003o1`3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo00X0oooo
00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00X0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?l000060?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool05`3oool00`00o`00oooo0?ooo`030?ooo`04003o003oool0oooo0000
o`L0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0
oooo00D0oooo00@0o`000?ooo`3oool00?l00`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo
00H00?l00?ooo`3oool0oooo0000o`3o000J0?ooo`80o`002P3oool00`3o0000oooo0?ooo`050?oo
o`03003o003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03003o003oool0
oooo0080oooo00<0003o0?l0003oool0603oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003o
ool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`050?l0003o
ool0oooo0?ooo`3o0000303oool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo
000m0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0A0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`05003o
003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00<0
oooo00<0003o0?ooo`3o00004`3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?oo
o`3o00001P3oool00`3o0000oooo003o00070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo1@3o000<0?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00/0oooo0P00o`040?ooo`030000o`3oool0oooo00L0oooo00H0003o0?l0
003oool0oooo0?l000000?l<0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`3oool0403o
ool01P000?l0oooo0?ooo`00o`00oooo003o0080oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo0P000?l<0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00H0o`00003o003oool0oooo003o003o00020?ooo`030000o`3oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`040?ooo`04003o003oool0oooo0000o`L0oooo00<0003o0?ooo`3o0000
0`3oool00`3o0000oooo0?ooo`0:0?ooo`060?l0003oool0oooo0?l0003oool0003o2`3oool00`00
0?l0oooo0?ooo`090?ooo`03003o003oool0oooo00H0oooo00<00?l00?l0003oool01P3oool00`3o
0000oooo0?ooo`0<0?ooo`800?l0103oool00`000?l0oooo0?ooo`0G0?ooo`03003o003oool0oooo
00<0oooo00@00?l00?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0
oooo003o00H0oooo00<00?l00?ooo`3oool01@3oool0103o0000oooo0?ooo`00o`030?ooo`050?l0
003oool0oooo0?ooo`000?l01@3oool01P00o`00oooo0?ooo`3oool0003o0?l001X0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo0080oooo00<0003o0?l0003oool0603o
ool0103o0000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`00o`00
oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo000R0?ooo`800000103oool2000000@0oooo
0P00000=0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0?0?ooo`80003o1`3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo00D00?l00?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool0103o
0000003o0?ooo`3o000A0?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l0
00060?ooo`030?l0003oool00?l000L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00`0oooo1@3o00040?ooo`030?l0003oool0oooo00X0oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool02@3oool01000o`00oooo0?ooo`00o`030?ooo`030000o`3oool0oooo00L0oooo
00H0003o0?ooo`3oool0oooo0?l000000?l<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool03`3oool01P000?l0oooo0?ooo`00o`00oooo003o0080oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0<03o
ool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`3o0000403oool00`000?l0oooo
0000o`0;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`00o`000P3oool01@00o`00o`00
0?ooo`3oool0003o00P0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00X0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o0000oooo
00@0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`04003o003oool0oooo
0000o`L0oooo00<0003o0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0:0?ooo`060?l0003oool0
oooo0?ooo`3o0000003o2`3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo
00<00?l00?l0003oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`800?l000<0oooo003o003oool0
0P3oool00`000?l0oooo0?ooo`0H0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`000?l0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool00?l000H0oooo00<00?l00?ooo`3oool0
1@3oool0103o0000oooo0?ooo`00o`030?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool01P00
o`00oooo0?ooo`3oool0003o0?l001X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`040?ooo`030?l00000o`00oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03003o
003oool0oooo0080oooo00<0003o0?l0003oool0603oool0103o0000oooo0?ooo`3o00080?ooo`03
0?l0003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l0000:0?ooo`050?l0003oool0oooo
0?ooo`3o00002`3oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo000Q0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo00/0oooo0P000?l?0?ooo`030000o`3oool0oooo00L0oooo00D0
003o0?ooo`3oool0oooo0?l000080?ooo`05003o003oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00@0o`000000o`3oool0o`004@3oool00`00
o`00oooo0?ooo`030?ooo`04003o003oool0oooo0?l000L0oooo00<0o`000?ooo`00o`001`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool0
0`000?l0o`000?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`030000o`3oool0oooo00L0oooo00D0o`000000o`3oool0oooo0000o`0=0?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`060000
o`3oool0oooo003o003oool00?l00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
02<0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0o`0000l0oooo00@0003o
0?ooo`3oool0003o2P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool00?l00080oooo00D0
0?l00?l0003oool0oooo0000o`070?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0?l0000:0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool01000o`00
oooo0?ooo`000?l70?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`020?ooo`030?l000000?l0oooo00X0oooo00<0003o0?ooo`3oool0203oool00`00
o`00oooo0?ooo`070?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool2003o
00@0oooo00@00?l00?ooo`3oool0003o6P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
003o00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo003o00070?ooo`03003o003oool0
oooo00@0oooo00<0o`000?ooo`00o`00103oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00H0
0?l00?ooo`3oool0oooo0000o`3o000W0?ooo`030?l0003oool0oooo00<0oooo00<0o`00003o003o
ool01P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool00P3oool00`00
0?l0o`000?ooo`0H0?ooo`030?l0003oool0o`0000T0oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo003o00020?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l0000;
0?ooo`03003o003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00240oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`L00000703oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0003o00l0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3o
ool0o`0000P0oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo
00<00?l00?ooo`3oool00P3oool01@3o0000oooo0000o`3oool0o`0000d0oooo00@0o`000?ooo`3o
ool00?l01P3oool01000o`00oooo0?ooo`3o00070?ooo`030?l0003oool00?l000L0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?l0003oool0103oool01`3o0000oooo0?ooo`3oool00?l00?ooo`3o0000603oool00`3o0000oooo
0?ooo`080?ooo`03003o003oool0oooo00X0oooo00D00?l00?ooo`3oool0oooo0?l000080?ooo`03
0?l0003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo
00L0oooo00D0o`000000o`3oool0oooo0000o`0=0?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool02@3oool20?l000@0oooo00H0003o0?ooo`3oool00?l00?ooo`00o`020?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20?l001/0oooo00<0003o0?ooo`3oool0
203oool01@000?l0oooo0?l0003oool0o`0000h0oooo00D0003o0?ooo`3oool0oooo0000o`090?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`00o`000P3oool01@00o`00o`000?ooo`3oool0
003o00L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00H0oooo00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l00000
0?l0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo0000o`L0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0080oooo00<0o`000000o`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`03003o
003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`800?l0
1P3oool01000o`00oooo0?ooo`000?lJ0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`00
0?l01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`00o`00oooo00L0oooo00<00?l00?ooo`3o
ool0103oool00`3o0000oooo003o00040?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool01P00
o`00oooo0?ooo`3oool0003o0?l002L0oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?oo
o`060?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`020?ooo`030000
o`3o0000oooo01P0oooo00<0o`000?ooo`3o00002@3oool00`3o0000oooo0?ooo`020?ooo`03003o
003oool00?l00080oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000X0
oooo00<00?l00?ooo`3oool04P3oool700000200oooo000Q0?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`D00?l000<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0000o`0>0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3o
ool0o`002@3oool01@00o`00oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0003o0080oooo00<0o`000?ooo`3oool02@3oool2
0?l000030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3o00001`3oool00`3o0000oooo003o0007
0?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3oool0003o003o00070?ooo`030000o`3o
ool0oooo00<0oooo00H0o`000?ooo`3oool0oooo003o003o000H0?ooo`80003o00<0o`000?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`0:0?ooo`05003o003oool0oooo0?ooo`3o0000203oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0003o2P3oool0
1@3o0000003o0?ooo`000?l0o`0000`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0o`0000<0oooo00H0003o0?ooo`3oool00?l00?ooo`00o`020?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l01P3oool0103o0000oooo0?l0003o000I0?oo
o`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3o0000oooo0?l0000=0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
0?l000@0oooo00@00?l00?ooo`3oool0003o1`3oool00`3o0000oooo0?ooo`040?ooo`050000o`3o
ool0oooo0?ooo`3o0000203oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000003o0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o
ool01@3oool01000o`00oooo0?ooo`000?l80?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0oooo00/0oooo00<0003o0?oo
o`3oool01P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo00<0o`000?oo
o`3oool00`3oool2003o00P0oooo00<00?l00?ooo`000?l06P3oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0003o00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l00?l00?ooo`070?oo
o`03003o003oool0oooo00<0oooo00@0o`000?ooo`3oool00?l0103oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00H00?l00?ooo`3oool0oooo0000o`3o000W0?ooo`030?l0003oool0oooo00<0
oooo00<0o`00003o003oool01P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0H0?ooo`80o`002@3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool00?l00080oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`3o000;
0?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool00240oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0240oooo00<0
003o003o0000o`000P00o`070?ooo`040000o`3oool0oooo0000o`d0oooo00<0003o0?ooo`3oool0
203oool010000?l0oooo0?ooo`3o00090?ooo`05003o003oool0oooo0?ooo`3o00000`3oool00`00
0?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00H0o`000?ooo`3oool0003o0?ooo`3o
000;0?ooo`030?l0003oool00?l000T0oooo00<00?l00?ooo`3o00001`3oool00`3o0000oooo003o
00060?ooo`030?l0003oool0oooo00H0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`060?ooo`03
0000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool00?l00?l0000H0?ooo`040000o`3oool0003o
0000o`P0oooo00<00?l00?ooo`3oool02`3oool01000o`00oooo0?ooo`3o00080?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l:0?ooo`050?l0
00000?l0oooo0000o`3o0000303oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00L0
oooo00@0o`000?ooo`3oool0o`000`3oool010000?l0oooo0?ooo`00o`020?ooo`03003o003oool0
003o00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`020?ooo`80o`005P3oool0
0`000?l0oooo0?ooo`090?ooo`050000o`3oool0o`000?ooo`3o00003@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo003o
00040?ooo`04003o003o0000oooo0000o`L0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo
0?ooo`3oool0o`0000P0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo
00D0oooo00@0o`000?ooo`3oool0003o103oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0
oooo00H0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0?ooo`0;0?ooo`030000o`3o
ool0oooo00H0oooo00<00?l00?ooo`3oool01`3oool00`3o00000?l00?ooo`080?ooo`030?l0003o
ool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0000o`0J0?ooo`03003o003o
ool0oooo00D0oooo00@00?l00?ooo`3oool0003o103oool00`000?l0oooo0?ooo`060?ooo`030000
o`00o`00oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo003o00050?ooo`050?l0
003oool0oooo0?ooo`000?l01P3oool01@00o`00oooo0?ooo`3oool0003o02L0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool00?l00080oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?l0000;0?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool0
0280oooo0P00000:0?ooo`8000003@3oool00`000000oooo0?ooo`0Q0?ooo`050000o`3oool0oooo
0?ooo`00o`001`3oool010000?l0oooo0?ooo`000?l<0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3o0000203oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
1@3oool00`00o`00oooo0?ooo`020?ooo`060?l0003oool0oooo0000o`3oool0o`002P3oool0103o
0000oooo0?ooo`00o`090?ooo`03003o003oool0o`0000L0oooo00<0o`000?ooo`00o`001P3oool0
0`3o0000oooo0?ooo`060?ooo`060?l0003oool0oooo0000o`3oool00?l01P3oool00`000?l0oooo
0?ooo`040?ooo`050?l0003oool0oooo003o003o00005`3oool01@000?l0oooo0?ooo`3o0000oooo
00<0003o1@3oool00`00o`00oooo0?ooo`0;0?ooo`04003o003oool0oooo0?l000T0oooo00<0o`00
0?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0003o00X0oooo00D0o`00
0?ooo`000?l0oooo0?l0000<0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool01`3o
ool0103o0000oooo0?ooo`3o00030?ooo`040000o`3oool0oooo003o0080oooo00<00?l00?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool01`3oool010000?l0oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00@0oooo0P3o00090?oo
o`80003o2@3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3o0000oooo0?l000`0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00@0o`00
0?ooo`3oool0003o3`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool00?l000@0oooo00@0
0?l00?l0003oool0003o1`3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000L0
oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l70?ooo`040?l0003oool0oooo
0000o`D0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
003o00P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?l0003oool02`3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0
oooo00P0oooo00<0o`00003o003oool0203oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
oooo00P0oooo00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
003o00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l00?l00?ooo`080?ooo`03003o003oool0
oooo0080oooo00<0o`000?ooo`00o`001@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00D0
0?l00?ooo`3oool0oooo0000o`0W0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
1P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<00?l00?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo00T0oooo00L0o`000?ooo`3oool0oooo003o003oool0
0?l00080oooo00<0o`000?ooo`3oool02@3oool00`3o00000?l00?l0000:0?ooo`03003o003oool0
oooo01T0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0<
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o0000203oool00`00o`00oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`80oooo00<0o`000?ooo`3oool01P3oool4003o00030?l0003oool0oooo00L0oooo
00<00?l00?ooo`3o00001`3oool00`3o0000oooo003o00060?ooo`030?l0003oool0oooo00H0oooo
00H0o`000?ooo`3oool0003o0?ooo`00o`060?ooo`030000o`3oool0oooo00D0oooo00@0o`00003o
003oool00?l05`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo0P000?l30?ooo`03003o003o
ool0oooo00/0oooo00@00?l00?ooo`3oool0o`002@3oool00`3o0000oooo0?ooo`040?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`000?l02P3oool00`3o0000oooo0000o`020?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`050?l0
003oool0oooo0?ooo`3o0000103oool00`000?l0oooo003o00020?ooo`03003o003oool0003o00P0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00H0oooo0P3o00060?oo
o`030000o`3oool0oooo0080003o1P3oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0oooo
0?ooo`3o00002`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0203oool0103o0000oooo0?ooo`000?l@0?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool00`00o`00oooo0?ooo`020?ooo`04003o003o0000oooo0000o`L0oooo00<0o`000?ooo`3o
ool01@3oool010000?l0oooo0?ooo`3o00070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`000?l01`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`070?ooo`03003o003oool0003o00L0oooo00<0o`000000o`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool02`3oool0
0`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`00o`002@3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00P0oooo00<00?l00000o`3oool0303oool0
0`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`000?l0103oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo003o00050?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool01@00o`00oooo0?oo
o`3oool0003o02P0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo02@0
oooo00L0o`000?ooo`3oool0oooo003o003oool00?l00080oooo00<0o`000?ooo`3oool02@3oool0
0`3o00000?l0003o000:0?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3oool07P3oool0
03d0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3o0000203oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo
0000o`D0oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`040?l0003o
ool0oooo0?ooo`D00?l000<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`03003o
003oool0o`0000L0oooo00<0o`00003o003oool01P3oool00`3o0000oooo0?ooo`060?ooo`060?l0
003oool0oooo0000o`3oool00?l01@3oool00`3o0000003o0?ooo`060?ooo`040?l00000o`00oooo
003o01L0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`00o`00
3@3oool00`00o`00oooo0?l0000:0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0000o`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
0P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`00o`000P3oool00`00o`00003o0?ooo`080?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o0?oo
o`3oool02`3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l04@3oool0
1@000?l0oooo0?ooo`3oool0o`000080oooo00<00?l00?ooo`3oool00P3oool01000o`00o`000?oo
o`000?l70?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000
oooo0?ooo`040?ooo`030?l000000?l0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0000o`070?oo
o`030?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3o0000oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`060?oo
o`050?l0003oool0oooo0?ooo`00o`001@3oool20000o`030?ooo`3o0000oooo00<0oooo00<00?l0
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool01P3oool00`00o`00oooo0000o`040?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool00?l000D0oooo00D0o`00
0?ooo`3oool0oooo0000o`060?ooo`05003o003oool0oooo0?ooo`000?l0:03oool00`3o0000oooo
0?ooo`020?ooo`03003o003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool0903oool01`3o0000oooo0?ooo`3oool00?l0
0?ooo`00o`000P3oool00`3o0000oooo0?ooo`090?ooo`040?l00000o`00o`00003o00T0oooo00<0
0?l00?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?l00008
0?ooo`03003o003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o1@3oool00`00o`00oooo0?oo
o`020?ooo`040?l0003oool0oooo0000o`<0oooo00@0o`000?ooo`3oool00?l0103oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool01P3oool00`3o0000
0?l00?ooo`060?ooo`030?l0003oool0oooo00H0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`05
0?ooo`030?l0003oool0003o00H0oooo00@0o`00003o003oool00?l05P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o000=0?ooo`03003o
003oool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0003o00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`070?l0
003oool0oooo0?ooo`000?l0oooo003o00020?ooo`03003o00000?l0oooo00P0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`050?ooo`80003o00<0oooo0000o`3oool03@3oool01@3o0000003o0?ooo`3o
ool0o`0000X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`000?l04@3oool01@000?l0oooo0?ooo`3oool0o`000080oooo
00<00?l00?ooo`3oool00P3oool01000o`00o`000?ooo`000?l70?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo00H0
oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<00?l00?oo
o`3oool0203oool00`00o`00003o0?ooo`070?ooo`030?l0003oool0003o00D0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo00/0oooo00<0003o0?oo
o`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<00?l00?oo
o`3oool00`3oool00`000?l0oooo0000o`020000o`<0oooo00<00?l00?ooo`3oool02@3oool00`00
0?l00?l00?ooo`0;0?ooo`03003o003oool00?l000X0oooo00<00?l00?ooo`3oool01`3oool00`00
o`00oooo0000o`040?ooo`030000o`3oool0oooo00H0oooo00<00?l00000o`3oool0203oool00`00
o`00oooo0?ooo`020?ooo`030?l00000o`00oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`06
0?ooo`05003o003oool0oooo0?ooo`000?l0:03oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool0903oool0103o0000oooo0?ooo`00o`020?ooo`04003o003oool0oooo0?l0
00/0oooo00D0o`00003o003o0000oooo003o00070?ooo`03003o003oool0oooo01X0oooo00<00000
0?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`030?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?oo
o`040000o`3oool0oooo003o00X0oooo00<0003o0?ooo`3o0000203oool00`00o`00oooo0?ooo`03
0?ooo`040?l0003oool0oooo0000o`H0oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`040000
o`3oool0oooo0?l00080oooo00D00?l00?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo
00L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`050?ooo`030?l0003oool0003o00L0oooo00<0
0?l00?l00000o`005P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00@0
003o0?ooo`3oool00?l03@3oool00`00o`00oooo0?l0000:0?ooo`030?l0003oool0oooo0080oooo
00<00?l00?ooo`3oool01`3oool00`00o`00oooo0000o`090?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`00o`000P3oool00`00
o`00003o0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0o`002`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0P000?l=0?ooo`030?l0003oool0
003o00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0
oooo0?ooo`3o00002`3oool00`3o0000003o0?ooo`0B0?ooo`060000o`3oool0oooo0?l0003oool0
0?l01@3oool01000o`00o`000?ooo`000?l70?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3o00001P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00o`002P3oool0
0`00o`00003o0?ooo`070?ooo`030?l0003oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo00`0oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`040?ooo`80o`001@3oool00`00o`00oooo0?ooo`030?ooo`050000o`3oool0
oooo0?ooo`3o00000`000?l00`00o`00oooo0?ooo`090?ooo`030000o`00o`00oooo00/0oooo00<0
0?l00?ooo`00o`002P3oool00`00o`00oooo0?ooo`080?ooo`03003o00000?l0oooo0080oooo00<0
003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`090?ooo`06003o003oool0oooo0?ooo`3o0000
0?l01P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00D00?l00?ooo`3oool0oooo0000o`0X
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000003o0?ooo`0T0?ooo`040?l0003o
ool0oooo003o00<0oooo00<00?l00?ooo`3o00002`3oool00`00o`00oooo0?l000020?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`00?@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo00@00?l00?ooo`3oool0003o
1P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00800?l02P3oool00`000?l0oooo
0?l000080?ooo`03003o003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o1P3oool01@00o`00
oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0o`000P3oool01@00o`00oooo0?ooo`3o
ool0o`0000H0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l20?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`000?l01`3oool00`00o`00o`00003o000F0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo003o000?0?ooo`03003o
003o0000oooo00X0oooo00@0o`000?ooo`3oool00?l02`3oool00`00o`00003o0?ooo`080?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool01P3o0000oooo0?ooo`3oool0003o
003o00<0oooo00<00?l00000o`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0
oooo0?l000`0oooo00@0o`000?ooo`3oool0003o6@3oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`00
00`0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?l000020?ooo`03003o003oool0oooo
00<0oooo00@00?l00?ooo`3o0000003o1`3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
oooo0?l000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`03003o003oool0oooo00P0oooo
00<00?l00000o`3oool01P3oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?l0000<0?ooo`030000o`3oool0oooo00<0
oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`80003o2@3oool00`000?l0oooo003o000;0?oo
o`05003o003oool0oooo0?ooo`00o`002@3oool00`00o`00oooo0?ooo`080?ooo`03003o00000?l0
oooo0080oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`090?ooo`06003o003oool0
oooo0?l0003oool00?l01P3oool0103o0000oooo0?ooo`000?l70?ooo`05003o003oool0oooo0?oo
o`000?l0:03oool01P3o0000oooo0?ooo`3oool0o`00003o00P0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`03003o003oool0oooo0080oooo00<0o`000000o`3oool0903oool0103o0000oooo
0?ooo`00o`030?ooo`03003o003o0000oooo00/0oooo00<00?l00?ooo`3o00000`3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo0000o`H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo003o00020?ooo`03003o003oool0oooo00P0
oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo0000
o`H0oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`060000o`3oool0oooo0?ooo`3o00000?l0
0`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0
003o0P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0003o00L0oooo00<00?l00?l00000
o`005P3oool00`000?l0oooo0?ooo`040?ooo`070?l0003oool0oooo0?ooo`000?l0oooo003o000?
0?ooo`03003o003o0000oooo00X0oooo00@0o`000?ooo`3oool00?l02`3oool00`00o`00003o0?oo
o`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?oo
o`000?l00?l000<0oooo00<00?l00000o`3oool01`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0o`0000d0oooo00@0o`000?ooo`3oool0003o6@3oool00`3o0000oooo0?ooo`020000o`03
0?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l0000<0?ooo`03
0000o`3o0000oooo0180oooo00<0003o0?ooo`3o00000P3oool00`00o`00oooo0?ooo`030?ooo`04
003o003oool0o`000000o`H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?l000040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool01P3oool00`3o0000oooo0?ooo`040?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`00o`00oooo0?ooo`080?ooo`03003o00000?l0
oooo00H0oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00@0003o0?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`030?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00H0o`000?ooo`3oool0oooo003o003oool20000o`L0oooo00@0003o0?oo
o`3oool00?l02P3oool01@00o`00oooo0?ooo`3oool00?l000T0oooo00<00?l00?ooo`3oool0203o
ool00`00o`00oooo0000o`020?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`000?l02@3o
ool01@00o`00oooo0?ooo`3o00000?l000L0oooo00@0o`000?ooo`3oool0003o1`3oool01P00o`00
oooo0?ooo`3oool0o`000000obL0oooo00H0o`000?ooo`3oool0oooo0?l00000o`080?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01`00o`00oooo0?ooo`3oool0o`000?ooo`000?l09@3oool0
103o0000oooo0?ooo`00o`030?ooo`03003o003o0000oooo00/0oooo00<00?l00?l0003oool0103o
ool01@00o`00oooo0?ooo`3oool00?l001d0oooo00<000000?ooo`3oool07P3oool003d0oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo0000o`H0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo003o00020?ooo`03003o003oool0oooo00P0oooo
00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`H0
oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`060000o`3oool0oooo0?ooo`3o00000?l00`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o
0P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0003o00L0oooo00@00?l00?l0003oool0
0?l0503oool00`000?l0oooo0?ooo`050?ooo`070?l0003oool0oooo0?ooo`000?l0oooo003o000?
0?ooo`03003o003oool0oooo00X0oooo00@0o`000?ooo`3oool00?l02`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0@0?ooo`050?l0003oool0oooo0?ooo`3o0000203oool01@3o0000oooo0?ooo`000?l00?l000@0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00d0
oooo00<0o`000000o`3oool06@3oool00`3o0000oooo0?ooo`020?ooo`80003o1`3oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3oool0o`0000`0oooo00<0003o0?l0003oool04`3oool01@000?l0
o`000?ooo`3oool00?l000D0oooo00@00?l00?ooo`3o0000003o1P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?l00006
0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`000P3oool00`00o`00oooo0?oo
o`090?ooo`03003o00000?l0oooo00H0oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0o`00303oool00`000?l0
oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo003o00030?oo
o`80003o1@3oool010000?l0oooo0?ooo`00o`090?ooo`03003o003oool0oooo00<0oooo00<00?l0
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0003o0080oooo00<0003o
0?ooo`3oool01`3oool00`00o`00oooo0000o`090?ooo`05003o003oool0oooo0?l00000o`001`3o
ool0103o0000oooo0?ooo`000?l70?ooo`06003o003oool0oooo0?ooo`3o0000003o:03oool01@3o
0000oooo0000o`3o00000?l000P0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`06003o003o
ool0oooo0?l0003oool0003o9P3oool00`3o0000oooo003o00030?ooo`03003o003o0000oooo00/0
oooo00<00?l00?l0003oool01@3oool01000o`00oooo0?ooo`00o`0M0?ooo`030000003oool0oooo
01h0oooo000m0?ooo`D00000803oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0003o00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo003o00040?ooo`03003o003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo0000
o`H0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?l00000o`000P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o
0P3oool00`00o`00oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`D0oooo00D00?l00?ooo`3o
ool0oooo003o000D0?ooo`030000o`3oool0oooo00D0oooo00L0o`000?ooo`3oool0oooo0000o`3o
ool00?l000l0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo003o000<0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo0100oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`050?l0003oool0oooo0000o`00
o`00103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003o
ool03@3oool00`3o0000003o0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool01@3oool20000o`@0oooo00<0003o0?ooo`3oool0303oool00`000?l0o`000?ooo`0:0?ooo`03
0000o`3oool0o`0001@0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o003o0000003o
00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`060?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo003o000;0?ooo`03003o00000?l0oooo00H0oooo00D0o`000?ooo`3oool0oooo
0000o`050?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`3oool0103oool010000?l0
oooo0?ooo`3o000<0?ooo`030000o`3oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l0000:
0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool00?l000D0oooo0P000?l30?ooo`040000o`3oool0oooo003o00T0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00X0oooo00D00?l00000o`3oool0
oooo0000o`090?ooo`03003o003oool0003o00X0oooo00@00?l00?ooo`3o00000?l01`3oool0103o
0000oooo0?ooo`000?l70?ooo`06003o003oool0oooo0?l0003oool0003o:03oool0103o0000oooo
0000o`00o`090?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool01P00o`00oooo0?ooo`3o0000
oooo0000obH0oooo00<0o`000?ooo`00o`000`3oool00`00o`00o`000?ooo`0;0?ooo`03003o003o
0000oooo00H0oooo0P00o`0J0?ooo`D00000803oool003d0oooo00<000000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`040?ooo`03003o00000?l0oooo00L0oooo00<0003o0?ooo`3oool0103oool0
0`000?l00?l00?ooo`040?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`H0oooo00D00?l00?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`00o`000P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`00o`00203oool00`00o`00oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`020?oo
o`040?l0003oool0oooo0000o`D0oooo00D00?l00?ooo`3oool0oooo003o000D0?ooo`030000o`3o
ool0oooo00H0oooo00H0o`000?ooo`3oool0oooo0000o`00o`0?0?ooo`03003o003oool0oooo00X0
oooo00<0o`000?ooo`00o`00303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo0?l0
00T0oooo00D0o`000?ooo`3oool0003o003o00040?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`000?l02P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o0000oooo00X0oooo00<0o`000?ooo`3o00002`3o
ool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0003o0000o`80oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l001<0oooo00D0003o0?ooo`3o
ool0oooo003o00060?ooo`03003o00000?l0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0o`000?ooo`020?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001@3oool0
0`3o0000oooo0?ooo`060?ooo`070000o`3oool0oooo0?ooo`3o0000oooo003o000<0?ooo`030000
o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`070?l0003oool0003o0?oo
o`000?l0oooo0?l000060?ooo`040000o`3oool0oooo0?l000d0oooo00D0003o0?ooo`3oool0oooo
003o00020?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00o`001`3oool30000o`<0oooo00<00?l00?ooo`3o
ool01P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o
ool02P3oool01@00o`00003o0?ooo`3oool0003o00P0oooo00@00?l00?ooo`3oool0003o2P3oool0
0`00o`00oooo003o00080?ooo`040?l0003oool0oooo0000o`L0oooo00H00?l00?ooo`3oool0o`00
0?ooo`000?lX0?ooo`040?l000000?l0003o003o00X0oooo00<0o`000?ooo`000?l01P3oool01P00
o`00oooo0?ooo`3o0000oooo0000obH0oooo00<0o`000?ooo`00o`000`3oool00`00o`00o`000?oo
o`0;0?ooo`03003o003o0000oooo00L0oooo00<00?l00?ooo`3oool0703oool00`000000oooo0?oo
o`0N0?ooo`00?@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<00?l0
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00@0o`00
0?ooo`3oool0003o1P3oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo00L0003o0?ooo`3oool0
oooo003o003oool0o`0000X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo003o00070?oo
o`03003o003o0000oooo00H0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l2
0?ooo`03003o003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool01@00o`00oooo0?oo
o`3oool00?l001<0oooo00<0003o0?ooo`3oool01`3oool01P3o0000oooo0?ooo`3oool0003o003o
00l0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo003o000<0?ooo`030000o`00o`00oooo
00L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0100oooo00@0o`000?ooo`3oool0o`002P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`00
o`00oooo00L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`050?l0003o
ool0oooo0?ooo`000?l02@3oool00`3o0000003o0?ooo`0=0?ooo`030000o`3o0000oooo00T0oooo
00@0o`000?ooo`3oool0o`002`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?oo
o`80003o3`3oool00`3o0000003o0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o00004`3oool0
10000?l0oooo0?ooo`00o`070?ooo`03003o00000?l0oooo00H0oooo00<0o`000?ooo`3oool02@3o
ool01@000?l0o`000?ooo`3oool0o`0000P0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0?l0003oool0oooo00L0oooo00H0003o0?ooo`3oool0o`000?ooo`00o`0<0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0
oooo0?ooo`80003o1P3oool010000?l0oooo0?ooo`3o000=0?ooo`040000o`3oool0oooo003o0080
oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00@0o`000?ooo`3oool00?l02P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
00X0oooo00@00?l00000o`3oool0003o2@3oool01000o`00oooo0?ooo`000?l:0?ooo`03003o003o
ool00?l000T0oooo00<0o`000?ooo`000?l0203oool01@00o`00oooo0?l0003oool0003o02P0oooo
00@0o`000000o`000?l00?l02P3oool00`3o0000oooo0000o`060?ooo`04003o003oool0oooo0?l0
0080oooo00<0003o0?ooo`3oool08`3oool00`3o00000?l00?ooo`030?ooo`03003o003o0000oooo
00/0oooo00<00?l00?l0003oool09P3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`00o`00oooo00H0oooo00<00?l00?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o1P3oool01@00
o`00oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo003o00020?l000X0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo003o00070?ooo`03003o003o0000oooo00D0oooo00<0
o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0oooo0080oooo
00@0o`000?ooo`3oool0003o1@3oool01@00o`00oooo0?ooo`3oool00?l001<0oooo00<0003o0?oo
o`3oool01`3oool01P3o0000oooo0?ooo`3oool0003o003o00l0oooo00<00?l00?ooo`3oool02`3o
ool00`3o00000?l00?ooo`0;0?ooo`030000o`00o`00oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0140oooo0P3o000;0?ooo`040?l0003o
ool0oooo0000o`<0oooo00<0003o003o003oool01`3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0003o2P3oool00`3o0000003o0?ooo`0<0?ooo`04
0000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo003o000?0?ooo`030?l000000?l0
003o00T0oooo00D0003o0?ooo`3oool0oooo0?l0000B0?ooo`050?l000000?l0oooo0?ooo`00o`00
1`3oool00`00o`00003o0?ooo`060?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`3oool0
o`00203oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool01`3oool01P00
0?l0oooo0?ooo`3o0000oooo003o00`0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool00P3oool00`3o0000oooo0000
o`050?ooo`050000o`3oool0oooo0?ooo`3o0000303oool01P000?l0oooo0?ooo`00o`00oooo0?l0
00d0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo
003o00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00003o0?l000000?l90?ooo`04003o003o
ool0oooo0000o`X0oooo00<00?l00?ooo`00o`002@3oool00`3o0000oooo0000o`080?ooo`05003o
003oool0o`000?ooo`000?l0:03oool0103o0000003o0000o`00o`0:0?ooo`030?l0003oool0003o
00H0oooo00@00?l00?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`0S0?ooo`030?l00000o`00
oooo00<0oooo00<00?l00?l0003oool02`3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0
oooo01h0oooo000m0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool01@3oool00`00
0?l00?l00?ooo`070?ooo`030000o`3oool0o`000080oooo00<0003o0?ooo`3oool01`3oool00`00
o`00oooo0?ooo`050?ooo`030?l000000?l0oooo00H0oooo00<00?l00?ooo`3oool0103oool0103o
0000oooo0?ooo`000?l60?ooo`05003o003oool0oooo0?ooo`3o0000103oool01P000?l0oooo0?oo
o`3oool00?l00?l000`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo003o00070?ooo`03
003o003o0000oooo00D0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`000?l30?oo
o`05003o003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0
oooo0?ooo`00o`004`3oool00`000?l0oooo0?ooo`080?ooo`050?l0003oool0oooo0000o`00o`00
3P3oool00`3o0000oooo003o000<0?ooo`030?l00000o`00oooo00/0oooo00<0003o003o003oool0
1`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
4@3oool20?l000/0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l00?l00?ooo`060?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02@3oool0103o0000oooo0?ooo`000?l:0?oo
o`030?l0003oool0003o00`0oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`3o
ool2003o00d0oooo00@0o`000?ooo`3oool0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool0403oool01@3o0000003o0?ooo`3oool00?l000L0oooo00<00?l00000o`3o
00001P3oool00`3o0000oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000L0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00@0003o0?oo
o`3oool00?l0303oool00`000?l00?l00?ooo`050?ooo`030?l0003oool0oooo0080oooo00@0003o
0?ooo`3oool0oooo0P000?l00`3oool0o`000?ooo`020?ooo`040?l0003oool0oooo0000o`<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`050000o`3oool0oooo003o003o
00003`3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`00o`003`3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0;0?ooo`030000o`3o0000003o00T0oooo00D00?l00?ooo`3oool0oooo0000o`0:
0?ooo`800?l02@3oool00`3o0000oooo0000o`080?ooo`03003o003oool0o`000080oooo00<0003o
0?ooo`3oool09@3oool010000?l0o`000000o`00o`0:0?ooo`030?l0003oool0003o00H0oooo00@0
0?l00?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`0S0?ooo`030?l00000o`00oooo00@0oooo
00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo
000m0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o
00080?ooo`050000o`3oool0o`000?ooo`000?l02P3oool00`00o`00oooo0?ooo`040?ooo`030?l0
003oool0003o00H0oooo00<00?l00?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l60?ooo`04
003o003oool0oooo0?l000H0oooo00<0003o0?ooo`00o`003P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool00?l000L0oooo00<00?l00?l0003oool01@3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0003o00<0oooo00D00?l00?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00T0oooo00D0o`000?ooo`3oool00?l00000o`0>0?ooo`030?l0003oool00?l000`0oooo00<0
o`00003o003oool02`3oool00`000?l00?l00?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00X0oooo00@0
o`000?ooo`3oool0003o0`3oool00`000?l00?l00?ooo`060?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0000o`0:0?ooo`040?l0003oool0oooo0000o`/0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`060?l0003oool0oooo003o
003oool00?l03@3oool00`3o0000oooo0?ooo`030?ooo`80003o103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00h0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`070?ooo`03003o
00000?l0o`0000H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0o`000?l000080?ooo`030000
o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0o`002`3oool010000?l0oooo0?ooo`00o`0<0?oo
o`030000o`00o`00oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`030?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool20000o`030?ooo`000?l0oooo00<0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l00?l00?l0000@0?ooo`05003o003oool0oooo0?ooo`000?l01@3o
ool00`3o0000oooo003o000@0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0203o
ool01@00o`00oooo0?ooo`3oool00?l000h0oooo00<0003o0?l000000?l02@3oool01@00o`00oooo
0?ooo`3oool0003o00X0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0000o`080?ooo`03
003o003oool0o`000080oooo00<0003o0?ooo`3oool09@3oool010000?l0o`000000o`00o`0:0?oo
o`030?l0003oool0003o00H0oooo00@00?l00?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`0=
0?ooo`030000o`3oool0oooo01<0oooo00<0o`00003o003oool0103oool00`00o`00oooo0?ooo`09
0?ooo`03003o003oool0oooo02L0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool00?l000P0oooo00D0003o0?l0
003oool00?l00000o`0:0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`000?l01P3oool0
0`00o`00oooo0?ooo`050?ooo`040?l0003oool0oooo0000o`H0oooo00@00?l00?ooo`3oool0o`00
1P3oool00`000?l0oooo003o000>0?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0
0?l01P3oool00`00o`00o`000?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00
0?l00`3oool01000o`00oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`00o`001@3oool0
0`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo00X0oooo00@0o`000?ooo`00o`00003o3P3o
ool00`3o0000oooo003o000<0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`00o`001`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0803o
ool00`3o0000oooo0000o`030?ooo`030000o`00o`00oooo00H0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`090?ooo`03003o00000?l0oooo00T0oooo00@0o`000?ooo`3oool0003o
2`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00o`00
0P3oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo0P000?l00`3oool0003o
0?ooo`050?ooo`030?l0003oool0oooo00h0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`070?oo
o`03003o00000?l0o`0000H0oooo00<0o`000?ooo`3oool02`3oool00`000?l0o`000?ooo`070?oo
o`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0o`00303oool00`000?l0oooo003o000<
0?ooo`030000o`00o`00oooo00@0oooo00<0o`000?ooo`3oool0103oool20000o`D0oooo00@0o`00
0?ooo`3oool0o`001@3oool20000o`@0oooo00<0o`000?ooo`3oool02`3oool00`000?l00?l00?oo
o`0@0?ooo`04003o003oool0oooo0000o`H0oooo00<0o`000?ooo`00o`00403oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo00T0oooo00D00?l00?ooo`3oool0oooo003o000>0?ooo`03
003o00000?l0003o00T0oooo00D00?l00?ooo`3oool0oooo0000o`0:0?ooo`03003o003oool0oooo
00P0oooo00<0o`000?ooo`000?l0203oool00`00o`00oooo0?l000020?ooo`030000o`3oool0oooo
00@0oooo00<00?l00?ooo`3oool07P3oool010000?l0o`000000o`00o`0:0?ooo`030?l0003oool0
003o00H0oooo00@00?l00?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`80003o5@3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool09`3o
ool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
o`0000<0oooo00@0003o0?ooo`3oool00?l0203oool010000?l0oooo003o00000?l;0?ooo`03003o
003oool0oooo00<0oooo00<0o`000?ooo`000?l01P3oool00`00o`00oooo0?ooo`050?ooo`040?l0
003oool0oooo0000o`H0oooo00@00?l00?ooo`3oool0o`001P3oool00`000?l0oooo003o000?0?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool00?l01P3oool00`00o`00oooo0?l00005
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l00`3oool01000o`00oooo0?ooo`3o
00040?ooo`050000o`3oool0oooo0?ooo`00o`001@3oool00`00o`00oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00X0oooo00@0o`000?ooo`00o`00003o3P3oool00`3o0000oooo003o000<0?ooo`03
003o003oool0oooo00P0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`070?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0
003o00<0oooo00<0003o0?ooo`00o`001P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo00T0oooo00<0003o003o003oool02@3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0
003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o000:0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool20000o`H0oooo00<0o`000?ooo`3oool03@3oool01`3o0000oooo
0?ooo`3oool0003o0?ooo`00o`001`3oool00`00o`00003o0?l000060?ooo`030?l0003oool0oooo
00/0oooo1@000?l40?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00303oool0
0`000?l0oooo003o000<0?ooo`030000o`00o`00oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0o`0000L0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`00o`00oooo0100oooo00@00?l00?ooo`3oool0003o1P3o
ool00`3o0000oooo003o000@0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02P3o
ool01000o`00oooo0?ooo`00o`0>0?ooo`03003o00000?l0o`0000P0oooo00<00?l00?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l0
203oool00`00o`00oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0
7P3oool010000?l0o`000000o`00o`0:0?ooo`030?l0003oool0003o00H0oooo00@00?l00?ooo`3o
ool0o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080003o4`3oool01`00
o`00003o0000o`000?l0oooo0?l00000o`002`3oool00`00o`00oooo0?ooo`0W0?ooo`030000003o
ool0oooo01h0oooo000m0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3o0000o`000P3o
ool010000?l0oooo0?ooo`00o`070?ooo`040?l000000?l00?l00000o``0oooo00<00?l00?ooo`3o
ool00`3oool00`3o0000oooo0000o`060?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`00
0?l0203oool00`00o`00oooo0?l000060?ooo`030000o`3oool00?l000l0oooo00D0o`000?ooo`3o
ool0oooo0?l000030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o00001@3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0003o00<0oooo00@00?l00?ooo`3oool0o`001@3oool0
10000?l0oooo0?ooo`00o`050?ooo`03003o003oool0oooo00h0oooo00<0003o0?ooo`3oool02`3o
ool0103o0000oooo003o00000?l=0?ooo`040?l0003oool0oooo003o00`0oooo00<00?l00?l0003o
ool01`3oool20?l000050?ooo`000?l0oooo0?ooo`00o`001`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0000o`030?oo
o`030000o`3oool00?l000H0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool00?l000T0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`80003o1P3oool0
0`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo003o00030?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0=0?ooo`060?l0003oool0oooo0?ooo`000?l00?l0203oool00`00o`00003o
0?l000050?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3oool50000o`L0oooo
00<0o`000?ooo`3o0000303oool010000?l0oooo003o003o000;0?ooo`030000o`00o`00oooo00@0
oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?l0000=0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000000o`3oool04@3oool01000o`00oooo0?ooo`000?l60?ooo`030?l0003oool00?l0
0140oooo00@00?l00?ooo`3oool00?l03@3oool01000o`00oooo0?ooo`00o`0?0?ooo`030000o`3o
0000oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`000?l0203oool00`00o`00oooo0?l000030?ooo`030000o`3o
ool0oooo00<0oooo00<00?l00?ooo`3oool07@3oool010000?l0oooo0?l000000?l;0?ooo`030?l0
003oool0003o00H0oooo00@00?l00?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool40000o`80oooo00@0003o0?ooo`3o
00000?l02`3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo000m0?ooo`03
0000003oool0oooo02<0oooo00@0003o0?ooo`3o0000o`000P3oool01@000?l0oooo0?ooo`3oool0
0?l000H0oooo00@00?l00000o`3oool0003o3@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003o
ool0003o00H0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0000o`080?ooo`03003o003o
ool0o`0000H0oooo00<0003o0?ooo`00o`003`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo
00<00?l00?ooo`3oool0103oool00`00o`00oooo0?l000050?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`000?l00`3oool01000o`00oooo0?ooo`3o00050?ooo`040000o`3oool0oooo003o
00D0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l00000o`00003o
00d0oooo00@0o`000?ooo`3oool00?l01@3oool:0000o`H0oooo00D0o`000?ooo`3o0000oooo0000
o`020?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?oo
o`3oool00?l000<0oooo00<0o`000?ooo`3oool08@3oool00`00o`00003o0?ooo`020?ooo`030000
o`3oool00?l000H0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`070?ooo`040000
o`3oool0o`00003o00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`<0
003o2@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool02@3oool00`3o00000?l00?ooo`040?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0003o003o003o
ool01`3oool00`00o`00003o0?l000050?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3o
ool03P3oool00`3o0000oooo0?l0000=0?ooo`030000o`00o`00o`0000/0oooo00<0003o003o003o
ool0103oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0000d0oooo00<0o`000?ooo`3o
ool0203oool0103o0000oooo003o00000?lA0?ooo`04003o003oool0oooo0000o`H0oooo00<0o`00
003o003oool04@3oool01000o`00oooo0?ooo`00o`0>0?ooo`03003o003oool00?l000h0oooo00@0
o`000000o`3oool0o`001`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo
00<0o`000000o`3oool02@3oool00`3o0000oooo0000o`080?ooo`03003o003oool0o`0000<0oooo
00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o000N0?ooo`050000o`3oool0o`00003o0000
0?l02P3oool00`3o0000oooo0000o`070?ooo`03003o003oool0o`0000<0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo10000?l20?ooo`03
003o003o0000oooo0080oooo00<0003o0?l00000o`002`3oool00`00o`00oooo0?ooo`0W0?ooo`03
0000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo02<0oooo00H0003o0?ooo`3o0000
oooo0?l000000?l40?ooo`03003o003oool0oooo0080oooo0P00o`001@3o0000oooo0000o`3oool0
o`0000`0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000o`060?ooo`03003o003oool0
oooo00D0oooo00<0o`000?ooo`000?l0203oool00`00o`00oooo0?l000070?ooo`030000o`00o`00
oooo00l0oooo00@0o`000?ooo`3oool0o`000`3oool00`00o`00oooo0?ooo`030?ooo`04003o003o
ool0oooo0?l000D0oooo00<0o`000?ooo`3oool0203oool00`3o0000003o0?ooo`030?ooo`04003o
003oool0oooo0?l000D0oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00`0oooo00@0o`00003o003oool0003o303oool01@3o0000oooo0?ooo`3o
ool00?l000<0oooo00<0003o0?ooo`3oool01@3oool00`00o`00o`000000o`050?ooo`060?l0003o
ool0oooo0?ooo`3o0000003o0P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00L0
oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo0240oooo00<00?l00000
o`3oool00P3oool00`000?l0oooo003o00050?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool01P3oool01P000?l00?l00?ooo`3oool0o`00003o00L0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0000o`020000oa/0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`000?l00?l00?ooo`080?ooo`030000
o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0303oool2003o00l0oooo0P3o000>0?ooo`040000
o`3oool0oooo0?l000X0oooo00<0003o003o003oool0103oool00`3o0000oooo0?ooo`0<0?ooo`03
003o003o0000oooo00`0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo003o00000?lA0?oo
o`04003o003oool0oooo0000o`H0oooo00<0o`00003o003oool04@3oool00`00o`00oooo003o000?
0?ooo`800?l03`3oool0103o00000?l00?ooo`3o00070?ooo`03003o003oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool20000o`X0oooo00<0o`000?ooo`000?l0203oool00`00o`00oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`00o`007P3oool01@000?l0oooo0?oo
o`00o`00003o00X0oooo00<0o`000?ooo`000?l01`3oool00`00o`00oooo0?l000040?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20000o`H0oooo0P000?l60?ooo`03003o
003o0000oooo0080oooo00<0003o0?l00000o`002`3oool00`00o`00oooo0?ooo`0W0?ooo`030000
003oool0oooo01h0oooo000m0?ooo`D000008@3oool01P000?l0o`000?ooo`3oool0o`000000o`D0
oooo00H00?l00?ooo`00o`000?l00?ooo`3o00020?ooo`030000o`3oool0o`0000d0oooo00D00?l0
0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01P3o
ool00`3o0000oooo0000o`080?ooo`03003o003oool0o`0000L0oooo00<0003o003o003oool03`3o
ool0103o0000oooo0?ooo`3o00040?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0
o`001@3oool00`3o0000oooo0?ooo`080?ooo`030?l000000?l0oooo00@0oooo00<00?l00?ooo`3o
00001@3oool010000?l0oooo0?ooo`00o`060?ooo`03003o003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool0103o00000?l00?ooo`000?l;0?ooo`030?l0003oool0oooo0080oooo00D00?l0
0?ooo`3oool0oooo0000o`060?ooo`05003o003oool0o`000?ooo`000?l00`3oool00`3o0000oooo
0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo
0?ooo`070?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`0Q0?ooo`05
003o003oool0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo003o00030?ooo`030?l00000o`00oooo
00D0oooo00<0o`000?ooo`3oool00`3oool20000oal0oooo00@0o`000?ooo`3oool0o`003@3oool0
0`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0003o003o003oool0203oool0
0`000?l0oooo0?l000040?ooo`030?l0003oool0oooo00`0oooo0P00o`0@0?ooo`030?l0003oool0
oooo00`0oooo00D00?l00000o`3oool0oooo0?l000090?ooo`030000o`3oool00?l000<0oooo00<0
o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00D0
o`000?ooo`3oool00?l00000o`0A0?ooo`04003o003oool0oooo0000o`L0oooo00<00?l00?ooo`3o
ool0403oool00`00o`00oooo003o000@0?ooo`03003o003oool0oooo00d0oooo00@0o`000?ooo`00
o`00o`001`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0
00000?l02P3oool00`3o0000oooo0000o`080?ooo`03003o003oool0o`0000<0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo003o000M0?ooo`060000o`3oool0oooo0?ooo`00o`00003o2P3o
ool00`3o0000oooo0000o`070?ooo`03003o003oool0o`0000@0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0003o203oool00`00o`00o`000?oo
o`030?ooo`030000o`3oool00?l000X0oooo00<00?l00?ooo`3oool08`3oool500000200oooo000m
0?ooo`030000003oool0oooo02<0oooo00<0003o0?l0003oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`800?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00D00?l0
0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01P3o
ool00`3o0000oooo0000o`080?ooo`03003o003oool0o`0000L0oooo00<0003o003o003oool03`3o
ool0103o0000oooo0?ooo`3o00040?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0
o`000P3oool010000?l0oooo0?ooo`3o000:0?ooo`030?l000000?l0oooo00@0oooo00<00?l00?oo
o`3o00001P3oool00`000?l0oooo003o00060?ooo`03003o003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool01000o`00o`000?ooo`000?l;0?ooo`030?l0003oool0oooo0080oooo00@00?l0
0?ooo`3oool0003o1`3oool01@00o`00oooo0?l0003oool0003o0080oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000003o0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`02003o0080oooo00<0o`000?ooo`3oool08P3oool01@00o`00oooo
0000o`3oool0003o0080oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo0080oooo0P000?l20?ooo`03003o003oool0oooo0080oooo00<0o`00003o003o
ool00`3oool00`3o0000oooo0?ooo`0U0?ooo`040?l0003oool0oooo0?l000d0oooo00<00?l00?oo
o`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo01<0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`00oooo00P0oooo00<0003o0?oo
o`3o0000103oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool00?l000l0oooo00<0o`000?oo
o`3oool0303oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`00o`000`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003o00000?l000d0oooo00<0o`000?oo
o`3oool01`3oool01@3o0000oooo003o003oool0003o0140oooo00@00?l00?ooo`3oool0003o1`3o
ool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool03@3o
ool0103o0000oooo003o003o00070?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool010000?l0oooo0?l000000?l:0?ooo`030?l0003oool0003o00P0oooo00<00?l00?ooo`3o
0000103oool01`000?l0oooo0?ooo`3oool00?l00?ooo`00o`007@3oool01P000?l0oooo0?ooo`3o
ool00?l00000o`X0oooo00<0o`000?ooo`000?l01`3oool00`00o`00oooo0?l000040?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool20000o`/0oooo00<00?l00?l0003oool0
0`3oool00`000?l0oooo003o00090?ooo`03003o003oool0oooo02P0oooo00<000000?ooo`3oool0
7P3oool003d0oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0003o00T0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0o`0000<0oooo
00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0003o00P0oooo
00<00?l00?ooo`3o00001`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0o`0000@0oooo
00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00020?ooo`040000o`3oool0oooo0?l0
00X0oooo00<0o`000000o`3oool0103oool00`00o`00oooo0?l000060?ooo`030000o`00o`00oooo
00H0oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`04003o003o0000oooo
0000o`/0oooo00<0o`000?ooo`3oool00P3oool01000o`00oooo0?ooo`000?l70?ooo`03003o003o
ool0o`000080oooo00<0003o0?l0003oool01@3oool00`3o0000003o0?ooo`020?ooo`03003o003o
ool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool0203o0000oooo0?ooo`00o`00oooo003o003o
ool0o`00903oool01@00o`00o`000000o`3oool0003o0080oooo00<00?l00?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0D0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`00o`00oooo0?oo
o`030?ooo`030?l00000o`00oooo0080oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?l0
000<0?ooo`03003o003oool0o`0000L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000?l00?l00?oo
o`080?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo003o
000N0?ooo`03003o003oool0003o00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo003o
00030?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`00o`003P3oool00`3o0000oooo0?oo
o`050?ooo`040?l0003oool0oooo003o0080oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo
0000o`080?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool07`3oool01@3o0000oooo
0?ooo`00o`00o`0000D0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80
003o00@0oooo0?l0003oool0003o2P3oool00`3o0000oooo0000o`090?ooo`03003o003o0000oooo
00<0oooo00L0003o0?ooo`3oool0oooo003o003oool00?l001d0oooo00H0003o0?ooo`3oool00?l0
0?ooo`000?l:0?ooo`030?l0003oool0003o00L0oooo00<00?l00?ooo`3o0000103oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo01D0oooo00<00?l00?ooo`3o00000`3oool00`3o0000
003o003o00090?ooo`03003o003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool0903oool01P000?l0oooo0?ooo`000?l0oooo0?l000P0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0o`0000<0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`030?l000000?l0oooo00L0oooo00<00?l00?oo
o`3o00001`3oool00`00o`00003o0?ooo`0@0?ooo`80o`001@3oool00`00o`00oooo0?ooo`020?oo
o`05003o003oool0oooo0?l0003oool00P000?l20?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0000o`3oool0103oool00`00o`00oooo0?l000060?ooo`030000o`00o`00oooo00H0oooo00<00?l0
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`04003o003oool0o`000000o`X0oooo00<0
o`000?ooo`3oool00`3oool00`00o`00oooo0000o`080?ooo`06003o003oool0oooo0?l0003oool0
003o203oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`000?ooo`3oool0203oool01`3o
0000oooo003o003oool00?l00?ooo`3o0000903oool01@00o`00o`000000o`3oool0003o0080oooo
00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0D0?ooo`040000o`3oool0oooo0000o`@0
oooo00<00?l00?ooo`3oool01@3oool01@3o00000?l00?ooo`3oool0o`0002P0oooo0P3o000=0?oo
o`03003o003oool0o`0000P0oooo00D00?l00?ooo`3oool0oooo0?l0000F0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0103oool00`00o`00003o0?ooo`080?ooo`030000o`3oool0
o`0000@0oooo00<0o`000?ooo`3oool02`3oool01@00o`00oooo0?ooo`3oool00?l001d0oooo00<0
0?l00?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo003o00<0oooo
00<0o`000?ooo`3oool0303oool00`00o`00oooo003o000>0?ooo`030?l0003oool0oooo00D0oooo
00@0o`000?ooo`3oool00?l00P3oool00`000?l0oooo0?ooo`0?0?ooo`03003o00000?l0oooo00L0
oooo00<00?l00?ooo`3oool0<`3oool01@3o0000oooo0?ooo`3oool00?l000D0oooo00<00?l00?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`000?l02P3oool0
0`3o0000oooo0000o`090?ooo`03003o003o0000oooo00<0oooo00L0003o0?ooo`3oool0oooo003o
003oool00?l001`0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00X0oooo00<0o`000?oo
o`000?l01`3oool00`00o`00o`000?ooo`040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool05P3oool00`00o`00oooo0?l000030?ooo`030?l000000?l00?l000T0oooo00<00?l00?oo
o`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0T0?ooo`06
0000o`3oool0oooo0000o`3oool0o`00203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00`0oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0
oooo00L0oooo00<0o`000000o`3oool01`3oool00`00o`00oooo0?l000070?ooo`03003o00000?l0
oooo0100oooo0P3o00050?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0o`000?oo
o`020000o`030?ooo`3o0000oooo00X0oooo00<0o`000000o`3oool0103oool00`00o`00oooo0?l0
00060?ooo`030000o`00o`00oooo00H0oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0>0?ooo`05003o003oool0o`000?ooo`000?l02@3oool00`3o0000oooo0?ooo`030?ooo`03003o
003oool0003o00P0oooo00<00?l00?ooo`3oool00P3o00000`000?l0oooo0?ooo`060?ooo`050000
o`3oool0oooo0?ooo`00o`001@3oool00`3o0000oooo0?ooo`080?ooo`070?l0003oool00?l00?oo
o`00o`00oooo0?l0000T0?ooo`05003o003o0000003o0?ooo`000?l00P3oool00`00o`00oooo0?oo
o`030?ooo`030?l0003oool0oooo01D0oooo0P000?l50?ooo`03003o003oool0oooo00H0oooo00@0
0?l00?ooo`3oool0o`00:@3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0o`0000P0oooo
00@00?l00?ooo`3oool0o`005`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo00<00?l00000o`3oool0203oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo00/0
oooo00D00?l00?ooo`3oool0oooo003o000M0?ooo`03003o003oool0003o00@0oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0oooo00d0oooo00@00?l0
0?ooo`3oool00?l03@3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo003o00<0oooo
00<0003o0?ooo`3oool03`3oool00`00o`00003o0?ooo`070?ooo`03003o003oool0oooo03<0oooo
00H0o`000?ooo`3oool0oooo0?l00000o`040?ooo`03003o003oool0oooo00D0oooo00<0003o0?oo
o`000?l0103oool0103o0000oooo0?ooo`000?l90?ooo`030?l000000?l0oooo00T0oooo00<00?l0
0?l0003oool00`3oool010000?l0oooo0?ooo`00o`030?ooo`03003o003oool0oooo01T0oooo00@0
003o0?ooo`3oool00?l00P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0003o00L0oooo
00<00?l00?l0003oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01H0oooo
00<00?l00?ooo`3o00000`3oool00`3o0000003o003o00090?ooo`03003o003oool0oooo02P0oooo
00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?oo
o`000?l20?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0<0?ooo`03003o003o0000oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo
0?ooo`070?ooo`030?l000000?l0oooo00L0oooo00<00?l00?ooo`3o00001`3oool00`00o`00003o
0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo
0?ooo`3o0000oooo0080003o00<0oooo0?l0003oool02P3oool00`3o0000003o0?ooo`040?ooo`03
003o003oool0o`0000H0oooo00<0003o003o003oool01P3oool00`00o`00oooo0?ooo`0:0?ooo`03
003o00000?l0oooo00l0oooo00D00?l00?ooo`3o0000oooo0000o`090?ooo`030?l0003oool0oooo
00<0oooo00<00?l00000o`3oool0203oool01000o`00oooo0?ooo`3o00020?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`0000/0oooo00L0
o`000?ooo`00o`00oooo003o003oool0o`0002@0oooo00D00?l00?l000000?l0oooo0000o`030?oo
o`05003o003oool0oooo0?ooo`3o0000603oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo00L0oooo00<00?l00?l0003oool0=`3oool00`00o`00oooo0?l000090?ooo`03003o003oool0
o`0001L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`03003o00000?l0
oooo00P0oooo00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`0;0?ooo`05003o003o
ool0oooo0?ooo`00o`00703oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0oooo00`0oooo00D00?l00?oo
o`3oool0oooo003o000=0?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool00?l00`3o
ool00`000?l0oooo0?ooo`0?0?ooo`03003o00000?l0oooo00L0oooo00<00?l00?ooo`3oool0<`3o
ool01P3o0000oooo0?ooo`3oool0o`00003o00@0oooo00<00?l00?ooo`3oool01@3oool20000o`@0
oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030?l000000?l0oooo00T0oooo00<00?l00?l0
003oool0103oool00`000?l0oooo003o00030?ooo`03003o003oool0oooo00d0oooo00<0003o0?oo
o`3oool02@3oool010000?l0oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`000?l01`3oool00`00o`00o`000?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool05@3oool01000o`00oooo0?ooo`3o00030?ooo`030?l0003oool0003o00T0oooo00<0
0?l00?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0T
0?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool00?l000T0oooo00<0o`000000o`3oool01`3oool00`00o`00oooo0?l000070?ooo`03003o
00000?l0oooo0140oooo00<0o`000?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool00?l00080
oooo00H0o`000000o`3oool0003o0?ooo`3o000;0?ooo`030?l000000?l0oooo00@0oooo00<00?l0
0?ooo`3o00001`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00T0oooo00<00?l0
0000o`3oool03`3oool01@00o`00oooo0?ooo`3o0000003o00P0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o00002`3oool01`3o00000?l0
0?ooo`3oool00?l00?ooo`3o0000903oool01@00o`00oooo0000o`3oool0003o00<0oooo00D00?l0
0?ooo`3oool0oooo0?l0000O0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0=@3o
ool01@00o`00oooo0?ooo`3oool0o`0000T0oooo0P00o`0H0?ooo`80o`001P3oool00`3o0000oooo
0?ooo`060?ooo`03003o00000?l0oooo00L0oooo00D0003o003o003oool0oooo0?l000020?ooo`03
0?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0I0?ooo`05
003o003oool0oooo0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@00?l0
0?ooo`3o0000o`003P3oool01@00o`00oooo0?ooo`3oool00?l000d0oooo00<0o`000?ooo`3oool0
0`3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool03`3oool00`00o`00
003o0?ooo`060?ooo`03003o003o0000oooo03@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
0?l00?ooo`020?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool01@3o0000
oooo0?ooo`3oool0003o00T0oooo00<0o`000000o`3oool02@3oool00`00o`00o`000?ooo`040?oo
o`030000o`3oool00?l000<0oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0000o`0:0?oo
o`030000o`3oool00?l000<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0000o`070?oo
o`03003o003o0000oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0F0?oo
o`04003o003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0003o2@3oool00`00o`00oooo0?oo
o`0X0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo02@0oooo00<0003o
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`040000o`3oool0oooo003o00X0oooo00<0
o`000000o`3oool01`3oool00`00o`00oooo0?l000070?ooo`03003o00000?l0oooo01P0oooo00@0
0?l00?ooo`3oool00?l0103oool01@000?l0oooo0000o`3oool0o`0000/0oooo00<0o`000000o`3o
ool01@3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3o
ool0203oool00`00o`00003o003o000@0?ooo`05003o003oool0oooo0?l000000?l0203oool00`3o
0000oooo0?ooo`040?ooo`030000o`00o`00oooo00L0oooo00<00?l00?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000<0oooo00D00?l00?ooo`3oool0oooo0?l0000;
0?ooo`070?l00000o`00oooo0?ooo`00o`00oooo0?l0000T0?ooo`05003o003oool0003o0?ooo`00
0?l00`3oool01@00o`00oooo0?ooo`3oool0o`0001h0oooo00<00?l00?ooo`3oool02P3oool00`00
o`00oooo0?ooo`0d0?ooo`04003o003oool0oooo0?ooo`80o`00203oool00`3o0000oooo003o000I
0?ooo`80o`00103oool00`3o0000oooo0?ooo`060?ooo`03003o00000?l0oooo00L0oooo00D0003o
003o003oool0oooo0?l000020?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0I0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?ooo`000?l20?l00003003o003o0000oooo00l0oooo00<00?l00?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0
0?l01@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o00000?l0oooo00H0oooo00<00?l00?ooo`3o
0000=03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool00?l00080oooo00<00?l00?ooo`3o
ool02`3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000000o`3oool02@3oool00`00
o`00oooo0?ooo`040?ooo`030000o`3oool00?l000<0oooo00<00?l00?ooo`3oool02`3oool01000
0?l0oooo0?ooo`000?l90?ooo`040000o`3oool0oooo003o00<0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0000o`080?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0F0?ooo`04003o003oool0oooo0?l00080oooo00D0o`000?ooo`3oool0
0?l00000o`080?ooo`03003o003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool003d0oooo
00<000000?ooo`3oool08`3oool0103o0000003o0?ooo`000?l40?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l00000o`00oooo0080
oooo00@0003o0?ooo`3oool00?l02P3oool00`3o0000003o0?ooo`080?ooo`03003o003o0000oooo
00H0oooo00<00?l00?ooo`000?l0603oool01000o`00oooo0?ooo`00o`040?ooo`050000o`3oool0
003o0?ooo`3o00002`3oool00`3o0000003o0?ooo`050?ooo`03003o003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`080?ooo`03003o00000?l00?l00100oooo00D0
0?l00?ooo`3oool0o`000000o`070?ooo`030?l0003oool0oooo00D0oooo00<0003o003o003oool0
1`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o0000
0`3oool01@00o`00oooo0?ooo`3oool0o`0000/0oooo00<0o`00003o003oool00P3oool00`00o`00
o`000?ooo`0S0?ooo`04003o003oool0o`000000o`@0oooo00D00?l00?ooo`3oool0oooo0?l0000N
0?ooo`03003o003oool0oooo00/0oooo0P00o`0d0?ooo`03003o003oool0oooo00<0oooo0`3o0005
0?ooo`030?l0003oool0oooo00800?l0503oool00`00o`00oooo0?ooo`020?ooo`80o`0000<0oooo
0?l0003oool0203oool00`00o`00003o0?ooo`070?ooo`050000o`00o`00oooo0?ooo`3o00000P3o
ool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0603o
ool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo0P3o000010000?l0oooo0?oo
o`00o`0A0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`03
003o00000?l0oooo00H0oooo00<00?l00?ooo`3o0000=03oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00800?l03P3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000000
o`3oool02@3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool00?l000<0oooo00<00?l00?oo
o`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`00o`00103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0003o00P0oooo00<00?l00?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<00?l00?oo
o`3oool02@3oool01000o`00oooo0?ooo`3o00020?ooo`050?l0003oool0oooo0?ooo`000?l01`3o
ool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0
oooo02<0oooo00@0o`000000o`3oool0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo003o00020?ooo`040000o`3oool0oooo003o00X0
oooo00<0o`000000o`3oool0203oool00`00o`00o`000?ooo`050?ooo`04003o003oool0oooo0000
oaP0oooo00@00?l00?ooo`3oool00?l00`3oool01P000?l0o`000?ooo`3oool0003o0?l000`0oooo
00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`03003o00000?l0oooo00L0oooo
00<00?l00?ooo`3oool01`3oool01000o`00003o0?ooo`00o`0?0?ooo`03003o003oool0oooo0080
oooo00<0o`000000o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool00?l000P0
oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000<0
oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`030?l00000o`00oooo0080oooo00<00?l00?oo
o`3oool08`3oool01000o`00oooo0?l000000?l40?ooo`05003o003oool0oooo0?ooo`3o00007P3o
ool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo0340oooo00<00?l00?ooo`3oool01P3o
ool30?l000030?ooo`3o0000oooo00@0oooo0P00o`0B0?ooo`800?l01@3oool20?l000P0oooo00<0
0?l00?ooo`000?l0203oool01@000?l0oooo003o003oool0o`000080oooo00<0o`000?ooo`3oool0
303oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`00o`003`3oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?oo
o`03003o003oool0o`0003@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02003o
00d0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo
00T0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo
00P0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00P0oooo00<0003o0?ooo`00o`00103o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0003o00P0oooo00<00?l00?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool02@3o
ool01000o`00oooo0?ooo`3o00020?ooo`060?l0003oool0oooo0?ooo`00o`00003o1P3oool00`00
o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo02<0
oooo00@0o`000?ooo`000?l0003o1@3oool0103o0000oooo0?ooo`3o000:0?ooo`030?l0003oool0
oooo00/0oooo00L0o`000?ooo`3oool0oooo003o003oool0003o0080oooo00<00?l00?ooo`3oool0
203oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo00D0oooo00@00?l00?ooo`3oool0
003o603oool01000o`00oooo0?ooo`00o`030?ooo`060000o`3o0000oooo0?ooo`000?l0o`00303o
ool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`000?l01`3o
ool00`00o`00oooo0?ooo`070?ooo`04003o00000?l0oooo003o00l0oooo00<00?l00?ooo`3oool0
0P3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`00o`00
203oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o0000
103oool01000o`00oooo0?ooo`3o000<0?ooo`05003o003oool0oooo0?ooo`00o`009@3oool01000
o`00oooo0?ooo`000?l40?ooo`05003o003oool0oooo0?ooo`3o00007P3oool00`00o`00oooo0?oo
o`0>0?ooo`03003o003oool0oooo02l0oooo00<00?l00?ooo`3oool02P3oool20?l000L0oooo00<0
0?l00?ooo`3oool03P3oool00`00o`00oooo003o000?0?ooo`03003o003oool0003o00P0oooo00D0
003o0?ooo`00o`00oooo0?l000020?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool01@000?l0oooo0?ooo`3oool00?l000l0oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?l000@0oooo00<00?l00?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3o0000<`3oool00`3o
0000oooo0?ooo`040?ooo`040?l0003oool0oooo003o00d0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00T0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool2
003o00030?ooo`000?l0oooo00D0oooo00<0003o0?ooo`00o`001@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l000000?l0oooo00L0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00/0oooo0P00o`0:0?ooo`07003o003oool0oooo0?ooo`3o0000oooo
0?l000030?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo
0?ooo`0N0?ooo`00?@3oool500000240oooo00<0o`000?ooo`000?l01`3oool00`3o0000oooo0?l0
000;0?ooo`030?l0003oool0oooo00X0oooo00L0o`000?ooo`3oool0oooo003o003oool0003o0080
oooo00<00?l00?ooo`3oool0203oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo00D0
oooo00@00?l00?ooo`3oool0003o6@3oool00`00o`00oooo003o00030?ooo`060000o`3o0000oooo
0?ooo`000?l0o`00303oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`000?l01`3oool00`00o`00oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`00o`00
3P3oool00`00o`00oooo0?ooo`020?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`00o`070?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?l000040?ooo`04003o003oool0oooo0?l000/0oooo00<00?l00?l0
003oool00P3oool00`00o`00oooo0?ooo`0R0?ooo`06003o003oool0oooo0?ooo`000?l0o`000`3o
ool01000o`00oooo0?ooo`3o000O0?ooo`03003o003oool0oooo00l0oooo0P00o`050?ooo`d00?l0
7@3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo00h0oooo00@00?l00?ooo`3oool0
0?l03P3oool00`00o`00oooo0000o`080?ooo`030000o`3oool00?l00080oooo00<0o`000?ooo`3o
00003P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00o`003`3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo00X0oooo00@0o`000?ooo`3oool0o`000`3oool0
0`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01P3oool0
0`00o`00oooo0?l0000c0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool0
1@000?l0oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`000?l01@3oool00`000?l0oooo003o
00050?ooo`030000o`3oool0oooo00T0oooo00<0o`000000o`3oool01`3oool00`00o`00oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo003o
000:0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0?l000030?ooo`03003o00000?l0oooo00D0
oooo00<00?l00?ooo`3oool09@3oool500000200oooo000m0?ooo`030000003oool0oooo02<0oooo
00<0o`000?ooo`000?l01`3oool20?l000`0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`020?ooo`05003o003oool0003o0?ooo`00o`002P3oool00`3o0000003o0?ooo`080?ooo`03
003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`0H0?ooo`03003o003oool00?l0
0080oooo00<0003o0?ooo`3o00000P3oool00`000?l0o`000?ooo`0;0?ooo`030000o`3oool0oooo
00@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0000o`080?ooo`03003o003oool0oooo
00D0oooo00<00?l00000o`3oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo
003o00L0oooo00<00?l00?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o0080oooo00D0
o`000?ooo`3oool0oooo003o00020?ooo`030?l0003oool0oooo00T0oooo00<00?l00?l0003oool0
0P3oool00`00o`00oooo0?ooo`0R0?ooo`06003o003oool0oooo0?ooo`000?l0oooo0`3o00001000
o`00oooo0?ooo`3o000N0?ooo`03003o003oool0oooo0180oooo1@00o`0=0?ooo`800?l06`3oool0
0`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0:0?ooo`05003o003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo003o
00020?ooo`030?l0003oool0o`0000h0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`0F0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0:0?ooo`030?l0003oool0o`0000@0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3o0000<`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00003o003oool01@3oool00`000?l0oooo0?oo
o`030?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool01P00o`00oooo0?oo
o`00o`00oooo0000o`D0oooo00<0003o003o003oool01@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l000000?l0oooo00L0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00/0oooo00<00?l00?ooo`00o`002P3oool01`00o`00oooo0?ooo`3oool0o`00
0?ooo`3o00000`3oool00`00o`00oooo0000o`050?ooo`03003o003oool0oooo02T0oooo00<00000
0?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0000o`080?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?oo
o`03003o00000?l00?l000/0oooo00<0o`000000o`3oool0203oool00`00o`00oooo0?ooo`050?oo
o`05003o003oool0oooo0?ooo`000?l0603oool00`00o`00oooo003o00020?ooo`030000o`3oool0
o`000080oooo00<0003o0?l0003oool02`3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`000?l0203oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0
oooo00@0oooo00<00?l00?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o0080oooo00L0
o`000?ooo`3oool0oooo003o003oool0o`0000`0oooo00<00?l00?l0003oool00P3oool00`00o`00
oooo0?ooo`0R0?ooo`03003o003oool0oooo00L0oooo00<00?l00?l0003o00007P3oool00`00o`00
oooo0?ooo`0V0?ooo`800?l06@3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00`0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo003o00020?ooo`030?l0003oool0o`0000d0
oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00`0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`80o`00103oool00`00o`00
oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo00<0003o003o003oool01@3oool01000o`00
oooo0?ooo`3o000c0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
00000?l00?ooo`050?ooo`03003o00000?l0oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`07003o003oool0oooo0?ooo`00o`00oooo0000o`030?ooo`030000o`3o
ool00?l000H0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`03003o003o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003o
ool00?l000T0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`03003o003o
ool0003o00D0oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`050?ooo`030000o`00o`00oooo00X0oooo00<0o`000000o`3oool0203oool0
0`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`000?l0403oool00`000?l0oooo0?oo
o`050?ooo`05003o003oool00?l00?ooo`000?l00P3oool01@3o0000oooo0?ooo`000?l0o`0000`0
oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo0000
o`L0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo
00X0oooo00<00?l00?ooo`3oool0103oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
00T0oooo00@0003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`020?ooo`03003o003o0000
oooo00/0oooo00<00?l00?l0003oool00P3oool00`3o00000?l00?ooo`0R0?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool07P3oool00`00o`00oooo0?ooo`0X0?ooo`800?l05P3oool0
0`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0103oool0
0`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo003o00020?ooo`030?l0003oool0o`0000d0oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`00o`00oooo00D0oooo00@00?l00?ooo`3oool0o`00<`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00003o003oool0103o
ool00`00o`00oooo0000o`050?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0003o0080oooo00<0003o003o003oool01P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00@00?l00?ooo`3oool00?l0
203oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0o`0000<0oooo00@00?l00?ooo`3oool0
003o103oool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000
003oool0oooo02<0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo00D0oooo00<0003o003o003oool02P3oool00`000?l0oooo0?ooo`080?ooo`03003o
003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`0?0?ooo`030000o`3oool0003o00H0
oooo0P00o`020?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?l0003oool02`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l00000o`00oooo00D0oooo00@00?l00?ooo`3oool0003o1`3oool0
0`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool010000?l0oooo0?oo
o`000?l20?ooo`030?l0003oool0oooo0080oooo00<00?l00?l0003oool02`3oool00`00o`00o`00
0?ooo`020?ooo`030?l00000o`00oooo0280oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?ooo`0N0?ooo`03003o003oool0oooo02X0oooo0P00o`0D0?ooo`03003o003oool0oooo01H0oooo
00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo
0P00o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`00o`000P3oool00`3o0000oooo
0?l0000=0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0<0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo
0?ooo`020?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l00?l0
0?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000<P3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`00003o003oool0103oool00`00o`00oooo0000o`050?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`040?ooo`06
003o00000?l0oooo0?ooo`000?l00?l01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo00L0oooo00<00?l00?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00@0
0?l00?ooo`3oool00?l0203oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0o`0000<0oooo
00@00?l00?ooo`3oool0003o103oool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o003o003oool02P3oool00`000?l0oooo
0?ooo`080?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0<0?ooo`040000o`3oool0oooo0000o`D0oooo0P00o`020?ooo`040000o`3oool0oooo0?l0
0080oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030?l00000o`00oooo
00@0oooo00D00?l00?ooo`3oool0oooo0000o`070?ooo`03003o003oool0oooo00<0oooo00<0003o
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00D0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0003o00@0oooo00H0o`000?ooo`3oool0oooo
003o003o000;0?ooo`03003o003oool0o`000080oooo00<0o`000?ooo`00o`008`3oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo01h0oooo00<00?l00?ooo`3oool0;03oool2003o0180
oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00H0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`00o`000P3oool20?l000h0oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`0D0?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`0?0?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0
0?l00?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000<P3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`00003o003oool0103oool00`00o`00oooo0000o`050?oo
o`05003o003oool0oooo0?ooo`000?l01`3oool00`00o`00oooo0?ooo`050?ooo`04003o00000?l0
oooo0000o`P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l00000
o`00oooo00H0oooo00D0003o0?ooo`00o`00oooo0000o`0>0?ooo`04003o003oool0oooo003o00P0
oooo00<00?l00?ooo`3oool00P3oool20?l000D0oooo00@00?l00?ooo`3oool0003o0P3oool00`00
o`00oooo0?ooo`0Z0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0280
oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0000o`040?ooo`030?l0003oool0003o00d0
oooo00<0003o0?ooo`3oool0103oool00`3o00000?l00?ooo`040?ooo`05003o003oool0oooo0?oo
o`000?l01`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<00?l00?oo
o`3oool0203oool00`00o`00oooo0?ooo`060?ooo`040000o`3o0000oooo0?l000@0oooo00<0003o
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo0P000?l4
0?ooo`060?l0003oool0oooo0?ooo`00o`00o`002`3oool02000o`00oooo0?ooo`3o0000oooo0?l0
003oool00?l08`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01d0oooo00<00?l0
0?ooo`3oool0;`3oool2003o0100oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`3oool00?l02@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool00?l000<0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?oo
o`080?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?oo
o`080?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool00?l000H0oooo00D00?l00?ooo`3oool0oooo0?l0000b0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00?ooo`040?ooo`04003o
003oool0oooo0000o`@0oooo00@00?l00?ooo`000?l0003o203oool00`00o`00oooo0?ooo`050?oo
o`04003o00000?l0003o003o00T0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`07
0?ooo`030?l00000o`00oooo00L0oooo00@0003o003o003oool0003o3@3oool01@00o`00oooo0?oo
o`3oool00?l000P0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o
003oool0oooo00@0003o;03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?oo
o`0R0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`000?l0103oool00`3o0000oooo0000
o`0=0?ooo`030000o`3oool0oooo00@0oooo00<0o`00003o003oool0103oool00`00o`00oooo0?oo
o`020?ooo`030000o`3oool0oooo00D0oooo00H00?l00?ooo`3oool0oooo0000o`00o`080?ooo`03
003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?l000030?ooo`03
0000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`80
003o103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00P00?l00?ooo`3o
ool0o`000?ooo`3o0000oooo003o02<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?oo
o`0M0?ooo`03003o003oool0oooo0340oooo0P00o`0=0?ooo`03003o003oool0oooo01T0oooo00<0
0?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l000X0oooo00<0
003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0oooo00`0oooo
00<00?l00?ooo`3oool0203oool3003o0180oooo00<00?l00?ooo`3oool0203oool01@000?l0oooo
0?ooo`3oool0003o00@0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`080?ooo`03
003o003oool0oooo00d0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool00?l000H0oooo00D00?l00?ooo`3oool0oooo0?l0000b0?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00?ooo`040?ooo`04003o003oool0oooo
0000o`@0oooo00<00?l00000o`3oool02@3oool00`00o`00oooo0?ooo`060?ooo`03003o00000?l0
oooo00T0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
0?l000P0oooo00@0003o003o003oool0003o3@3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003o
ool0oooo00<0oooo00<00?l00000o`000?l00`000?lW0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`08
0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0000o`04
0?ooo`030?l0003oool0003o00d0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo003o0005
0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool01@00o`00oooo0?ooo`00
0?l00?l000T0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`070?ooo`030000o`3o
ool0o`000080oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo00T0oooo00P00?l00?ooo`3oool0o`000?ooo`3o0000oooo003o02<0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo03<0oooo0P00o`0;0?oo
o`03003o003oool0oooo01T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0:0?oo
o`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`02
0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool02`3oool4003o00h0oooo00<00?l0
0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool00?l000H0oooo00D00?l00?ooo`3oool0oooo
0?l0000b0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l0
0?ooo`040?ooo`04003o003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0203oool00`00o`00
oooo0?ooo`080?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool00?l000P0oooo00<0003o0?ooo`000?l03P3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0U0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0280oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l00000o`00oooo00@0oooo
00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00`0oooo
00<0003o0?l0003oool0103oool00`3o0000oooo003o00050?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool01@00o`00oooo0?ooo`000?l00?l000T0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`080?ooo`030000o`3o0000oooo0080oooo00<0003o0?ooo`3o
ool0203oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3o
ool00P3oool01P3o0000oooo0?ooo`3oool0o`00003o00/0oooo00H00?l00?ooo`3oool0o`000?oo
o`3o00020?ooo`03003o003oool0oooo0200oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?ooo`0M0?ooo`03003o003oool0oooo03D0oooo0P00o`090?ooo`03003o003oool0oooo01X0oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0F0?ooo`030000o`3oool0oooo00D0oooo
00@0003o0?ooo`3oool00?l00P3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00l0
oooo0`00o`0;0?ooo`03003o003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o1@3oool00`00
o`00oooo0?ooo`090?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0303oool00`00
o`00oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`00o`001P3oool01@00
o`00oooo0?ooo`3oool0o`000380oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l00000o`00oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`80003o00<0
oooo003o003oool0203oool00`00o`00oooo0?ooo`0C0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo003o00080?ooo`030000o`3oool0003o00h0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0R
0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00?ooo`04
0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0000o`0<0?ooo`030000o`3o
0000oooo00@0oooo00<0o`000?ooo`00o`001@3oool00`00o`00oooo0?ooo`020?ooo`030000o`3o
ool0oooo00D0oooo00@00?l00?ooo`000?l00?l02`3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo00P0oooo00D0003o0?l0003oool0oooo0000o`0;0?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool04P3oool01P3o0000oooo0?ooo`3o0000oooo003o00T0oooo00L00?l0
0?ooo`3oool0oooo0?l0003oool0o`000080oooo00<00?l00?ooo`3oool0803oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo01`0oooo00<00?l00?ooo`3oool0=`3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo01X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool00?l04@3oool00`00o`00
oooo0?ooo`0A0?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool02@3oool010000?l0
oooo0?ooo`000?l50?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool02P3oool00`00
o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo003o00050?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0<03oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00003o003oool00`3oool00`00
o`00oooo0?ooo`020?ooo`80003o0`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
01<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool00?l0
00L0oooo00@00?l00?ooo`000?l0003o3P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool50000
0200oooo00<0o`000?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l00000o`00oooo00@0oooo00<00?l0
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00@0003o
0?ooo`3oool0003o1@3oool00`3o0000oooo0000o`0<0?ooo`030000o`3o0000oooo00@0oooo00@0
o`000?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00@00?l00?ooo`000?l00?l02`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0
oooo00@0003o0?ooo`3oool0003o303oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
0180oooo00H0o`000?ooo`3oool0o`000?ooo`00o`090?ooo`07003o003oool0oooo0?ooo`3o0000
oooo0?l000020?ooo`03003o003oool0oooo0200oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`0K0?ooo`03003o003oool0oooo03T0oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`0L0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0603oool00`000?l0
oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`00o`004@3oool00`00o`00oooo0?ooo`0B0?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0000o`060?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`0;0?oo
o`03003o003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo003o00050?oo
o`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3o0000oooo00T0oooo00<0o`00003o003oool00`3oool00`00o`00oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo003o00070?oo
o`04003o003oool0003o003o00h0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo0200oooo1@00000P0?ooo`00?@3oool00`000000oooo0?ooo`0R0?oo
o`030?l0003oool0oooo01T0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00?ooo`030?ooo`03003o003oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`80003o1P3oool0
0`3o0000oooo0000o`0<0?ooo`030000o`3o0000oooo00@0oooo00@0o`000?ooo`3oool00?l00`3o
ool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo10000?l00`3oool00?l00?oo
o`0:0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02P3oool20000o`d0oooo00D0
0?l00?ooo`3oool0oooo003o000E0?ooo`060?l0003oool0oooo0?l0003oool00?l02@3oool01`00
o`00oooo0?ooo`3oool0o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`0O0?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`0j0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0703oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo01P0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool00?l00140oooo
00<00?l00?ooo`3oool04P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00X0oooo
0P000?l60?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo
0?ooo`0:0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo
0?ooo`00o`040?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000
oooo0?ooo`080?ooo`80o`00203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?l0003oool02@3oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo00L0
oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0D0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo003o00060?ooo`05003o003oool0oooo0000
o`00o`003@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool02`3oool01@00o`00oooo0?ooo`3oool00?l000H0oooo00<0003o0?ooo`3oool0903oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo
01X0oooo00@0o`000?ooo`3oool0o`003P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000
oooo00P0oooo00<0o`00003o003oool00`3oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0
o`000000o`/0oooo00<0003o0?ooo`3o0000103oool0103o0000oooo0?ooo`00o`030?ooo`03003o
003oool0oooo00@0oooo1@000?l30?ooo`800?l03@3oool00`00o`00oooo0?ooo`040?ooo`03003o
003oool0oooo00X0oooo0P000?l=0?ooo`05003o003oool0oooo0?ooo`00o`005@3oool01P3o0000
oooo0?ooo`3o0000oooo003o00T0oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool00?l00240oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0K0?ooo`03003o003o
ool0oooo03/0oooo0P00o`030?ooo`03003o003oool0oooo01d0oooo00D00?l00?ooo`3oool0oooo
003o000K0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o000@0?ooo`03
003o003oool0oooo01<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0;0?ooo`80
003o1P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3o
ool02P3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3o
ool0oooo003o00040?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool=0?l0
01l0oooo00<0o`000?ooo`3oool02P3oool20?l000H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00T0oooo00<0o`000?ooo`00o`000`3oool00`00
o`00oooo0?ooo`070?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0503oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`00o`001P3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o0006
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0o`000100oooo00<0003o0?oo
o`3oool0203oool00`000?l0o`000?ooo`080?ooo`030?l00000o`00oooo00<0oooo00<00?l00?oo
o`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo00@0o`000?oo
o`3o0000003o2`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo003o00<0oooo00<0
0?l00?ooo`3oool0303oool2003o00d0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00D00?l00?ooo`3oool0oooo003o000F0?ooo`030?l0
003oool0o`000080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`00o`008@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo01/0
oooo00<00?l00?ooo`3oool0?@3oool01000o`00oooo0?ooo`00o`0O0?ooo`05003o003oool0oooo
0?ooo`00o`006`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`00o`00403o
ool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0303o
ool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0303o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool0203o
ool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool00`3oool50?l000d0oooo
00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0<0?ooo`80o`00103oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool0203oool0103o0000oooo
0?ooo`00o`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0D0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool0103o0000
oooo0?ooo`00o`050?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02P3oool00`00
o`00oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool01@00
o`00oooo0?ooo`3oool00?l000H0oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`0N
0?ooo`00?@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01/0oooo0P3o000@0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool01`3oool00`3o0000oooo003o00040?oo
o`03003o003oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0000o`0F0?ooo`040?l0003oool0
o`000000o`/0oooo00<0003o0?ooo`3o0000103oool0103o0000oooo0?ooo`00o`030?ooo`03003o
003oool0oooo00`0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo01/0oooo00@00?l00?ooo`3oool00?l05P3oool00`3o0000oooo0?l000020?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l0
0240oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo
03h0oooo0P00o`0Q0?ooo`03003o003oool00?l001`0oooo00<0003o0?ooo`3oool00`3oool01@00
0?l0oooo0?ooo`3oool00?l00100oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`06
0?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`03003o003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0>0?ooo`80o`0000<0
oooo0?l0003oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00P0oooo00@0
o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool05@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00@0o`000?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00/0
oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`030000o`3oool0oooo02@0oooo00<000000?oo
o`3oool07P3oool003d0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`070?ooo`03
0?l0003oool00?l000@0oooo00<00?l00?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0003o
01H0oooo00@0o`000?ooo`3o0000003o2`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0
oooo003o00<0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`0=0?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool06`3oool01000o`00oooo0?ooo`00o`0F0?ooo`030?l0
003oool0o`000080oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o
003oool0oooo00T0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`100?ooo`03003o
003oool0oooo01l0oooo00<00?l00?ooo`00o`00703oool00`000?l0oooo0?ooo`030?ooo`050000
o`3oool0oooo0?ooo`00o`00403oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00H0
oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00h0
oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo01H0oooo00<0o`000?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0@0?ooo`80o`002`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`09
0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool05@3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool00?l0103oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool01@3oool01@00o`00oooo0?oo
o`3oool00?l000h0oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`030000o`3oool0oooo02@0
oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0]0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool01`3oool00`3o0000oooo
003o00040?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`000?l0603oool00`3o0000oooo
0000o`0;0?ooo`030000o`3oool0o`0000@0oooo00@0o`000?ooo`3oool00?l00`3oool00`00o`00
oooo0?ooo`0L0?ooo`05003o003oool0oooo0?ooo`00o`007P3oool00`00o`00oooo003o000G0?oo
o`80o`000`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00P0oooo00<00?l00?oo
o`3oool04@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00T0oooo00<00?l00?oo
o`3oool06P3oool00`00o`00oooo0?ooo`1S0?ooo`03003o003oool0oooo01/0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00d0oooo00<00?l00?oo
o`3oool05@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01<0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`00o`00103oool0
0`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3oool00?l00P3o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool00?l0
103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0
1P3oool01000o`00oooo0?ooo`00o`0>0?ooo`05003o003oool0oooo0?ooo`00o`001P3oool00`00
0?l0oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0240
oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o0000oooo00L0
oooo00<0o`000?ooo`00o`00103oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0003o01P0
oooo00<0o`000?ooo`000?l02`3oool00`000?l0oooo0?l000040?ooo`070?l0003oool0oooo0?oo
o`00o`00oooo003o000O0?ooo`05003o003oool0oooo0?ooo`00o`007P3oool00`00o`00oooo003o
000H0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`080?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?oo
o`0:0?ooo`03003o003oool0oooo01T0oooo00<00?l00?ooo`3oool0H`3oool00`00o`00oooo0?oo
o`0K0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0=0?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0D0?ooo`03003o003oool0oooo00@0oooo0P00o`0C0?ooo`800?l01P3oool00`00o`00oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03003o
003oool0oooo01P0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0M0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?l0003oool0203oool0103o0000oooo0?ooo`00o`020?ooo`03
003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`00o`030?oo
o`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`070?oo
o`04003o003oool0oooo003o00h0oooo00D00?l00?ooo`3oool0oooo003o00070?ooo`030000o`3o
ool0oooo02<0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool01`3oool0
0`3o0000oooo003o00030?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0000o`0;0?ooo`030000o`3oool0o`0000@0oooo00L0o`000?ooo`3oool0oooo003o
003oool00?l001l0oooo00D00?l00?ooo`3oool0oooo003o000N0?ooo`03003o003oool00?l001P0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0
oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo00X0
oooo00<00?l00?ooo`3oool06@3oool00`00o`00oooo0?ooo`210?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo01D0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo0080
oooo0P00o`0G0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0403oool00`000?l0
oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0I0?oo
o`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3o0000oooo00P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0=0?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool05P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
0000oooo00H0oooo00@0o`000?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`050?ooo`03003o
003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool01000o`00oooo0?ooo`00o`0>0?ooo`05
003o003oool0oooo0?ooo`00o`001`3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo
01h0oooo000R0?ooo`800000103oool2000000D0oooo0`00000;0?ooo`030000003oool0oooo0200
oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000oooo00L0
oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003oool0003o
00/0oooo00<0003o0?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l0
0200oooo00<00?l00?ooo`00o`007`3oool00`00o`00oooo003o000H0?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo
0100oooo00<00?l00?ooo`00o`002`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo
01P0oooo00<00?l00?ooo`3oool0P`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`02003o01X0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l001/0oooo00<0o`000?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l0003oool0203oool0
1P3o0000oooo0?ooo`00o`00oooo003o00d0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0F0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool01P3oool0103o0000oooo
0?ooo`00o`030?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo0?ooo`070?ooo`04003o003oool0oooo003o00l0oooo00<00?l00?ooo`00o`00203oool00`00
0?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
02l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`070?ooo`040?l0003oool0oooo
003o0080oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0000o`0;0?ooo`030000o`3oool0
o`0000<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo003o000P0?ooo`03003o003oool0
0?l001l0oooo00<00?l00?ooo`00o`007P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo003o000;0?ooo`03003o003oool0
oooo00X0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`230?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0
oooo01H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0E0?ooo`<00?l07@3oool2
003o0080oooo00<00?l00?ooo`3oool04@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00D00?l00?ooo`3oool0oooo003o000L0?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3o0000203oool01P3o0000oooo0?ooo`00o`00oooo003o00d0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0F0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003o
ool01P3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`3oool0203oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l000l0oooo00<00?l00?oo
o`00o`00203oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`04
0000003oool0oooo000000P0oooo1@00000;0?ooo`L00000703oool00`3o0000oooo0?ooo`0_0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?l0003oool01`3oool0103o0000oooo0?ooo`00o`02
0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`000?l02`3oool00`000?l0oooo0?l00003
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`00803oool00`00o`00oooo003o000P
0?ooo`800?l07P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool03`3oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool0603oool00`00o`00oooo0?ooo`230?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo01H0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo01l0oooo0P00o`0D
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`00
o`0L0?ooo`030?l0003oool0oooo00T0oooo0P3o000<0?ooo`030?l0003oool0oooo01h0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?l000080?ooo`040?l0003oool0oooo0?ooo`800?l0
3@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01H0oooo00<0003o0?ooo`3oool0
203oool00`000?l0o`000?ooo`050?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo003o000?0?ooo`03003o003oool00?l000P0oooo00<0003o0?ooo`3oool07@3oool700000200
oooo000Q0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?l000080?ooo`040?l0003oool0oooo003o0080oooo00<00?l00?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool00P3oool0
0`00o`00oooo003o000Q0?ooo`03003o003oool0oooo01l0oooo00<00?l00?ooo`3oool07@3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool03P3oool0
1000o`00oooo0?ooo`00o`0;0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0603o
ool00`00o`00oooo0?ooo`230?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0h0?ooo`03003o003oool0oooo01<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo003o01d0oooo00<0o`000?ooo`3oool0
1P3oool20?l000030?ooo`3o0000oooo00/0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0o`0000P0oooo00@0o`000?ooo`3oool0oooo0P00o`0=0?ooo`05
003o003oool0oooo0?ooo`00o`006@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o0000oooo
00D0oooo00<0o`000?ooo`3oool00P3oool2003o00X0oooo00<00?l00?ooo`3oool01`3oool00`00
o`00oooo0?ooo`080?ooo`800?l0403oool00`00o`00oooo003o00080?ooo`030000o`3oool0oooo
02<0oooo00<000000?ooo`3oool07P3oool00240oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0000000<0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000P0oooo00@0o`000?ooo`3oool00?l00P3oool0
0`00o`00oooo0?ooo`0X0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o00000`3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool00?l00240oooo00<00?l00?ooo`3oool07`3oool0
0`00o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`0>0?ooo`04003o003oool0oooo003o00X0oooo00<00?l00?ooo`3oool0303o
ool00`00o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo08<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool0603o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo04h0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`04003o003oool0oooo003o01h0oooo00<0o`000?ooo`3oool0
103oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool07P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0o`0000P0oooo00@0o`000?ooo`3oool0oooo0P00o`0=0?oo
o`05003o003oool0oooo0?ooo`00o`006@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o0000
oooo00D0oooo00<0o`000?ooo`3oool00P3oool2003o00X0oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`090?ooo`800?l0403oool00`00o`00oooo003o00080?ooo`030000o`3oool0
oooo02<0oooo00<000000?ooo`3oool07P3oool00280oooo0P00000;0?ooo`800000303oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?l000080?ooo`040?l0003oool0oooo003o0080oooo00<00?l00?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`120?ooo`03003o003oool0oooo01h0oooo00D00?l00?ooo`3oool0oooo003o
000<0?ooo`03003o003oool0oooo00h0oooo00D00?l00?ooo`3oool0oooo003o00090?ooo`03003o
003oool0oooo00`0oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`240?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o
003oool0oooo01P0oooo00D00?l00?ooo`3oool0oooo003o001B0?ooo`050000o`3oool0oooo0?oo
o`000?l01@3oool00`00o`00oooo003o000O0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?l000080?ooo`050?l0003oool0oooo0?ooo`00o`003`3oool0
1000o`00oooo0?ooo`00o`0J0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00001P3o
ool00`3o0000oooo0?ooo`020?ooo`800?l02P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o
ool0oooo00X0oooo00<00?l00?ooo`3oool03P3oool00`00o`00oooo003o00090?ooo`030000o`3o
ool0oooo0280oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000203oool0
103o0000oooo0?ooo`00o`020?ooo`03003o003oool0oooo02P0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0H`3o
ool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo00h0oooo00D00?l00?ooo`3oool0
oooo003o00090?ooo`03003o003oool0oooo00`0oooo00<00?l00?ooo`3oool05P3oool00`00o`00
oooo0?ooo`240?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0<0?ooo`03003o003oool0oooo01P0oooo00D00?l00?ooo`3oool0oooo003o001B0?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`00o`00oooo003o000P0?ooo`030?l0003oool0
oooo0080o`001P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01l0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?l000080?ooo`050?l0003oool0oooo0?ooo`00o`003`3o
ool01000o`00oooo0?ooo`00o`0J0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000
1P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`00o`00
2@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003o
ool0oooo0200oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0o`0000P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0/0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3o00000`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo06<0
oooo00@00?l00?ooo`3oool00?l03@3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo
01D0oooo00<00?l00?ooo`3oool0Q03oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<00?l0
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0I0?ooo`04003o003oool0oooo003o05<0oooo00@0
003o0?ooo`3oool0003o1@3oool00`00o`00oooo003o000P0?ooo`030?l0003oool0o`0000P0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3o0000203oool01@3o0000oooo0?ooo`3oool00?l000l0oooo00<00?l00?ooo`00
o`006`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool06`3oool00`00o`00oooo003o00090?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3o
ool07P3oool003d0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0a0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3o0000203oool01P3o0000oooo0?ooo`00o`00oooo003o
02`0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool0I03oool00`00o`00oooo003o000>0?ooo`03003o003oool0
oooo00`0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
oooo00d0oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`240?ooo`050000o`3oool0
oooo0?ooo`000?l01P3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo01T0oooo00@0
0?l00?ooo`3oool00?l0D`3oool00`000?l0oooo0000o`060?ooo`03003o003oool00?l00240oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00080?ooo`030?l0003oool0oooo0140
oooo00<00?l00?ooo`00o`006`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0
oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo01`0
oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0o`0000P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0/0?oo
o`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`1Z
0?ooo`03003o003oool00?l000h0oooo00<00?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`02
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`0D
0?ooo`03003o003oool0oooo08H0oooo00@0003o0?ooo`3oool0003o1P3oool00`00o`00oooo0?oo
o`0;0?ooo`03003o003oool0oooo01T0oooo00@00?l00?ooo`3oool00?l0E03oool20000o`H0oooo
00<00?l00?ooo`00o`00:`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00080?ooo`030?l0003oool0oooo0140
oooo00<00?l00?ooo`00o`006`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0
oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01`0
oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0o`0000P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0/0?oo
o`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0
oooo06X0oooo00<00?l00?ooo`00o`003P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0
oooo01<0oooo00<00?l00?ooo`3oool0QP3oool010000?l0oooo0?ooo`000?l60?ooo`03003o003o
ool0oooo00/0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo003o001D0?ooo`80003o1P3o
ool00`00o`00oooo003o000[0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool07`3o
ool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool0
4P3oool2003o01/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l000060?ooo`030?l0
003oool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0M0?ooo`03003o
003oool0oooo00P0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`00?@3o
ool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?l000070?ooo`070?l0003oool0oooo0?ooo`00o`00oooo003o000/0?ooo`03
0000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo
06X0oooo0P00o`0?0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`060?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool04P3oool00`00
o`00oooo0?ooo`270?ooo`040000o`3oool0oooo0000o`H0oooo00<00?l00?ooo`3oool02`3oool0
0`00o`00oooo0?ooo`0J0?ooo`800?l0EP3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
0?l002/0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0
oooo00<0oooo00@0003o0?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`0B0?ooo`03003o003o
ool0oooo01X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l000060?ooo`030?l0003o
ool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0M0?ooo`03003o003o
ool0oooo00P0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool0
0`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?l000070?ooo`030?l0003oool0oooo0080oooo0P00o`0/0?ooo`030000o`3oool0
oooo00L0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0006h0oooo00<00?l00?ooo`3oool0
3@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool0
Q`3oool010000?l0oooo0?ooo`000?l60?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3o
ool06P3oool2003o05h0oooo0P00o`0[0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?oo
o`3oool04`3oool00`00o`00oooo0?ooo`0J0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3o00001P3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo000m0?ooo`D0
00007@3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool0o`001P3oool00`3o0000oooo0?ooo`020?ooo`800?l0;03oool00`000?l0oooo0?ooo`070?oo
o`070000o`3oool0oooo0?ooo`3o0000oooo0?l0001^0?ooo`03003o003oool0oooo00d0oooo00<0
0?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo08P0oooo00@0
003o0?ooo`3oool0003o1P3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo01/0oooo
00<00?l00?ooo`3oool0G03oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000L0
oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0
oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo02T0
oooo00<0003o0?ooo`3oool07@3oool500000200oooo000m0?ooo`030000003oool0oooo01l0oooo
00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l000H0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0[0?ooo`030000o`3oool0oooo00L0
oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0007l0oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo08P0oooo00@0003o0?ooo`3oool0003o1P3o
ool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo01`0oooo00<00?l00?ooo`3oool0G03o
ool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`3oool0
<03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo02T0oooo00<0003o0?ooo`3oool0
8@3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo0380oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3o00060?ooo`030?l0
003oool0oooo0080oooo00<00?l00?ooo`3oool0:`3oool00`000?l0oooo0?ooo`070?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo0?l0001o0?ooo`03003o003oool0oooo00X0oooo00<00?l00?oo
o`3oool0103oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00l0oooo00<00?l00?oo
o`3oool03`3oool00`00o`00oooo0?ooo`290?ooo`040000o`3oool0oooo0000o`H0oooo00<00?l0
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`1k0?ooo`03003o003oool0oooo02/0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`04
0?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0[0?ooo`030000o`3oool0oooo00L0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0007l0
oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo08T0
oooo00@0003o0?ooo`3oool0003o1P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo
07/0oooo00<00?l00?ooo`3oool0:`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0240oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00070?ooo`030?l0003oool0
oooo0300oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0
oooo0100oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0Z0?ooo`030000o`3oool0
oooo0240oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0o`001P3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo02/0oooo00<0003o0?ooo`3oool01`3oool0
1`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000O`3oool00`00o`00oooo0?ooo`090?ooo`03003o
003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0A0?ooo`03003o
003oool0oooo00d0oooo00<00?l00?ooo`3oool0RP3oool010000?l0oooo0?ooo`000?l70?ooo`03
003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0Z@3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo0240oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00070?oo
o`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l000050?oo
o`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo0240oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool0o`001P3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00L0oooo00L0003o0?oo
o`3oool0oooo0?l0003oool0o`000800oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?oo
o`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool04P3oool00`00o`00oooo0?oo
o`0<0?ooo`03003o003oool0oooo08/0oooo00<0003o0?ooo`000?l01`3oool00`00o`00oooo0?oo
o`090?ooo`03003o003oool0oooo0:T0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000oooo
0?ooo`0`0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo
0?ooo`0A0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo01h0oooo00<0
o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l000H0oooo
00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`070?ooo`070000o`3oool0oooo0?ooo`3o
0000oooo0?l000200?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool02`3oool00`00
o`00oooo0?ooo`2<0?ooo`030000o`3oool0003o00L0oooo00<00?l00?ooo`3oool02@3oool00`00
o`00oooo0?ooo`2Y0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`3oool0<03oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`3oool04P3oool0
1@00o`00oooo0?ooo`3oool00?l002`0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?oo
o`0N0?ooo`00?@3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo03@0oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo0300oooo00<0
003o0?ooo`3oool01`3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000P@3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`0B0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0S03oool00`000?l0
oooo0000o`070?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0Z@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool00P3oool010000?l0
oooo0?ooo`3o00070?ooo`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool01P3oool01000
0?l0oooo0?ooo`3o00040?ooo`030?l0003oool0oooo0180oooo00D00?l00?ooo`3oool0oooo003o
000]0?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool07P3oool003d0oooo00<00000
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00L0oooo00L0
003o0?ooo`3oool0oooo0?l0003oool0o`000880oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool04`3oool00`00o`00
oooo0?ooo`090?ooo`03003o003oool0oooo08d0oooo00<0003o0?ooo`000?l01`3oool00`00o`00
oooo0?ooo`090?ooo`03003o003oool0oooo0:T0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000060?oo
o`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o0004
0?ooo`030?l0003oool0oooo0180oooo00D00?l00?ooo`3oool0oooo003o000]0?ooo`030000o`3o
ool0oooo0200oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00060?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool01P3oool01`000?l0oooo0?oo
o`3oool0o`000?ooo`3o0000PP3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00P0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`3oool0S@3oool00`000?l0oooo0000o`070?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`3oool0ZP3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0240
oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0o`000?oo
o`3oool0<03oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`00
0?ooo`3oool04P3oool01000o`00oooo0?ooo`00o`0^0?ooo`030000o`3oool0oooo0200oooo00<0
00000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0d
0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003o
ool0oooo0340oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80o`00P`3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0SP3o
ool20000o`T0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`2Z0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00H0oooo
00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`0B0?ooo`04003o003oool0oooo003o
02h0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0N0?ooo`00?@3oool5000001/0
oooo00<0o`000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`230?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01@0oooo00<00?l00?oo
o`3oool01P3oool2003o0900oooo0P000?l90?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool0Z`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0240oooo00<0003o0?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool0<@3oool0
0`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool04`3o
ool00`00o`00oooo003o000^0?ooo`030000o`3oool0oooo01`0oooo1@00000P0?ooo`00?@3oool0
0`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0Q03oool01@00o`00oooo0?oo
o`3oool00?l000/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0D0?ooo`03003o
003oool0oooo00@0oooo0P00o`2B0?ooo`80003o2@3oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo0:/0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0oooo0340
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00040?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`00o`00;P3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo
01h0oooo000m0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0=@3oool00`000?l0
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0a0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`240?oo
o`05003o003oool0oooo0?ooo`00o`002`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo01@0oooo00<00?l00?ooo`3oool00P3oool2003o09@0oooo0P000?l:0?ooo`03003o003oool0
oooo00H0oooo00<00?l00?ooo`3oool0Z`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo02<0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo0340oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00040?ooo`030?l0
003oool0oooo01<0oooo00<00?l00?ooo`00o`00;P3oool00`000?l0oooo0?ooo`0P0?ooo`030000
003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0=P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0a0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`250?ooo`04003o003oool0oooo003o00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`0E0?ooo`04003o003oool00?l0003o09L0oooo00<0003o0?ooo`3oool0203oool00`00
o`00oooo0?ooo`060?ooo`03003o003oool0oooo0:/0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103o
ool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool00?l002l0oooo00<0003o0?ooo`3oool07`3o
ool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo03H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0QP3oool2003o00d0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0E0?ooo`800?l0V@3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool0Z`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02<0oooo00@0
003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0340oooo
00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00040?ooo`030?l0003oool0oooo01<0
oooo0P00o`0`0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0503oool00`000000
oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo03H0oooo
00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0<P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0QP3oool2003o00d0oooo00D00?l00?ooo`3oool0oooo003o002c0?ooo`030000o`3oool0oooo
00P0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`2[0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo02h0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0=P3oool01@000?l0oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`270?ooo`03003o003o
ool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o002c0?ooo`030000o`3oool0oooo00T0oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`2/0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo02h0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo000m0?ooo`03
0000003oool0oooo01d0oooo00<0o`000?ooo`3oool0=P3oool01@000?l0oooo0?ooo`3oool0003o
00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0V`3oool01@00o`00oooo0?ooo`3oool00?l00;<0oooo00<0003o
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0:`0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`@0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0
;P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0
7P3oool003d0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0g0?ooo`050000o`3o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0380oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`2K0?ooo`05003o003oool0oooo0?ooo`00
o`00_`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0:`0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030?l0003oool0oooo04H0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo
01`0oooo00<0o`000?ooo`3oool0>03oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo09`0oooo00@00?l00?ooo`3oool00?l0`03oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo0:`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0S0?ooo`040000o`3o
ool0oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000
o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo04H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0>03oool010000?l0oooo
0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0<P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo09`0oooo00@00?l00?ooo`3oool00?l0`03oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo0:`0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0F0?ooo`030000003oool0oooo01h0oooo000m0?ooo`D000006P3oool00`3o0000oooo0?ooo`0h
0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0b0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0W03oool01000o`00oooo0?oo
o`00o`300?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0[@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool0103oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0180oooo1@00000P0?ooo`00?@3oool00`000000oooo0?ooo`1G0?ooo`04
0000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0b0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0W03oool01000o`00oooo0?ooo`00o`31
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0[@3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01L0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0E`3o
ool010000?l0oooo0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo09`0oooo00@00?l00?ooo`3oool0
0?l0`@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0:d0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo05L0
oooo00@0003o0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
03<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2L0?ooo`04003o003oool0oooo
003o0<40oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`2^0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`170?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`1G
0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0W@3oool00`00o`00oooo003o
00320?ooo`05003o003oool0oooo0?ooo`00o`00/03oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo02D0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo0380oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0o`000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0F03oool20000o`D0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0W@3oool00`00o`00oooo003o00320?ooo`05003o003oool0oooo0?ooo`00
o`00/03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l004T0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo01h0oooo000m0?ooo`03
0000003oool0oooo05P0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool0<`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo09d0oooo0P00o`330?ooo`05
003o003oool0oooo0?ooo`00o`00/03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
02D0oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0380oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo
0?l004X0oooo00D0003o0?ooo`3oool0oooo0000o`0K0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo05P0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo09d0oooo0P00o`34
0?ooo`04003o003oool0oooo003o0;00oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0U0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0b0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?oo
o`3o001:0?ooo`050000o`3oool0oooo0?ooo`000?l06`3oool00`000000oooo0?ooo`0N0?ooo`00
?@3oool00`000000oooo0?ooo`1H0?ooo`80003o1@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo03<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2M0?ooo`800?l0
a03oool01000o`00oooo0?ooo`00o`2`0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool0<`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3o
ool0o`00BP3oool01@000?l0oooo0?ooo`3oool0003o01/0oooo00<000000?ooo`3oool07P3oool0
03d0oooo00<000000?ooo`3oool0F03oool20000o`D0oooo00D0o`000?ooo`3oool0oooo0?l0000f
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0W@3oool2003o0<@0oooo00@00?l0
0?ooo`3oool00?l0/03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02D0oooo0P00
0?l60?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`00BP3oool010000?l0oooo
0?ooo`000?lL0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo05P0oooo
0P000?l50?ooo`050?l0003oool0oooo0?ooo`3o0000=P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo09h0oooo00<00?l00?ooo`3oool0`P3oool00`00o`00oooo003o002a0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09@3oool20000o`H0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool0103o0000oooo0?ooo`3o001:0?ooo`040000o`3oool0oooo0000oa`0oooo00<00000
0?ooo`3oool07P3oool003d0oooo1@00001G0?ooo`030000o`3oool0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0?l0000f0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0WP3oool0
0`00o`00oooo0?ooo`330?ooo`800?l0/P3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo0P00
0?l60?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`00BP3oool010000?l0oooo
0?ooo`000?lH0?ooo`D00000803oool003d0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000=P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo09h0oooo00<00?l00?ooo`3oool0``3oool2003o0;80oooo00D0o`000?ooo`3o
ool0oooo0?l0000X0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`3o001:0?ooo`030000o`3oool0003o01d0oooo00<000000?ooo`3oool07P3oool0
03d0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo
0?ooo`3o0000=P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0?l0ooooI@3oool2
003o0;80oooo00D0o`000?ooo`3oool0oooo0?l0000X0?ooo`030000o`3oool0oooo00@0oooo00D0
o`000?ooo`3oool0oooo0?l0000f0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?l0001<0?ooo`80003o7@3oool00`000000oooo0?ooo`0N0?ooo`00?@3o
ool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0?l0000f0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0o`3ooomV0?ooo`03003o
003oool0oooo0;00oooo00@0o`000?ooo`3oool0o`00:@3oool00`000?l0oooo0?ooo`040?ooo`05
0?l0003oool0oooo0?ooo`3o0000=P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3o0000C03oool20000oad0oooo00<000000?ooo`3oool07P3oool003d0
oooo00<000000?ooo`3oool0G`3oool01@3o0000oooo0?ooo`3oool0o`0003H0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`3o0?ooofH0oooo00<00?l00?ooo`3oool0/03oool0103o
0000oooo0?ooo`3o000Y0?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0
000f0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l0
001<0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool07P3oool003d0oooo00<00000
0?ooo`3oool0G`3oool01@3o0000oooo0?ooo`3oool0o`0003H0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`3o0?ooool0oooo6P3oool0103o0000oooo0?ooo`3o000Y0?ooo`030000
o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0000f0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l0001<0?ooo`030000o`3oool0oooo01`0
oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0G`3oool01@3o0000oooo
0?ooo`3oool0o`0003L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`3o0?ooool0
oooo6`3oool0103o0000oooo0?ooo`3o000Y0?ooo`030000o`3oool0oooo00@0oooo00D0o`000?oo
o`3oool0oooo0?l0000f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?l0001[0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo
05l0oooo00D0o`000?ooo`3oool0oooo0?l0000g0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0o`3ooooo0?oooa/0oooo00@0o`000?ooo`3oool0o`00<03oool01@3o0000oooo0?oo
o`3oool0o`0003H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0o`0006/0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0H03o
ool0103o0000oooo0?ooo`3o000g0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
o`3ooooo0?oooa`0oooo00<0o`000?ooo`3o0000<03oool01@3o0000oooo0?ooo`3oool0o`0003H0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`0006/0
oooo00<000000?ooo`3oool07P3oool00280oooo0P0000040?ooo`800000103oool2000000d0oooo
00<000000?ooo`3oool0H03oool0103o0000oooo0?ooo`3o000g0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0o`3ooooo0?oooa`0oooo00<0o`000?ooo`3o0000<03oool01@3o0000
oooo0?ooo`3oool0o`0003H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0o`0006/0oooo00<000000?ooo`3oool07P3oool00240oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0600oooo00@0o`00
0?ooo`3oool0o`00=`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0?l0ooooo`3o
oolL0?ooo`030?l0003oool0o`000300oooo00D0o`000?ooo`3oool0oooo0?l0000f0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?l0001[0?ooo`030000
003oool0oooo01h0oooo000Q0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
2P3oool7000005`0oooo00@0o`000?ooo`3oool0o`00=`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0?l0ooooo`3ooolL0?ooo`030?l0003oool0o`000300oooo00D0o`000?ooo`3o
ool0oooo0?l0000f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?l0001U0?ooo`L00000803oool00240oooo00@000000?ooo`3oool000002@3oool20000
00d0oooo00<000000?ooo`3oool0H03oool0103o0000oooo0?ooo`3o000g0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0o`3ooooo0?oooa`0oooo00<0o`000?ooo`3o0000<03oool0
1@3o0000oooo0?ooo`3oool0o`0003H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0o`0006/0oooo00<000000?ooo`3oool07P3oool00240oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00@0
o`000?ooo`3oool0o`00=`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0?l0oooo
o`3ooolL0?ooo`030?l0003oool0o`000300oooo00D0o`000?ooo`3oool0oooo0?l0000f0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?l0001[0?ooo`03
0000003oool0oooo01h0oooo000R0?ooo`8000002P3oool3000000`0oooo00<000000?ooo`3oool0
H03oool00`3o0000oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
o`3ooooo0?oooa`0oooo00<0o`000?ooo`3o0000<03oool01@3o0000oooo0?ooo`3oool0o`0003H0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`80o`00J`3oool00`000000
oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`1P0?ooo`030?l0003oool0o`0003P0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`3o0?ooool0oooo703oool20?l00340oooo
00D0o`000?ooo`3oool0oooo0?l0000f0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool20?l006/0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0
H03oool00`3o0000oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
o`3ooooo0?oooad0oooo00<0o`000?ooo`3oool0<03oool0103o0000oooo0?ooo`3o000g0?ooo`05
0000o`3oool0oooo0?ooo`000?l01P3oool20?l006/0oooo00<000000?ooo`3oool07P3oool003d0
oooo00<000000?ooo`3oool0H03oool00`3o0000oooo0?l0000h0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0o`3ooooo0?oooad0oooo00<0o`000?ooo`3oool0<03oool0103o0000
oooo0?ooo`3o000g0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`3o0000oooo0?ooo`1Z
0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0600oooo00<0o`000?oo
o`3o0000>03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0?l0ooooo`3ooolM0?oo
o`030?l0003oool0oooo0300oooo00@0o`000?ooo`3oool0o`00=`3oool01@000?l0oooo0?ooo`3o
ool0003o00H0oooo00<0o`000?ooo`3oool0JP3oool00`000000oooo0?ooo`0N0?ooo`00?@3oool0
0`000000oooo0?ooo`1P0?ooo`030?l0003oool0o`0003P0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`3o0?ooool0oooo7@3oool00`3o0000oooo0?ooo`0`0?ooo`040?l0003oool0
oooo0?l003L0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo06X0oooo
00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0H03oool00`3o0000oooo0?l0
000h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0o`3ooooo0?oooad0oooo00<0
o`000?ooo`3oool0<03oool00`3o0000oooo0?l0000h0?ooo`050000o`3oool0oooo0?ooo`000?l0
1P3oool00`3o0000oooo0?ooo`1Z0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003o
ool0oooo0600oooo00<0o`000?ooo`3o0000>@3oool01@000?l0oooo0?ooo`3oool0003o0?l0oooo
o`3ooomB0?ooo`030?l0003oool0o`0003P0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`03
0?l0003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool003d0oooo1@00001N0?ooo`030?l0
003oool0o`0003T0oooo00D0003o0?ooo`3oool0oooo0000o`3o0?ooool0ooooDP3oool00`3o0000
oooo0?l0000h0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`3o0000oooo0?ooo`1V0?oo
o`D00000803oool003d0oooo00<000000?ooo`3oool0H03oool00`3o0000oooo0?l0000i0?ooo`05
0000o`3oool0oooo0?ooo`000?l0o`3ooooo0?oooe80oooo00<0o`000?ooo`3o0000>03oool01@00
0?l0oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool0JP3oool00`000000oooo0?ooo`0N
0?ooo`00?@3oool00`000000oooo0?ooo`1P0?ooo`030?l0003oool0o`0003T0oooo00D0003o0?oo
o`3oool0oooo0000o`3o0?ooool0ooooDP3oool00`3o0000oooo0?l0000h0?ooo`050000o`3oool0
oooo0?ooo`000?l01P3oool00`3o0000oooo0?ooo`1Z0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo0600oooo00<0o`000?ooo`3o0000>@3oool01@000?l0oooo0?ooo`3o
ool0003o0?l0ooooo`3ooomB0?ooo`030?l0003oool0o`0003P0oooo00D0003o0?ooo`3oool0oooo
0000o`1c0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo0600oooo00<0
o`000?ooo`3o0000>@3oool010000?l0oooo0?ooo`000?oo0?ooool0ooooD`3oool00`3o0000oooo
0?l0000h0?ooo`050000o`3oool0oooo0?ooo`000?l0L`3oool00`000000oooo0?ooo`0N0?ooo`00
?@3oool00`000000oooo0?ooo`1P0?ooo`030?l0003oool0o`0003T0oooo00@0003o0?ooo`3oool0
003oo`3ooooo0?oooe<0oooo00<0o`000?ooo`3o0000>03oool01@000?l0oooo0?ooo`3oool0003o
07<0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0H@3oool20?l003T0
oooo00@0003o0?ooo`3oool0003oo`3ooooo0?oooe<0oooo00<0o`000?ooo`3o0000>03oool01@00
0?l0oooo0?ooo`3oool0003o07<0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?oo
o`3oool0H@3oool20?l003T0oooo00@0003o0?ooo`3oool0003oo`3ooooo0?oooe<0oooo00<0o`00
0?ooo`3o0000>03oool010000?l0oooo0?ooo`000?md0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3oool0>03oool010000?l0oooo0?ooo`00
0?oo0?ooool0ooooD`3oool00`3o0000oooo0?l0000h0?ooo`040000o`3oool0oooo0000og@0oooo
00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?oo
o`0h0?ooo`040000o`3oool0oooo0000ool0ooooo`3ooomC0?ooo`030?l0003oool0o`0003P0oooo
00@0003o0?ooo`3oool0003oM03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo
0?ooo`1Q0?ooo`030?l0003oool0oooo03P0oooo00@0003o0?ooo`3oool0003oo`3ooooo0?oooe<0
oooo00<0o`000?ooo`3o0000>03oool010000?l0oooo0?ooo`000?md0?ooo`030000003oool0oooo
01h0oooo000m0?ooo`D00000G`3oool00`3o0000oooo0?ooo`0h0?ooo`040000o`3oool0oooo0000
ool0ooooo`3ooomC0?ooo`030?l0003oool0o`0003P0oooo00@0003o0?ooo`3oool0003oL03oool5
00000200oooo000m0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3oool0>03oool01000
0?l0oooo0?ooo`000?oo0?ooool0ooooD`3oool00`3o0000oooo0?l0000h0?ooo`040000o`3oool0
oooo0000og@0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0H@3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0003o0?l0ooooo`3ooomC0?ooo`030?l0003oool0
o`0003T0oooo00<0003o0?ooo`000?l0M03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`00
0000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo03T0oooo00<0003o0?ooo`000?l0o`3ooooo0?oo
oe@0oooo0P3o000i0?ooo`030000o`3oool0003o07@0oooo00<000000?ooo`3oool07P3oool003d0
oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0003o0?l0
ooooo`3ooomD0?ooo`80o`00>@3oool00`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3oool0>@3oool00`000?l0oooo
0000o`3o0?ooool0ooooE03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo
00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0W@3oool00`000?l0oooo0000
o`3o0?ooool0ooooE03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo00<0
00000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0W@3oool00`000?l0oooo0000o`3o
0?ooool0ooooE03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo00<00000
0?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0W@3oool00`000?l0oooo0000o`3o0?oo
ool0ooooE03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo00<000000?oo
o`3oool07P3oool003d0oooo00<000000?ooo`3oool0W@3oool00`000?l0oooo0000o`3o0?ooool0
ooooE03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo00<000000?ooo`3o
ool07P3oool003d0oooo00<000000?ooo`3oool0W@3oool00`000?l0oooo0000o`3o0?ooool0oooo
E03oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0003o07@0oooo00<000000?ooo`3oool0
7P3oool003d0oooo1@00002K0?ooo`030000o`3oool0003o0?l0ooooo`3ooomD0?ooo`030?l0003o
ool0oooo03P0oooo00<0003o0?ooo`000?l0L03oool500000200oooo000m0?ooo`030000003oool0
oooo09d0oooo00<0003o0?ooo`000?l0o`3ooooo0?oooe@0oooo00<0o`000?ooo`3oool0>03oool0
0`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo
09d0oooo00<0003o0?ooo`000?l0o`3ooooo0?oooe@0oooo00<0o`000?ooo`3oool0>03oool00`00
0?l0oooo0000o`1d0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo09d0
oooo0P000?oo0?ooool0ooooT03oool00`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo09d0oooo0P000?oo0?ooool0ooooT03oool00`000?l0oooo
0000o`1d0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo09d0oooo0P00
0?oo0?ooool0ooooT03oool00`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo09h0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooohh0oooo00<0003o
0?ooo`000?l0M03oool00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`2N0?oo
o`030000o`3oool0oooo0?l0ooooo`3ooon>0?ooo`030000o`3oool0003o07@0oooo00<000000?oo
o`3oool07P3oool003d0oooo00<000000?ooo`3oool0WP3oool00`000?l0oooo0?ooo`3o0?ooool0
ooooSP3oool20000ogD0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0
WP3oool00`000?l0oooo0?ooo`3o0?ooool0ooooSP3oool20000ogD0oooo00<000000?ooo`3oool0
7P3oool003d0oooo00<000000?ooo`3oool0WP3oool00`000?l0oooo0?ooo`3o0?ooool0ooooS`3o
ool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo01h0oooo000m0?ooo`D00000W03oool0
0`000?l0oooo0?ooo`3o0?ooool0ooooS`3oool00`000?l0oooo0?ooo`1_0?ooo`D00000803oool0
03d0oooo00<000000?ooo`3oool0WP3oool00`000?l0oooo0?ooo`3o0?ooool0ooooS`3oool00`00
0?l0oooo0?ooo`1c0?ooo`030000003oool0oooo01h0oooo000m0?ooo`030000003oool0oooo09h0
oooo00<0003o0?ooo`3oool0o`3ooooo0?ooohl0oooo00<0003o0?ooo`3oool0L`3oool00`000000
oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooola0?ooo`030000
o`3oool0oooo07<0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo<@3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo01h0oooo000m
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooc40oooo00<0003o0?ooo`3oool0L`3oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooola0?oo
o`030000o`3oool0oooo07<0oooo00<000000?ooo`3oool07P3oool003d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo<@3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo01h0
oooo000m0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`1T0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0N0?ooo`008P3oool2000000@0oooo0P0000030?ooo`<000003@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07P3oool00240oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000<0?ooo`L00000403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool09`3oool700000200oooo000Q0?ooo`040000003oool0oooo000000P0
oooo0`00000=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0N0?ooo`008@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0
ooooo`00003o00000?l00000Z`00000P0?ooo`008P3oool2000000X0oooo0`00003o0?ooool0oooo
o`3ooooG0?ooo`00o`3ooooo0?ooool0ooooo`3oool90?ooo`00\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {566.438, 361.563}} -> {-13.6225, \
0.965253, 0.115893, 0.00182298}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Raw Tapping Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions3b];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.258542 1.15042 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02906 -24 -4.5 ]
[-0.0125 .02906 0 4.5 ]
[-0.0125 .08658 -18 -4.5 ]
[-0.0125 .08658 0 4.5 ]
[-0.0125 .14411 -24 -4.5 ]
[-0.0125 .14411 0 4.5 ]
[-0.0125 .20163 -18 -4.5 ]
[-0.0125 .20163 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02906 m
.00625 .02906 L
s
[(0.25)] -0.0125 .02906 1 0 Mshowa
0 .08658 m
.00625 .08658 L
s
[(0.3)] -0.0125 .08658 1 0 Mshowa
0 .14411 m
.00625 .14411 L
s
[(0.35)] -0.0125 .14411 1 0 Mshowa
0 .20163 m
.00625 .20163 L
s
[(0.4)] -0.0125 .20163 1 0 Mshowa
.125 Mabswid
0 .04057 m
.00375 .04057 L
s
0 .05207 m
.00375 .05207 L
s
0 .06358 m
.00375 .06358 L
s
0 .07508 m
.00375 .07508 L
s
0 .09809 m
.00375 .09809 L
s
0 .10959 m
.00375 .10959 L
s
0 .1211 m
.00375 .1211 L
s
0 .1326 m
.00375 .1326 L
s
0 .15561 m
.00375 .15561 L
s
0 .16711 m
.00375 .16711 L
s
0 .17862 m
.00375 .17862 L
s
0 .19012 m
.00375 .19012 L
s
0 .01756 m
.00375 .01756 L
s
0 .00606 m
.00375 .00606 L
s
0 .21313 m
.00375 .21313 L
s
0 .22463 m
.00375 .22463 L
s
0 .23614 m
.00375 .23614 L
s
0 .24764 m
.00375 .24764 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .02906 m
1 .02906 L
s
.99375 .08658 m
1 .08658 L
s
.99375 .14411 m
1 .14411 L
s
.99375 .20163 m
1 .20163 L
s
.125 Mabswid
.99625 .04057 m
1 .04057 L
s
.99625 .05207 m
1 .05207 L
s
.99625 .06358 m
1 .06358 L
s
.99625 .07508 m
1 .07508 L
s
.99625 .09809 m
1 .09809 L
s
.99625 .10959 m
1 .10959 L
s
.99625 .1211 m
1 .1211 L
s
.99625 .1326 m
1 .1326 L
s
.99625 .15561 m
1 .15561 L
s
.99625 .16711 m
1 .16711 L
s
.99625 .17862 m
1 .17862 L
s
.99625 .19012 m
1 .19012 L
s
.99625 .01756 m
1 .01756 L
s
.99625 .00606 m
1 .00606 L
s
.99625 .21313 m
1 .21313 L
s
.99625 .22463 m
1 .22463 L
s
.99625 .23614 m
1 .23614 L
s
.99625 .24764 m
1 .24764 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .13234 m
.0423 .11937 L
.05155 .14827 L
.0608 .0951 L
.07004 .15265 L
.07929 .0984 L
.08853 .08886 L
.09778 .03101 L
.10703 .20846 L
.11627 .12573 L
.12552 .13333 L
.13477 .08378 L
.14401 .12941 L
.15326 .11175 L
.16251 .10295 L
s
.16251 .10295 m
.16917 0 L
s
.17351 0 m
.181 .17025 L
.19025 .08785 L
.19949 .12402 L
.20874 .10001 L
.21798 .11636 L
.22723 .08438 L
.23648 .20347 L
.24572 .00512 L
.25497 .10887 L
.26422 .10916 L
.27346 .11708 L
.28271 .11964 L
.29196 .19136 L
.3012 .09898 L
.31045 .09882 L
.31969 .0758 L
.32894 .10988 L
.33819 .08212 L
.34743 .14198 L
.35668 .13303 L
.36593 .13189 L
.37517 .07527 L
.38442 .12725 L
.39367 .0885 L
.40291 .06915 L
.41216 .09502 L
.42141 .10999 L
.43065 .10273 L
.4399 .11627 L
.44914 .12607 L
.45839 .13614 L
.46764 .10828 L
.47688 .11997 L
.48613 .12493 L
.49538 .13087 L
.50462 .14536 L
.51387 .11836 L
.52312 .13239 L
.53236 .06682 L
.54161 .07149 L
.55086 .1366 L
.5601 .09342 L
.56935 .12014 L
.57859 .10359 L
.58784 .15925 L
.59709 .13464 L
.60633 .05866 L
.61558 .13115 L
.62483 .11323 L
Mistroke
.63407 .12153 L
.64332 .08647 L
.65257 .13073 L
.66181 .13831 L
.67106 .11172 L
.68031 .07364 L
.68955 .08852 L
.6988 .03893 L
.70804 .14214 L
.71729 .06216 L
.72654 .05897 L
.73578 .12388 L
.74503 .06965 L
.75428 .08834 L
.76352 .12123 L
.77277 .15188 L
.78202 .11098 L
.79126 .11551 L
.80051 .00622 L
.80975 .16405 L
.819 .11078 L
.82825 .12448 L
.83749 .10705 L
.84674 .11528 L
.85599 .12045 L
.86523 .12065 L
Mfstroke
.86523 .12065 m
.87106 0 L
s
.8768 0 m
.88373 .21074 L
.89297 .12883 L
.90222 .10695 L
.91147 .09925 L
.92071 .10353 L
.92996 .08942 L
.9392 .12724 L
.94845 .08248 L
.9577 .10062 L
.96694 .08548 L
.97619 .12358 L
s
0 1 0 r
.03306 .13638 m
.0423 .14679 L
.05155 .12382 L
.0608 .13767 L
.07004 .12147 L
.07929 .17799 L
.08853 .10937 L
.09778 .04424 L
.10703 .15802 L
.11627 .0801 L
.12552 .12493 L
.13477 .09524 L
.14401 .09987 L
.15326 .1078 L
.16251 .16383 L
.17175 .04562 L
.181 .14411 L
.19025 .10302 L
.19949 .11177 L
.20874 .09368 L
.21798 .12583 L
.22723 .13485 L
.23648 .10607 L
.24572 .21695 L
.25497 .09984 L
.26422 .12538 L
.27346 .09906 L
.28271 .14129 L
.29196 .09967 L
.3012 .09322 L
.31045 .12081 L
.31969 .10446 L
.32894 .10705 L
.33819 .16449 L
.34743 .11357 L
.35668 .12088 L
.36593 .16947 L
.37517 .107 L
.38442 .11472 L
.39367 .0885 L
.40291 .12415 L
.41216 .14692 L
.42141 .13738 L
.43065 .14756 L
.4399 .12246 L
.44914 .14082 L
.45839 .11148 L
.46764 .14484 L
.47688 .13734 L
.48613 .14523 L
Mistroke
.49538 .12018 L
.50462 .11785 L
.51387 .14053 L
.52312 .13828 L
.53236 .11649 L
.54161 .14411 L
.55086 .11439 L
.5601 .10481 L
.56935 .15729 L
.57859 .13781 L
.58784 .1365 L
.59709 .12537 L
.60633 .1414 L
.61558 .16079 L
.62483 .13182 L
.63407 .13046 L
.64332 .15476 L
.65257 .11877 L
.66181 .13487 L
.67106 .13884 L
.68031 .1168 L
.68955 .05908 L
.6988 .09371 L
.70804 .18868 L
.71729 .13767 L
.72654 .16879 L
.73578 .14923 L
.74503 .14323 L
.75428 .16892 L
.76352 .1089 L
.77277 .12576 L
.78202 .1911 L
.79126 .11325 L
.80051 .07651 L
.80975 .18456 L
.819 .12622 L
.82825 .12584 L
.83749 .07336 L
.84674 .14029 L
.85599 .12045 L
.86523 .12193 L
.87448 .05393 L
.88373 .12225 L
.89297 .09373 L
.90222 .10155 L
.91147 .11361 L
.92071 .14725 L
.92996 .12448 L
.9392 .13973 L
.94845 .10229 L
Mistroke
.9577 .14603 L
.96694 .14741 L
.97619 .15474 L
Mfstroke
0 0 1 r
.03306 .10608 m
.0423 .10864 L
.05155 .1027 L
.0608 .14203 L
.07004 .10068 L
.07929 .0984 L
.08853 .17657 L
s
.08853 .17657 m
.09406 .25 L
s
.09935 .25 m
.10703 .00832 L
.11627 .16896 L
.12552 .11653 L
.13477 .19577 L
.14401 .14552 L
.15326 .15524 L
.16251 .10802 L
s
.16251 .10802 m
.16753 .25 L
s
.17532 .25 m
.181 .06044 L
.19025 .18393 L
.19949 .139 L
.20874 .1811 L
.21798 .1326 L
.22723 .15556 L
.23648 .06526 L
.24572 .15273 L
.25497 .16609 L
.26422 .14025 L
.27346 .15866 L
.28271 .11387 L
.29196 .08377 L
.3012 .1826 L
.31045 .15517 L
.31969 .19453 L
.32894 .15787 L
.33819 .12819 L
.34743 .11925 L
.35668 .12088 L
.36593 .07343 L
.37517 .19252 L
.38442 .13282 L
.39367 .1978 L
.40291 .1815 L
.41216 .13286 L
.42141 .12742 L
.43065 .1245 L
.4399 .13606 L
.44914 .10791 L
.45839 .12717 L
.46764 .12168 L
.47688 .11749 L
.48613 .10463 L
.49538 .12374 L
.50462 .11159 L
.51387 .1159 L
.52312 .10413 L
.53236 .19149 L
.54161 .1592 L
.55086 .12381 L
.5601 .17657 L
.56935 .09737 L
.57859 .1334 L
.58784 .07904 L
.59709 .11478 L
.60633 .17473 L
.61558 .08285 L
.62483 .12975 L
Mistroke
.63407 .12281 L
.64332 .13357 L
.65257 .12529 L
.66181 .10161 L
.67106 .12424 L
.68031 .18436 L
.68955 .22719 L
.6988 .24215 L
.70804 .04397 L
.71729 .17496 L
.72654 .14704 L
.73578 .10169 L
.74503 .16192 L
.75428 .11753 L
.76352 .14466 L
.77277 .09716 L
.78202 .07271 L
.79126 .14603 L
Mfstroke
.79126 .14603 m
.79785 .25 L
s
.80197 .25 m
.80975 .02619 L
.819 .1378 L
.82825 .12448 L
.83749 .19439 L
.84674 .11923 L
.85599 .13389 L
.86523 .13222 L
s
.86523 .13222 m
.86943 .25 L
s
.87822 .25 m
.88373 .0418 L
.89297 .15223 L
.90222 .16629 L
.91147 .16193 L
.92071 .12402 L
.92996 .1609 L
.9392 .10782 L
.94845 .19002 L
.9577 .12814 L
.96694 .1419 L
.97619 .09648 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00DP3oool200000:P0oooo100000030?ooo`800000Y`3oool30000
0080oooo0P00002V0?ooo`<00000103oool200000:H0oooo0P0000040?ooo`800000XP3oool50000
0080oooo0P0000040?ooo`800000A03oool00540oooo00@000000?ooo`3oool00000Y`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000Y03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
@@3oool00540oooo00@000000?ooo`3oool00000Z03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:@0oooo1@0000001@3oool000000?ooo`3oool000000:D0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3oool010000000oooo0?ooo`00002Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool3000000<0oooo00@000000?ooo`3o
ool00000Y@3oool2000000<0oooo00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3o
ool010000000oooo0?ooo`00002W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000:H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00DP3oool200000:T0oooo0P0000040?oo
o`800000Y`3oool2000000<0oooo0P00002W0?ooo`<000000`3oool200000:H0oooo0P0000040?oo
o`800000X`3oool2000000@0oooo0P0000040?ooo`800000A03oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03`0ooooX00000001@3o00000000000000000000o`000?l00000o`00002B000000030?l000000000
000000<0000000<0o`00000000000000LP00000I0?ooo`00?03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000P
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0?l0000P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
08H0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0680oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`260?oo
o`050?l0003oool0oooo0?ooo`3o0000803oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0
oooo08P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo0680oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000B0?ooo`030000003oool0oooo
08H0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`030000003oool0oooo0200oooo00<0o`00
0?ooo`3oool0R03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool0803oool00`3o0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0@03oool00`000000oooo0?ooo`0Z0?ooo`D000006@3oool003`0oooo00<000000?oo
o`3oool0W@3oool01@3o0000oooo0?ooo`3oool0o`0004<0oooo00<0o`000?ooo`3oool0o`3ooooo
0?ooo`X0oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0740oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool00`00
0?l0oooo0?ooo`0h0?ooo`050?l0003oool0oooo0?ooo`3o0000@`3oool00`3o0000oooo0?ooo`3o
0?ooool0oooo2P3oool00`3o0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1R0?oo
o`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`110?oo
o`030?l0003oool0oooo0?l0ooooo`3oool:0?ooo`030?l0003oool0oooo03l0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`1a0?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo0680oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0440oooo00<0o`000?ooo`3oool0o`3ooooo0?ooo`X0oooo00<0o`000?ooo`3o
ool0?`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0740oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0@@3oool20?l00?l0ooooo`3oool;0?ooo`030?l0
003oool0oooo03l0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1a0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0=`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0400oooo0P3o003o0?ooool0oooo2P3o
ool20?l00400oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1a0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0=`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0400oooo0P3o003o0?ooool0oooo2P3oool2
0?l00400oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1a0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0400oooo0P3o003o0?ooool0oooo2P3oool20?l0
0400oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1a0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0=`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0400oooo0P3o003o0?ooool0oooo2P3oool00`3o0000
oooo0?l0000o0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool500000600oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo03l0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooo`X0oooo
00<0o`000?ooo`3o0000?`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo06d0oooo
1@00000I0?ooo`00?03oool00`000000oooo0?ooo`1R0?ooo`80003o>03oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo03l0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooo`X0oooo00<0
o`000?ooo`3o0000?`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0700oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool20000ocP0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0o0?ooo`030?l0003oool0o`000?l0ooooo`3oool:
0?ooo`030?l0003oool0o`0003l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1`
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0680oooo0P000?lh0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?l0003o0?oo
ool0oooo2P3oool00`3o0000oooo0?l0000o0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool0L03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1R0?ooo`80
003o>03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo03l0oooo00<0o`000?ooo`3o
0000o`3ooooo0?ooo`X0oooo00<0o`000?ooo`3o0000?`3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo0700oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
HP3oool20000ocP0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0o0?ooo`030?l0
003oool0o`000?l0ooooo`3oool:0?ooo`030?l0003oool0o`0003l0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0680oooo0P000?lh0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0?`3o
ool0103o0000oooo0?ooo`3o003o0?ooool0oooo2@3oool00`3o0000oooo0?l0000o0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1R0?ooo`80003o>03oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo03l0oooo00@0o`000?ooo`3oool0o`00o`3ooooo0?ooo`T0oooo00<0o`000?ooo`3o0000
?`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0HP3oool20000ocP0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0o0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`040?l0
003oool0oooo0?l003l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1`0?ooo`03
0000003oool0oooo01L0oooo000K0?ooo`800000103oool2000000<0oooo100000030?ooo`800000
3@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0o0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`04
0?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0700oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000`0oooo00<00000
0?ooo`3oool0H@3oool00`000?l0oooo0000o`0g0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0?`3oool0103o0000oooo0?ooo`3o003o0?ooool0oooo203oool0103o0000oooo0?oo
o`3o00070?ooo`030000o`3oool0oooo03D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`1`0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`L00000G@3oool00`000?l0oooo
0000o`0g0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0?`3oool0103o0000oooo
0?ooo`3o003o0?ooool0oooo203oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo
03D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1Z0?ooo`L000006@3oool001X0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0o0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`040?l0003oool0
oooo0?l000L0oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0700oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
FP3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0o0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`04
0?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0700oooo00<000000?ooo`3oool05`3oool001/0oooo0P00000:0?ooo`80
0000103oool3000000`0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0o0?ooo`04
0?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o
0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0700oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0o0?oo
o`040?l0003oool0oooo0?l00?l0ooooo`3oool80?ooo`050?l0003oool0oooo0?ooo`3o00001P3o
ool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`000?l0=`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo03l0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooool0oooo1`3oool01@3o0000oooo0?oo
o`3oool0o`0000H0oooo0P000?lf0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
L03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1I0?ooo`80o`001P3o
ool00`000?l0oooo0000o`0g0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0?`3o
ool01@3o0000oooo0?ooo`3oool0o`000?l0ooooo`3oool70?ooo`050?l0003oool0oooo0?ooo`3o
00001P3oool20000ocH0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1`0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05T0oooo0P3o00060?ooo`040000
o`3oool0oooo0000ocH0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0o0?ooo`05
0?l0003oool0oooo0?ooo`3o0000o`3ooooo0?ooo`L0oooo00D0o`000?ooo`3oool0oooo0?l00006
0?ooo`80003o=P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0700oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0F@3oool20?l000H0oooo00@0003o0?oo
o`3oool0003o=P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo03h0oooo00D0o`00
0?ooo`3oool0oooo0?l0003o0?ooool0oooo1P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00@0oooo0P000?le0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1I0?ooo`80o`001P3oool0
10000?l0oooo0?ooo`000?lf0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0?P3o
ool01@3o0000oooo0?ooo`3oool0o`000?l0ooooo`3oool60?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool20000ocD0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`1`0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05T0oooo0P3o
00060?ooo`040000o`3oool0oooo0000ocH0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0m0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooonV0?ooo`030?l0
003oool0oooo05X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`80003o
=@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
5`3oool003`0oooo1@00001G0?ooo`80o`001P3oool010000?l0oooo0?ooo`000?lf0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0?l0ooooYP3oool00`3o0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool20000ocD0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`1/0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?l0
00060?ooo`040000o`3oool0oooo0000ocH0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0m0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooonV0?ooo`030?l0
003oool0oooo05X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0003o03D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo06/0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0F03o
ool0103o0000oooo0?ooo`3o00050?ooo`040000o`3oool0oooo0000ocH0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool0o`3ooonU0?ooo`80o`00G03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`000?l0=@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`1H0?ooo`040?l0003oool0oooo0?l000D0oooo00@0003o0?ooo`3oool0003o=@3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`3o0?ooojD0oooo0P3o00080?ooo`030000o`3oool0oooo0540oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o03D0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo06/0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0F03oool0103o0000oooo003o003o00050?oo
o`040000o`3oool0oooo0000ocD0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0m
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooonU0?ooo`80o`00203oool0
0`000?l0oooo0?ooo`1A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0000o`0e0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`1[0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
05P0oooo00@0o`000?ooo`00o`00o`001@3oool010000?l0oooo0?ooo`000?le0?ooo`030?l0003o
ool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l0000o0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0o`3ooonT0?ooo`030?l0003oool0o`0000L0oooo00<0003o0?ooo`3oool0
D@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l0
=@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
J`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1H0?ooo`040?l0003o
ool00?l00?l000D0oooo00@0003o0?ooo`3oool0003o=@3oool00`3o0000oooo0?ooo`020?ooo`05
003o003oool0oooo0?ooo`3o0000?`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0?l0ooooY03oool00`3o0000oooo0?l000070?ooo`030000o`3oool0oooo0540oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o03D0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo06/0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0E`3oool01@3o0000oooo0?ooo`00o`00o`00
00D0oooo00@0003o0?ooo`3oool0003o=@3oool00`3o0000oooo0?ooo`020?ooo`05003o003oool0
oooo0?ooo`3o0000?`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooX`3o
ool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo0540oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo0000oc@0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`020?ooo`80003oK03oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`1G0?ooo`050?l0003oool00?l0003o003o00001@3oool010000?l0
oooo0?ooo`000?le0?ooo`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l0000o
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooonS0?ooo`040?l0003oool0
oooo0?l000L0oooo00<0003o0?ooo`3oool0D@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo0080oooo0P000?m/0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo05L0oooo00D0o`000?ooo`00o`000?l00?l000050?ooo`040000o`3oool0oooo0000ocD0
oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`0003l0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooj<0oooo00@0o`000?ooo`3oool0o`001`3oool0
0`000?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`000?ld0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool20000of`0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E`3oool0
1@3o0000oooo003o0000o`00o`0000D0oooo00@0003o0?ooo`3oool0003o=@3oool00`3o0000oooo
0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o0000?`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0?l0ooooX`3oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo
0500oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo
0000oc@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`80003oK03oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool5000005D0oooo00D0o`000?ooo`00o`00oooo003o0005
0?ooo`040000o`3oool0oooo0000ocD0oooo00<0o`000?ooo`3oool00P3oool2003o0080oooo00<0
o`000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooX`3o
ool0103o0000oooo0?ooo`3o00070?ooo`80003oD@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo0P000?mX0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0
E`3oool01@3o0000oooo003o003oool00?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`0d0?oo
o`070?l0003oool0oooo0?ooo`00o`00oooo003o00020?ooo`030?l0003oool0oooo03d0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooj80oooo00D0o`000?ooo`3oool0oooo
0?l000070?ooo`80003oD@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?oo
o`80003oK03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1F0?ooo`06
0?l0003oool0oooo003o003oool00?l01@3oool01@000?l0oooo0?ooo`3oool0003o03@0oooo00L0
o`000?ooo`3oool0oooo003o003oool00?l00080oooo00<0o`000?ooo`3oool0?@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooXP3oool01@3o0000oooo0?ooo`3oool0o`00
00L0oooo0P000?mA0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?ld0?ooo`030?l0003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l0
00030?ooo`80003oK03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1F
0?ooo`060?l0003oool0oooo003o003oool00?l01@3oool01@000?l0oooo0?ooo`3oool0003o03@0
oooo00L0o`000?ooo`3oool0oooo003o003oool00?l00080oooo00<0o`000?ooo`3oool0?@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooXP3oool01@3o0000oooo0?ooo`3o
ool0o`0000H0oooo00<0003o0?ooo`000?l0D@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`030?ooo`05003o
003oool0oooo0?ooo`3o00000`3oool20000of`0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0EP3oool00`3o0000oooo003o00020?ooo`03003o003oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0000o`0d0?ooo`070?l0003oool0oooo0?ooo`00o`00oooo003o0002
0?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o
0?oooj80oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0003o0540oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000oc@0oooo
00<0o`000?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000<0oooo0P000?m/0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05H0oooo00<0o`000?ooo`00o`00
0P3oool00`00o`00oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0=03oool01`3o0000
oooo0?ooo`3oool00?l00?ooo`00o`000P3oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0o`3ooonQ0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0000o`1A0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?ld0?ooo`030?l0003oool0oooo00<0oooo00D0
0?l00?ooo`3oool0oooo0?l000030?ooo`80003oK03oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1F0?ooo`030?l0003oool00?l00080oooo00<00?l00?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0003o03@0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l0
0080oooo00<0o`000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
0?l0ooooC@3oool00`3o0000oooo0?ooo`1@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0000o`0>0?ooo`80o`00@@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`02
0?ooo`800?l00`3oool0103o0000oooo0?ooo`3oool20000of`0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0EP3oool00`3o0000oooo003o00020?ooo`03003o003oool0
oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0d0?ooo`070?l0003oool0oooo0?ooo`00o`00
oooo003o00020?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`3o0?ooodd0oooo00<0o`000?ooo`3oool0B`3oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`0;0?ooo`<0
o`0000<0oooo0?l0003oool0@03oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0003o=03oool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l0
0080oooo00@0o`000?ooo`3oool0oooo0P000?m/0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo05D0oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool00?l00080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0g
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooom=0?ooo`030?l0003oool0
oooo04/0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`000?l0203oool30?l000@0oooo00<0o`000?ooo`3oool0?`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o<`3o
ool00`3o0000oooo0?ooo`030?ooo`03003o003oool00?l00080oooo00L0o`000?ooo`3oool0oooo
0000o`3oool0003o06/0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
E@3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00
o`000`3oool01@3o0000oooo0?ooo`3oool0003o03T0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`3o0?ooodd0oooo00<0o`000?ooo`3oool0B`3oool2003o00<0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00H0oooo0P3o00070?oo
o`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`000?l0<P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
0?l00080oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o06/0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0E@3oool00`3o0000oooo003o00030?ooo`03003o003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003o
ool0oooo0080oooo00@00?l00?ooo`3oool00?l00P3oool01@3o0000oooo0?ooo`3oool0003o03T0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oood`0oooo00<0o`000?ooo`3o
0000C03oool2003o00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0003o00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0m0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o
0380oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo003o00020?ooo`040?l0003oool0oooo
0000o`80oooo00<0003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool50000
05<0oooo00<0o`000?ooo`00o`000`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo
003o0080oooo00D0o`000?ooo`3oool0oooo0000o`0i0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0o`3ooom<0?ooo`030?l0003oool0o`0004/0oooo00<00?l00?ooo`00o`000P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0<P3oool00`3o0000oooo
0?ooo`030?ooo`03003o003oool00?l00080oooo00@0o`000?ooo`3oool0003o0P3oool00`000?l0
oooo0?ooo`1U0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0E@3oool00`3o0000oooo
003o00030?ooo`03003o003o0000oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0a0?ooo`030?l0003oool0oooo0080oooo00@00?l00?ooo`3oool00?l00P3oool01@3o0000
oooo0?ooo`3oool0003o03<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0?l0ooooC03oool00`3o0000oooo0?l0001;0?ooo`03003o003oool00?l0
0080oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o0380oooo00<0o`00
0?ooo`3oool00`3oool00`00o`00oooo003o00020?ooo`040?l0003oool0oooo0000o`80oooo00<0
003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1E
0?ooo`030?l0003oool00?l000<0oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool00P3oool01000o`00oooo0?ooo`00
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0<`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooom<0?ooo`030?l0003oool0o`0004/0oooo
00H00?l00?ooo`3oool00?l00?ooo`3o00060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`000?l01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo03d0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0<P3oool0
0`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo003o0080oooo00@0o`000?ooo`3oool0003o
0P3oool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo05@0oooo00@0o`000?ooo`3oool00?l0103oool01@00o`00oooo0?ooo`3oool0003o00@0
oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo003o
0080oooo00D0o`000?ooo`3oool0oooo0000o`0c0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?ooo`L0oooo0P3o00130?ooo`030?l0003oool0
o`0004/0oooo00H00?l00?ooo`3oool00?l00?ooo`3o00060?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo03d0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00
0?l0<P3oool00`3o0000oooo0?ooo`020?ooo`04003o003oool0oooo003o0080oooo00@0o`000?oo
o`3oool0003o0P3oool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo05@0oooo00@0o`000?ooo`3oool00?l0103oool01@00o`00oooo0?ooo`3o
ool0003o00@0oooo00<0003o0?ooo`3oool0<@3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo
00@00?l00?ooo`3oool0o`000`3oool20000oc80oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0oooo1`3oool0103o0000oooo0?l0003o00110?oo
o`030?l0003oool0o`0004/0oooo00H00?l00?ooo`3oool00?l00?ooo`3o00070?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo03d0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`020?ooo`07003o003oool0oooo0?ooo`00
o`00oooo0?l000020?ooo`040000o`3oool0oooo0000of/0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0E03oool0103o0000oooo0?ooo`00o`040?ooo`05003o003oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0a0?ooo`050?l0003oool0oooo0?ooo`00o`00
0`3oool01000o`00oooo0?ooo`3o00030?ooo`80003o<P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0R`3oool00`3o0000oooo0?ooo`1g0?ooo`04
0?l0003oool0oooo0?ooo`80o`00?`3oool00`3o0000oooo0?l0001;0?ooo`06003o003oool0oooo
0?ooo`00o`00o`001`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`@0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00H0oooo
00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0080
oooo00L00?l00?ooo`3oool0oooo003o003oool0o`000080oooo00@0003o0?ooo`3oool0003oJ`3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1D0?ooo`030?l0003oool0
0?l000D0oooo00D00?l00?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0340oooo00D0
o`000?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?l000<0oooo0P000?lb0?ooo`80
003o103oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo08X0oooo0P3o001i0?ooo`03
0?l0003oool0oooo00<0oooo0P3o000m0?ooo`030?l0003oool0o`0004/0oooo00D00?l00?ooo`3o
ool0oooo003o00080?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o103oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0;03oool0
0`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0<03o
ool00`3o0000oooo0?ooo`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo0?l000020?ooo`04
0000o`3oool0oooo0000of/0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0E03oool00`3o0000oooo003o00050?ooo`05003o003oool0oooo0?ooo`000?l01@3oool00`00
0?l0oooo0?ooo`0`0?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3o
00030?ooo`80003o<@3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0RP3oool00`3o0000oooo0?l0001g0?ooo`030?l0003oool0oooo00H0oooo0P3o
000j0?ooo`050?l0003oool0oooo0?ooo`3o0000B@3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l40?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0/0?ooo`03
0?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0`0?oo
o`030?l0003oool0oooo0080oooo00L00?l00?ooo`3oool0oooo003o003oool0o`000080oooo00@0
003o0?ooo`3oool0003oJ`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`1D0?ooo`030?l0003oool00?l000D0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030000
o`3oool0oooo0300oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?l0
00<0oooo0P000?la0?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`290?ooo`040?l0003oool0oooo0?l007L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0h0?ooo`050?l0003oool0oooo0?ooo`3o0000B@3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`000?l40?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool20?l00200oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`@0
oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`020?ooo`07003o003oool0oooo0?oo
o`00o`00oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`000?l0JP3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`1C0?ooo`040?l0003oool0oooo003o00D0oooo00D0
0?l00?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo0300oooo00D0o`000?ooo`3oool0
oooo003o00040?ooo`03003o003oool0o`0000<0oooo0P000?la0?ooo`030000o`3oool0003o00@0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1X0?ooo`030000o`3oool0oooo01h0
oooo00@0o`000?ooo`3oool0o`00M`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
03P0oooo00D0o`000?ooo`3oool0oooo0?l000130?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00P3oool00`3o00000?l00?ooo`060?ooo`030?l0003oool0oooo0080oooo00@0003o
0?ooo`3oool0003o103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3o0000803oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00@0
o`000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo01T0oooo
00D0o`000?ooo`3oool0oooo003o00040?ooo`03003o003oool0o`000080oooo00D0003o0?ooo`3o
ool0oooo0000o`1Z0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05<0
oooo00@0o`000?ooo`3oool00?l01@3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<0003o
0?ooo`3oool0<03oool01@3o0000oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3o00000`3o
ool20000oc40oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo06P0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo07@0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0h0?ooo`050?l0003o
ool0oooo0?ooo`3o0000@`3oool20?l000@0oooo00<00?l00?ooo`3oool00P3oool00`3o00000?l0
0?ooo`060?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o103oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`007P3oool20000
o`/0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0
oooo01@0oooo00<00?l00?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool00?l000@0oooo00<0
0?l00?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0003o06X0oooo00<000000?ooo`3oool0
5`3oool003`0oooo1@00001A0?ooo`040?l0003oool0oooo003o00D0oooo00D00?l00?ooo`3oool0
oooo0000o`050?ooo`030000o`3oool0oooo0300oooo00D0o`000?ooo`3oool0oooo003o00040?oo
o`03003o003oool0o`0000<0oooo0P000?la0?ooo`030000o`3oool0003o00@0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0M03oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo03L0oooo00D0o`000?oo
o`3oool0oooo0?l000120?ooo`030?l0003oool0o`0000@0oooo00L00?l00?ooo`3oool0oooo0?l0
003oool00?l000L0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l40?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0303oool0103o0000oooo0?ooo`3o000N0?oo
o`80003o2`3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`00o`00103o
ool00`00o`00oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`000?l0IP3oool5000001T0oooo
000l0?ooo`030000003oool0oooo05<0oooo00@0o`000?ooo`3oool00?l01@3oool01@00o`00oooo
0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0<03oool01@3o0000oooo0?ooo`3oool00?l0
00@0oooo00<00?l00?ooo`3o00000`3oool20000oc40oooo00<0003o0?ooo`000?l0103oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3oool09`3oool20000
o`P0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
07<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0g0?ooo`050?l0003oool0oooo
0?ooo`3o0000@P3oool0103o0000oooo0?ooo`3o00030?ooo`07003o003oool0oooo0?ooo`3o0000
oooo003o00070?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o103oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00D0o`000?ooo`3oool0oooo0?l0000M
0?ooo`030000o`3oool0003o00X0oooo00<0o`000?ooo`3oool00`3oool01@00o`00oooo0?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`800?l06`3o
ool01@3o0000oooo0?ooo`3oool00?l000D0oooo00D00?l00?l0003oool0oooo0000o`030?ooo`03
0000o`3oool0oooo06P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
D`3oool00`3o0000oooo003o00060?ooo`05003o003oool0oooo0?ooo`000?l01@3oool00`000?l0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?l000030?ooo`80003o<@3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0?03oool20?l002T0oooo0P000?l80?ooo`030?l0003oool0oooo01<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1c0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0=`3oool01@3o0000oooo0?ooo`3oool0o`000480oooo00@0o`000?oo
o`3oool0o`000P3oool00`00o`00oooo0?ooo`020?ooo`040?l0003oool0oooo003o00H0oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`3o00003@3oool00`3o0000
oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o0000703oool010000?l0oooo0?ooo`000?l:
0?ooo`030?l0003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l000020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool04P3oool00`00o`00oooo003o000J0?ooo`050?l0003o
ool0oooo0?ooo`00o`001@3oool01@00o`00o`000?ooo`3oool0003o00<0oooo00<0003o0?ooo`3o
ool0J03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1C0?ooo`030?l0
003oool00?l000H0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo02l0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0o`0000<0
oooo0P000?la0?ooo`030000o`3oool0003o00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0l0?ooo`030?l0003oool0o`0002P0oooo0P000?l70?ooo`030?l0003oool0o`0001<0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1b0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0?`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00o`00103oool0
103o0000oooo0?ooo`00o`060?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@000?l0oooo
0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo01T0oooo00@0003o0?ooo`3oool0003o2P3oool00`3o0000oooo0?ooo`020?oo
o`800?l00`3oool0103o0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo0180oooo00<00?l0
0?ooo`00o`006P3oool01@3o0000oooo0?ooo`3oool00?l000D0oooo00D00?l00?l0003oool0oooo
0000o`030?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0DP3oool0103o0000oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00
0?l01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0o`000080oooo00<0003o0?ooo`00
0?l0<@3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0>`3oool0103o0000oooo0?ooo`3o000X0?ooo`80003o1`3oool00`3o0000oooo0?l0000C
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo003o0004
0?ooo`040?l0003oool0oooo003o00L0oooo00@0o`000?ooo`3oool0003o0`3oool01@000?l0oooo
0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo01T0oooo00@0003o0?ooo`3oool0003o2P3oool00`3o0000oooo0?ooo`020?oo
o`800?l00`3oool0103o0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo0180oooo00<00?l0
0?ooo`00o`006P3oool01@3o0000oooo0?ooo`3oool00?l000D0oooo00D00?l00?l0003oool0oooo
0000o`030?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0DP3oool0103o0000oooo0?ooo`00o`060?ooo`050?l00000o`00oooo0?ooo`00
0?l01@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0o`000080oooo00<0003o0?ooo`00
0?l0<@3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool0>P3oool0103o0000oooo0?ooo`3o000X0?ooo`030000o`3oool0003o00H0oooo00<0o`00
0?ooo`3o00004P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0740oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0W0?ooo`80003o3@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool00`3oool00`3o00000?l00?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?ooo`00
0?l30?ooo`050000o`3oool0oooo0?ooo`3o00003@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool05`3oool01@000?l0oooo0?ooo`3oool0003o00X0
oooo00<0o`000?ooo`3oool00P3oool2003o00<0oooo00@0o`000?ooo`3oool0003o1@3oool00`00
0?l0oooo0?ooo`0B0?ooo`03003o003oool00?l001X0oooo00@0o`000?ooo`3oool00?l01P3oool0
1@00o`00o`000?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`1B0?ooo`040?l0003oool0oooo003o00H0oooo00D0
o`00003o003oool0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0
:P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o0000
0P3oool010000?l0oooo0?ooo`000?l_0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo03X0oooo00@0o`000?ooo`3oool0o`003`3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o00004P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0740oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0W0?ooo`80003o3@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo03h0oooo00<0o`000?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo00<0
0?l00?ooo`3oool0103oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?ooo`3o
00003@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool05`3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool00P3oool2003o
00<0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0
0?l001X0oooo00@0o`000?ooo`3oool00?l01P3oool01@00o`00o`000?ooo`3oool0003o00<0oooo
00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`1B0?ooo`040?l0003oool0oooo003o00H0oooo00D0o`00003o003oool0oooo0000o`050?ooo`03
0000o`3oool0oooo0080oooo0P00o`0[0?ooo`050?l0003oool0oooo0?ooo`00o`001@3oool00`00
o`00oooo0?l000020?ooo`040000o`3oool0oooo0000obl0oooo00D0003o0?ooo`3oool0oooo0000
o`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo0?oo
o`000?l60?ooo`030?l0003oool0o`000140oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`1`0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo
0000o`0=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0h0?ooo`030?l0003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`03
003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o0`3oool01@000?l0oooo0?ooo`3oool0
o`0000d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo01H0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`050?l0003oool0oooo0?ooo`00o`00
0P3oool01000o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool04@3oool01000o`00oooo0?ooo`00o`0J0?ooo`040?l0003oool0oooo003o00H0oooo00D00?l0
0?l0003oool0oooo0000o`030?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000@0oooo0P0000040?ooo`8000003@3oool0
0`000000oooo0?ooo`1B0?ooo`040?l0003oool0oooo003o00H0oooo00D0o`00003o003oool0oooo
0000o`050?ooo`030000o`3oool0oooo0080oooo0P00o`0?0?ooo`030?l0003oool0oooo01T0oooo
00D0o`000?ooo`3oool0oooo003o00050?ooo`03003o003oool0o`000080oooo00@0003o0?ooo`3o
ool0003o:@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo0P3o000G0?ooo`040000o`3oool0
oooo0000o`H0oooo00<0o`000?ooo`3o00004@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo0700oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0003o00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo03L0oooo00<0o`000?ooo`3oool01@3oool01@00o`00o`000?ooo`3oool0o`0000@0oooo
00<00?l00?ooo`3oool0103oool0103o0000oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?oo
o`3o00003@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00D0o`000?oo
o`3oool0oooo003o00020?ooo`04003o003oool0oooo0?l00080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0A0?ooo`04003o003oool0oooo003o01X0oooo00@0o`000?ooo`3oool0
0?l01P3oool01@00o`00o`000?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0=`3oool20?l0
02l0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`00o`001`3oool0
1@3o00000?l00?ooo`3oool0003o00D0oooo00L0003o0?ooo`3oool0oooo003o003oool00?l000l0
oooo00<0o`000?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool00?l000H0oooo00D00?l00?l0
003oool0oooo0000o`020?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0;0?ooo`80o`005`3oool010000?l0oooo0?ooo`000?l50?ooo`050?l0003oool0oooo0?ooo`3o
00003`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo06l0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0U0?ooo`040000o`3oool0oooo0000o``0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03L0oooo00<0o`000?oo
o`3oool0103oool00`00o`00oooo0?l000020?ooo`030?l0003oool0oooo00<0oooo00<00?l00?oo
o`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`040000o`3oool0oooo0?l000h0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`00o`00
0P3oool01000o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool04@3oool01000o`00oooo0?ooo`00o`0I0?ooo`050?l0003oool0oooo0?ooo`00o`001`3oool0
1000o`00oooo0?ooo`000?l40?ooo`030000o`3oool0oooo03H0oooo0P3o000@0?ooo`030?l0003o
ool0oooo01`0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`L00000C@3oool0103o0000oooo0?ooo`00o`070?ooo`050?l0
0000o`00oooo0?ooo`000?l01@3oool01`000?l0oooo0?ooo`3oool00?l00?ooo`00o`003`3oool0
0`3o0000oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool01@00o`00oooo0?l0
003oool0003o0080oooo00<0003o0?ooo`3oool09P3oool20?l000D0oooo00D0003o0?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool08@3oool20000oaD0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0001H0
oooo00@0003o0?ooo`3oool0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1^0?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool09@3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool20000oaP0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`040?ooo`03003o003oool0oooo0080o`001P3oool00`00o`00oooo0?ooo`030?ooo`040?l0003o
ool0oooo0000o`@0oooo00@0003o0?ooo`3oool0o`003P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`030?oo
o`030?l0003oool0003o00D0oooo00<0003o0?ooo`3oool04@3oool01@00o`00oooo0?ooo`3oool0
0?l001P0oooo00D0o`000?ooo`3oool0oooo003o00070?ooo`04003o003oool0oooo0000o`@0oooo
00<0003o0?ooo`3oool0=@3oool0103o0000oooo0?ooo`3o000>0?ooo`80o`00603oool7000001T0
oooo000P0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1A0?ooo`040?l0003oool0oooo003o00P0oooo00@00?l00?ooo`3oool0003o1@3oool0
1`000?l0oooo0?ooo`3oool00?l00?ooo`00o`003P3oool00`3o0000oooo0?l0000J0?ooo`050?l0
003oool0oooo0?ooo`00o`001P3oool01@00o`00oooo0?l0003oool0003o0080oooo00<0003o0?oo
o`3oool09P3oool20?l000D0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool08@3oool20000oa@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo0?l001H0oooo00@0003o0?ooo`3oool0003o
1@3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool0303oool00`3o0000
oooo0?ooo`1^0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool010000?l0
oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool20000
oaP0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
0080o`001P3oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o
0?ooo`3o00003`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo003o00030?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`050?ooo`03
0000o`3oool0oooo0140oooo00D00?l00?ooo`3oool0oooo003o000H0?ooo`050?l0003oool0oooo
0?ooo`00o`001`3oool01000o`00oooo0?ooo`000?l40?ooo`030000o`3oool0oooo03D0oooo00@0
o`000?ooo`3oool0o`003P3oool20?l001h0oooo00<000000?ooo`3oool05`3oool00200oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0540
oooo00@0o`000?ooo`3oool00?l0203oool01000o`00oooo0?ooo`000?l50?ooo`050000o`3oool0
oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0o`0001X0oooo00D0
o`000?ooo`3oool0oooo003o00060?ooo`05003o003oool0o`000?ooo`000?l00P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo01l0oooo0P3o00050?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0240oooo0P000?lD0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3o000F
0?ooo`040000o`3oool0oooo0000o`D0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`03003o
003oool0oooo00d0oooo00<0o`000?ooo`3oool0K@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo02D0oooo00@0003o0?ooo`3oool0003o2`3oool00`3o0000oooo0?ooo`050?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000o`0G0?ooo`80o`007P3oool00`3o0000oooo0?ooo`05
0?ooo`05003o003oool0oooo0?ooo`3o00001`3oool00`00o`00oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`@0oooo00<0003o0?ooo`3o00003`3oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`07003o003oool0oooo0?oo
o`3o0000oooo0000o`050?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0F0?ooo`040?l0003oool0oooo003o00P0oooo00@00?l00?l0003oool0003o
103oool00`000?l0oooo0?ooo`0e0?ooo`050?l0003oool0oooo0?ooo`3o0000303oool0103o0000
oooo0?ooo`3o000M0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000002P3oool2000000d0
oooo00<000000?ooo`3oool0D@3oool0103o0000oooo0?ooo`00o`080?ooo`04003o003oool0oooo
0000o`H0oooo00@0003o0?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003o
ool0o`0001X0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`05003o003oool0o`000?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo01l0oooo0P3o00050?ooo`05
0000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
0200oooo00<0003o0?ooo`000?l0503oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00T0oooo00@0o`000?ooo`3oool0o`005@3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00D0
o`000?ooo`3oool0oooo0?l0000>0?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`3oool0
K@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00L0o`000?ooo`3oool0
oooo0000o`3oool0003o01L0oooo00<0o`000?ooo`3o00007@3oool00`3o0000oooo0?ooo`050?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l4
0?ooo`030000o`3oool0o`0000l0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool01`00o`00oooo0?ooo`3oool0o`000?ooo`00
0?l01@3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool05P3oool0103o0000oooo0?ooo`00o`080?ooo`04003o003o0000oooo0000o`@0oooo00<0003o
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0=0?ooo`050?l0003oool0oooo0?ooo`3o0000303o
ool0103o0000oooo0?ooo`3o000M0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0500oooo00D0o`000?ooo`3oool0oooo003o00080?ooo`04003o003oool0oooo0000o`H0
oooo00@0003o0?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0o`00
01X0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`05003o003oool0o`000?ooo`000?l00P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3o00001@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0000X0oooo00<0o`000?ooo`3oool0803o
ool010000?l0oooo0?ooo`000?lB0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
203oool01@3o0000oooo0?ooo`3oool0o`0001D0oooo00D0003o0?ooo`3oool0oooo0000o`050?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`00o`00o`00003o000>0?oo
o`030?l0003oool0oooo06d0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?oo
o`070?l0003oool0oooo0?ooo`000?l0oooo0000o`0G0?ooo`030?l0003oool0o`0001d0oooo00<0
o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo00@0
o`000?ooo`3oool0003o103oool00`000?l0oooo0?l0000?0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00L00?l00?ooo`3o
ool0oooo0?l0003oool0003o00H0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?ooo`02
0?ooo`03003o003oool0oooo01H0oooo00@0o`000?ooo`3oool00?l0203oool01000o`00o`000?oo
o`000?l40?ooo`030000o`3oool0oooo02@0oooo0P3o000?0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0001d0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`020?ooo`03003o
003oool0oooo00H0oooo00@00?l00?ooo`3oool0003o1P3oool010000?l0oooo0?ooo`00o`020?oo
o`03003o003oool0oooo00/0oooo00<0o`000?ooo`3o00006P3oool01@3o0000oooo0?ooo`3oool0
0?l000H0oooo00D00?l00?ooo`3o0000oooo0000o`020?ooo`030000o`3oool0oooo00@0oooo0P3o
000O0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?l0
000;0?ooo`030?l0003oool0oooo01l0oooo00@0003o0?ooo`3oool0003o4P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000E0?ooo`05
0000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00X0oooo00<00?l00?ooo`00o`003`3oool00`3o0000oooo0?ooo`1/0?ooo`030?l0003oool0oooo
00`0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01@3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l05`3o
ool00`3o0000oooo0?l0000M0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3o00003`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool00?l0
103oool01`00o`00oooo0?ooo`3oool0o`000?ooo`000?l01P3oool00`000?l0oooo0?ooo`0?0?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool05P3oool0103o0000oooo0?ooo`00o`08
0?ooo`04003o003o0000oooo0000o`@0oooo00<0003o0?ooo`3oool0903oool20?l000h0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1>
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01`3oool01000o`00oooo0?ooo`00
0?l60?ooo`040000o`3oool0oooo003o00<0oooo00<00?l00?ooo`3oool02P3oool0103o0000oooo
0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool01@00o`00oooo0?l0003oool0
003o0080oooo00<0003o0?ooo`3oool0103oool20?l001l0oooo00@0o`000?ooo`3oool0o`00103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0000/0oooo00<0o`000?ooo`3oool07P3o
ool01@000?l0oooo0?ooo`3oool0003o0140oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04P3oool01@000?l0oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`03
003o003oool00?l000l0oooo00<0o`000?ooo`3oool0K03oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo
01<0oooo00@0o`000?ooo`3oool0o`00703oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0
oooo00/0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0
o`000100oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0
oooo003o00@0oooo00L00?l00?ooo`3oool0oooo0?l0003oool0003o00H0oooo00<0003o0?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01H0oooo00@0o`000?ooo`3o
ool00?l0203oool01000o`00o`000?ooo`000?l40?ooo`030000o`3oool0oooo02<0oooo00@0o`00
0?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`07
0?ooo`04003o003oool0oooo0000o`H0oooo00<0003o0?ooo`00o`00103oool00`00o`00oooo0?oo
o`090?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool00?l000H0
oooo00D00?l00?ooo`3o0000oooo0000o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3o00003`3oool00`00o`00oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000/0oooo00<0o`000?ooo`3oool07P3oool0
1@000?l0oooo0?ooo`3oool0003o00H0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0
003oool0oooo00T0oooo00@00?l00?l0003oool00?l0403oool00`3o0000oooo0?ooo`1Z0?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0C0?ooo`040?l0003oool0oooo
0?l001`0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0
oooo0080oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?l0000@0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`00o`040?ooo`07003o003o
ool0oooo0?ooo`3o0000oooo0000o`060?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0F0?ooo`040?l0003oool0oooo003o00T0oooo00<00?l00?oo
o`000?l0103oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo01d0oooo00D0o`000?oo
o`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0C03oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
00L0oooo00@0o`00003o003oool0003o1P3oool00`000?l0oooo003o00040?ooo`03003o003oool0
oooo00T0oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo0080oooo00<0
0?l00?ooo`3oool0103oool01@00o`00oooo0?l0003oool0003o0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?l0000>0?ooo`800?l03P3oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo01h0
oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`800?l02P3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0
oooo00T0oooo00D00?l00?l0003oool0oooo003o000?0?ooo`030?l0003oool0oooo06X0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00D0
o`000?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo01<0oooo00D0o`000?ooo`3oool0
oooo0?l0000K0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool02`3oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3o0000403oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool00?l0103oool01`00
o`00oooo0?ooo`3oool0o`000?ooo`000?l01P3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool05@3oool0103o0000oooo0?ooo`00o`090?ooo`03003o
003oool0003o00@0oooo00<0003o0?ooo`3oool00P3oool2003o01h0oooo00D0o`000?ooo`3oool0
oooo0?l0000=0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00D0oooo
00<00?l00?ooo`3oool01`3oool00`3o00000?l00000o`070?ooo`030000o`3oool00?l000@0oooo
00<00?l00?ooo`3oool02@3oool01@3o0000oooo003o0000o`00o`0001P0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`050?ooo`04003o003o0000oooo0000o`<0oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0?ooo`3o000=0?ooo`03003o003oool00?l000d0oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00002`3o
ool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo
0P00o`020?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`090?ooo`05
003o003oool0oooo0?ooo`00o`00403oool00`3o0000oooo0?ooo`1Y0?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool02`3oool20?l001H0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o0P3oool0
0`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo0?ooo`3o00006`3oool00`3o0000oooo0?oo
o`050?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000
o`040?ooo`030000o`3oool0o`000100oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool00?l000H0oooo00H00?l00?ooo`3oool0o`000?ooo`000?l60?ooo`03
0000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`04
0?l0003oool0oooo003o00T0oooo00<00?l00?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0
0?l00080oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool00`00
o`00oooo0?ooo`070?ooo`030?l00000o`00003o00L0oooo00<0003o0?ooo`00o`00103oool00`00
o`00oooo0?ooo`090?ooo`040?l0003oool00?l00?ooo`800?l05`3oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool0oooo00D0oooo00@00?l00?l0003oool0003o0`3oool00`000?l0oooo0?oo
o`020?ooo`040?l0003oool0oooo0?l000`0oooo00@00?l00?ooo`3oool00?l03@3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?l0000;0?oo
o`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`04
0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`03
0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`070?ooo`03003o003o
0000oooo0080oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`1Y0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l0000E0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`040?l0003o
ool0oooo0000o`80oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo01P0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0;0?ooo`03003o
003oool0oooo0080oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?l0000@0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo003o00060?ooo`05003o
003oool0oooo0?l000000?l01`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool05@3oool00`3o0000oooo003o000:0?ooo`03003o003oool0003o00@0
oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo01P0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00D0o`000?oo
o`3oool0oooo0?l000080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool5000003D0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0oooo00L0oooo00<0o`00003o00000?l01`3oool00`00
0?l0oooo003o00050?ooo`03003o003oool0oooo00P0oooo00<0o`00003o003oool00P3oool00`3o
00000?l0003o000E0?ooo`050?l0003oool0oooo0?ooo`00o`00203oool01000o`00o`000?ooo`00
0?l30?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`00303oool01000o`00oooo
0?ooo`00o`0<0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`050?oo
o`030000o`3oool0o`0000/0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool00?l000D0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`07
0?ooo`03003o003o0000oooo0080oooo00<00?l00?ooo`3oool03`3oool00`3o0000oooo0?ooo`1X
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l00007
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0003o0`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?oo
o`060?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000
o`040?ooo`030000o`3o0000oooo0100oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0oooo003o00H0oooo00D00?l00?ooo`3oool0o`000000o`070?ooo`03
0000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`03
0?l0003oool00?l000X0oooo00<00?l00?ooo`000?l01@3oool010000?l0oooo0?ooo`00o`040?oo
o`800?l05`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0@0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0=P3oool20?l0
00h0oooo0`000?l90?ooo`03003o003oool0oooo00P0oooo00<0o`00003o00000?l01`3oool00`00
0?l0oooo003o00050?ooo`03003o003oool0oooo00P0oooo00<0o`00003o003oool00P3oool00`3o
0000oooo0?ooo`02003o01<0oooo00D0o`000?ooo`3oool0oooo003o00080?ooo`04003o003o0000
oooo0000o`<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o000;0?ooo`05003o
003oool0oooo0?ooo`00o`00303oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?oo
o`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`00o`00oooo00@0oooo0P3o00000`00
o`00o`000?l000050?l000d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o0007
0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?l0003oool00`3oool00`00o`00oooo0?ooo`0>
0?ooo`030?l0003oool0oooo06P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`09
0?ooo`040?l0003oool0oooo0?l000H0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0000
o`040?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0H0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?oo
o`020?ooo`030?l000000?l0oooo00@0oooo00<0003o0?l0003oool04@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool00?l01P3oool01@00o`00oooo
0?ooo`3o0000003o00L0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`040?ooo`03
003o003oool0oooo01D0oooo00<0o`000?ooo`00o`002P3oool00`00o`00oooo0000o`050?ooo`03
0000o`3oool00?l000L0oooo00<00?l00?ooo`3oool0203oool20?l000X0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
00002P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?l000090?ooo`@0003o
0P3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00P0oooo00<0o`00003o00000?l0
1`3oool00`000?l0oooo003o00050?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`00o`00
0`3oool00`3o0000oooo0?ooo`020?ooo`800?l04@3oool01@3o0000oooo0?ooo`3oool00?l000P0
oooo00@00?l00?l0003oool0003o0`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o00002P3oool01P00o`00oooo0?ooo`3o0000oooo003o00/0oooo00<0o`000?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?l0003oool02P3oool00`3o0000
0?l00?ooo`0?0?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`00o`00
003o0?ooo`050?ooo`030?l0003oool00?l001D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00`3oool010000?l0
oooo0?ooo`3o00070?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3o0000103oool00`00
o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo06H0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`090?ooo`040?l0003oool0oooo0?l000H0oooo0P000?l<0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
003o00@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo01P0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0=0?ooo`06003o003oool0
oooo0?ooo`3o0000003o1@3oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo003o00070?ooo`05003o003oool0oooo0?l00000
0?l01`3oool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool05@3oool00`3o0000oooo003o000:0?ooo`03003o003oool0003o00D0oooo00<0003o0?ooo`00
o`00203oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo0080o`001`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?l0000:0?ooo`050?l0003oool0oooo0?ooo`000?l05`3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0o`0000H0oooo0`000?l60?ooo`03
0000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool0203oool00`3o00000?l00000o`070?ooo`03
0000o`3oool00?l000D0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo003o00030?ooo`03
0?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool03P3oool01@3o0000oooo0?ooo`3oool00?l0
00P0oooo00@00?l00?l0003oool0003o0`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`3o00002@3oool01000o`00oooo0?ooo`3oool20?l00003003o003oool0oooo00P0oooo
00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?l0003o
ool02P3oool00`3o00000?l00?ooo`0>0?ooo`800?l0303oool00`000?l0oooo0?ooo`020?ooo`03
003o00000?l0oooo00D0oooo00<0o`000?ooo`00o`005@3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`040?ooo`04
0000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`3oool01P3oool00`00o`00o`000?ooo`040?oo
o`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`80003o303oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0000o`040?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool03@3oool0
1P00o`00oooo0?ooo`3oool0o`000000o`D0oooo00<0003o0?l0003oool04@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`00o`001`3oool01@00o`00oooo
0?ooo`3o0000003o00L0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo01D0oooo00<0o`000?ooo`00o`002P3oool00`00o`00oooo0000o`050?ooo`03
0000o`3oool00?l000T0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`80
o`00103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`000?l05`3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0o`0000H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo00P0
oooo00<0o`00003o00000?l01`3oool00`000?l00?l00?ooo`050?ooo`03003o003oool0oooo00L0
oooo00<0o`00003o003oool0103oool00`3o0000oooo0?ooo`040?ooo`800?l03P3oool01@3o0000
oooo0?ooo`3oool00?l000P0oooo00@00?l00?l0003oool0003o0`3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0o`000?ooo`3oool01`3oool01`00o`00oooo0?ooo`3o0000oooo0?l00000
o`002P3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`00
0?l0o`000?ooo`0:0?ooo`030?l00000o`000?l000h0oooo00<00?l00?ooo`00o`002`3oool00`00
0?l0oooo0?ooo`020?ooo`03003o00000?l0oooo00D0oooo00@0o`000?ooo`3oool00?l0503oool0
1@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`040?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool01@3oool00`00o`00o`00
0?ooo`040?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0I@3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`80003o303oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0=0?ooo`06003o003oool0oooo0?ooo`3o
0000003o1P3oool00`000?l0oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`00
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo003o00070?ooo`05003o003oool0oooo0?l000000?l01`3o
ool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool05@3o
ool00`3o0000oooo003o000:0?ooo`030?l00000o`00003o00D0oooo00<0003o003o003oool02P3o
ool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo0P3o00020?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo0?ooo`00o`0E0?ooo`040?l0
003oool0oooo0000oaL0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
;P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo00P0oooo00<0o`00003o00000?l0
1`3oool00`000?l00?l00?ooo`060?ooo`03003o003oool0oooo00H0oooo00<0o`00003o003oool0
103oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo00/0oooo00D0o`000?ooo`3oool0
oooo003o00080?ooo`04003o003o0000oooo0000o`<0oooo00L0003o0?ooo`3oool0oooo0?l0003o
ool00?l00080oooo00<0o`000?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0o`000080oooo
00<0o`00003o003oool0203oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l01P3oool00`000?l0o`000?ooo`0;0?ooo`800?l03P3oool00`00o`00oooo003o000:0?ooo`03
0000o`3oool0oooo0080oooo00@00?l00?ooo`3oool0003o1@3oool0103o0000oooo0?ooo`00o`0D
0?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00@0oooo00@0003o0?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`050?ooo`03003o
003o0000oooo00D0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo05P0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`0;0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0
00000?l0oooo00<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`03003o
003oool0oooo00d0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0100oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool00?l000L0oooo00D00?l00?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo
00d0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0003oool00?l0
00X0oooo00<0o`00003o00000?l01@3oool00`000?l00?l00?ooo`0;0?ooo`04003o003oool0oooo
0?l000/0oooo0P3o000;0?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo003o
000E0?ooo`040?l0003oool0oooo0000oaL0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0;03oool30000o`L0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0003o00P0oooo00<00?l00?ooo`3oool0203oool00`3o00000?l00000
o`070?ooo`030000o`00o`00oooo00H0oooo00<00?l00?ooo`3oool01P3oool00`3o00000?l00?oo
o`040?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?oo
o`020?ooo`03003o003oool0oooo00H0oooo00@00?l00?l0003oool0003o0`3oool01P000?l0oooo
0?ooo`3oool0o`000?ooo`800?l00P3oool00`3o0000oooo0?ooo`050?ooo`04003o003oool0oooo
0?l000<0oooo00<0o`00003o003oool01`3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0
oooo0?ooo`000?l01P3oool00`000?l0o`000?ooo`0;0?ooo`800?l03@3oool01000o`00oooo0?oo
o`00o`0:0?ooo`030000o`3oool0oooo0080oooo00@00?l00?ooo`3oool0003o1@3oool0103o0000
oooo0?ooo`00o`0>0?ooo`800?l01@3oool0103o0000oooo0?ooo`3o00090?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000090?ooo`030?l0003oool0
oooo00@0oooo00<00?l00?ooo`3o00001P3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3o0000E@3oool01@000?l0oooo0?ooo`3oool0o`000140oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0o`000000o`3oool0103oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0000o`090?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool03@3oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0403oool0103o0000
oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`00003o003oool01`3oool01@00
o`00oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`06
0?ooo`03003o003oool0oooo01@0oooo00<0o`00003o003oool02P3oool00`3o0000003o0?ooo`05
0?ooo`030000o`00o`00oooo00/0oooo00<00?l00?ooo`3o00006@3oool00`3o0000oooo0?ooo`07
0?ooo`050?l0003oool0oooo0?ooo`00o`005@3oool0103o0000oooo0?ooo`000?lG0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02X0oooo0P000?l20?ooo`030000o`3o
ool0oooo00@0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0003o00P0oooo00<00?l00?ooo`3oool0203oool00`3o00000?l00000o`070?ooo`030000
o`00o`00oooo00H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`030?l0
003oool0oooo00P0oooo0P00o`080?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0
1P3oool01000o`00o`000?ooo`000?l30?ooo`0;0000o`3oool0oooo0?ooo`3o0000oooo003o003o
ool00?l00?ooo`3o00001P3oool01@00o`00oooo0?ooo`3oool0o`0000@0oooo00<00?l00?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?oo
o`3oool02`3oool00`00o`00oooo003o000<0?ooo`04003o003oool0oooo003o00X0oooo00<0003o
0?ooo`3oool00P3oool01000o`00oooo0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0
0?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`02003o00<0oooo00<0o`000?ooo`3o00002P3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00002@3o
ool00`3o0000oooo0?ooo`040?ooo`03003o003oool0o`0000H0oooo00<00?l00?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l003<0oooo00<0003o0?ooo`3oool0
7P3oool20000o`<0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool00?l000<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo00<0
oooo0P3o00030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`090?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`000?l0203oool00`3o0000
oooo0?ooo`070?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool00P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo00@0o`000?ooo`000?l0003o0P3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l00000o`00oooo00L0oooo00D00?l00?ooo`3oool0oooo0000o`08
0?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0D
0?ooo`030?l00000o`00oooo00X0oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`0<
0?ooo`03003o003oool0oooo01T0oooo00<0o`000?ooo`3oool01P3oool01P3o0000oooo0?ooo`00
o`00oooo003o01@0oooo00@0o`000?ooo`3oool0003o5`3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`0M0?ooo`80003o2@3oool20000o`D0oooo00<0003o0?ooo`3oool0
0`3oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`00
0?l01`3oool00`00o`00oooo0?ooo`090?ooo`030?l00000o`00003o00L0oooo00<0003o003o003o
ool01P3oool00`00o`00oooo0?ooo`050?ooo`030?l00000o`00oooo00D0oooo00<0o`000?ooo`3o
ool02P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00oooo0000o`030?ooo`060000o`3oool0oooo0?ooo`3o00000?l00`3oool0
0`00o`00o`000?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000103oool00`3o00000?l00?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o0`3oool01@00o`00oooo
0?ooo`3oool0003o00d0oooo00<00?l00?ooo`00o`002`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l40?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`020?oo
o`<00?l000<0o`000?ooo`3o00002`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3o00002@3oool00`3o0000oooo0?ooo`040?ooo`03003o003o0000oooo
00H0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0;`3oool20000ob00oooo0P000?l30?ooo`030?l0003oool0oooo
0100oooo00<0o`000?ooo`3oool01`3oool00`3o00000?l0003o00030?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`030?ooo`80o`000`3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o0?ooo`04
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`08
0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`3o0000oooo0?ooo`060?ooo`03003o003o
ool0oooo00h0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0140oooo00H0o`000000o`3oool0003o0?ooo`3o000B0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`030?l00000o`00oooo00L0
oooo00D00?l00?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00/0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0D0?ooo`030?l00000o`00oooo00X0oooo00<0o`000000
o`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool00?l001X0oooo00<0o`000?oo
o`3oool01P3oool01P3o0000oooo0?ooo`00o`00oooo003o01@0oooo00<0o`000?ooo`000?l0603o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`@0003o0`3oool2
0000o`L0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0000o`070?ooo`03003o003oool0oooo00T0oooo00<0
o`00003o00000?l0203oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0
o`00003o003oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`04003o003oool0oooo0?ooo`80o`00
1`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0003o00<0oooo00H0003o0?ooo`3oool0
oooo0?l00000o`040?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l00006
0?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`03
0?ooo`05003o003oool0oooo0?ooo`000?l0303oool01000o`00o`000?ooo`00o`0;0?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`05003o
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`3oool01P3oool2003o00030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00<0oooo00<00?l00?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0o`0000P0oooo00<00?l00?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`020?ooo`80o`001P3oool00`3o0000oooo0?ooo`0]0?ooo`04
0000o`3oool0oooo0000oah0oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00H0oooo00@0o`00003o003oool00?l0103oool0103o0000oooo0?ooo`00
0?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o0?oo
o`040?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`080?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`3o0000oooo0?ooo`060?ooo`03003o
003oool0oooo00h0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
00000?l0oooo0180oooo00H0o`000000o`3oool0003o0?ooo`3o000B0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`030?l00000o`00oooo
00P0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo003o000F0?ooo`030?l00000o`00oooo00X0oooo00<0
o`000000o`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`00o`00
6@3oool00`3o0000oooo0?ooo`060?ooo`060?l0003oool0oooo003o003oool00?l05@3oool00`3o
0000003o0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02<0
oooo0`000?l90?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`09
0?ooo`030?l00000o`00003o00P0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`04
0?ooo`030?l00000o`00oooo00H0oooo00<0o`000?ooo`3oool02P3oool01000o`00oooo0?ooo`3o
00050?ooo`050000o`3oool0oooo0?ooo`00o`002@3oool00`00o`00oooo0000o`030?ooo`060000
o`3oool0oooo0?ooo`3o00000?l0103oool00`3o00000?l00?ooo`030?ooo`05003o003oool0oooo
0?ooo`3o00001P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`000?l00P3oool2003o00<0oooo00<0003o0?ooo`3oool02P3oool01@00o`00o`000?l0003o
00000?l000X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00D00?l00?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo
00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00X0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo00<0oooo
0P00o`040?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3o0000203oool00`00o`00oooo
0?ooo`0B0?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00@0003o0?ooo`3oool0003o7@3oool01000
0?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool01P3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00@0o`000?ooo`3oool0003o0`3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00T0oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0>0?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`0B0?oo
o`060?l000000?l0oooo0000o`3oool0o`004`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`04003o003o
ool0oooo0000o`P0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`020?ooo`030?l0
003oool0o`000080oooo00<00?l00?ooo`3oool0503oool00`3o00000?l00?ooo`0:0?ooo`030?l0
00000?l0oooo00@0oooo00<00?l00000o`3oool02`3oool01@3o0000oooo0?ooo`3oool00?l001T0
oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00030?ooo`03003o003oool00?l0
01D0oooo00<0o`000000o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5000002d0
oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`3oool01P3oool0103o0000oooo0?ooo`000?l70?ooo`03003o003oool0oooo00X0oooo00<0o`00
0000o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0o`0000H0oooo00D0003o
0?ooo`3oool0oooo003o00090?ooo`03003o003o0000003o00@0oooo00D0003o0?ooo`3oool0o`00
003o00050?ooo`050?l00000o`00oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`050?ooo`03
003o003o0000oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000o`020?ooo`80
0?l00`3oool00`3o0000003o0?ooo`0:0?ooo`05003o003oool0oooo0?ooo`00o`001@3o00040?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`05003o003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0o`000?ooo`030?ooo`04003o003oool0
0?l0003o0080oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?l000080?ooo`03003o003o
ool0oooo0180oooo00<0o`000?ooo`3o00002P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00h0oooo0P3o000=0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0001<0oooo00<0o`000?ooo`3oool01@3o
ool00`00o`00o`000?ooo`020?ooo`05003o003oool0oooo0?ooo`3o00000P3oool01@000?l0oooo
0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo
00T0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<00?l0
0?ooo`3oool03P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0000o`3oool04P3oool01@000?l0oooo0?ooo`000?l0o`0001@0oooo00@0o`000?ooo`3oool00?l0
1P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0
203oool01000o`00oooo0?ooo`000?l80?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3o
ool00P3oool01P3o0000oooo0?ooo`3o0000oooo003o01D0oooo00<0o`000?ooo`00o`002`3oool0
0`3o0000003o0?ooo`040?ooo`03003o003oool0003o00X0oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?oo
o`00o`020?ooo`03003o003oool0oooo01<0oooo00<0o`000000o`3oool04`3oool5000001T0oooo
000l0?ooo`030000003oool0oooo0300oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050?l0
003oool0oooo0?ooo`000?l0203oool0103o0000oooo0?ooo`000?l70?ooo`03003o003oool0oooo
00X0oooo00<0o`000000o`3oool01P3oool00`00o`00003o0?ooo`070?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo
00D0oooo00D0003o0?ooo`3oool0oooo003o00090?ooo`03003o003o0000003o00@0oooo00@0003o
0?ooo`3oool00?l01P3oool01@3o0000oooo003o003oool00?l000<0oooo00<0o`000?ooo`3oool0
1P3oool00`00o`00o`000?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`000?l0
0P3oool2003o00<0oooo00<0o`000000o`3oool02P3oool01@00o`00oooo0?ooo`3oool00?l000D0
oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`03003o003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0103oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool0
1`00o`00oooo0?ooo`3oool00?l00?ooo`3o00000`3oool00`00o`00oooo0?l0000:0?ooo`03003o
003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0003o00h0oooo00@0o`000?ooo`3oool0o`002`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?l0000C0?ooo`03
0?l0003oool0oooo00D0oooo00<00?l00?l0003oool00P3oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0003o00<0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0000o`0<0?ooo`05
0000o`3oool0oooo0?ooo`3o00002`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo
00l0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`030?l000000?l0oooo0180oooo00D0003o
0?ooo`3oool0003o0?l0000D0?ooo`030?l0003oool0oooo00800?l0103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo0080oooo00H0003o0?ooo`3oool0oooo0?l00000o`0:0?ooo`04
003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3o00002`3oool01@00o`00oooo0?ooo`3oool0
o`0000@0oooo00<0o`00003o003oool0503oool00`3o0000oooo003o000;0?ooo`030?l000000?l0
0?l000@0oooo00<00?l00?ooo`000?l02P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0
oooo01H0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040?l0003oool0oooo003o00<0oooo
00<00?l00?ooo`3oool04P3oool00`3o0000003o0?ooo`0G0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo0300oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050?l0
003oool0oooo0?ooo`000?l0203oool0103o0000oooo0?ooo`000?l70?ooo`03003o003oool0oooo
00X0oooo00<0o`000000o`3oool01P3oool00`00o`00003o0?ooo`070?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l00000o`00oooo
00D0oooo0P000?l30?ooo`03003o003oool0oooo00L0oooo00<00?l00?l000000?l0103oool01000
0?l0oooo0?l00000o`060?ooo`040?l0003oool0oooo003o00@0oooo00<0o`000?ooo`3oool01P3o
ool00`00o`00o`000?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`000?l00P3o
ool2003o00<0oooo00<0o`000000o`3oool02P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00<0oooo0P3o00000`3oool00?l00?ooo`050?ooo`03003o003oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`03003o003o0000oooo0080oooo00<0
0?l00?ooo`3o00002P3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`000?l01P3oool00`00o`00oooo0?ooo`050?ooo`040?l0003oool0oooo0?l000X0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`80003o2P3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0o`0001@0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo
0?l000030?ooo`03003o003oool0oooo0080oooo00<0o`000000o`3oool00`3oool00`000?l0oooo
0?l000040?ooo`030?l0003oool0003o00`0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?ooo`03
0000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool03`3oool01@00o`00oooo0?ooo`3oool0003o
00D0oooo00<0o`000000o`3oool04P3oool01@000?l0oooo0?ooo`000?l0o`0001@0oooo00<0o`00
0?ooo`3oool00P00o`040?ooo`030000o`3oool0oooo00P0oooo0`3o00020?ooo`060000o`3oool0
oooo0?ooo`3o00000?l02P3oool01000o`00oooo0?ooo`000?l80?ooo`040000o`3oool0o`000?l0
00T0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l00000o`00oooo
01<0oooo00<0o`00003o003oool02`3oool00`3o0000003o003o00030?ooo`04003o003oool0oooo
0000o`T0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0
oooo0080003o0P3oool0103o0000oooo0?ooo`00o`030?ooo`03003o003oool0oooo0180oooo00<0
003o0?l0003oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0`
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
00D0o`000?ooo`3oool0oooo0000o`060?ooo`03003o003oool0oooo00X0oooo00<0o`000000o`3o
ool01P3oool00`00o`00003o0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool00?l000H0oooo0P000?l20?ooo`03
003o003oool0oooo00P0oooo00<00?l00?l000000?l0103oool010000?l0oooo0?l00000o`060?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?l000020?oo
o`030?l0003oool0oooo00L0oooo00D0o`000?ooo`000?l0oooo003o00020?ooo`05003o003oool0
oooo0?l000000?l02`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0
0?l00?ooo`3oool0103oool2003o0080oooo00<00?l00?ooo`3o00002P3oool00`00o`00oooo0?oo
o`0Q0?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o1@3oool00`00o`00oooo
0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P000?l70?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3o0000503oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0o`0000@0
oooo00<00?l00?ooo`3oool00P3oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`000?l0303oool01@000?l0oooo0?ooo`3oool0o`0000/0oooo00<0003o0?l0
003oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0?0?ooo`05003o003oool0oooo0?ooo`000?l01@3oool0
0`3o0000003o0?ooo`0B0?ooo`050000o`3oool0oooo0?ooo`000?l05@3oool01@3o0000oooo003o
003oool00?l000<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?l000050000
o`3oool0oooo0?ooo`00o`002`3oool01000o`00oooo0?ooo`000?l80?ooo`040000o`3oool0o`00
0?l000T0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`03003o003oool0oooo0180oooo00<0
o`00003o003oool02`3oool00`3o0000003o003o00030?ooo`04003o003oool0oooo0000o`T0oooo
00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo0080003o
0P3oool0103o0000oooo0?ooo`00o`030?ooo`03003o003oool0oooo0180oooo00<0003o0?l0003o
ool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0`0?ooo`050000
o`3oool0oooo0?ooo`3o00001@3oool0103o0000oooo0?ooo`000?l80?ooo`050?l0003oool0oooo
0?ooo`000?l01@3oool00`00o`00oooo0?ooo`0;0?ooo`030?l000000?l0oooo00H0oooo00<00?l0
0000o`3oool0203oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo003o00060?ooo`80003o0P3oool00`00o`00oooo0?ooo`08
0?ooo`03003o003o0000003o00@0oooo00@0003o0?ooo`3o00000?l01`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00P0oooo00D00?l00?l0003oool0oooo0?l000090?ooo`050?l0
003oool0003o0?ooo`00o`000P3oool01@00o`00oooo0?ooo`3o0000003o00/0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003o0000oooo00D0oooo00<00?l00?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool02`3oool00`00o`00oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`00o`002@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool0
0`3o00000?l0003o00020?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`00o`00oooo003o
00050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?l0000D0?ooo`050?l0003oool0oooo0?ooo`00o`00
0P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00d0oooo00<0003o0?ooo`3o0000
303oool00`000?l0o`000?ooo`050?ooo`040000o`3oool0oooo0?l000X0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3o
ool0o`002@3oool00`00o`00oooo0?ooo`0@0?ooo`05003o003oool0oooo0?ooo`000?l01@3oool0
0`3o0000003o0?ooo`0B0?ooo`050000o`3o0000oooo0?ooo`000?l05@3oool01@3o00000?l00?oo
o`3oool00?l000<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`050000
o`3o0000oooo0?ooo`00o`002`3oool01000o`00oooo0?ooo`000?l80?ooo`050000o`3oool0o`00
0?ooo`3o0000203oool01@00o`00oooo0?ooo`3oool0o`0000L0oooo00<00?l00?l0003oool04P3o
ool00`3o00000?l00?ooo`0;0?ooo`030?l000000?l00?l000<0oooo00@00?l00?ooo`3oool0003o
203oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo01D0oooo00H0o`000?ooo`000?l0
oooo0000o`3o00030?ooo`05003o003oool0oooo0?ooo`00o`00503oool00`000?l0o`000?ooo`0G
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0340oooo00@0003o0?oo
o`3oool0o`001@3oool00`3o0000oooo0000o`080?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`030?l000000?l0oooo00H0oooo00<00?l0
0000o`3oool0203oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool0103o0000oooo0?ooo`00o`060?ooo`80003o0P3oool00`00o`00oooo0?oo
o`080?ooo`03003o003o0000003o00@0oooo00<0003o0?ooo`00o`00203oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00P0oooo00D00?l00?ooo`3o0000oooo0?l000090?ooo`050?l0
003oool0003o0?ooo`00o`000P3oool01@00o`00oooo0?ooo`3o0000003o00/0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`04003o003oool0o`000?l000@0oooo00<00?l0
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool0303oool00`00o`00oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`800?l0203o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01@3o
ool00`3o0000oooo003o00020?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00L0003o0?ooo`3oool0oooo
003o003oool00?l000D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`80
003o0P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo01@0oooo00@0o`000?ooo`3o
ool00?l00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000003o0?ooo`050?ooo`030?l000000?l0oooo00`0oooo00<0003o0?oo
o`3o0000303oool00`000?l0o`000?ooo`050?ooo`050000o`3oool0o`000?ooo`3o00002@3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool0
10000?l0oooo0?ooo`3o00090?ooo`03003o003oool0oooo0100oooo00H00?l00?ooo`3oool0oooo
0000o`3o00040?ooo`030?l000000?l0oooo0140oooo00<0003o0?ooo`3o00000P3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l00000o`00oooo0080oooo00@00?l00?ooo`3oool0003o2@3oool00`3o
0000oooo0?ooo`030?ooo`050000o`3oool0o`000?l00000o`002`3oool01000o`00oooo0?ooo`00
0?l80?ooo`030000o`3o0000oooo0080oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0?oo
o`3o00080?ooo`03003o003oool0o`000180oooo00<0o`00003o003oool02`3oool00`3o0000003o
003o00020?ooo`05003o003oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`080?ooo`03
003o003oool0oooo01D0oooo00H0o`000?ooo`000?l0oooo0000o`3o00020?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool04@3oool00`000?l0o`000?ooo`0G0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0340oooo00@0003o0?ooo`3oool0o`001@3oool0
0`3o0000oooo0000o`080?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`0;0?ooo`030?l000000?l0oooo00H0oooo00<00?l00000o`3oool0203oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
103o0000oooo0?ooo`00o`060?ooo`80003o0P3oool00`00o`00oooo0?ooo`080?ooo`03003o003o
0000003o00@0oooo00<0003o0?ooo`00o`00203oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00T0oooo00@00?l00?ooo`3o0000o`002P3oool0103o0000003o0?ooo`00o`030?ooo`05
003o003oool0oooo0?l000000?l02`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`050000o`3oool0oooo
0?ooo`3o00001`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo00<00?l0
0?ooo`3oool02P3oool01P3o0000oooo0?ooo`3oool00?l00?ooo`800?l01P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool01@3o0000oooo
0?ooo`3oool0o`0000`0oooo00<00?l00?ooo`3oool08P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00L0003o0?ooo`3oool0oooo003o003oool00?l000D0oooo00<0o`00
0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`80003o203oool00`000?l0o`000?ooo`0D0?ooo`040?l0003o
ool0oooo003o00<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`070000
o`3o0000oooo0?ooo`3o0000oooo0000o`060?ooo`030?l000000?l0oooo00`0oooo00<0003o0?oo
o`3o0000303oool00`000?l0o`000?ooo`060?ooo`040000o`3o0000oooo0?ooo`80o`001P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?l000090?ooo`03003o003oool0oooo0100oooo00H00?l00?ooo`3oool0oooo0000
o`3o00040?ooo`030?l000000?l0oooo0140oooo00H0003o0?ooo`3o0000oooo0?l000000?lF0?oo
o`03003o003oool0oooo0080oooo00<00?l00000o`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`00o`002`3oool01000o`00oooo0?ooo`000?l80?ooo`030000o`3o
0000oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?l000090?ooo`03003o003o
ool0oooo0080o`00403oool00`3o00000?l00?ooo`0;0?ooo`030?l000000?l00?l00080oooo00D0
0?l00?ooo`3oool0oooo0000o`070?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0
503oool01P3o0000oooo0000o`3oool0003o0?l00080oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0A0?ooo`030000o`3o0000oooo01L0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0003o00P0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00/0
oooo00<0o`000000o`3oool01P3oool00`00o`00003o0?ooo`080?ooo`06003o003oool0003o0?oo
o`00o`00o`002P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?l000000?l0103oool00`000?l0oooo003o00080?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool02P3oool00`00o`00oooo0?l0000:0?ooo`040?l000000?l0oooo003o00<0oooo00D0
0?l00?ooo`3oool0o`000000o`0;0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`030?ooo`80o`000P3oool01@00o`00oooo0?ooo`3oool0003o00D0
oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`3o00090?ooo`04003o003oool0oooo
003o00l0oooo00<00?l00?ooo`3oool02P3oool0103o0000oooo0?ooo`00o`040?ooo`03003o003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`030?ooo`03003o003o
ool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`03003o003oool0oooo02<0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`060000o`3oool0oooo003o003o
ool00?l0103oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0000o``0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3o0000oooo00D0oooo00<00?l0
0?ooo`3oool0303oool00`3o0000oooo003o00040?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00P3oool01@000?l0o`000?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0o`0000`0oooo00<0003o0?l0003oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?l0003oool02@3o
ool00`00o`00oooo0?ooo`0@0?ooo`06003o003oool0oooo0?ooo`000?l0o`00103oool00`3o0000
003o0?ooo`0A0?ooo`060000o`3oool0o`000?ooo`3o0000003o5P3oool00`00o`00oooo0?ooo`02
0?ooo`03003o00000?l0oooo00T0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool00?l000/0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0o`000?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00@00?l00?ooo`3oool0o`002@3oool00`00o`00oooo0?ooo`020?ooo`80
o`003P3oool00`3o00000?l00?ooo`0;0?ooo`030?l000000?l00?l00080oooo00D00?l00?ooo`3o
ool0oooo0000o`070?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0503oool01P3o
0000oooo0000o`3oool0003o0?l00080oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0@0?ooo`040000o`3oool0oooo0?l001L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0<@3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0003o00P0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00<0
o`000000o`3oool01P3oool00`00o`00003o0?ooo`090?ooo`05003o00000?l0oooo003o003o0000
2`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
0P3oool00`000?l0oooo0000o`020?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo003o00090?ooo`040?l0003oool0oooo0?l000d0oooo00<00?l00?ooo`3o
ool02P3oool0103o0000003o0?ooo`00o`030?ooo`05003o003oool0oooo0?l000000?l02`3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool2
0?l00005003o003oool0oooo0?ooo`000?l01@3oool00`00o`00oooo0?ooo`040?ooo`040000o`3o
ool0oooo0?l000T0oooo00@00?l00?ooo`3oool00?l0403oool00`00o`00oooo0?ooo`090?ooo`04
0?l0003oool0oooo003o00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?oo
o`030?l000000?l0oooo0080oooo00<00?l00?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0
o`0000`0oooo00<00?l00?ooo`3oool0903oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0
003o0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0o`0000T0oooo00<0o`000000o`000?l0
3@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<00?l0203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3o0000oooo00D0oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo
003o00040?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool010000?l0o`00
0?ooo`3o00030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?l0000<0?ooo`030000o`3o0000oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3o0000oooo00T0oooo00<00?l00?ooo`3oool0403oool01P00o`00
oooo0?ooo`3oool0003o0?l000<0oooo00@0o`000?ooo`3oool0003o4@3oool01P000?l0oooo0?l0
003oool0o`000000o`h0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`00o`0;0?oo
o`04003o003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool0o`0000X0oooo00<00?l00?ooo`3oool0103oool20?l000`0oooo00<0o`00
003o003oool02`3oool01@3o0000003o003o003oool00?l000@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo01D0oooo00D0003o0?ooo`3oool0003o
0?l000020?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0403oool010000?l0oooo
0?ooo`3o000G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02D0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0003o00P0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo
00<0o`000000o`3oool01@3oool00`00o`00oooo0000o`0:0?ooo`04003o00000?l0oooo003o00`0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`00o`002@3oool0103o0000oooo0?ooo`3o000=0?ooo`03003o003oool0oooo
00X0oooo00<0o`000000o`00o`00103oool01P00o`00oooo0?ooo`3o0000oooo0000o`X0oooo00<0
0?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool00?l000X0oooo00D00?l00?l0003o0000
o`000000o`050?ooo`03003o003oool0oooo00@0oooo00@0003o0?ooo`3oool0o`002@3oool00`00
o`00oooo003o000A0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`00o`000`000?l30?oo
o`800?l000<0oooo0000o`3oool0203oool00`3o0000003o0?ooo`020?ooo`03003o003oool0oooo
00L0oooo00@0o`000?ooo`3oool0o`003@3oool00`00o`00oooo0?ooo`0T0?ooo`040?l0003oool0
oooo0000o`H0oooo00<0003o0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0o`0000P0oooo
0P000?l00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo00@00?l00000o`00o`00
0?l00P3oool00`00o`00oooo0?ooo`060?ooo`80o`00203oool00`000?l0oooo0?ooo`030?ooo`03
003o003oool00?l000h0oooo00<0o`00003o003oool00P3oool00`3o0000oooo0?ooo`040?ooo`03
003o003oool0oooo0080oooo00@0003o0?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?l0003oool02P3oool010000?l0oooo0?ooo`3o0005
0?ooo`030?l000000?l0oooo00H0oooo0P3o00020?ooo`030?l0003oool0oooo00/0oooo00D0o`00
0?ooo`00o`00oooo0000o`0<0?ooo`030?l000000?l0oooo00P0oooo00<00?l00?ooo`3oool04@3o
ool01P00o`00oooo0?ooo`3oool0003o0?l000<0oooo00@0o`000?ooo`3oool0003o4@3oool01`00
0?l0oooo0?l0003oool0o`000?ooo`000?l03@3oool00`000?l0oooo0?ooo`050?ooo`03003o003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool00?l000d0oooo00<00?l00?ooo`000?l02@3oool00`000?l0oooo0?ooo`040?ooo`070?l0003o
ool0oooo0?ooo`00o`00oooo0?l0000:0?ooo`04003o003oool0oooo0000o`D0oooo0P3o000:0?oo
o`03003o003oool0oooo00/0oooo00<0o`000000o`3oool00P00o`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0E0?ooo`070000o`3oool0oooo
0000o`3o0000oooo003o00060?ooo`03003o003oool0oooo0100oooo00@0003o0?ooo`3oool0o`00
5`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`80o`00303o
ool00`000?l0o`000?ooo`050?ooo`030?l000000?l0oooo00L0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00<0o`000000o`3oool01@3o
ool00`00o`00oooo0000o`0:0?ooo`80003o00<00?l00?l0003oool02`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0000
o`020?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`000?l00?l00?oo
o`090?ooo`040?l0003oool0oooo0?l000d0oooo00<00?l00?ooo`3oool02P3oool00`3o0000003o
003o00040?ooo`06003o003oool0oooo0?l0003oool0003o2@3oool00`00o`00oooo0?ooo`050?oo
o`05003o003oool0oooo0?ooo`00o`002P3oool01P00o`00oooo0?ooo`3oool0003o0?l000@0oooo
00<00?l00?ooo`3oool0103oool010000?l0oooo0?ooo`3o000:0?ooo`800?l04@3oool00`00o`00
oooo0?ooo`0:0?ooo`030?l0003oool0003o00<0oooo10000?l00`3oool00?l00000o`090?ooo`03
0?l0003oool0003o0080oooo00<00?l00?ooo`3oool01`3oool0103o0000oooo0?ooo`3o000=0?oo
o`03003o003oool0oooo02D0oooo00<0o`000000o`3oool01`3oool00`000?l00?l00?ooo`020?oo
o`04003o003oool0oooo0?l000L0oooo0P000?l30?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`00o`000P00o`000`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo00<0o`00
0?ooo`3o0000203oool00`000?l0oooo0?ooo`030?ooo`03003o003oool00?l000h0oooo00<00?l0
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`04003o003oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?l0003oool02P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l000000?l0oooo00P0oooo
0P3o000>0?ooo`050?l0003oool00?l0003o00000?l0303oool00`3o0000003o0?ooo`080?ooo`03
003o003oool0oooo0140oooo00H00?l00?ooo`3oool0oooo0000o`3o00030?ooo`040?l0003oool0
oooo0000oa00oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000oooo0000o`d0oooo0P000?l50?oo
o`03003o003oool0o`0000@0oooo00<0003o003o003oool01`3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool00?l000d0oooo00@00?l00?ooo`000?l0o`00203oool00`000?l0oooo0?ooo`04
0?ooo`060?l0003oool0oooo0?ooo`00o`00o`00303oool01000o`00oooo0000o`000?l60?ooo`04
0?l00000o`000?l0003o0080o`00103oool00`00o`00oooo0?ooo`0;0?ooo`030?l000000?l0oooo
00800?l0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00<00?l00?oo
o`3oool0503oool010000?l0oooo0?ooo`000?l20?ooo`03003o003oool0oooo00D0oooo00<00?l0
0?ooo`3oool03`3oool010000?l0oooo0?ooo`3o000G0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`D000008P3oool00`3o0000oooo0?l0000;0?ooo`030000o`3o0000oooo00H0oooo00D0003o
0?ooo`3oool0oooo003o00040?ooo`030?l0003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo
003o000>0?ooo`030?l000000?l0oooo00D0oooo00<00?l00?ooo`000?l02P3oool20000o`03003o
003o0000oooo00/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03003o
003oool0oooo0080oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`030000
o`3oool0oooo00<0oooo00<0003o003o003oool02@3oool00`3o0000oooo0?l0000?0?ooo`03003o
003oool0oooo00T0oooo00<0o`000000o`00o`00103oool01P00o`00oooo0?ooo`3o0000oooo0000
o`T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo003o000<0?ooo`05003o003oool0003o
0?ooo`3o00000`3oool00`00o`00oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000X0oooo00<0
0?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0:0?ooo`030?l000000?l00?l000L0oooo0`00
0?l90?ooo`030?l0003oool0003o0080oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?l0
000>0?ooo`03003o003oool0oooo02D0oooo00<0o`000000o`3oool01`3oool00`000?l0oooo0?oo
o`030?ooo`03003o003oool0o`0000D0oooo0P000?l60?ooo`80o`003@3oool010000?l00?l00?oo
o`000?l70?ooo`03003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`001`3oool00`000?l0
oooo0?ooo`020?ooo`04003o003oool0oooo003o00h0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`050?ooo`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3o0000oooo00X0oooo00@0003o0?ooo`3oool0o`00103o
ool0103o0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo00`0oooo00D0o`000?ooo`00o`00
0?l00000o`0<0?ooo`030?l0003oool0003o00L0oooo00<00?l00?ooo`3oool04`3oool01@00o`00
oooo0000o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0003o403oool010000?l0oooo0?ooo`3o
ool20?l000030?ooo`000?l0oooo00/0oooo00<0003o0?ooo`000?l01@3oool00`00o`00oooo0?l0
00030?ooo`040000o`3oool0oooo003o00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
003o000=0?ooo`04003o003oool0003o0?l000L0oooo00<0o`000000o`3oool01P3oool01@3o0000
oooo0?ooo`00o`00o`0000`0oooo00@00?l00?ooo`000?l0003o1`3oool00`00o`00oooo0?ooo`04
003o0080o`0000<00?l00?ooo`3oool02`3oool0103o0000003o0?ooo`00o`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0D0?ooo`040000o`3o
ool0oooo0000o`80oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0?0?ooo`050000
o`3oool0oooo0?ooo`3o00004P3oool5000001T0oooo000l0?ooo`030000003oool0oooo02<0oooo
00@0o`000?ooo`3oool0o`002`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080
0?l0103oool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`00o`003P3oool00`3o
0000003o0?ooo`050?ooo`03003o003oool0003o00X0oooo00@0003o0?ooo`000?l0o`003@3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000
o`020?ooo`040000o`3oool0oooo003o00/0oooo00<0003o0?ooo`3oool00`3oool00`000?l00?l0
0?ooo`0:0?ooo`80o`003`3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`00o`00oooo00<0oooo
00H00?l00?ooo`3oool0o`000?ooo`000?l90?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`00o`00303oool01@00o`00oooo0000o`3oool0o`0000<0oooo00<00?l00?ooo`3oool01@3oool0
10000?l0oooo0?ooo`3o000M0?ooo`03003o003oool0oooo00X0oooo00<0003o003o003oool02@3o
ool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0003o0080oooo00<00?l00?ooo`3oool01`3o
ool00`3o0000oooo0?l0000>0?ooo`03003o003oool0oooo0240oooo00H00?l00?ooo`3oool0oooo
0000o`3o00080?ooo`03003o00000?l0oooo00<0oooo00<00?l00?l0003oool00`3oool20000o`X0
oooo0P3o000;0?ooo`030000o`3oool0003o00T0oooo00<00?l00?ooo`3oool00`3oool0103o0000
oooo0?ooo`3o00060?ooo`030?l000000?l0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o000=
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0?ooo`00
0?l80?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003oool03@3oool00`000?l0oooo0?oo
o`0:0?ooo`040000o`3oool0oooo0?l000@0oooo00@0o`000?ooo`3oool0003o603oool01@3o0000
0?l00?ooo`000?l00?l000/0oooo00@0o`000?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`0C
0?ooo`05003o003oool0003o0?ooo`3o00000`3oool0103o0000oooo0?ooo`000?l@0?ooo`050000
o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o00D0
oooo00<00?l00?ooo`3o00000`3oool010000?l0oooo0?ooo`00o`070?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`00o`003@3oool01000o`00oooo0000o`3o00070?ooo`030?l000000?l0
oooo00L0oooo00<0o`000?ooo`00o`003@3oool01@00o`00oooo0000o`3oool0003o00D0oooo00<0
0?l00?ooo`3oool01@3oool3003o00d0oooo00@0o`000000o`3oool00?l01P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool0503oool010000?l0o`00
0?ooo`000?l20?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool01@000?l0
oooo0?ooo`3oool0o`0001H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool08`3oool0103o0000oooo0?ooo`3o000;0?ooo`030?l000000?l0oooo00H0oooo00<0003o0?oo
o`3oool00P00o`040?ooo`030?l0003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo003o000>
0?ooo`030?l000000?l00?l000D0oooo00<00?l00?ooo`000?l02P3oool010000?l00?l00000o`3o
000=0?ooo`050?l0003oool0oooo0?ooo`3o0000203oool01000o`00oooo0?ooo`000?l20?ooo`04
0000o`3oool0oooo003o00/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?oo
o`06003o003oool0oooo0?l0003oool0003o2@3oool00`00o`00oooo0?ooo`060?ooo`03003o003o
ool00?l000`0oooo00D00?l00?ooo`000?l0oooo0?l000030?ooo`03003o003oool0oooo00D0oooo
00@0003o0?ooo`3oool0o`007@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3o00000?l000X0
oooo00<00?l00?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0oooo
00L0oooo00<0o`000?ooo`3o00003`3oool00`00o`00oooo0?ooo`0P0?ooo`07003o003oool0oooo
0?ooo`000?l0oooo0?l000070?ooo`03003o00000?l0oooo00<0oooo00@00?l00?l0003oool0oooo
0P000?l>0?ooo`80o`002@3oool00`00o`00003o0000o`090?ooo`03003o003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo0080oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003o0000oooo00<0oooo
00<0o`000?ooo`3oool01@3oool01000o`00oooo0?ooo`000?l80?ooo`030000o`3oool0oooo0080
oooo00<0003o0?l0003oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l0
00<0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo00d0oooo00@00?l0
0?ooo`000?l00?l02`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool0
503oool01@00o`00oooo0000o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0003o403oool01@00
0?l0oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`00
0?l40?ooo`04003o003oool0oooo0?l00080oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`00o`003@3oool01000o`00oooo0000o`3o00070?oo
o`030?l000000?l0oooo00L0oooo00<0o`00003o003o00003@3oool00`00o`00oooo0000o`020?oo
o`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`3o00004@3oool00`00o`00oooo0?ooo`0B0?ooo`050000o`3oool0
o`000?ooo`000?l00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00h0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`06003o003oool0oooo0?ooo`3o0000003o1P3oool01P000?l0o`000?ooo`00o`00oooo003o
00@0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool00?l000h0oooo00<0o`00
0000o`00o`001@3oool00`00o`00oooo0000o`0:0?ooo`040000o`00o`00003o0?l000d0oooo00D0
o`000?ooo`3oool0oooo0?l000080?ooo`04003o003oool0oooo0000o`80oooo00@0003o0?ooo`3o
ool00?l02`3oool00`000?l0oooo0?ooo`030?ooo`03003o00000?l0oooo00X0oooo00<0o`000?oo
o`3oool03`3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00H00?l00?oo
o`3oool0o`000?ooo`000?l90?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool02`3o
ool00`00o`00oooo0000o`020?ooo`040?l0003oool0oooo003o00L0oooo00@0003o0?ooo`3oool0
o`007P3oool00`00o`00oooo0?ooo`070?ooo`040000o`3oool0o`00003o00/0oooo00<00?l00?oo
o`3oool01@3oool0103o0000oooo0?ooo`000?l20?ooo`03003o003oool0oooo00L0oooo00<0o`00
0?ooo`3o00003`3oool00`00o`00oooo0?ooo`0F0?ooo`80003o1`3oool00`00o`00oooo003o0002
0?ooo`040000o`3oool0oooo0?l000H0oooo00<00?l00?ooo`000?l00`3oool01000o`00o`000000
o`000?lB0?ooo`80o`001`3oool00`00o`00003o0?ooo`0:0?ooo`05003o003oool0oooo0?ooo`3o
0000103oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo0080oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0:0?ooo`06003o003o0000oooo0000o`3oool0o`00203oool0
1000o`00oooo0?ooo`000?l90?ooo`060000o`3oool0oooo0000o`3oool0o`003P3oool00`000?l0
oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0000o`07
0?ooo`80003o00<0oooo0000o`3oool03@3oool01@00o`00003o0?ooo`3oool00?l000X0oooo00D0
o`000?ooo`3oool0oooo0000o`050?ooo`03003o003oool0oooo01@0oooo00D00?l00?ooo`000?l0
oooo0?l000030?ooo`040?l0003oool0oooo0000o`l0oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`000?l<0?ooo`040000o`3oool0oooo0000o`@0oooo00@00?l00?ooo`3oool0o`00
0P3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo003o000=0?ooo`04003o00000?l0oooo0?l000L0oooo00<0o`000000o`3oool0203oool00`00
0?l0oooo0?ooo`0<0?ooo`03003o00000?l0oooo0080oooo00D0003o0?ooo`3oool0oooo003o000I
0?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0?l0000A0?ooo`03003o003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`030?ooo`070000o`3o
ool0o`000?ooo`3o0000003o003o00080?ooo`03003o003oool0oooo00h0oooo00<0003o0?ooo`3o
ool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool2003o0080oooo00<0o`000000o`3oool0
1@3oool010000?l0o`000?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`3o00001P3oool01@00
0?l0oooo0?ooo`3oool00?l000h0oooo00<0o`000000o`00o`001@3oool01P00o`00oooo0?ooo`00
0?l0oooo0?l000L0oooo00<0003o003o00000?l03P3oool0103o0000oooo0?ooo`3o00090?ooo`04
003o003oool0oooo0000o`80oooo00@0003o0?ooo`3oool00?l02`3oool00`000?l0oooo0?ooo`03
0?ooo`03003o00000?l0oooo01`0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`04
0?ooo`05003o003oool0o`000?ooo`000?l02@3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo00`0oooo00L00?l00000o`3oool0oooo0?l0003oool00?l000P0oooo00@0003o0?ooo`3o
ool0o`007P3oool00`00o`00oooo0?ooo`060?ooo`050000o`3oool0oooo0?l00000o`002`3oool0
0`00o`00oooo0?ooo`050?ooo`060?l0003oool0oooo0000o`3oool00?l02`3oool00`3o0000oooo
0?ooo`0>0?ooo`03003o003oool0oooo01@0oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo
00D00?l00?ooo`00o`00oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00@00?l00?ooo`3o
ool0003o0`3oool20000oaH0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?oo
o`05003o003oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?ooo`050?l000000?l0
oooo0?ooo`00o`001P3oool00`00o`00oooo0?ooo`090?ooo`06003o003o0000oooo0000o`3oool0
o`00203oool01000o`00oooo0?ooo`000?l90?ooo`060000o`3oool0oooo0000o`3oool0o`003@3o
ool00`00o`00o`000000o`0;0?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
2`3oool00`00o`00003o0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo01@0oooo00<00?l00?ooo`000?l0
0P3oool0103o0000oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01000
o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool00?l000d0oooo00@00?l00000o`3oool0o`001`3o
ool00`3o0000003o0?ooo`040?ooo`<00?l00P000?l>0?ooo`03003o00000?l0oooo00<0oooo00@0
003o0?ooo`3oool00?l06@3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00180
oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`800?l0103oool01`000?l0
oooo0?l0003o0000oooo0000o`00o`002@3oool00`00o`00oooo0?ooo`0=0?ooo`030000o`3oool0
oooo01T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool08@3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`00o`000P3oool00`3o
0000003o0?ooo`050?ooo`030000o`3o00000?l000<0oooo00@00?l00?ooo`3oool0o`001`3oool0
1@000?l0oooo0?ooo`3oool00?l000h0oooo00<0o`000000o`00o`001@3oool01@00o`00oooo0?oo
o`000?l0oooo0080o`001@3oool010000?l0oooo0?ooo`000?l>0?ooo`040?l0003oool0oooo0?l0
00T0oooo00@00?l00?ooo`3oool0003o0`3oool00`000?l0oooo003o000;0?ooo`030000o`3oool0
oooo00<0oooo00<00?l00000o`3oool07@3oool00`00o`00oooo0?ooo`070?ooo`03003o00000?l0
oooo00D0oooo00D00?l00?ooo`3o0000oooo0000o`090?ooo`03003o003oool0oooo01H0oooo00L0
003o0?ooo`3oool0oooo0?l0003oool00?l000P0oooo00@0003o0?ooo`3oool0o`007P3oool00`00
o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool00`00
o`00oooo0?ooo`050?ooo`060?l0003oool0oooo0000o`3oool00?l02`3oool00`3o0000oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo0`000?l50?ooo`030000o`3oool0oooo0080oooo00H0
0?l00?ooo`3oool0oooo003o00000?l50?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool30000
o`030?l00000o`00oooo01H0oooo0P3o00030?ooo`03003o003oool0oooo00/0oooo00@00?l00?oo
o`3oool0o`001`3oool01P3o0000oooo0?ooo`3oool0o`000000o`80oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080003o00<0oooo0?l0003oool0
203oool00`00o`00oooo0000o`090?ooo`060000o`3oool0oooo0000o`3oool0o`00303oool01000
o`00oooo003o00000?l;0?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo0?ooo`090?ooo`03003o0000
0?l0oooo00<0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0000o`020?ooo`040?l0003o
ool0oooo0?l00080oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`040?ooo`03
0?l000000?l0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`00o`00oooo00`0oooo00@00?l00000o`3oool0o`001`3oool00`3o0000003o003o0004003o
00<0oooo0P000?l>0?ooo`03003o00000?l0oooo00<0oooo00<0003o0?ooo`00o`006P3oool00`00
0?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00180oooo00<00?l00?ooo`3oool00P3oool0
0`000?l0oooo0000o`060?ooo`03003o003oool00?l000@0oooo00L0003o0?ooo`3oool0o`000?oo
o`000?l00?l000T0oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?ooo`0I0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`08003o003oool0oooo003o003oool0o`000?ooo`000?l50?oo
o`030000o`3o00000?l000<0oooo00@00?l00?ooo`3oool0o`001`3oool01@000?l0oooo0?ooo`3o
ool00?l000h0oooo00<0o`000000o`00o`001@3oool02000o`00oooo0?ooo`000?l0oooo0?l0003o
ool0o`00103oool010000?l0oooo0?ooo`000?l?0?ooo`80o`002P3oool00`00o`00oooo0000o`04
0?ooo`030000o`00o`00oooo00/0oooo00<0003o0?ooo`3oool00`3oool00`00o`00003o0?ooo`0N
0?ooo`03003o003oool0oooo00H0oooo00<0003o0?l0003oool01@3oool01@00o`00o`000?ooo`3o
ool0003o00T0oooo00<00?l00?ooo`3oool05P3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`00
o`002@3oool00`000?l0oooo0?l0000N0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00D0oooo00H0o`000?ooo`3o
ool0003o0?ooo`00o`0;0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool03P3oool2
0000o`P0oooo00<0003o0?ooo`3oool00P3oool01P00o`00oooo0?ooo`3oool00?l00000o`H0oooo
00@0o`000?ooo`3oool00?l00`3oool01@000?l0oooo0?ooo`3o00000?l001T0oooo00@0o`000?oo
o`3oool00?l03P3oool00`00o`00oooo0?l000070?ooo`080?l0003oool0oooo0?ooo`3o0000003o
0?ooo`00o`070?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P000?l00`3oool0
o`000?ooo`080?ooo`03003o003oool0003o00T0oooo00H0003o0?ooo`3oool0003o0?ooo`3o000;
0?ooo`05003o003oool0oooo003o00000?l02`3oool010000?l0oooo0?ooo`3oool20?l000H0oooo
00@0003o0?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o0000oooo00@0
oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0000o`020?ooo`030?l0003oool0o`0000<0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`040?ooo`030?l000000?l0oooo
00@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00`0oooo00@00?l00000o`3oool0o`001P3oool0103o0000oooo0000o`00o`060?ooo`030000o`3o
ool0003o00h0oooo00<00?l00000o`3oool0103oool00`000?l00?l00?ooo`0I0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3o0000503oool01`00o`00oooo0?ooo`3oool0003o0?ooo`00
0?l01P3oool01000o`00oooo0?ooo`00o`030?ooo`070000o`3oool0oooo0?l0003oool0003o003o
00090?ooo`03003o003oool0oooo00d0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo003o00040?ooo`04003o003oool0oooo0000o`D0oooo00<0003o003o003o0000
0`3oool01000o`00oooo0?ooo`3o00070?ooo`050000o`3oool0oooo0?ooo`00o`003P3oool00`3o
0000003o003o00040?ooo`07003o003oool0oooo0?ooo`000?l0oooo0?l000020?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`002P3oool00`00o`00oooo
0000o`040?ooo`030000o`00o`00oooo00/0oooo00<0003o003o003oool00P3oool00`00o`00oooo
0000o`0P0?ooo`03003o003oool0oooo00D0oooo00<0003o0?l0003oool01@3oool00`00o`00o`00
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool05P3oool01`000?l0oooo
0?ooo`3oool0o`000?ooo`00o`002@3oool00`000?l0o`000?ooo`0N0?ooo`03003o003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00o`000?ooo`0:0?ooo`03003o003oool0oooo
00D0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`0N0?ooo`03003o003oool0oooo00/0oooo0P00
0?l;0?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`000?l00?l00?ooo`060?ooo`030?l0
0000o`00oooo00D0oooo00@0o`000?ooo`3oool00?l06@3oool00`3o00000?l00?ooo`0>0?ooo`03
003o003oool0o`0000P0oooo00L0o`000?ooo`3oool0o`000?ooo`000?l00?l000P0oooo00<00?l0
0?ooo`3oool01`3oool01`00o`00oooo0?ooo`000?l0oooo0000o`3o00002@3oool00`00o`00003o
0?ooo`0:0?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool0203oool01@00o`00oooo
0?ooo`3o0000003o00/0oooo00@0003o0?ooo`3oool0oooo0P3o00060?ooo`<0003o2P3oool00`00
0?l0oooo0?ooo`070?ooo`040000o`00o`00oooo0?l000@0oooo00<00?l00?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo003o01P0oooo00<00?l00?ooo`000?l00P3o
ool00`3o0000oooo0?l000030?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`00103o
ool00`3o0000003o0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0<0?ooo`04003o00000?l0oooo0?l000H0oooo00@0o`000?ooo`000?l0
0?l01@3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool00`3oool00`00
o`00003o0?ooo`0I0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000503oool01`00
o`00oooo0?ooo`3oool0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`05003o003oool0oooo0?ooo`00
0?l02P3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo01l0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool00?l000@0
oooo00@00?l00?ooo`3oool0003o103oool010000?l0oooo003o003o00030?ooo`04003o003oool0
oooo0?l000P0oooo00<0003o0?ooo`00o`003`3oool00`000?l0oooo003o00040?ooo`07003o003o
ool0oooo0?ooo`000?l0oooo0?l000030?ooo`80o`0000D0oooo0000o`3oool0oooo0000o`0?0?oo
o`030?l0003oool0oooo00X0oooo00<00?l00000o`3oool00`3oool00`000?l00?l00?ooo`0;0?oo
o`030000o`00o`00oooo0080oooo00<00?l00?l000000?l08@3oool00`00o`00oooo0?ooo`030?oo
o`03003o00000?l0o`0000H0oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0?ooo`060?oo
o`03003o003oool0oooo01H0oooo00L0003o003o003oool0oooo0?l0003oool00?l000T0oooo00<0
003o0?l0003oool07P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?l0003oool02P3oool00`00o`00oooo0?ooo`040?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo003o000N0?ooo`03003o003oool0oooo00T0oooo0P000?l>0?ooo`030000o`3oool00?l000@0
oooo00<0003o003o003oool01`3oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo003o
01X0oooo00<00?l00?l0003o00003P3oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0o`00
0080oooo00<0003o003o003oool01`3oool00`00o`00oooo0?ooo`060?ooo`07003o003oool0oooo
0?ooo`000?l0oooo0000o`0:0?ooo`03003o00000?l0oooo00X0oooo00<0003o0?ooo`000?l00P3o
ool00`3o0000oooo0?ooo`070?ooo`06003o003oool0oooo0?ooo`3o0000003o2P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`050?ooo`050000o`3oool00?l00?ooo`3o00001@3oool00`00o`00oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool00?l0603oool00`00o`00oooo0000o`02
0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o0004
0?ooo`030?l000000?l0oooo00D0oooo00@00?l00?ooo`3oool0o`002P3oool00`000?l0oooo0?oo
o`0<0?ooo`04003o00000?l0oooo0?l000H0oooo00@0o`000?ooo`000?l00?l01@3oool01@000?l0
oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool00`3oool00`00o`00003o0?ooo`0I0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000503oool01`00o`00oooo0?ooo`3oool0
003o0?ooo`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0003o00D0oooo00<0
003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`020000o`T0oooo00<0003o0?ooo`3oool06P3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`00o`001@3oool0103o00000?l00?ooo`000?l40?ooo`040000o`00
o`00oooo0?l000<0oooo00@00?l00?ooo`3oool0o`00203oool00`000?l0oooo003o000?0?ooo`03
0000o`3o00000?l000@0oooo00H00?l00?ooo`3oool0oooo0000o`3o00060?ooo`050?l000000?l0
oooo0?ooo`000?l0703oool00`00o`00003o0?ooo`030?ooo`030000o`00o`00oooo00/0oooo00<0
003o003o003oool00P3oool00`00o`00o`000000o`0R0?ooo`03003o003oool0oooo0080oooo00<0
0?l00000o`3o00001P3oool00`00o`00o`000?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
0?l00?ooo`3oool05P3oool01P000?l00?l00?ooo`3oool0o`00003o00X0oooo00<0003o0?l0003o
ool07`3oool01@00o`00oooo0?ooo`3oool0003o00H0oooo00<00?l00?l0003oool02`3oool00`00
o`00oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo003o000O0?ooo`03003o003o
ool0oooo00H0oooo0P000?lA0?ooo`030000o`00o`00oooo00<0oooo00<0003o0?ooo`00o`001`3o
ool00`00o`00o`000?ooo`040?ooo`040?l0003oool0oooo003o01X0oooo00@00?l00?ooo`3oool0
o`003@3oool00`00o`00oooo0?ooo`080?ooo`80o`000P3oool00`000?l0oooo0?ooo`070?ooo`03
003o003oool0oooo00H0oooo00L00?l00?ooo`3oool0003o0?l0003oool0003o00X0oooo00<00?l0
0000o`3oool02P3oool20000o`<0oooo00<0o`000?ooo`3oool01P3oool02000o`00oooo0?ooo`3o
ool0o`000?ooo`000?l00?l02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00X0
oooo1@00o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`000P3oool00`3o0000
oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo003o000I0?ooo`03003o003oool0003o0080oooo00<0o`000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool00?l000D0oooo00<0003o0?ooo`3oool0103oool01000o`00
oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo00`0oooo00@00?l00000o`3oool0o`001P3oool0
0`3o0000oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo0000oaT0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?l0000D0?ooo`04003o003oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo00@0oooo00<0003o0?ooo`3oool0
2@3oool00`00o`00oooo0?ooo`020000o`T0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`00o`001@3oool01@3o0000oooo003o003oool0003o00<0oooo00@0003o003o003oool0
o`00103oool00`00o`00oooo0?l000080?ooo`030000o`3oool00?l000l0oooo00<0003o0?l00000
o`00103oool01P00o`00oooo0?ooo`3oool0003o0?l000H0oooo00H0003o0?l0003oool0o`000?oo
o`000?lK0?ooo`030000o`3oool0oooo00<0oooo00<0003o003o003oool02`3oool00`000?l00?l0
0?ooo`020?ooo`03003o003o0000003o02<0oooo00L00?l00?ooo`3oool0oooo003o00000?l0o`00
00H0oooo00<00?l00?l0003oool00P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo
01D0oooo00<0003o0?ooo`00o`000P3oool00`3o00000?l00?ooo`090?ooo`030000o`3o0000oooo
01l0oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`03003o003o0000oooo00/0oooo00<00?l0
0?ooo`3oool0103o00030?ooo`030000o`00o`00oooo01l0oooo00<00?l00?ooo`3oool0103oool2
0000oa@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?l0003oool00`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo01H0oooo00<0
0?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool00?l000T0oooo0P3o
00020?ooo`030000o`3oool0oooo00P0oooo00<00?l00?ooo`3oool01@3oool01`00o`00oooo0?oo
o`000?l0o`000?ooo`000?l02`3oool00`000?l0oooo0?ooo`090?ooo`80003o0`3oool00`3o0000
oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0003o003o00080?oo
o`030000o`3oool0oooo00X0oooo1@00o`040?ooo`03003o003oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo0000o`020?ooo`05003o003oool0oooo0?ooo`3o00001@3oool01@00o`00oooo0?oo
o`3oool0o`0000L0oooo00<0003o0?ooo`00o`006P3oool01`00o`00003o0?ooo`3oool0o`000?oo
o`3o00000`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`00o`00oooo00<0oooo00<0003o0?l0
003oool01@3oool01000o`00oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3o00001P3oool0103o0000oooo003o00000?l30?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`000?l0
603oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0001D0oooo00<00?l00?ooo`000?l0
0`3oool01@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00000o`3oool0103oool00`000?l0
oooo0?ooo`090?ooo`06003o003oool0oooo0000o`3oool0003o203oool00`000?l0oooo0?ooo`0J
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D000006`3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool00?l000D0oooo00D0o`000?ooo`3oool00?l00000o`030?ooo`040000o`3oool0
oooo0?l000@0oooo00<00?l00?l0003oool0203oool00`000?l0oooo003o000?0?ooo`030000o`3o
00000?l000@0oooo00H00?l00?ooo`3oool0oooo0000o`3o00060?ooo`060000o`3oool0o`000?l0
003oool0003o6`3oool00`000?l0oooo0?ooo`030?ooo`030000o`00o`00oooo00/0oooo00<0003o
003o003oool00P3oool00`00o`00o`000000o`0M0?ooo`030000o`3oool0oooo00@0oooo00H00?l0
0?ooo`3oool00?l00000o`3o00060?ooo`03003o003o0000oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0F0?ooo`030000o`3oool00?l000<0oooo00<00?l00?ooo`3oool0
203oool00`000?l0o`000?ooo`0O0?ooo`05003o003oool0oooo0?ooo`000?l01P3oool00`00o`00
oooo0?l000090?ooo`80o`0000<00?l00?l0003o00001`3oool00`000?l00?l00?ooo`0;0?ooo`03
0000o`3oool0oooo0140oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`03
003o003oool0003o0080oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`04003o003oool0oooo
0?l000<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0
oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo003o000:0?ooo`040?l0003oool0
0?l00000o`X0oooo00<00?l00?ooo`3oool01@3oool01`00o`00oooo0?ooo`000?l0o`000?ooo`00
0?l02`3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`00
o`00oooo0?ooo`030?ooo`050?l0003oool0oooo0000o`00o`00203oool00`000?l0oooo0?ooo`0:
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0000o`03
0?ooo`03003o003oool0oooo0080oooo0P3o00040?ooo`04003o003oool0oooo0?l000L0oooo00<0
003o0?ooo`00o`006P3oool01`00o`00003o0?ooo`3oool0o`000?ooo`3o00000`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool01@3oool01000o`00
oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o00001P3oool0103o
0000oooo003o00000?l20?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool0
1@000?l0oooo0?ooo`3oool00?l000@0oooo00<0003o0?ooo`3oool00`3oool50000o`h0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?l0000E0?ooo`03003o003oool0003o00<0oooo00D0
003o0?ooo`3oool0oooo003o00070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
2@3oool00`00o`00oooo0000o`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5P3oool5000001T0oooo000l0?ooo`030000003oool0oooo02T0oooo00<0o`00003o003oool01@3o
ool01@3o0000oooo0?ooo`00o`00003o00<0oooo00@0003o0?ooo`3oool0o`00103oool00`00o`00
o`000?ooo`080?ooo`030000o`3oool00?l000l0oooo00<0003o0?l00000o`00103oool01P00o`00
oooo0?ooo`3oool0003o0?l000H0oooo00H0003o0?ooo`3oool0o`000?ooo`000?lK0?ooo`030000
o`3oool0oooo00<0oooo00<0003o003o003oool02`3oool020000?l00?l00?ooo`3oool00?l00?oo
o`3o0000003o7@3oool00`000?l0oooo0?ooo`050?ooo`800?l000<0oooo0000o`3o00001P3oool0
0`00o`00o`000?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool05P3oool0
0`000?l0oooo003o00030?ooo`03003o003oool0oooo00P0oooo00<0003o0?l0003oool07`3oool0
1000o`00oooo0?ooo`000?l60?ooo`04003o003oool0oooo0?l000P0oooo00@0o`000?ooo`3oool0
0?l02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0003o0080oooo00D0003o0?ooo`3o
ool0oooo003o00050?ooo`05003o003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool00?l000`0oooo00<00?l00000o`3oool02P3oool00`00o`00oooo0?ooo`03
0?ooo`08003o003oool0oooo0?ooo`000?l0oooo0?l000000?l;0?ooo`030000o`3oool0oooo00X0
oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo00@0oooo00H0o`000?oo
o`3oool0003o0?ooo`00o`070?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool0203o
ool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0103o
ool01`3o0000oooo0?ooo`3oool00?l00?ooo`3o0000203oool00`000?l00?l00?ooo`0J0?ooo`07
003o00000?l0oooo0?ooo`3o0000oooo0?l000030?ooo`030000o`3oool0oooo00`0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?l000050?ooo`03003o003oool0o`0000/0oooo00<0003o
0?ooo`3oool03@3oool00`000?l0oooo0?l000050?ooo`050?l0003oool0oooo003o00000?l00P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0003o003o003oool00P3o
ool00`00o`00oooo0?ooo`030?ooo`D0003o103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0503oool00`00o`00oooo0000o`030?ooo`040000o`3o
ool0oooo003o00P0oooo00<0003o0?ooo`3oool00P3oool00`00o`00003o0?ooo`0:0?ooo`03003o
003oool0003o00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02X0oooo00<00?l00?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`<0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00o`000?ooo`080?ooo`030000o`3oool00?l000l0oooo00<0003o0?l00000o`00
103oool01P00o`00oooo0?ooo`3oool0003o0?l000H0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo00<0oooo00<0003o003o003oool02`3oool02000
0?l00?l00?ooo`3oool00?l00?ooo`3o0000003o7@3oool20000o`L0oooo00@00?l00?ooo`000?l0
o`001P3oool00`00o`00o`000?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3o
ool05P3oool01`000?l0oooo0?ooo`00o`00oooo003o003o00002P3oool00`000?l0o`000?ooo`0O
0?ooo`04003o003oool0oooo0000o`H0oooo00@00?l00?ooo`3oool0o`001`3oool01@3o0000oooo
0?ooo`3oool00?l000X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0B0?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool04P3oool01000o`00oooo0?ooo`3oool20000
o`D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`80o`001@3oool00`00
o`00oooo0?ooo`0E0?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool00?l000X0oooo00<00?l00?ooo`000?l02`3oool00`00o`00oooo0?ooo`03
0?ooo`04003o003oool0oooo0000o`80oooo00<0o`000?ooo`000?l02P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool01P3o0000oooo0?oo
o`000?l0oooo003o00L0oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`090?ooo`03
003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool2003o
00T0oooo00<0003o0?ooo`3oool06@3oool01`00o`00003o0?ooo`3oool0o`000?ooo`3o0000103o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00<0oooo00<0003o0?ooo`3o00001@3o
ool00`00o`00oooo0?l0000;0?ooo`03003o00000?l0oooo00d0oooo00<0003o0?ooo`3o00001@3o
ool01`3o0000oooo0?ooo`00o`00003o0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0;0?ooo`05
0000o`00o`00oooo0?ooo`00o`003`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool00?l0
00L0oooo00<0003o0?ooo`00o`000`3oool00`00o`00oooo0000o`0;0?ooo`03003o00000?l0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool02@3oool00`00o`00
o`000?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l0103oool01P3o0000
oooo0?ooo`3oool00?l00?l000T0oooo00<0003o0?ooo`00o`003`3oool00`000?l0o`00003o0004
0?ooo`06003o003oool0oooo0?ooo`000?l0o`001P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo01T0oooo00<0003o003o003oool00`3oool00`000?l00?l00?ooo`0;0?ooo`090000
o`00o`00oooo0?ooo`00o`00oooo0?l0003oool0003o01/0oooo00<0003o0?ooo`000?l02@3oool0
0`000?l0o`000?ooo`050?ooo`03003o003o0000oooo0080oooo00<0003o0?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0E0?ooo`080000o`3oool0oooo0?ooo`00o`00oooo003o003o000:0?ooo`03
0000o`3o0000oooo01l0oooo00@00?l00?ooo`3oool0003o1P3oool01000o`00oooo0?ooo`3o0006
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo01<0oooo00@00?l00?ooo`3oool0003o5@3oool00`00o`00oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`030?l0
003oool0oooo00@0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo003o000:0?ooo`03003o003oool0003o00/0
oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003oool0003o
00X0oooo00<0003o0?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool00?l000L0oooo00@0o`00
0?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo00L0oooo0P3o
00020?ooo`030?l00000o`000?l000H0oooo00<00?l00000o`3oool06P3oool01`00o`00003o0?oo
o`3oool0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00<0
oooo00<0003o0?ooo`3o00001@3oool00`00o`00oooo0?l0000:0?ooo`03003o003oool0003o00h0
oooo00<0003o0?ooo`3o00001@3oool0103o0000oooo0?ooo`00o`020000o`P0oooo00<0003o0?oo
o`3oool02`3oool01@000?l00?l00?ooo`3oool00?l000l0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l00?l00?ooo`070?ooo`040000o`3oool0oooo003o0080oooo00<00?l00?ooo`000?l02`3o
ool00`00o`00003o0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`03003o003oool0
oooo00P0oooo00<00?l00?l0003oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`00
003o00@0oooo00H0o`000?ooo`3oool0oooo003o003o00090?ooo`030000o`00o`00oooo00l0oooo
00@0003o0?l0003oool00?l00P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3o0000oooo00D0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool00?l000@0
oooo00<0003o003o003oool02`3oool02@000?l00?l00?ooo`3oool00?l00?ooo`3o0000oooo0000
o`0K0?ooo`040000o`3oool0oooo0000o`P0oooo00<0003o0?ooo`3o00001P3oool01@00o`00oooo
0?ooo`3oool0003o00L0oooo00<00?l00?ooo`3oool05@3oool020000?l0oooo0?ooo`3oool00?l0
0?ooo`00o`00o`002P3oool00`000?l0o`000?ooo`0P0?ooo`03003o00000?l0oooo00H0oooo00@0
0?l00?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0000o`0D0?ooo`04003o003oool0oooo0000o`T0
oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`090?ooo`04003o003oool0oooo003o
00d0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
00H0oooo00@00?l00?ooo`3oool0003o303oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00H0
003o0?ooo`3oool0o`000?ooo`000?l90?ooo`030000o`3oool00?l00100oooo1000o`070?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo
00T0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo
00T0oooo0P3o00030?ooo`800?l0103oool00`00o`00003o0?ooo`0J0?ooo`03003o00000?l0oooo
0080oooo0P3o00040?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<00?l00000o`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<00?l00?ooo`3o00002P3oool00`00o`00oooo0000o`0>
0?ooo`030000o`3oool0o`0000D0oooo00@0o`000?ooo`3oool00?l00P000?l90?ooo`030000o`3o
ool0oooo00X0oooo00@0003o0?ooo`00o`000?l0403oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`00o`00oooo00L0oooo00@0003o0?ooo`3oool00?l00P3oool00`00o`00oooo0000o`0;0?ooo`03
003o00000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`0M0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool01P3oool01000o`00
oooo0?ooo`3o00040?ooo`030?l0003oool0oooo00<0oooo00<0003o003o00000?l0103oool01P3o
0000oooo0?ooo`3oool0o`00003o00X0oooo00<0003o0?ooo`3oool03P3oool010000?l0o`000?oo
o`00o`020?ooo`03003o003oool0oooo0080oooo00<0003o0?l0003oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`00o`00103oool00`000?l00?l0
0?ooo`0;0?ooo`040000o`00o`00oooo003o0080oooo00<0o`000?ooo`000?l06`3oool010000?l0
oooo0?ooo`000?l80?ooo`030000o`3oool0o`0000H0oooo00D00?l00?ooo`3oool0oooo0000o`07
0?ooo`03003o003oool0oooo01D0oooo00P0003o0?ooo`3oool0oooo003o003oool00?l00?l000X0
oooo00<0003o0?l0003oool0803oool00`00o`00003o0?ooo`060?ooo`04003o003oool0oooo0?l0
00@0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`000?l05@3oool00`00o`00oooo0000o`080?ooo`03003o003oool00?l0
00T0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`00o`002@3oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`800?l00`3oool0
0`000?l0oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`00o`002`3oool5003o00030?l0003o
ool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00<0oooo
00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00L0oooo
00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`800?l000@0oooo003o003oool0
003o6`3oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`00
o`002P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`00o`00oooo0000o`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`00
o`00o`000?ooo`090?ooo`03003o003oool0003o00h0oooo00@0003o0?ooo`3oool0o`00103oool0
1@3o0000oooo003o003oool0003o00X0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo003o
0000o`0@0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`0E0?ooo`030000o`3oool0oooo00<0oooo00<0003o003o003oool01`3oool010000?l0oooo
0?ooo`3oool2003o0080oooo00<0003o0?ooo`3oool02@3oool00`00o`00003o0?ooo`050?ooo`05
0000o`3oool0oooo0?ooo`000?l07@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0O0?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool0o`00103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0003o00@0oooo00H0o`000?ooo`3oool0oooo0?l00000
o`0:0?ooo`030000o`3oool0oooo00h0oooo00@0003o0?l0003oool00?l00P3oool00`00o`00oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0H0?ooo`030000o`3oool00?l000@0oooo00<0003o003o003oool02`3oool01P000?l0o`00
003o0000o`00oooo0?l00080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?oo
o`050000o`3oool0oooo0?ooo`000?l01P3oool010000?l0oooo0?ooo`3o00060?ooo`03003o003o
ool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo0080oooo00<00?l00?ooo`3o00002P3oool00`000?l0o`000?ooo`0P0?ooo`03003o0000
0?l0oooo00D0oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00080?ooo`03003o
003oool0oooo00H0oooo00<00?l00000o`3oool02P3oool00`000?l0oooo0000o`0E0?ooo`03003o
003oool0003o00L0oooo00D00?l00?ooo`3oool0oooo003o00080?ooo`03003o003oool0oooo00/0
oooo00<00?l00?ooo`00o`003P3oool00`00o`00oooo0?ooo`040?ooo`800?l00`3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`03003o003oool0oooo00@00?l01@3oool00`000?l0oooo0?ooo`090?ooo`05
003o003oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`00o`002P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<0003o
0?ooo`3oool0203oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00L0oooo00<00?l0
0?ooo`3oool04P3oool2003o00030?ooo`000?l0oooo01X0oooo00<00?l00000o`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool00?l000T0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0003o0P3o
ool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo
0000o`0>0?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`00o`00303oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3oool00?l00140oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`00o`00103oool00`00o`00
003o0?ooo`070?ooo`040000o`3oool0oooo0?ooo`800?l00P3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0003o7@3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo00D0oooo00@00?l00?oo
o`3oool0o`000`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00H0o`00
0?ooo`3oool0oooo0?l00000o`0:0?ooo`030000o`3oool0oooo00h0oooo00@0003o0?l0003oool0
0?l00P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool00?l000@0oooo00<0003o003o003o
ool02`3oool01P000?l0o`00003o0000o`00oooo0?l00080oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool010000?l0oooo0?oo
o`3o00060?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo
0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo
0?ooo`3o00090?ooo`030?l000000?l0oooo0200oooo00<0003o0?ooo`3oool01@3oool00`00o`00
oooo0?ooo`020?ooo`030?l0003oool0o`0000T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00
003o0?ooo`0:0?ooo`030000o`3oool0003o01D0oooo00<00?l00?ooo`000?l01P3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool02`3oool2003o00l0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0
oooo0`00o`090?ooo`030000o`3oool0oooo00X0oooo00<00?l00?ooo`00o`000`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`00o`002P3oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0<0?oo
o`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool05P3oool00`000?l0oooo0?ooo`0I0?oo
o`03003o00000?l0oooo0080oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo003o0000o`08
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`07003o003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00<00?l00?ooo`3oool02@3oool00`00o`00oooo0000o`0>0?ooo`040000o`3oool0oooo0?l000@0
oooo00<0o`000?ooo`00o`00303oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool00?l00140
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01@0
oooo00<0003o0?ooo`00o`00103oool00`00o`00003o0?ooo`070?ooo`030000o`3oool0oooo0080
oooo00@00?l00?ooo`3oool0003o2`3oool00`000?l00?l00?ooo`070?ooo`80003o7P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo00<0
oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo
00<0oooo00H0o`000?ooo`3oool0oooo0?l00000o`0:0?ooo`030000o`3oool0oooo00h0oooo00@0
003o0?l0003oool00?l00P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool00?l000@0oooo
00<0003o003o003oool02`3oool01P000?l0o`00003o0000o`00oooo0?l00080oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool010000?l0oooo0?ooo`3o00060?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`80003o2P3oool00`000?l0oooo0?ooo`03
0?ooo`04003o003oool0oooo0?l000T0oooo00<0o`000000o`3oool0803oool00`000?l0oooo0?oo
o`050?ooo`03003o003oool0oooo0080oooo0P3o000:0?ooo`03003o003oool0oooo00H0oooo00<0
0?l00000o`3oool02P3oool00`000?l0oooo0000o`0F0?ooo`030000o`3oool0oooo00@0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00d0oooo00<0
0?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo0P00
o`040?ooo`03003o003oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo0?l0000C0?ooo`030000
o`3oool0oooo00X0oooo00<00?l00?ooo`00o`000`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`00o`002@3oool00`00o`00oooo0?ooo`040?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`04003o
003oool0oooo0000o`X0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo01L0oooo00<0003o0?ooo`3oool0603oool00`00o`00003o0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00@0003o003o003oool00?l0203oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool01`00o`00oooo0?ooo`3oool0
003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<0
0?l00?ooo`000?l03P3oool010000?l0oooo0?ooo`3o00030?ooo`040?l0003oool0oooo003o00`0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool00?l000<0
oooo00<00?l00?ooo`000?l01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0
oooo00<0003o003o003oool01`3oool20000oah0oooo00<000000?ooo`3oool05`3oool001/0oooo
0P0000040?ooo`800000103oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo0280oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000L0
oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3o00000?l000X0oooo00<0003o0?oo
o`3oool03P3oool010000?l0o`000?ooo`00o`020?ooo`03003o003oool0oooo0080oooo00<0o`00
0000o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01H0oooo00D0003o
0?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo00/0oooo00<0003o0?l00000o`000P3o
ool0103o0000oooo0?ooo`000?l90?ooo`030000o`3oool0003o00h0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000H0oooo00<00?l00?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`00
0?l02P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3o
ool0803oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool02@3oool00`00o`00oooo0?ooo`060?ooo`03003o00000?l0oooo00X0oooo00<0003o0?ooo`00
0?l05P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo00800?l02`3oool01@00o`00
oooo0?ooo`3oool00?l000d0oooo00@0o`000?ooo`3oool0o`004`3oool00`000?l0oooo0?ooo`0:
0?ooo`03003o003oool00?l00080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool00?l000T0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00
0?l:0?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0G0?ooo`030000o`3oool0oooo01T0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`040000
o`00o`00oooo003o00P0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0oooo0P000?l50?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0000o`0>0?ooo`040000o`3oool0oooo
0?l000<0oooo00@0o`000?ooo`3oool00?l0303oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0140oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`030?l00000
0?l0oooo01D0oooo00@0003o0?ooo`3oool00?l00P3oool00`00o`00oooo0000o`070?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`000?l00?l00?ooo`080?ooo`030000
o`3oool0oooo01`0oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000`0oooo00<000000?oo
o`3oool08`3oool01000o`00oooo0?ooo`00o`050?ooo`040?l0003oool0oooo0?l000h0oooo00D0
o`000?ooo`3oool0o`00003o000:0?ooo`030000o`3oool0oooo00h0oooo00@0003o0?l0003oool0
0?l00P3oool00`00o`00oooo0?ooo`020?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0F0?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3o00000?l00080oooo00@0o`000?ooo`3oool0003o2@3oool0
0`000?l0oooo0000o`0>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3o00060?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`T0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030?l000000?l0oooo01l0oooo00<0003o0?ooo`00o`00
1P3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00D0oooo00<00?l00000o`3oool0
2@3oool010000?l0oooo0?ooo`000?lF0?ooo`030000o`00o`00oooo0080oooo00<00?l00?ooo`3o
ool0203oool01@00o`00oooo0?ooo`3oool00?l00240oooo0P00o`0>0?ooo`04003o003oool0oooo
003o00h0oooo00<0o`000?ooo`3o00004`3oool00`000?l0oooo0?ooo`0;0?ooo`05003o003oool0
oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo003o00L0oooo
00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`00o`00oooo0000o`0:0?ooo`03003o003oool0oooo00h0oooo
00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0G0?ooo`030000o`3oool0oooo01P0oooo
00<0003o003o003oool0203oool01@000?l00?l00?ooo`3oool00?l000L0oooo00<0003o0?ooo`3o
ool02`3oool010000?l0oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`00o`002`3oool0
1000o`00oooo0?ooo`000?l=0?ooo`040000o`00o`00oooo0?l000<0oooo00@0o`000?ooo`3oool0
0?l0303oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo01@0oooo00D0003o0?ooo`3o
ool0oooo003o00020?ooo`04003o003oool0oooo0000o`H0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`00o`00oooo02L0oooo00<000000?ooo`3oool05`3oool0
01X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo1`00000O0?ooo`04003o003oool0oooo003o00H0oooo00<0o`000?ooo`3o00003P3o
ool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00H0oooo00<00?l00000o`3oool03`3o
ool010000?l0o`000?ooo`00o`020?ooo`03003o003oool0oooo0080oooo00<0o`000000o`3oool0
0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01H0oooo00D0003o0?ooo`3oool0
oooo003o00030?ooo`030000o`3oool0oooo00/0oooo00<0003o0?l00000o`000P3oool0103o0000
oooo0?ooo`000?l90?ooo`030000o`3oool0003o00h0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000H0oooo00<00?l00?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o2@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3oool07`3o
ool00`000?l0oooo003o00060?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00003o0?ooo`090?ooo`040000o`3oool0oooo0000oaH0oooo00D0003o003o003oool0
oooo003o000<0?ooo`04003o003oool0oooo003o0240oooo00<00?l00?ooo`3oool03P3oool2003o
00l0oooo0P3o000D0?ooo`030000o`3oool0oooo00/0oooo00D00?l00?ooo`3oool0oooo0000o`07
0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool00?l01`3oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`03003o003oool0003o00T0oooo00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo01P0oooo00<0003o0?ooo`3oool0603oool00`000?l00?l00?oo
o`080?ooo`050000o`00o`00oooo0?ooo`00o`001P3oool00`000?l0oooo0?ooo`0<0?ooo`040000
o`00o`000?l0003o0080oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0o`00003o000:0?ooo`05003o003oool0oooo
0?ooo`000?l03@3oool010000?l00?l00?ooo`3o00030?ooo`040?l0003oool0oooo003o00d0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`0D0?ooo`070000o`3oool0oooo0?ooo`00
o`00oooo003o00030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool00?l00240oooo1`00000I0?ooo`006P3oool010000000
oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`8000003@3oool00`000000oooo0?ooo`0T
0?ooo`800?l01`3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0o`000080oooo00<00?l0
0?ooo`3oool01P3oool00`00o`00003o0?ooo`0?0?ooo`060000o`3o0000oooo003o003oool00?l0
1@3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3o0000oooo0080oooo00@0o`000?ooo`3oool0003o2@3oool00`00
0?l0oooo0000o`0>0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`3o00060?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3oool07`3oool0
0`000?l0oooo003o00050?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool01@3oool0
0`00o`00003o0?ooo`090?ooo`050000o`3oool0oooo0?ooo`000?l05@3oool010000?l0oooo003o
0000o`0=0?ooo`04003o003oool0oooo003o03<0oooo00<00?l00?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`040000o`3oool0oooo003o00H0oooo00<00?l00?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`00
o`00003o0?ooo`080?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0H0?ooo`030000o`3oool0oooo01P0oooo00<0003o003o003oool0203oool01@00
0?l00?l00?ooo`3oool00?l000H0oooo00<0003o0?ooo`3oool0303oool01`00o`00003o0?ooo`3o
ool00?l00?ooo`000?l0203oool00`00o`00oooo0?ooo`090?ooo`050?l0003oool0oooo0?l00000
o`002P3oool01@00o`00oooo0?ooo`3oool0003o00d0oooo00@0003o003o003oool0o`000`3oool0
0`3o0000oooo003o000>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3o0000oooo00L0oooo00<0o`000000o`3oool0503oool0
1`000?l0oooo0?ooo`3oool00?l00?ooo`00o`000`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo003o000W0?ooo`030000
003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<00?l00?ooo`3o
ool01@3oool20?l000l0oooo00<0o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`060?ooo`03
003o003oool0003o00l0oooo00H0003o0?l0003oool00?l00?ooo`00o`050?ooo`030?l000000?l0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`80003o2@3oool0
1@000?l0oooo0?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool02`3oool00`000?l0o`000?oo
o`020?ooo`040?l0003oool0oooo0000o`T0oooo00@0003o0?ooo`3oool0003o303oool00`000?l0
oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`040?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000000o`3oool07`3oool00`000?l0oooo003o00050?oo
o`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`000?l9
0?ooo`050000o`3oool0oooo0?ooo`000?l0503oool010000?l0oooo0?ooo`00o`0?0?ooo`800?l0
FP3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool01@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
003o0?ooo`080?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0H0?ooo`030000o`3oool0oooo01P0oooo00<0003o003o003oool0203oool01@000?l0
0?l00?ooo`3oool00?l000H0oooo00<0003o0?ooo`3oool02P3oool2003o00070?ooo`000?l0oooo
0?ooo`00o`00oooo0000o`070?ooo`03003o003oool0oooo00X0oooo00H0o`000?ooo`3oool0o`00
0?ooo`00o`090?ooo`05003o003oool0oooo0?ooo`000?l03@3oool010000?l00?l00?ooo`3o0003
0?ooo`030?l0003oool00?l000h0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?l0003oool01`3oool00`3o0000oooo0000o`0D
0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`05
003o02<0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00000:0?ooo`800000103oool30000
00`0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0o`00
0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`0?0?ooo`060000o`3o0000oooo
003o003oool00?l01@3oool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0000o`070?ooo`030000o`3oool0oooo0080oooo00D0
0?l00?ooo`3oool0oooo0000o`0=0?ooo`050000o`3o0000oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0303oool00`000?l0oooo0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000000o`3oool07P3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003o
ool0oooo0100oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`000?l90?ooo`050000
o`3oool0oooo0?ooo`000?l0503oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo05P0
oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0
oooo00D0003o0?ooo`3oool0oooo003o00050?ooo`03003o003oool0oooo00P0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool0603oool00`000?l0oooo0?ooo`0H0?ooo`030000o`00o`00oooo00P0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00D00?l00?oo
o`3oool0oooo0000o`020?ooo`03003o003oool0003o00L0oooo00<00?l00?ooo`3oool02`3oool0
1@3o0000oooo0?l0003oool00?l000T0oooo00D00?l00?ooo`3oool0oooo0000o`0=0?ooo`040000
o`00o`00oooo0?l00080oooo00@0o`000?ooo`3oool00?l03P3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`070?oo
o`030?l0003oool0003o01<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00D0oooo1@00o`0N0?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo02h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?l000020?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`000?l03`3oool01P000?l0o`000?ooo`00o`00oooo
003o00@0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00X0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00<0oooo00@0
0?l00?ooo`3oool0003o3@3oool01@000?l0o`000?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool01P3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00<0003o0?ooo`3oool01P3oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`06
0?ooo`030?l000000?l0oooo01h0oooo00@0003o0?ooo`3oool00?l01@3oool00`00o`00oooo0?oo
o`0A0?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0003o2@3oool01@000?l0oooo
0?ooo`3oool0003o01@0oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`03
003o003oool0oooo0180oooo00@00?l00?ooo`3oool00?l0703oool00`000?l0oooo0?ooo`0G0?oo
o`030000o`00o`00oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?oo
o`030000o`3oool0oooo00P0oooo0P00o`040?ooo`050000o`3oool0oooo0?ooo`000?l0203oool0
0`00o`00oooo0?ooo`0;0?ooo`050?l0003oool0o`000?ooo`00o`002@3oool01@00o`00oooo0?oo
o`3oool0003o00d0oooo00@0003o003o003oool0o`000P3oool0103o0000oooo0?ooo`00o`0>0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3o0000oooo00L0oooo00<0o`000?ooo`000?l04`3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00X0oooo00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`0o0?ooo`80o`000P3oool00`00o`00oooo0?ooo`060?ooo`03
003o003oool0003o00l0oooo00H0003o0?l0003oool00?l00?ooo`00o`040?ooo`030?l0003oool0
003o00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`04003o003oool0
oooo0000o`d0oooo00D0003o0?l0003oool0oooo0?l000040?ooo`030000o`3oool0oooo00D0oooo
00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool00?l000@0oooo00<0003o0?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3o
ool07P3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool04@3oool00`00
o`00oooo0?ooo`030?ooo`04003o003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo06d0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0
1@00o`00oooo0?ooo`3oool00?l000`0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0?oo
o`0B0?ooo`04003o003oool0oooo003o01`0oooo00<0003o0?ooo`3oool05`3oool00`000?l00?l0
0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`03
003o003oool0oooo00/0oooo0P3o00020?ooo`03003o003oool0oooo00L0oooo00D00?l00?ooo`3o
ool0oooo0000o`0=0?ooo`040000o`00o`00oooo0?l00080oooo00@0o`000?ooo`3oool00?l03P3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0o`000?ooo`070?ooo`030?l0003oool0003o01<0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo01X0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`000?l03`3oool01P000?l0o`000?ooo`00o`00oooo003o00@0oooo
00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00@00?l00?ooo`3oool0003o3@3oool01@000?l0o`000?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`00o`00103oool0
0`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0000o`0N0?ooo`030000o`3oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o
000D0?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0003o203oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`00303oool01@3o0000oooo0?ooo`3oool0o`00
00X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o00070?ooo`03003o003oool0oooo
0180oooo00@00?l00?ooo`3oool00?l0703oool00`000?l0oooo0?ooo`0G0?ooo`030000o`00o`00
oooo00P0oooo00<00?l00000o`3oool00`3oool01@00o`00oooo0?ooo`3oool0003o00P0oooo00<0
0?l00?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<00?l00?ooo`3oool0
303oool0103o0000oooo0?ooo`00o`090?ooo`05003o003oool0oooo0?ooo`000?l03@3oool01000
0?l00?l00?ooo`3o00020?ooo`040?l0003oool0oooo003o00h0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?l0003oool01`3o
ool00`3o0000oooo0000o`0C0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0303o
ool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo03l0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`04003o003oool0
oooo0000o`l0oooo00@0003o0?l0003oool0oooo0P00o`040?ooo`030?l0003oool0003o00<0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo
00D0003o0?ooo`3oool0oooo0000o`050?ooo`04003o003oool0oooo0000o`d0oooo00D0003o0?l0
003oool0oooo0?l000040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo0P000?l40?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`00o`00103oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0
oooo00D0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00/0oooo00<0
o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`000?lM0?ooo`030000o`3oool0oooo0080oooo
00D00?l00?ooo`3oool0oooo003o000D0?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3o
ool0003o203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo003o00d0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool00?l0
1@3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool00?l001`0oooo00<0003o0?ooo`3oool0
5`3oool00`000?l00?l00?ooo`080?ooo`03003o00000?l0oooo00<0oooo00@00?l00?ooo`3oool0
003o2@3oool00`00o`00oooo0?ooo`060?ooo`050000o`3oool0oooo0000o`00o`001`3oool00`00
o`00oooo0?ooo`0<0?ooo`040?l0003oool0oooo003o00T0oooo00D00?l00?ooo`3oool0oooo0000
o`0=0?ooo`040000o`00o`00oooo0?l00080oooo00@0o`000?ooo`3oool00?l03`3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
o`000?ooo`060?ooo`040?l0003oool0oooo0000oa80oooo00<0003o0?ooo`3oool02`3oool01@00
0?l0oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=
0?ooo`800?l06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0o0?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`000?l?
0?ooo`040000o`3oool0o`000?ooo`800?l0103oool00`3o0000oooo0000o`030?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0003o00H0oooo00@00?l00?ooo`3oool0003o3@3oool01@000?l0o`000?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool20000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo003o00040?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool00`000?l0
oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool00`3o0000oooo0?ooo`050?oo
o`040?l0003oool0oooo0000oad0oooo00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3o
ool00?l001@0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0003o00P0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo06h0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`0=0?ooo`040?l0003oool0oooo0?l0
00`0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`050?ooo`03003o003oool0
oooo01@0oooo0P00o`0M0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`00o`00203oool0
0`00o`00003o0?ooo`030?ooo`04003o003oool0oooo0000o`P0oooo00<00?l00?ooo`3oool01`3o
ool01@000?l0oooo0?ooo`000?l00?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo
003o003oool0o`000080oooo00<0o`000?ooo`00o`00403oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`060?ooo`05
0?l0003oool0oooo0?ooo`000?l04@3oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo
0000o`/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0
oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0A03oool00`00
o`00oooo0?ooo`040?ooo`04003o003oool0oooo0000o`l0oooo00D0003o0?ooo`3o0000oooo003o
00050?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo0P000?l60?ooo`04003o003oool0oooo0000o`d0oooo
00D0003o0?l0003oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool00?l000D0oooo00D0003o0?ooo`3o
ool0oooo003o00070?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0003o2`3oool0
0`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0000oa`0oooo00<0003o0?ooo`3oool00`3o
ool01@00o`00oooo0?ooo`3oool00?l001@0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo
0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo06h0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o000>0?ooo`04
0?l0003oool0oooo0?l000`0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
0?l000@0oooo00<00?l00?ooo`3oool05@3oool00`00o`00oooo0?ooo`0K0?ooo`030000o`3oool0
oooo01L0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0000o`050?ooo`03003o003oool0
003o00P0oooo00<00?l00?ooo`3oool01`3oool01@000?l0oooo0000o`3oool00?l000H0oooo00<0
0?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool02P3oool01`000?l0oooo003o003oool0o`000?ooo`3o00000P3oool00`00o`00
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0503oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3o0000oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`0A0?oo
o`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`140?ooo`03003o003oool0oooo00@0oooo00D00?l00?oo
o`3oool0oooo0000o`0>0?ooo`050000o`3oool0o`000?ooo`00o`001@3oool00`3o0000oooo0000
o`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`000?l0303oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`00o`001@3oool01@000?l0oooo0?oo
o`3oool00?l000H0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`000?l;0?ooo`03
0?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o000E0?ooo`05003o003oool0
oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`1^0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo0P00
o`0>0?ooo`040?l0003oool0oooo0?l000`0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo01H0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0000o`050?ooo`03
003o00000?l0oooo00L0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0000o`020?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo0?ooo`00o`00oooo
0080o`000P3oool00`00o`00oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0503oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o0000oooo00H0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?oo
o`3oool0003o303oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<00?l0
0?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000480oooo00<00?l00?oo
o`3oool0103oool01@00o`00oooo0?ooo`3oool0003o00h0oooo00D0003o0?ooo`3o0000oooo003o
00050?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`000?l0303oool00`000?l0oooo0?l0
00020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool00?l000H0oooo00@0003o0?ooo`3oool00?l01P3oool00`000?l0oooo
0?ooo`0:0?ooo`80003o3@3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`X0
oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool00?l001H0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo06h0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`00o`00oooo0?ooo`0>0?ooo`80o`003@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00@00?l00?ooo`3oool00?l0=`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000o`3oool00?l000L0oooo00<00?l00?ooo`000?l01@3oool00`00o`00003o0?ooo`07
0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool00?l00?ooo`020?l00080oooo00<0
0?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01@0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0003o00`0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`D000006@3oool003`0oooo00<00000
0?ooo`3oool0A@3oool00`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`000?l03P3o
ool01@000?l0oooo0?l0003oool00?l000D0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0403oool2003o00030000
o`3oool0oooo00X0oooo00D0003o0?ooo`3o0000oooo0?l000050?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo003o00070?ooo`030000o`3oool00?l000H0
oooo00<0003o0?ooo`3oool02P3oool20000o`d0oooo00<0o`000?ooo`3oool0103oool0103o0000
oooo0?ooo`000?l90?ooo`80003o403oool00`000?l0oooo0?ooo`050?ooo`03003o003oool00?l0
01H0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo06l0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0>0?ooo`80o`003@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00@00?l00?ooo`3oool00?l0=`3oool00`000?l0oooo0?oo
o`0F0?ooo`030000o`3oool00?l000L0oooo00<00?l00?ooo`000?l01P3oool00`000?l0oooo0?oo
o`050?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`000?l00P3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`030?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool00?l00?ooo`020?l00080oooo
00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0003o00`0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo04D0oooo00<00?l00?ooo`3oool00`3oool01@00o`00oooo0?oo
o`3oool0003o00h0oooo00D0003o0?ooo`3o0000oooo003o00040?ooo`040?l0003oool0oooo0000
o`80oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
0100oooo0P00o`000`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080o`001@3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`00o`00203oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`000?l03`3oool0
0`000?l0oooo0?ooo`050?ooo`03003o003oool00?l001H0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0700oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo003o
000g0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0000
o`050?ooo`030000o`00o`00oooo00H0oooo00<00?l00?ooo`3oool02P3oool20000o`<0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo003o003oool0
0P3o00020?ooo`03003o003oool0oooo00h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0000o`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0:@3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`150?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0o`0000H0oooo00@0
o`000?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0403oool2003o00030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
003o00080?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`040?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`000?l03`3oool00`000?l0
oooo0?ooo`050?ooo`03003o003oool00?l001H0oooo00D00?l00?ooo`3oool0oooo003o00040?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0700oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0=0?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool2003o03P0oooo00<0003o0?ooo`3oool05P3oool0
0`000?l0oooo003o00070?ooo`03003o003oool0003o00D0oooo00<0003o003o003oool01@3oool0
0`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o
000D0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?oo
o`090?ooo`050000o`3oool0oooo003o003oool00P3o00000`3oool00?l00?ooo`0@0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0o`0000H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00d0oooo0P000?l=0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
:P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`150?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0o`0000H0oooo00@0o`000?ooo`3oool0oooo0P000?l;0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool04@3oool2003o00030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
003o00080?ooo`03003o00000?l0oooo00@0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`040?ooo`040?l0003oool0oooo0000o`P0oooo00@0003o0?ooo`3oool0003o3`3oool00`00
0?l0oooo0?ooo`050?ooo`03003o003oool00?l001H0oooo00@00?l00?ooo`3oool00?l01@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool0
1@000?l0oooo0?ooo`3oool0003o02L0oooo00@0003o0?ooo`3oool0003o1`3oool00`00o`00oooo
0?ooo`0f0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`00o`001P3oool01000o`00oooo
0?ooo`000?l50?ooo`030000o`3oool00?l000D0oooo00<00?l00?ooo`3oool02`3oool00`000?l0
oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`00503oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool01P000?l0oooo0?ooo`00o`00
oooo0?l00080oooo00<00?l00?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo01@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo04D0oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o00001P3oool0
103o0000oooo0?ooo`3oool20000o``0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0B0?ooo`03003o003oool0003o00/0oooo00<0003o0?ooo`3oool00P3o00050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo003o00080?ooo`03003o003o
ool0003o00<0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`040?ooo`040?l0003o
ool0oooo0000o`P0oooo00@0003o0?ooo`3oool0003o3P3oool00`000?l0oooo0?ooo`060?ooo`03
003o003oool00?l001L0oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`1`0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03@3oool01@000?l0oooo0?ooo`3oool0003o
02L0oooo00@0003o0?ooo`3oool0003o@@3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0
0?l000H0oooo00@00?l00?ooo`3oool0003o103oool010000?l0oooo0?ooo`00o`040?ooo`03003o
003oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`00o`0D0?ooo`03
003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`06
0000o`3oool0oooo003o003oool0o`000P3oool00`00o`00oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
o`0000D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo02X0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0A@3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?l000060?ooo`040?l0003oool0oooo0?ooo`80003o303oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`000?l02`3oool00`000?l0oooo0?ooo`02
0?l000D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0
oooo003o00L0oooo00@00?l00?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`050000o`3oool0oooo0?oo
o`000?l03@3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo01H0oooo00<00?l00?oo
o`00o`001@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool03P3oool00`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool03@3oool01@000?l0oooo0?ooo`3oool0003o02L0oooo00@0003o0?ooo`3oool0003o@@3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool00?l000H0oooo00@00?l00?ooo`3oool0003o
103oool010000?l0oooo0?ooo`00o`040?ooo`03003o003oool0oooo0180oooo00@00?l00?ooo`3o
ool00?l05@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0003o0?oo
o`3oool02@3oool01P000?l0oooo0?ooo`00o`00oooo0?l00080oooo00<00?l00?ooo`3oool0403o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`160?ooo`05003o003oool0
oooo0?ooo`00o`001@3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000H0oooo
00@0o`000?ooo`3oool0oooo0P000?l<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04P3oool00`00o`00oooo0000o`0;0?ooo`030000o`3oool0oooo0080o`001P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool00?l01`3oool01000
o`00oooo0?ooo`000?l20?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo003o
00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo0740oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`0=0?ooo`040000o`3oool0oooo0000obP0oooo00@0003o0?ooo`3oool0003o@@3oool00`000?l0
oooo0?ooo`0E0?ooo`040000o`3oool0oooo003o00D0oooo00@00?l00?ooo`3oool0003o103oool0
10000?l0oooo0?ooo`00o`030?ooo`03003o003oool0oooo01<0oooo00@00?l00?ooo`3oool00?l0
5@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
2@3oool01P000?l0oooo0?ooo`00o`00oooo0?l00080oooo00<00?l00?ooo`3oool0403oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?l000050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool20000
ob00oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo04H0oooo00D00?l00?ooo`3oool0oooo003o00050?oo
o`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`3o
ool20000o``0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool00P3o00060?ooo`050000o`3oool0oooo0?ooo`000?l0
2@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
0P3oool0103o0000oooo0?ooo`00o`070?ooo`04003o003oool0oooo0?ooo`80003o7`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`00
o`00oooo0?ooo`0F0?ooo`03003o003oool00?l000D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0L@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00@0003o0?ooo`3oool0003o:03oool0
10000?l0oooo0?ooo`000?m10?ooo`030000o`3oool0oooo01D0oooo00@0003o0?ooo`3oool00?l0
1@3oool01000o`00oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0080oooo00@00?l00?ooo`3o
ool00?l05P3oool00`00o`00oooo003o000E0?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool0103oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo003o00@0oooo00<00?l0
0?ooo`3oool0403oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01D0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool00P3oool20000ob<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Z
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04H0oooo00D00?l00?oo
o`3oool0oooo003o00050?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`001P3o
ool0103o0000oooo0?ooo`3oool20000o``0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0E0?ooo`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0o`001`3oool01@000?l0
oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`02
0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0240oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`1a
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03P3oool010000?l0oooo0?ooo`00
0?lY0?ooo`030000o`3oool0003o0440oooo00<0003o0?ooo`3oool0503oool01@000?l0oooo0?oo
o`3oool00?l000D0oooo00@00?l00?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool00?l001L0oooo0P00o`0F0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0103oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo003o00@0oooo00<00?l00?oo
o`3oool0403oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01D0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool00P000?lU0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool5000004@0oooo00D00?l00?ooo`3oool0oooo003o00050?oo
o`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0E
0?ooo`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0o`001`3oool01@000?l0oooo0?oo
o`3oool0003o00X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0280
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0240
oooo0P00o`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo0740oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0003o02T0oooo00<0003o0?ooo`000?l0@@3oool00`000?l0
oooo0?ooo`0D0?ooo`050000o`3oool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool0
003o00<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o000G0?ooo`800?l05P3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool02@3oool0
10000?l0oooo0?ooo`00o`030?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o00001@3o
ool00`3o0000oooo0?ooo`0:0?ooo`80003o9`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo02L0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`160?ooo`04003o003oool0
oooo003o00H0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo01D0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`3o00070?ooo`05
0000o`3oool0oooo0?ooo`000?l02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0180oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`03003o003oool0oooo00D0oooo00<00?l0
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool08P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0780oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0003o02T0oooo00<0003o
0?ooo`000?l0@@3oool00`000?l0oooo0?ooo`0D0?ooo`050000o`3oool0oooo0?ooo`00o`00103o
ool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0003o00H0oooo00<00?l00?ooo`3oool05`3o
ool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103o
ool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`00o`000P3oool00`00o`00oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0AP3oool01000o`00oooo0?ooo`00o`060?ooo`030000o`3oool0oooo00X0oooo
00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00T0
oooo00@0003o0?ooo`3oool0o`001`3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo0?ooo`3o00000P3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0280oooo00<00?l00?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`1c0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0403o
ool00`000?l0oooo0000o`0Y0?ooo`030000o`3oool0003o0480oooo00<0003o0?ooo`3oool04`3o
ool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0000o`060?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo
0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000050?ooo`03
0?l0003oool0oooo03<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0[0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`00o`00
1P3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3o
ool02@3oool010000?l0oooo0?ooo`3o00070?ooo`040000o`3oool0oooo0000o``0oooo00D0003o
0?ooo`3oool0oooo0000o`0E0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo02<0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`1c0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo
0000o`0Y0?ooo`030000o`3oool0003o0480oooo00<0003o0?ooo`3oool04`3oool01@000?l0oooo
0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0000o`0g0?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`05
0000o`3oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0o`00
00@0oooo00<0o`000?ooo`3oool0=03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
02/0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0A`3oool00`00o`00
oooo003o00060?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0003o303oool0
1@000?l0oooo0?ooo`3oool0003o01D0oooo00@0o`000?ooo`3oool0o`000`3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo0280oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0L`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`000?l0:@3oool20000od<0oooo
00<0003o0?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3o
ool00P3oool20000ocT0oooo00D00?l00?ooo`3oool0oooo003o00070?ooo`030000o`3oool0oooo
00T0oooo00D0003o0?ooo`3oool0oooo003o00020?ooo`03003o003oool0oooo0180oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3o0000103oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`170?oo
o`03003o003oool00?l000L0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`3o0005
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`00
0?l<0?ooo`050000o`3oool0oooo0?ooo`000?l05@3oool0103o0000oooo0?ooo`3o00030?ooo`03
003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0903oool01@3o0000oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1c0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool04@3oool20000ob/0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0C
0?ooo`050000o`3oool0oooo0?ooo`00o`00103oool00`00o`00oooo0?ooo`020?ooo`80003o>@3o
ool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo
0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000040?ooo`03
0?l0003oool0oooo03@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0[0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`00o`00
1`3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0000o``0oooo00D0003o0?oo
o`3oool0oooo0000o`0E0?ooo`040?l0003oool0oooo0?l000<0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0T0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0003o00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0[0?ooo`05
0000o`3oool0oooo0?ooo`000?l02P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
07<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo
02T0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0C0?ooo`050000o`3oool0oooo
0?ooo`00o`000`3oool00`00o`00oooo0?ooo`030?ooo`80003o>@3oool01@00o`00oooo0?ooo`3o
ool00?l000P0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool00?l00080oooo
00<00?l00?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01H0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo03@0oooo
00D0003o0?ooo`3oool0oooo0000o`0^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo04L0oooo00<00?l00?ooo`00o`001`3oool00`000?l0oooo0?ooo`090?ooo`040000
o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`04
0000o`3oool0oooo0000o``0oooo00@0003o0?ooo`3oool0003o5P3oool0103o0000oooo0?ooo`3o
00040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0903oool0103o0000oooo0?oo
o`3o00050?ooo`050000o`3oool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo02`0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0180oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo
01<0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`050?ooo`030000o`3oool0
oooo03P0oooo00D00?l00?ooo`3oool0oooo003o00080?ooo`030000o`3oool0oooo00P0oooo00L0
003o0?ooo`3oool0oooo003o003oool00?l001D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0F0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o0000103oool00`3o0000
oooo0?ooo`0d0?ooo`050000o`3oool0oooo0?ooo`000?l0;P3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`170?ooo`800?l0203oool00`000?l0oooo0?ooo`090?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00@0003o0?ooo`3oool0003o3@3oool00`000?l0oooo0000o`0F0?ooo`040?l0003oool0
oooo0?l000@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0T0?ooo`040?l0003o
ool0oooo0?l000D0oooo00@0003o0?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo02`0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
01<0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo
0180oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`050?ooo`030000o`3oool0
oooo03P0oooo00D00?l00?ooo`3oool0oooo003o00080?ooo`030000o`3oool0oooo00P0oooo00L0
003o0?ooo`3oool0oooo003o003oool00?l001H0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o0000103oool00`3o0000oooo0?ooo`0e0?oo
o`040000o`3oool0oooo0000obh0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0B03oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0000o`0>0?ooo`030000o`3oool0003o01H0oooo00@0o`000?ooo`3oool0o`00103o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo02@0oooo00@0o`000?ooo`3oool0o`00
1@3oool010000?l0oooo0?ooo`000?l;0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0;03oool010000?l0oooo0?ooo`000?l;0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool0M03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080oooo00@00?l00?oo
o`3oool00?l0@03oool01@00o`00oooo0?ooo`3oool00?l000P0oooo00<0003o0?ooo`3oool0203o
ool01`000?l0oooo0?ooo`3oool00?l00?ooo`00o`005P3oool01@000?l0oooo0?ooo`3oool0003o
01P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo
03D0oooo00@0003o0?ooo`3oool0003o;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`180?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`80003o3P3oool00`000?l0oooo0000o`0F0?ooo`040?l0003oool0oooo0?l000@0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0T0?ooo`040?l0003oool0oooo0?l000H0oooo
00<0003o0?ooo`000?l02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02`0oooo
00@0003o0?ooo`3oool0003o303oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo07D0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`240?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`100?ooo`05003o003oool0oooo
0?ooo`00o`00203oool00`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`00o`00oooo
003o000F0?ooo`050000o`3oool0oooo0?ooo`000?l06@3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0=@3oool010000?l0oooo0?ooo`000?l^0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`D00000AP3oool00`00o`00oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool20000o`h0oooo00<0003o0?ooo`000?l05P3oool0103o
0000oooo0?ooo`3o00040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0903oool0
103o0000oooo0?ooo`3o00060?ooo`80003o303oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo02`0oooo00@0003o0?ooo`3oool0003o303oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo07D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`240?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`100?ooo`04
003o003oool0oooo003o00T0oooo00<0003o0?ooo`3oool0203oool01`000?l0oooo0?ooo`3oool0
0?l00?ooo`00o`005P3oool01@000?l0oooo0?ooo`3oool0003o01T0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo03D0oooo00@0003o0?ooo`3oool0
003o:P3oool5000001T0oooo000l0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0
2@3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`80003o3`3oool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l0
00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0U0?ooo`030?l0003oool0o`00
00H0oooo0P000?l=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0;@3oool01000
0?l0oooo0?ooo`000?l<0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0MP3oool0
1@000?l0oooo0?ooo`3oool0003o08L0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`020?ooo`03003o003oool00?l00480oooo00<00?l00?ooo`00o`002@3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0080oooo0P00o`0F0?ooo`050000o`3oool0oooo0?ooo`000?l0
6@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0
=P3oool010000?l0oooo0?ooo`000?l^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01L0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`80003o3`3oool00`000?l0
oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l000@0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0U0?ooo`030?l0003oool0o`0000H0oooo0P000?l=0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0;@3oool010000?l0oooo0?ooo`000?l<0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool0MP3oool01@000?l0oooo0?ooo`3oool0003o08L0oooo00<0
003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool00?l00480oooo00<0
0?l00?ooo`00o`002@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo0P00
o`0F0?ooo`040000o`3oool0oooo0000oaX0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?l000030?ooo`030?l0003oool0oooo03H0oooo00<0003o0?ooo`000?l0;`3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo00T0oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo01<0oooo00@0003o0?ooo`3oool0
003o6P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0o`0000@0oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`0U0?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02d0oooo00@0003o0?ooo`3o
ool0003o303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo07H0oooo00D0003o0?oo
o`3oool0oooo0000o`280?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool00P3oool0
0`00o`00oooo003o00120?ooo`03003o003oool00?l000T0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo01D0oooo00@0003o0?ooo`3oool0003o6P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0=P3o
ool00`000?l0oooo0000o`0_0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo0540oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
o`000?ooo`3oool04`3oool010000?l0oooo0?ooo`000?lJ0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0o`0000@0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0U0?ooo`030?l0003oool0o`0000H0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02d0oooo
00<0003o0?ooo`000?l03@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo07L0oooo
00@0003o0?ooo`3oool0003oR@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080
oooo00<00?l00?ooo`00o`00@P3oool00`00o`00oooo003o00090?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0E0?ooo`040000o`3oool0oooo0000
oaX0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo
03H0oooo00<0003o0?ooo`000?l0;`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`1B0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`030?l0003oool0oooo01<0oooo00@0003o0?ooo`3oool0003o6P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?l00004
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool09@3oool00`3o0000oooo0?l0000F
0?ooo`050000o`3oool0oooo0?ooo`000?l0<03oool00`000?l0oooo0000o`0=0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0M`3oool010000?l0oooo0?ooo`000?n90?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo003o00120?ooo`03003o
003oool00?l000T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`03003o
003oool0oooo01H0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0=P3oool00`000?l0oooo0000o`0_0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0203o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool04`3oool010000?l0oooo
0?ooo`000?lJ0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000
oooo0?l000040?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool09P3oool00`3o0000
oooo0?l0000F0?ooo`050000o`3oool0oooo0?ooo`000?l0<03oool00`000?l0oooo0000o`0=0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0N03oool010000?l0oooo0?ooo`000?n9
0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool2003o0480oooo00<00?l0
0?ooo`00o`002@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<00?l0
0?ooo`3oool05P3oool00`000?l0oooo0000o`0J0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0003o02l0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`080?oo
o`050000o`3oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`0D0?ooo`040000o`3oool0
oooo0000oaX0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003o
ool0o`0000@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0V0?ooo`80o`005`3o
ool01@000?l0oooo0?ooo`3oool0003o0340oooo0P000?l>0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool0N03oool00`000?l0oooo0000o`2:0?ooo`030000o`3oool0oooo0140oooo
00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`110?ooo`03003o003oool00?l000T0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0003o01X0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo03L0oooo
0P000?l_0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0
003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool0
503oool010000?l0oooo0?ooo`000?lJ0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0<`3oool00`3o0000oooo0?l000050?ooo`05003o003oool0oooo0?ooo`00o`00:03oool20?l0
01L0oooo00D0003o0?ooo`3oool0oooo0000o`0a0?ooo`80003o3P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo07X0oooo0P000?n:0?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`110?ooo`800?l02P3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0003o0?oo
o`3oool0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0000o`0K0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<`3oool0
0`3o0000oooo0?l000050?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool00`3o0000oooo0?oo
o`0F0?ooo`030000o`3oool0003o0380oooo0P000?l>0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0N`3oool20000oh/0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`040?ooo`03003o003oool0oooo0480oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0?oo
o`080?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool0>03oool00`000?l0oooo
0?ooo`0^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0
003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool0
503oool00`000?l0oooo0000o`0K0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
<`3oool00`3o0000oooo0?l000050?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool00`3o0000
oooo0?ooo`0F0?ooo`030000o`3oool0003o0380oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo07/0oooo0P000?n;0?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`120?ooo`03003o003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0003o01X0
oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo
03P0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000500
oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0000o`0K0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?oo
o`3oool0<`3oool00`3o0000oooo0?l000050?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0003o0380oooo00<0003o0?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo07`0oooo00<0003o0?ooo`3oool0RP3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo04T0oooo00<00?l00?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01`0oooo0P000?lK0?ooo`030000o`3oool0
oooo00P0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3o
ool0oooo02X0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0
oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo01D0oooo0P00
0?lK0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?l0
00050?ooo`05003o003oool0oooo0?ooo`00o`00:@3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0003o0380oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo07`0oooo00<0003o0?ooo`3oool0RP3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo04T0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo01d0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`080?ooo`040000
o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool0J@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0
oooo0?l000020?ooo`030?l0003oool0oooo01D0oooo0P000?lK0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?l000050?ooo`05003o003oool0oooo0?oo
o`00o`00@`3oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo00d0oooo00D0003o0?oo
o`3oool0oooo0000o`3o0?ooo`d0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`1E
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0I
0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?oo
o`1Y0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0003o
0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0=03o
ool20?l000H0oooo00D00?l00?ooo`3oool0oooo003o00130?ooo`030000o`3oool0oooo0440oooo
00@0003o0?ooo`3oool0003oo`3oool?0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool0E@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0001[
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0003o0?oo
o`3oool0203oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000603oool00`000?l0oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0=03oool20?l000H0oooo00D0
0?l00?ooo`3oool0oooo003o00130?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`000?l0
o`3oool?0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo
0?ooo`080?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0001[0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0203oool01`000?l0
oooo0?ooo`3oool0o`000?ooo`3o0000603oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool0=03oool20?l000H0oooo00D00?l00?ooo`3oool0oooo003o
00280?ooo`80003oo`3oool@0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0E@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0203o
ool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000J`3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo00P0oooo00L0003o0?ooo`3oool0
oooo0?l0003oool0o`0003D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0e0?oo
o`030?l0003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo003o00280?ooo`80003oo`3oool@
0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0203oool01`000?l0oooo0?ooo`3o
ool0o`000?ooo`3o0000J`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`1B0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool20?l003H0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo00@0oooo00@0
0?l00?ooo`3oool00?l0R@3oool00`000?l0oooo0?ooo`3o0?ooo`l0oooo00<0003o0?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`1E0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
>@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?ooo`80o`00K03oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool00`3oool20?l003H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`00o`00o`3ooonL0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3oool20?l006`0
oooo00<000000?ooo`3oool05`3oool00240oooo0P0000040?ooo`8000001@3oool3000000/0oooo
00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo
0P3o000f0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo
0?ooo`050?ooo`03003o003oool00?l00?l0ooooW03oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo05D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0i0?ooo`030000
o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo0P3o001/0?ooo`030000003oool0oooo01L0
oooo000P0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1C0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool20?l003H0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo00D0
oooo00<00?l00?ooo`00o`00o`3ooonL0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool0E@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3o
ool0203oool010000?l0oooo0?ooo`3oool20?l006`0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool00000203oool5000000/0oooo1`00001?0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00`3oool20?l003H0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`00o`00o`3ooonL0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3oool2
0?l006H0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000`0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo0P3o000f0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0=@3o
ool00`3o0000oooo0?ooo`050?ooo`03003o003oool00?l00?l0ooooW03oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0i0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo0P3o001/0?ooo`030000
003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
=@3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool00?l00?l0ooooW@3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0i0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo0P3o001/0?ooo`03
0000003oool0oooo01L0oooo000Q0?ooo`8000002`3oool2000000`0oooo00<000000?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
=@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03d0oooo00<00?l00?ooo`00o`00
o`3ooonM0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo
0?ooo`3oool20?l006`0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
=@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03d0oooo00<00?l00?ooo`00o`00
o`3ooonM0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0o`0006d0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
=@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03d0oooo00<00?l00?ooo`00o`00
o`3ooonM0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0o`0006d0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
=@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03d0oooo00<00?l00?ooo`00o`00
o`3ooonM0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0o`0006d0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0m0?ooo`03003o003oool00?l00?l0ooooWP3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l0001]0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
?@3oool2003o0?l0ooooW`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo05L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo
00D0003o0?ooo`3oool0oooo0?l0001]0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo05<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0k0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0?P3oool00`00o`00oooo0?ooo`3o0?oooid0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo06l0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0n0?ooo`03003o003oool0oooo0?l0ooooW@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5
00000580oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0?P3oool00`00o`00oooo0?ooo`3o0?oooid0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo06/0oooo1@00000I
0?ooo`00?03oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03h0oooo00<00?l00?oo
o`3oool0o`3ooonN0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0E`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05@0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0?P3oool00`00o`00oooo0?ooo`3o0?oooih0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo06l0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0n0?ooo`03003o
003oool0oooo0?l0ooooWP3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo05L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0?l0oooog`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0?l0oooog`3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0?l0ooooh03oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0?l0
ooooh03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1D0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0?l0ooooh03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0?l0ooooh03oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo05L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0?l0ooooh03oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo05P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool500000580oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0k0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0o`3ooooQ0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
03/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1[0?ooo`D000006@3oool003`0
oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03/0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`3o0?ooon40oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo06l0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`3o0?ooon40oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo06l0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`3o0?ooon80oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo06l0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`3o0?ooon80oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1H
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0E@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`3o0?ooon<0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`3o0?ooonD0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0>`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo03d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`3o0?ooonD0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0700oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`3o0?ooonH0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0700oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`3o0?ooonH0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1I
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool05`3oool003`0oooo1@00001C0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0?l0ooooi`3oool01@000?l0oooo0?ooo`3oool0003o05/0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0K03oool5000001T0oooo000l0?ooo`030000003oool0oooo05D0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0o`3ooooX0?ooo`040000o`3oool0oooo0000oe/0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0L03oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0?l0ooooj03oool010000?l0oooo0?ooo`000?mK0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0700oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`3o0?oo
onT0oooo00<0003o0?ooo`000?l0F`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
03d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0m0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0o`3ooooZ0?ooo`80
003oF`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo05D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0m0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0o`3ooooZ0?ooo`80003oG03oool01@000?l0oooo
0?ooo`3oool0003o03l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1`0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
o`3oooo[0?ooo`030000o`3oool0oooo05X0oooo00D0003o0?ooo`3oool0oooo0000o`0o0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0L03oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`1F0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
?@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0?l0ooooo`3ooom90?ooo`050000
o`3oool0oooo0?ooo`000?l0?`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0700
oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0o0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool07@3oool01@000?l0oooo
0?ooo`3oool0003o03l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0o0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
?@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
7@3oool01@000?l0oooo0?ooo`3oool0003o03l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0o0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo
00D000000?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool07@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0503oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool500000180oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`000000
oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0L0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo01d0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`H000006@3oool0
03`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo
02T0oooo00D000000?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo01`0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool07@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0503o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`00?03ooomI000000030000o`00000000000080000000<0003o
000000000000?@0000000`000?l0000000000005000000030000o`00000000000?l00000o`000019
000000050000o`0000000000000000000?l0?`0000000`000?l0000000000005000000030000o`00
00000000074000006@3oool00001\
\>"],
  ImageRangeCache->{{{26.375, 849.063}, {253.313, 48.4375}} -> {-13.4117, \
0.261472, 0.114894, 0.000923454}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mazurka in F minor, Op. 7, No. 3 performed by Rosen 1989", "Subsection"],

Cell[CellGroupData[{

Cell["Manually Corrected Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions4];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.117367 0.693539 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02134 -18 -4.5 ]
[-0.0125 .02134 0 4.5 ]
[-0.0125 .05602 -24 -4.5 ]
[-0.0125 .05602 0 4.5 ]
[-0.0125 .09069 -18 -4.5 ]
[-0.0125 .09069 0 4.5 ]
[-0.0125 .12537 -24 -4.5 ]
[-0.0125 .12537 0 4.5 ]
[-0.0125 .16005 -18 -4.5 ]
[-0.0125 .16005 0 4.5 ]
[-0.0125 .19473 -24 -4.5 ]
[-0.0125 .19473 0 4.5 ]
[-0.0125 .2294 -18 -4.5 ]
[-0.0125 .2294 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02134 m
.00625 .02134 L
s
[(0.2)] -0.0125 .02134 1 0 Mshowa
0 .05602 m
.00625 .05602 L
s
[(0.25)] -0.0125 .05602 1 0 Mshowa
0 .09069 m
.00625 .09069 L
s
[(0.3)] -0.0125 .09069 1 0 Mshowa
0 .12537 m
.00625 .12537 L
s
[(0.35)] -0.0125 .12537 1 0 Mshowa
0 .16005 m
.00625 .16005 L
s
[(0.4)] -0.0125 .16005 1 0 Mshowa
0 .19473 m
.00625 .19473 L
s
[(0.45)] -0.0125 .19473 1 0 Mshowa
0 .2294 m
.00625 .2294 L
s
[(0.5)] -0.0125 .2294 1 0 Mshowa
.125 Mabswid
0 .02828 m
.00375 .02828 L
s
0 .03521 m
.00375 .03521 L
s
0 .04215 m
.00375 .04215 L
s
0 .04908 m
.00375 .04908 L
s
0 .06295 m
.00375 .06295 L
s
0 .06989 m
.00375 .06989 L
s
0 .07682 m
.00375 .07682 L
s
0 .08376 m
.00375 .08376 L
s
0 .09763 m
.00375 .09763 L
s
0 .10457 m
.00375 .10457 L
s
0 .1115 m
.00375 .1115 L
s
0 .11844 m
.00375 .11844 L
s
0 .13231 m
.00375 .13231 L
s
0 .13924 m
.00375 .13924 L
s
0 .14618 m
.00375 .14618 L
s
0 .15311 m
.00375 .15311 L
s
0 .16698 m
.00375 .16698 L
s
0 .17392 m
.00375 .17392 L
s
0 .18085 m
.00375 .18085 L
s
0 .18779 m
.00375 .18779 L
s
0 .20166 m
.00375 .20166 L
s
0 .2086 m
.00375 .2086 L
s
0 .21553 m
.00375 .21553 L
s
0 .22247 m
.00375 .22247 L
s
0 .01441 m
.00375 .01441 L
s
0 .00747 m
.00375 .00747 L
s
0 .00053 m
.00375 .00053 L
s
0 .23634 m
.00375 .23634 L
s
0 .24327 m
.00375 .24327 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .02134 m
1 .02134 L
s
.99375 .05602 m
1 .05602 L
s
.99375 .09069 m
1 .09069 L
s
.99375 .12537 m
1 .12537 L
s
.99375 .16005 m
1 .16005 L
s
.99375 .19473 m
1 .19473 L
s
.99375 .2294 m
1 .2294 L
s
.125 Mabswid
.99625 .02828 m
1 .02828 L
s
.99625 .03521 m
1 .03521 L
s
.99625 .04215 m
1 .04215 L
s
.99625 .04908 m
1 .04908 L
s
.99625 .06295 m
1 .06295 L
s
.99625 .06989 m
1 .06989 L
s
.99625 .07682 m
1 .07682 L
s
.99625 .08376 m
1 .08376 L
s
.99625 .09763 m
1 .09763 L
s
.99625 .10457 m
1 .10457 L
s
.99625 .1115 m
1 .1115 L
s
.99625 .11844 m
1 .11844 L
s
.99625 .13231 m
1 .13231 L
s
.99625 .13924 m
1 .13924 L
s
.99625 .14618 m
1 .14618 L
s
.99625 .15311 m
1 .15311 L
s
.99625 .16698 m
1 .16698 L
s
.99625 .17392 m
1 .17392 L
s
.99625 .18085 m
1 .18085 L
s
.99625 .18779 m
1 .18779 L
s
.99625 .20166 m
1 .20166 L
s
.99625 .2086 m
1 .2086 L
s
.99625 .21553 m
1 .21553 L
s
.99625 .22247 m
1 .22247 L
s
.99625 .01441 m
1 .01441 L
s
.99625 .00747 m
1 .00747 L
s
.99625 .00053 m
1 .00053 L
s
.99625 .23634 m
1 .23634 L
s
.99625 .24327 m
1 .24327 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .12234 m
.0423 .15708 L
.05155 .10224 L
.0608 .11816 L
.07004 .08939 L
.07929 .1235 L
.08853 .04565 L
.09778 .05642 L
.10703 .2182 L
.11627 .05174 L
.12552 .10159 L
.13477 .0492 L
.14401 .17532 L
.15326 .07503 L
.16251 .15504 L
.17175 .07874 L
.181 .0992 L
.19025 .03741 L
.19949 .07734 L
.20874 .0199 L
.21798 .1447 L
.22723 .02243 L
.23648 .15971 L
.24572 .10184 L
.25497 .10017 L
.26422 .09009 L
.27346 .09043 L
.28271 .12614 L
.29196 .20548 L
.3012 .08783 L
.31045 .13739 L
.31969 .03869 L
.32894 .12441 L
.33819 .09489 L
.34743 .11207 L
.35668 .12309 L
.36593 .13651 L
.37517 .05076 L
.38442 .1923 L
.39367 .07753 L
.40291 .14671 L
.41216 .15451 L
.42141 .13113 L
.43065 .12295 L
.4399 .11576 L
.44914 .08976 L
.45839 .10931 L
.46764 .15011 L
.47688 .12187 L
.48613 .11975 L
Mistroke
.49538 .10687 L
.50462 .10822 L
.51387 .12113 L
.52312 .1829 L
.53236 .10188 L
.54161 .09159 L
.55086 .1654 L
.5601 .09582 L
.56935 .09617 L
.57859 .09294 L
.58784 .1807 L
.59709 .10616 L
.60633 .07401 L
.61558 .08506 L
.62483 .19234 L
.63407 .08795 L
.64332 .07591 L
.65257 .08838 L
.66181 .19394 L
.67106 .07887 L
.68031 .08338 L
.68955 .04759 L
.6988 .11303 L
.70804 .14113 L
.71729 .14236 L
.72654 .07752 L
.73578 .14291 L
.74503 .0869 L
.75428 .09796 L
.76352 .11483 L
.77277 .13783 L
.78202 .13913 L
.79126 .07827 L
.80051 .05287 L
.80975 .22179 L
.819 .04407 L
.82825 .13494 L
.83749 .03033 L
.84674 .19504 L
.85599 .03876 L
.86523 .17122 L
.87448 .07354 L
.88373 .18994 L
.89297 .02414 L
.90222 .13765 L
.91147 .02749 L
.92071 .13922 L
.92996 .00595 L
.9392 .07189 L
.94845 .02495 L
Mistroke
.9577 .08334 L
.96694 .01408 L
.97619 .04801 L
Mfstroke
0 1 0 r
.03306 .08838 m
.0423 .10039 L
.05155 .11736 L
.0608 .12781 L
.07004 .11665 L
.07929 .06225 L
.08853 .13812 L
.09778 .109 L
.10703 .07927 L
.11627 .15004 L
.12552 .13996 L
.13477 .12804 L
.14401 .07988 L
.15326 .13122 L
.16251 .0902 L
.17175 .05344 L
.181 .12178 L
.19025 .20906 L
.19949 .21086 L
.20874 .1999 L
.21798 .12759 L
.22723 .16344 L
.23648 .08215 L
.24572 .14002 L
.25497 .17017 L
.26422 .11829 L
.27346 .17778 L
.28271 .03737 L
.29196 .07851 L
.3012 .12601 L
.31045 .1264 L
.31969 .136 L
.32894 .1606 L
.33819 .09218 L
.34743 .15901 L
.35668 .09597 L
.36593 .14169 L
.37517 .18947 L
.38442 .08031 L
.39367 .07459 L
.40291 .10488 L
.41216 .09724 L
.42141 .1199 L
.43065 .10563 L
.4399 .11503 L
.44914 .11595 L
.45839 .12835 L
.46764 .11423 L
.47688 .11207 L
.48613 .12712 L
Mistroke
.49538 .14089 L
.50462 .12939 L
.51387 .12405 L
.52312 .10207 L
.53236 .12942 L
.54161 .1527 L
.55086 .14135 L
.5601 .19558 L
.56935 .07993 L
.57859 .13229 L
.58784 .09262 L
.59709 .12844 L
.60633 .09637 L
.61558 .11006 L
.62483 .08432 L
.63407 .15456 L
.64332 .09985 L
.65257 .14061 L
.66181 .07808 L
.67106 .14663 L
.68031 .09583 L
.68955 .15086 L
.6988 .1074 L
.70804 .08446 L
.71729 .09154 L
.72654 .07931 L
.73578 .12264 L
.74503 .14429 L
.75428 .12037 L
.76352 .13062 L
.77277 .11402 L
.78202 .0688 L
.79126 .10074 L
.80051 .10816 L
.80975 .05384 L
.819 .14287 L
.82825 .10725 L
.83749 .16875 L
.84674 .09576 L
.85599 .13459 L
.86523 .08776 L
.87448 .02385 L
.88373 .09015 L
.89297 .11165 L
.90222 .14818 L
.91147 .17728 L
.92071 .10885 L
.92996 .18303 L
.9392 .10771 L
.94845 .15742 L
Mistroke
.9577 .12863 L
.96694 .10876 L
.97619 .1016 L
Mfstroke
0 0 1 r
.03306 .13071 m
.0423 .08397 L
.05155 .12184 L
.0608 .09546 L
.07004 .1354 L
.07929 .15569 L
.08853 .15767 L
.09778 .17602 L
.10703 .04397 L
.11627 .13966 L
.12552 .09989 L
.13477 .1642 L
.14401 .08624 L
.15326 .13519 L
.16251 .0962 L
.17175 .20926 L
.181 .12046 L
.19025 .09496 L
.19949 .05324 L
.20874 .12164 L
.21798 .06915 L
.22723 .15557 L
.23648 .09957 L
.24572 .09958 L
.25497 .07109 L
.26422 .13306 L
.27346 .07322 L
.28271 .17793 L
.29196 .05745 L
.3012 .1276 L
.31045 .07765 L
.31969 .16675 L
.32894 .05643 L
.33819 .15437 L
.34743 .07036 L
.35668 .12238 L
.36593 .06323 L
.37517 .1012 L
.38442 .06884 L
.39367 .18932 L
.40291 .08985 L
.41216 .08969 L
.42141 .09041 L
.43065 .11285 L
.4399 .11065 L
.44914 .13573 L
.45839 .10378 L
.46764 .0771 L
.47688 .10749 L
.48613 .09456 L
Mistroke
.49538 .09368 L
.50462 .10384 L
.51387 .09625 L
.52312 .05647 L
.53236 .11014 L
.54161 .09715 L
.55086 .03469 L
.5601 .05004 L
.56935 .16534 L
.57859 .11621 L
.58784 .06812 L
.59709 .10683 L
.60633 .17106 L
.61558 .14633 L
.62483 .06478 L
.63407 .09893 L
.64332 .16567 L
.65257 .11245 L
.66181 .06942 L
.67106 .11594 L
.68031 .16223 L
.68955 .14298 L
.6988 .12101 L
.70804 .11585 L
.71729 .10754 L
.72654 .18461 L
.73578 .07589 L
.74503 .11025 L
.75428 .1231 L
.76352 .09599 L
.77277 .0896 L
.78202 .13351 L
.79126 .16243 L
.80051 .18041 L
.80975 .0658 L
.819 .1545 L
.82825 .09925 L
.83749 .14235 L
.84674 .05064 L
.85599 .16809 L
.86523 .08247 L
.87448 .24405 L
.88373 .06134 L
.89297 .20565 L
.90222 .0556 L
.91147 .13667 L
.92071 .09336 L
.92996 .15246 L
.9392 .16184 L
.94845 .15906 L
Mistroke
.9577 .12946 L
.96694 .2186 L
.97619 .19183 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00DP3oool200000:P0oooo100000030?ooo`800000Y`3oool30000
0080oooo0P00002V0?ooo`<00000103oool200000:H0oooo0P0000040?ooo`800000XP3oool50000
0080oooo0P0000040?ooo`800000A03oool00540oooo00@000000?ooo`3oool00000Y`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000Y03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
@@3oool00540oooo00@000000?ooo`3oool00000Z03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:@0oooo1@0000001@3oool000000?ooo`3oool000000:D0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3oool010000000oooo0?ooo`00002Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool3000000<0oooo00@000000?ooo`3o
ool00000Y@3oool2000000<0oooo00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3o
ool010000000oooo0?ooo`00002W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000:H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00DP3oool200000:T0oooo0P0000040?oo
o`800000Y`3oool2000000<0oooo0P00002W0?ooo`<000000`3oool200000:H0oooo0P0000040?oo
o`800000X`3oool2000000@0oooo0P0000040?ooo`800000A03oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03`0ooooo`00003o00000?l00000/`00000I0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:`0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo09X0oooo00<0o`000?ooo`3oool03P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000o`3ooooo0?ooool0oooo
J`3oool00`3o0000oooo0?ooo`0k0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0ooooK@3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooofd0oooo00<0o`000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom]0?oo
o`80o`00@03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3ooom]0?ooo`80o`00@03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooom]0?ooo`80o`00@03oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool500000?l0ooooo`3ooooo0?ooofX0oooo00<0o`000?ooo`3o00008@3oool00`3o0000oooo0?oo
o`0H0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooK03oool0
0`3o0000oooo0?l0000Q0?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooK03oool00`3o0000oooo0?l0000Q0?oo
o`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooK03oool00`3o0000oooo0?l0000Q0?ooo`80o`007@3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom/0?ooo`040?l0
003oool0oooo0?l001l0oooo00<0o`000?ooo`3o00007@3oool00`000000oooo0?ooo`0G0?ooo`00
8@3oool2000000@0oooo0P0000030?ooo`@00000303oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom/0?ooo`040?l0003oool0oooo0?l001l0oooo00<0o`000?ooo`3o00007@3oool00`000000
oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0`P3oool00`3o0000oooo0?ooo`3o0?ooool0ooooYP3oool0103o0000
oooo0?ooo`3o000O0?ooo`030?l0003oool0o`0001d0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0<0?ooo`L00000_P3oool00`3o
0000oooo0?ooo`3o0?ooool0ooooYP3oool0103o0000oooo0?ooo`3o000O0?ooo`040?l0003oool0
oooo0?l001H0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0`P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0?l0ooooo`3ooonD0?ooo`040?l0003oool0oooo0?l001l0oooo00@0o`000?ooo`3oool0
o`00703oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool0`@3oool20?l00140oooo00<0o`000?oo
o`3oool0o`3ooooo0?ooof40oooo00<00?l00?ooo`3oool0<03oool0103o0000oooo0?ooo`3o000O
0?ooo`040?l0003oool0oooo0?l001`0oooo00<000000?ooo`3oool05`3oool00240oooo0P00000:
0?ooo`8000003@3oool00`000000oooo0?ooo`310?ooo`80o`004@3oool00`3o0000oooo0?ooo`3o
0?ooool0ooooH@3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo01l0oooo00@0o`00
0?ooo`3oool0o`003P3oool00`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0oooo0?l001`0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0`@3oool20?l00140oooo00<0
o`000?ooo`3oool0o`3ooooo0?ooof40oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0O0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`310?ooo`80o`004@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooH@3o
ool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo01l0oooo00D0o`000?ooo`3oool0oooo
0?l0000=0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0<40oooo00<0
o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`3o0?ooool0ooooH03oool00`00o`00oooo003o
000?0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool01@3o0000oooo0?oo
o`3oool0o`0000`0oooo0P3o000?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000;l0oooo00<0o`000?ooo`3o0000403o
ool00`3o0000oooo0?ooo`3o0?ooool0ooooH03oool00`00o`00oooo003o000?0?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo01D0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`300?ooo`040?l0003oool0
oooo0?l000l0oooo0P3o003o0?ooool0oooo@03oool00`3o0000oooo0?ooo`0O0?ooo`03003o003o
ool00?l000l0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l0000>0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`300?ooo`040?l0003oool0oooo0?l000l0oooo0P3o003o0?ooool0oooo@03o
ool00`3o0000oooo0?ooo`0O0?ooo`03003o003oool00?l000l0oooo0P3o000?0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0o`0000h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0<00oooo00@0o`000?ooo`3oool0o`003`3o
ool00`3o0000oooo0?l0003o0?ooool0oooo?`3oool00`3o0000oooo0?ooo`0O0?ooo`03003o003o
ool00?l000l0oooo0P3o000?0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo0<00oooo00@0o`000?ooo`3oool0o`003`3oool00`3o0000oooo0?l0003o0?ooool0oooo?`3o
ool00`3o0000oooo0?ooo`0O0?ooo`03003o003oool00?l000l0oooo0P3o000?0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0o`0000h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0<00oooo00@0o`000?ooo`3oool0o`003`3o
ool00`3o0000oooo0?l0003o0?ooool0oooo?`3oool00`3o0000oooo0?ooo`0O0?ooo`03003o003o
ool00?l000h0oooo00<0o`000?ooo`3o00003`3oool20?l000h0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000_P3o
ool0103o0000oooo0?ooo`3o000?0?ooo`030?l0003oool0o`000?l0oooo<03oool00`000?l0oooo
0?ooo`3o0?ooo``0oooo00<0o`000?ooo`3oool07P3oool01000o`00oooo0?ooo`00o`0>0?ooo`03
0?l0003oool0o`0000h0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool04`3oool5000001T0oooo000l0?ooo`030000003oool0oooo0;l0
oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`030?l0003oool0o`000?l0oooo<03oool20000
ool0oooo303oool20?l00200oooo00D00?l00?ooo`3oool0oooo003o000=0?ooo`030?l0003oool0
o`0000h0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2a
0?ooo`030?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`030?l0003o
ool0o`000380oooo00<00?l00?ooo`3oool0nP3oool20000ool0oooo303oool20?l00200oooo00D0
0?l00?ooo`3oool0oooo003o000=0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3o0000
3P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3oool0
oooo0?l0000<0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05`3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2a0?ooo`030?l0003oool0oooo00/0oooo
00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`030?l0003oool0o`000380oooo00<00?l00?ooo`3o
ool0803oool00`3o0000oooo0?ooo`3G0?ooo`030000o`3oool0003o0?l0oooo2`3oool20?l00100
oooo00<0o`000?ooo`3oool03@3oool01@00o`00oooo0?ooo`3oool00?l000d0oooo00<0o`000?oo
o`3o00003P3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0;40oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00<0o`00
0?ooo`3o0000<P3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003oool0oooo0=H0oooo00@0003o
0?ooo`3oool0003oo`3oool;0?ooo`80o`00403oool00`3o0000oooo0?ooo`0=0?ooo`05003o003o
ool0oooo0?ooo`00o`003@3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0o`0000h0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o
0000303oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0/@3oool20?l000`0oooo00D0o`000?ooo`3oool0
oooo0?l0000?0?ooo`030?l0003oool0o`000380oooo0P00o`0Q0?ooo`030?l0003oool0oooo0=H0
oooo00D0003o0?ooo`3oool0oooo0000o`3o0?ooo`X0oooo00<0o`000?ooo`3o00003`3oool00`3o
0000oooo0?ooo`0=0?ooo`05003o003oool0oooo0?ooo`00o`003@3oool00`3o0000oooo0?l0000>
0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0/03oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?l0000b0?ooo`800?l08@3oool00`3o0000oooo0?ooo`3F0?oo
o`050000o`3oool0oooo0?ooo`000?l0o`3oool:0?ooo`030?l0003oool0o`0000l0oooo00<0o`00
0?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<0o`00
0?ooo`3o00003P3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`D00000[P3oool00`3o0000oooo0?l0000;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?l0000b0?ooo`800?l08@3oool00`3o0000oooo0?ooo`3F0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0o`3oool70?ooo`030?l0003oool0o`00
00l0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00/0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0A0?ooo`D000006@3oool003`0
oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`1;0?ooo`030?l0003oool0o`0000/0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l0
0380oooo0P00o`0Q0?ooo`030?l0003oool0oooo0=H0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`3d0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o00003`3oool00`3o
0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool0103o
0000oooo0?ooo`3o000=0?ooo`030?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`1;0?ooo`030?l0003oool0o`00
00/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo
0?l00380oooo00<00?l00?ooo`00o`007`3oool00`3o0000oooo0?l0003G0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0m03oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
o`0000l0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00X0oooo00@0o`000?ooo`3oool0o`003@3oool00`3o0000oooo0?l0000=0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`1;0?ooo`040?l0003oool0oooo0?l000X0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l00340oooo00@00?l00?ooo`3oool0
0?l07`3oool00`3o0000oooo0?l0003F0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0l`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0o`0000l0oooo0P3o000=0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool0103o0000oooo0?ooo`3o000=0?oo
o`030?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0D@3oool20?l000l0oooo00<0003o0?ooo`3oool0B`3oool0103o0000oooo0?ooo`3o000:0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`3o000a
0?ooo`04003o003oool0oooo003o01l0oooo00<0o`000?ooo`3o0000eP3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0?<0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?l0
000?0?ooo`80o`003@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00@0
o`000?ooo`3oool0o`003@3oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3o00003P3oool00`000?l0oooo
0?ooo`1:0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00<@3oool01000o`00oooo0?ooo`00o`0O
0?ooo`030?l0003oool0o`000=H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1h
0?ooo`030?l0003oool0oooo07L0oooo00<0o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`3o
000>0?ooo`030?l0003oool0o`0000d0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0:0?ooo`040?l0003oool0oooo0?l000d0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0503oool00`000000
oooo0?ooo`0G0?ooo`00?03oool5000004l0oooo00@0o`000?ooo`3oool0o`003@3oool00`000?l0
oooo0?ooo`0G0?ooo`030?l0003oool0oooo0300oooo00D0o`000?ooo`3oool0oooo0?l000090?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0
o`000300oooo00D00?l00?ooo`3oool0oooo003o000N0?ooo`030?l0003oool0o`000=H0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1h0?ooo`030?l0003oool0oooo07L0oooo0P3o
000>0?ooo`040?l0003oool0oooo0?l000h0oooo00<0o`000?ooo`3o0000303oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo00X0oooo00@0o`000?ooo`3oool0o`00303oool01@3o0000
oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0M0?oo
o`D000006@3oool003`0oooo00<000000?ooo`3oool0D@3oool01@3o0000oooo0?ooo`3oool0o`00
00`0oooo0P000?lH0?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool01@3o
0000oooo0?ooo`3oool0o`000300oooo00D00?l00?ooo`3oool0oooo003o000N0?ooo`030?l0003o
ool0o`000=H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1g0?ooo`030?l0003o
ool0oooo07L0oooo0P3o000>0?ooo`040?l0003oool0oooo0?l000h0oooo00<0o`000?ooo`3o0000
303oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00X0oooo00@0o`000?ooo`3oool0
o`00303oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0500
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o603oool00`3o0000
oooo0?ooo`0`0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0000`0?oo
o`05003o003oool0oooo0?ooo`00o`007P3oool00`3o0000oooo0?l0000b0?ooo`030?l0003oool0
oooo0:40oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1f0?ooo`80o`00N@3oool2
0?l000h0oooo00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0o`0000`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:0?ooo`040?l0003o
ool0oooo0?l000`0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0000o`070?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o0000<03oool01@00o`00oooo0?ooo`3oool00?l0
01h0oooo00<0o`000?ooo`3o0000<P3oool00`3o0000oooo0?ooo`2Q0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0MP3oool00`3o0000oooo0?l0001h0?ooo`80o`003P3oool0103o
0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o0000303oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0?l0
000<0?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo0240oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0D03o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l01`3o
ool00`3o0000oooo0?ooo`0=0?ooo`80o`008P3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo
00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`000300oooo00D00?l00?ooo`3o
ool0oooo003o000N0?ooo`030?l0003oool0o`000380oooo00<0o`000?ooo`3oool0X03oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo07H0oooo00<0o`000?ooo`3o0000I`3oool00`3o
0000oooo0?ooo`0>0?ooo`80o`003P3oool0103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3o0000303oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`050?l0003oool0oooo0?ooo`3o0000
303oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0
5`3oool001/0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P00000=0?ooo`030000003o
ool0oooo0500oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0003o00L0oooo00<0o`000?ooo`3oool03@3oool20?l00280oooo00<00?l00?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000060?ooo`030?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0000`0?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool06`3oool00`3o0000oooo0?l0000b0?ooo`03
0?l0003oool0oooo0:00oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`1f0?ooo`03
0?l0003oool0o`0006L0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`80
o`003P3oool0103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3o0000303oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00P0oooo00D0o`000?oo
o`3oool0oooo0?l0000<0?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool05`3oool001X0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000`0oooo
00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`000?l01`3oool20?l000h0oooo0P3o000R0?ooo`03003o003oool0oooo00`0oooo
00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`3o0000<03oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo01X0oooo00D0o`000?ooo`3oool0oooo0?l0000a
0?ooo`030?l0003oool0oooo0:00oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`1e
0?ooo`040?l0003oool0oooo0?l006H0oooo0P3o00080?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3o00003P3oool0103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3o0000303oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00P0oooo
00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3o
ool0oooo0?l0000<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool7000004`0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0003o00L0oooo0P3o000>0?ooo`030?l0003oool0o`00
0200oooo0P00o`0>0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P000?l20?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo02h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0J0?oo
o`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`0X0?ooo`80o`00RP3oool0
0`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0M@3oool0
103o0000oooo0?ooo`3o001V0?ooo`80o`00203oool00`00o`00oooo0?ooo`040?ooo`030?l0003o
ool0o`0000h0oooo00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0o`0000/0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`080?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`050?l0
003oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0
oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080
oooo0P00000=0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0003o00L0oooo0P3o000>0?ooo`030?l0003oool0o`000200
oooo00<00?l00?ooo`00o`003@3oool00`3o0000oooo0?ooo`040?ooo`080?l0003oool0oooo0000
o`3oool0003o0?ooo`3o00080?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0^0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0E0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo
0?ooo`0X0?ooo`80o`00RP3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0M03oool0103o0000oooo0?ooo`3o001U0?ooo`030?l0003oool0o`0000L0
oooo0P00o`060?ooo`030?l0003oool0o`0000h0oooo00@0o`000?ooo`3oool0o`001@3oool20000
o`L0oooo00<0o`000?ooo`3o00002`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003oool0oooo00L0oooo00D0o`00
0?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1@0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0000o`070?ooo`80o`00
3P3oool00`3o0000oooo0?l0000P0?ooo`03003o003oool00?l000d0oooo00<0o`000?ooo`3oool0
103oool0203o0000oooo0?ooo`000?l0oooo0000o`3oool0o`00203oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`03
0?ooo`05003o003oool0oooo0?ooo`000?l05`3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo
00<0003o0?ooo`3oool0:03oool20?l008X0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo07@0oooo00@0o`000?ooo`3oool0o`00I@3oool00`3o0000
oooo0?l000070?ooo`800?l01P3oool00`3o0000oooo0?l0000>0?ooo`040?l0003oool0oooo0?l0
00D0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?l0000;0?ooo`03003o003oool0oooo
00H0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`00
0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo000K0?ooo`8000002P3oool2
000000@0oooo0`00000<0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00L0oooo0P3o000=0?ooo`040?l0003oool0
oooo0?l00200oooo00<00?l00?ooo`00o`003@3oool00`3o0000oooo0?ooo`040?ooo`080?l0003o
ool0oooo0000o`3oool0003o0?ooo`3o00080?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0^0?ooo`03003o003oool0oooo00<0oooo00D00?l00?oo
o`3oool0oooo0000o`0G0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?oo
o`0X0?ooo`030?l0003oool0o`0008P0oooo00<0003o0?ooo`000?l05@3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo07<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`1R0?ooo`030?l0003oool0o`0000L0oooo0P00o`060?ooo`040?l0003oool0oooo0?l000`0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o
00002`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00D0o`000?ooo`3o
ool0oooo0?l0000:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`000?l60?ooo`030?l0003oool0o`00
00`0oooo00@0o`000?ooo`3oool0o`007`3oool01000o`00oooo0?ooo`00o`0=0?ooo`030?l0003o
ool0oooo00D0oooo00L0o`000?ooo`000?l0oooo0000o`3oool0o`0000P0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02d0oooo00<00?l00?ooo`3o
ool0103oool01@00o`00oooo0?ooo`3oool0003o01L0oooo00D0o`000?ooo`3oool0oooo0?l00005
0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o0000R03oool00`000?l0oooo0000o`0E
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0L`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0640oooo00@0o`000?ooo`3oool0o`001`3oool00`00o`00oooo003o
00050?ooo`040?l0003oool0oooo0?l000`0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`03
0000o`3oool0003o00H0oooo00@0o`000?ooo`3oool0o`002P3oool00`00o`00oooo0?ooo`060?oo
o`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`80003o103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
04l0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo
0000o`D0oooo00@0o`000?ooo`3oool0o`00303oool0103o0000oooo0?ooo`3o000O0?ooo`04003o
003oool0oooo003o00`0oooo00<0o`000?ooo`3oool01P3oool01P3o0000003o0?ooo`3oool0003o
0?l000T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo02d0oooo00<00?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0003o01L0oooo00D0
o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o0000
R03oool00`000?l0oooo0000o`0E0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
L`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0640oooo00@0o`000?ooo`3oool0
o`001`3oool00`00o`00oooo003o00050?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00H0oooo00@0o`000?oo
o`3oool0o`002P3oool00`00o`00oooo0?ooo`070?ooo`04003o003oool0oooo0000o`H0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`80003o103oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?oo
o`3o000;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool5000004H0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o1@3oool0103o0000oooo
0?ooo`3o000<0?ooo`040?l0003oool0oooo0?l001l0oooo00@00?l00?ooo`3oool00?l0303oool0
0`3o0000oooo0?ooo`060?ooo`060?l000000?l0oooo0?ooo`000?l0o`002@3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;@3oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo0080003o5P3oool01@3o0000oooo0?ooo`3oool0o`0000D0
oooo0P000?lQ0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o0000R03oool00`000?l0
oooo0000o`0E0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0L`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0640oooo00D0o`000?ooo`3oool0oooo0?l000060?oo
o`03003o003oool00?l000D0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`000?l01P3oool0103o0000oooo0?ooo`3o
000:0?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo0?l000/0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`D000006@3oool003`0oooo
00<000000?ooo`3oool0B03oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`000?l50?ooo`040?l0003oool0oooo0?l0
00`0oooo00@0o`000?ooo`3oool0o`007`3oool01000o`00oooo0?ooo`00o`0<0?ooo`030?l0003o
ool0oooo00H0oooo00H0o`000000o`3oool0oooo0000o`3o00090?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool00P000?lF0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0000o`0Q0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o0000R03oool00`00
0?l0oooo0000o`0E0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0LP3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0600oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`04003o003oool0oooo003o00D0oooo00@0o`000?ooo`3oool0o`00303o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`000?l01P3o
ool0103o0000oooo0?ooo`3o00090?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`3oool0
003o1P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`180?ooo`03003o
003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`040000
o`3oool0oooo0000o`D0oooo00@0o`000?ooo`3oool0o`00303oool0103o0000oooo0?ooo`3o000N
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`06
0?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;@3oool00`00o`00oooo0?ooo`05
0?ooo`05003o003oool0003o0?ooo`000?l05P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`000?l08@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0008L0oooo
00@0003o0?ooo`3oool0003o5@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo03T0
oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0600
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0oooo003o
00D0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0
0?l00?ooo`3oool0203oool01000o`00oooo0?ooo`000?l60?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`0000`0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo04L0oooo0P00o`060?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool0103oool010000?l0oooo0?ooo`000?l50?ooo`040?l0003oool0oooo0?l000/0
oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;03oool0
0`00o`00oooo0?ooo`050?ooo`05003o003oool0003o0?ooo`000?l05@3oool00`3o0000oooo0?oo
o`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`0Q0?ooo`80003o1@3oool0103o0000
oooo0?ooo`3o00270?ooo`050000o`3oool0oooo0?ooo`000?l04`3oool00`000?l0oooo0?ooo`0;
0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo05h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`04003o003oool0003o003o00D0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo
0?ooo`3oool0o`0000T0oooo00<00?l00?ooo`3oool0203oool01000o`00oooo0?ooo`000?l60?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`030?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0S0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`00
o`001@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3o
ool0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00D0o`000?ooo`3oool0oooo0?l0
000N0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3o0000oooo0080oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;03oool00`00o`00oooo0?oo
o`050?ooo`05003o003oool0003o0?ooo`000?l05@3oool00`3o0000oooo0?ooo`030?ooo`070?l0
003oool0oooo0?ooo`000?l0oooo0000o`0P0?ooo`030000o`3oool0003o00D0oooo00@0o`000?oo
o`3oool0o`00Q`3oool01@000?l0oooo0?ooo`3oool0003o01<0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0i0?ooo`80003o=`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo05h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`04003o003o
ool0003o003o00D0oooo00@0o`000?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`00
00T0oooo00<00?l00?ooo`3oool0203oool01000o`00oooo0?ooo`000?l60?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
o`0000d0oooo00D0o`000?ooo`3oool0oooo0?l0000U0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`00o`00103oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0003o1@3oool01@3o0000oooo0?oo
o`3oool0o`0000X0oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`060000o`3o0000oooo0?oo
o`3o0000003o2@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0;03oool00`00o`00oooo0?ooo`060?ooo`04003o00000?l0oooo0000oaD0oooo00<0
o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0803oool00`000?l0
oooo0000o`050?ooo`040?l0003oool0oooo0?l008L0oooo00D0003o0?ooo`3oool0oooo0000o`0C
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0P
0?ooo`80003o=P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo05h0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0003o003o00D0oooo00@0
o`000?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<00?l00?ooo`3o
ool0203oool01000o`00oooo0?ooo`000?l60?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`0000d0oooo00D0o`000?oo
o`3oool0oooo0?l0000U0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
04L0oooo00<00?l00?ooo`00o`00103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o00002P3o
ool01@3o0000oooo0?ooo`3oool0o`0001h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00H0003o0?l0003oool0oooo0?l000000?l:0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo02`0oooo00<00?l00?ooo`3oool01P3oool01000o`00003o0?ooo`000?lE
0?ooo`030?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o0200oooo
00<0003o0?ooo`000?l01@3oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo07`0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0P0?ooo`80003o8@3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0D@3oool00`00o`00
oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool01000o`00
oooo0000o`00o`050?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`030?ooo`050?l0003o
ool0oooo0?ooo`3o00002@3oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo0000o`H0
oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool2
0?l000d0oooo00D0o`000?ooo`3oool0oooo0?l0000U0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`D00000A@3oool00`00o`00oooo003o00040?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00D0o`000?ooo`3oool0oooo
0?l0000:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool06P3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool01P000?l0oooo
0?l0003oool0o`000000o`X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0;03oool00`00o`00oooo0?ooo`060?oo
o`04003o00000?l0oooo0000oaD0oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3o
ool0003o0?ooo`000?l0403oool00`000?l0oooo0?ooo`0=0?ooo`040000o`3oool0oooo0000o`@0
oooo00@0o`000?ooo`3oool0o`001`3oool00`000?l0oooo0?ooo`1l0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01D0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0000o`0Q0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1A0?ooo`03003o003oool0oooo
00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo
0000o`00o`001@3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0o`0000T0oooo00<00?l00?ooo`3oool02@3oool01000o`00oooo0000o`000?l50?oo
o`030?l0003oool0oooo00<0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`3oool0303oool01@3o0000oooo0?ooo`3oool0o`000240oooo1@00000I0?ooo`00?03o
ool00`000000oooo0?ooo`170?ooo`03003o003oool00?l000@0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0J0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`060000o`3oool0o`000?ooo`3o0000003o2P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo01D0oooo00<00?l00?ooo`3oool01P3oool01@00o`00003o0?ooo`3oool0
003o01@0oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0
403oool00`000?l0oooo0?ooo`0=0?ooo`040000o`3oool0oooo0000o`@0oooo00@0o`000?ooo`3o
ool0o`001P3oool20000ogh0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0000o`0P0?oo
o`040000o`3oool0oooo0000ob00oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo0540oooo0P00o`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool01P00o`00oooo0?ooo`000?l0oooo003o00@0oooo00D0o`000?ooo`3oool0
oooo0?l0000:0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`03003o003oool0
oooo00X0oooo00@00?l00?ooo`000?l0003o103oool00`3o0000oooo0?ooo`040?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?oo
o`3o00009@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`160?ooo`04
003o003oool0oooo003o00@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0J0?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`070000o`3oool0oooo0?l0003oool0o`000000o`0:0?ooo`040?l0003oool0oooo0?ooo`80003o
103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
5@3oool00`00o`00oooo0?ooo`070?ooo`040000o`3oool0oooo0000oa@0oooo00<0o`000?ooo`3o
ool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l0403oool00`000?l0oooo0?ooo`0=
0?ooo`040000o`3oool0oooo0000o`@0oooo00@0o`000?ooo`3oool0o`001P3oool20000ogh0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool0503oool00`000?l0oooo0000o`0P0?ooo`040000o`3oool0oooo0000oal0
oooo00<0003o0?ooo`000?l04P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0500
oooo00<00?l00?ooo`00o`002@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080
oooo00H00?l00?ooo`000?l0oooo0000o`00o`040?ooo`050?l0003oool0oooo0?ooo`3o00002P3o
ool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`00o`00oooo0?ooo`0:0?ooo`04
003o003oool0003o0000o`@0oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
003o0080oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool0303oool0103o0000oooo0?ooo`3o000V0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo04H0oooo00@00?l00?ooo`3oool00?l0
103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00P0003o0?ooo`3oool0
o`000?ooo`3o0000oooo0000o`T0oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool20000oa00oooo00<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`070?ooo`040000o`3oool0oooo0000oa@0oooo00<0o`000?ooo`3oool0
0`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool03@3oool20000o`h0
oooo00@0003o0?ooo`3oool0003o103oool0103o0000oooo0?ooo`3o00060?ooo`80003oOP3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0003o0200oooo00@0003o0?ooo`3oool0003o7`3o
ool00`000?l0oooo0000o`0B0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0C`3o
ool00`00o`00oooo003o00090?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o
ool01P00o`00oooo0000o`3oool0003o003o00@0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?oo
o`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`03003o003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool01000o`00003o0?ooo`000?l40?ooo`030?l0003oool0oooo00@0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`0002H0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0AP3oool01000o`00oooo0?ooo`00o`040?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool06@3oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?l0
0080oooo00<0003o0?ooo`3oool01`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01<0oooo0P000?l@0?ooo`030000o`3o
ool0oooo00@0oooo00<00?l00?ooo`3oool01`3oool010000?l0oooo0?ooo`000?lD0?ooo`030?l0
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo00d0
oooo0P000?l=0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l01`3oool00`00o`00oooo0?ooo`1c0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo01@0oooo00<0003o0?ooo`000?l0403oool00`3o0000oooo0?ooo`0=0?oo
o`050000o`3oool0oooo0?ooo`000?l07P3oool00`000?l0oooo0000o`0B0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool0C`3oool00`00o`00oooo003o00080?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool00P3oool01P00o`00oooo0000o`3oool0003o003o00@0oooo
00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l00008
0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool01000o`00003o0?ooo`00
0?l40?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040000
o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`03
0?l0003oool0o`0002H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
AP3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`030000o`3oool0oooo00L0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o00l0oooo00<0
003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`040000o`3oool0oooo0000oa@0oooo
00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0000o`0=0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3o
ool0o`00103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00H0oooo0P00o`1e0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo01@0oooo00@0003o0?ooo`3oool0003o3`3oool20?l000h0oooo00D0003o
0?ooo`3oool0oooo0000o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`000?l04P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool09`3o
ool01000o`00oooo0?ooo`00o`070?ooo`030?l0003oool0oooo00H0oooo00D0o`000?ooo`3oool0
oooo003o00020?ooo`040000o`3oool0003o003o00@0oooo00D0o`000?ooo`3oool0oooo0?l0000:
0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`03003o003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool01000o`00003o0?ooo`000?l40?ooo`030?l0
003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040000o`3oool0oooo0?l0
00H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`00
02H0oooo00<000000?ooo`3oool05`3oool003`0oooo1@0000140?ooo`05003o003oool0oooo0?oo
o`00o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool02@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`T0oooo00L0o`00
0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0B0?ooo`040000o`3oool0oooo0000o`l0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`080?ooo`040000o`00o`00oooo0000oa@0oooo00<0o`000?ooo`3oool0103oool0103o
0000oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`000?l03@3oool0
0`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0000o`040?ooo`800?l00P3oool00`00o`00oooo0?ooo`1b0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo01@0oooo00@0003o0?ooo`3oool0003o3P3oool0103o0000oooo0?ooo`3o000=0?ooo`05
0000o`3oool0oooo0?ooo`000?l03@3oool00`3o0000oooo0?l0000=0?ooo`040000o`3oool0oooo
0000oa40oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0
oooo02L0oooo00@00?l00?ooo`3oool00?l01`3oool00`3o0000oooo0?ooo`060?ooo`050?l0003o
ool0oooo0?ooo`00o`000P3oool010000?l0oooo0000o`00o`040?ooo`050?l0003oool0oooo0?oo
o`3o00002P3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00@00?l00000o`3oool0003o103o
ool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0oooo
0?l000070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo
0?l0000R0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0AP3oool01@00o`00oooo0?oo
o`3oool00?l00080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l90?ooo`07
0?l0003oool0oooo0?ooo`000?l0oooo0000o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool04P3oool010000?l0oooo0?ooo`000?l>0?ooo`80003o1@3oool00`00o`00oooo0?oo
o`070?ooo`050000o`3oool00?l00?ooo`000?l03P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0003o00d0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00040?ooo`03
0?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o0P3oool01P00o`00oooo0?ooo`3oool0
o`00003o04@0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0C0?ooo`050000o`3o
ool0oooo0?ooo`000?l03P3oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00D0003o0?ooo`3o
ool0oooo0000o`0<0?ooo`040?l0003oool0oooo0?l000d0oooo00D0003o0?ooo`00o`00oooo0000
o`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?oo
o`060?ooo`80003o9`3oool01@00o`00oooo0?ooo`3oool00?l000H0oooo00<0o`000?ooo`3oool0
1`3oool01@3o0000oooo0?ooo`3oool00?l00080oooo00@0003o0?ooo`000?l00?l00`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`04003o00000?l0oooo0000o`@0oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo0?oo
o`3oool0003o0080oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo01/0oooo00<0o`000?ooo`3o00009P3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`150?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0o`00
3@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool0
0P3oool0103o0000oooo0?ooo`00o`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0000o`80oooo00D0003o0?oo
o`3oool0oooo0?l000060?ooo`030?l0003oool0oooo0180oooo00@0003o0?ooo`3oool0003o3P3o
ool20000o`D0oooo00<00?l00?ooo`3oool01`3oool01@000?l0oooo003o003oool0003o00h0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00<0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0000o`0=0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3o0000103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`00
o`00103oool00`3o00000?l00?ooo`130?ooo`030000o`3oool0oooo02d0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool04`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool01@3o
0000oooo0?ooo`3oool0o`0000`0oooo00D0003o0?ooo`00o`00oooo0000o`060?ooo`80o`00203o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool01P3o
ool20000obL0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003o
ool0oooo00L0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`040000o`3oool0003o003o00<0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00@0oooo00D0o`000?oo
o`3oool0oooo0000o`020?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`0002H0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo
0?l000d0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo003o00020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo00<00?l00?ooo`3oool00`3oool0103o0000oooo0?ooo`00o`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`040?l0003o
ool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0oooo0140
oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o00@0oooo00<00?l00?oo
o`3oool01`3oool00`000?l0oooo003o00020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00<0oooo00<0003o0?oo
o`3oool0303oool010000?l0oooo0?ooo`000?l<0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3o0000103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0003o003o003oool0103o
ool00`3o0000oooo003o00120?ooo`030000o`3oool0003o02d0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3o
ool01@000?l0oooo003o003oool0003o00H0oooo00@0o`000?ooo`3o0000o`001P3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo01`0oooo00<00?l00?ooo`3oool01P3oool20000obL0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00L0
oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`040000o`3oool0003o003o00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00@0o`00
0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`040?ooo`80o`001P3oool00`000?l0oooo0000
o`040?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000
o`3oool0o`0000L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0
003oool0oooo02D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0A@3o
ool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo003o00020?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00o`00
oooo0?ooo`060?ooo`80o`002@3oool00`00o`00oooo0?ooo`030?ooo`80o`000P3oool00`00o`00
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo0?l00006
0?ooo`030?l0003oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3o
ool0003o00@0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo003o00020?ooo`030000o`3o
ool0oooo00X0oooo0P000?l40?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0000o``0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`00o`00
003o0?ooo`050?ooo`030?l0003oool00?l00480oooo00<0003o0?ooo`000?l0;@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`040?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`090?ooo`050000o`3oool00?l00?ooo`000?l01P3oool0103o0000oooo0?ooo`3oool2
0?l000<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0J0?ooo`800?l0203oool2
0000obL0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo00L0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`040000o`3oool0003o003o00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo
00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0o`0000D0
oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000
o`<0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
01`0oooo00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`150?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0o`003@3oool00`3o
0000oooo0?ooo`020?ooo`030000o`00o`000?l000<0oooo00@0003o0?ooo`3oool0o`001P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`00o`00oooo0?ooo`050?ooo`030?l0003oool0o`0000T0oooo00<00?l00?ooo`3oool00`3oool2
0?l00080oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l20?ooo`050000o`3o
ool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00`0oooo
00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o00@0oooo00<00?l00?ooo`3o
ool01`3oool01P000?l0oooo0?ooo`00o`00oooo0000o``0oooo0P000?l40?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0
oooo0000o`/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000040?ooo`040?l0003o
ool0oooo0000o`<0oooo00<00?l00000o`3oool01@3oool20?l00003003o003oool0oooo0400oooo
00<0003o0?ooo`000?l0;@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo
00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00`0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`060000o`3oool00?l00?ooo`00
o`00003o1P3oool00`3o0000oooo0?ooo`030?ooo`80o`0000<0oooo0?l0003oool02`3oool00`3o
0000oooo0?ooo`0I0?ooo`04003o003o00000?l00?l000H0oooo00@0003o0?ooo`3oool0003o9P3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo003o00030?ooo`040000o`3oool0003o003o00<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l0
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
103oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`000?l0
103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00@0oooo00<0003o0?l0003oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`150?ooo`03003o003o
ool0oooo0080oooo00@00?l00?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`020?ooo`030000
o`00o`000?l000<0oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo003o00060?ooo`03
0?l0003oool0o`0000T0oooo00<00?l00?ooo`3oool00`3oool01@3o0000oooo0?l0003oool00?l0
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00D0o`00
0?ooo`3oool0oooo003o000=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0000o`040?ooo`03003o003oool0oooo00L0oooo00H0003o0?ooo`3oool00?l0
0?ooo`000?l<0?ooo`030000o`3oool0003o00<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0000o`030?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3oool0003o2`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o0`3oool0
0`00o`00003o0?ooo`050?ooo`80o`0000<00?l00?ooo`3oool0?`3oool01@000?l0oooo0?ooo`3o
ool0003o02`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool00`3oool2003o00d0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`070000o`3oool00?l00?ooo`00o`00oooo0000o`050?ooo`03
0?l0003oool0oooo00D0oooo0P3o000<0?ooo`030?l0003oool0oooo01T0oooo00@00?l00?l0003o
ool00?l01P3oool010000?l0oooo0?ooo`000?lV0?ooo`03003o003oool0oooo00<0oooo00D00?l0
0?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool00?l000<0oooo00D0003o0?ooo`3oool0003o
003o00020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0003o00@0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`03
0?l0003oool0oooo00<0oooo00<0003o003o003oool01@3oool00`3o0000oooo0?l000050?ooo`03
0000o`3oool0003o00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`040?ooo`03
0000o`3o0000oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo02D0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000S0?ooo`030000
o`3oool0oooo01`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?l0000=0?ooo`030?l0
003oool0oooo0080oooo00@0003o003o003oool00?l00P3oool010000?l0oooo0?ooo`3o00070?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`03003o003oool00?l000H0oooo00<0o`000?ooo`3o0000203oool00`00o`00oooo0?ooo`030?oo
o`060?l0003oool0oooo0?l0003oool00?l01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000003o0?ooo`030?ooo`030000o`3o
ool0o`0000P0oooo00D0o`000?ooo`3oool0oooo003o000=0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`000?l40?ooo`03003o003oool0oooo00L0
oooo00H0003o0?ooo`3oool00?l00?ooo`000?l<0?ooo`030000o`3oool0003o00<0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0oooo00/0oooo00@0003o
0?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00<0oooo00@0
o`000?ooo`3oool0003o0`3oool00`00o`00003o0?ooo`050?ooo`80o`0000<0oooo003o003oool0
?`3oool01@000?l0oooo0?ooo`3oool0003o02`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool00`3oool2003o00`0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo003o00040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`070000o`3oool00?l00?oo
o`00o`00oooo0000o`050?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`0;0?ooo`05003o003oool0o`000?ooo`00o`001P3oool010000?l0oooo0?oo
o`000?lU0?ooo`03003o003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`03
0?l0003oool00?l000<0oooo00D0003o0?ooo`3oool0003o003o00020?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o
00D0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`00
oooo00D0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`000?l0103oool00`000?l0o`000?ooo`070?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0@03oool5000001T0oooo000l0?ooo`030000003oool0oooo
02D0oooo00<0003o0?ooo`3oool0703oool00`00o`00oooo0?ooo`040?ooo`03003o003o0000oooo
00d0oooo00<0o`000?ooo`3oool00P3oool010000?l00?l00?ooo`00o`020?ooo`040000o`3oool0
oooo0?l000L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0080oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo0?l000080?ooo`03003o003o
ool0oooo00<0oooo00H0o`000?ooo`3oool0oooo0?l00000o`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00<0
oooo00<0003o0?ooo`3o0000203oool01@3o0000oooo0?ooo`3oool00?l000d0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000o`@0oooo00<00?l0
0?ooo`3oool01`3oool01P000?l0oooo0?ooo`00o`00oooo0000o``0oooo00<0003o0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00@0oooo00<00?l00000o`3oool0
103oool01@3o0000oooo0?l0003oool00?l003l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo0P00o`0<0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`00o`00103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool01@3oool01`000?l0oooo003o003oool00?l00?ooo`000?l01@3oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00X0oooo0P00o`0;0?ooo`06003o003oool0
oooo0?l0003oool00?l01P3oool010000?l0oooo0?ooo`000?lU0?ooo`03003o003oool0oooo00@0
oooo00D00?l00?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool00?l00080oooo00H0003o0?oo
o`3oool0oooo0000o`00o`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00D0oooo00@0003o0?ooo`3oool0o`00
1@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o0000
1@3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l0
103oool00`000?l0o`000?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
A03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo01`0oooo00<00?l00?ooo`3oool0103oool00`00o`00o`000?ooo`0=0?ooo`060?l0003o
ool0oooo0?ooo`000?l00?l00P3oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
0080oooo00<00?l00000o`00o`001P3oool00`3o0000oooo0?l000080?ooo`03003o003oool0oooo
00<0oooo00H0o`000?ooo`3oool0oooo0?l00000o`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00<0oooo00<0
003o0?ooo`3o0000203oool0103o0000oooo0?ooo`3oool2003o00/0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000o`@0oooo00<00?l00?ooo`3o
ool01`3oool01P000?l0oooo0?ooo`00o`00oooo0000o`/0oooo00@0003o0?ooo`3oool0003o0`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00@0oooo00<00?l00000o`3oool0103o
ool01@3o0000oooo0?l0003oool00?l003l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0X0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo0P00o`0<0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo
00<0003o003o0000o`001@3oool01@000?l0oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3o
ool00`3oool020000?l0oooo0?ooo`00o`00oooo003o003oool0003o103oool00`3o0000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00T0oooo00@00?l00?ooo`3oool00?l02@3oool01`00o`00oooo
0?ooo`3oool0o`000?ooo`00o`001P3oool01@000?l0oooo0?ooo`3oool0003o02@0oooo00<00?l0
0?ooo`3oool01@3oool01000o`00oooo0?ooo`3o000;0?ooo`030?l0003oool00?l00080oooo00H0
003o0?ooo`3oool0oooo0000o`00o`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00D0oooo00@0003o0?ooo`3o
ool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3o00001@3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`000?l0103oool00`000?l0o`000?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0A03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0T0?oo
o`030000o`3oool0003o01d0oooo00<00?l00?ooo`3oool0103oool00`00o`00o`000?ooo`0>0?oo
o`050?l0003oool0oooo0000o`00o`000P3oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo0080oooo00<00?l00000o`00o`001P3oool00`3o0000oooo0?l000080?ooo`03003o003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l00000
0?l0oooo00<0oooo00<0003o0?ooo`3o0000203oool01P3o0000oooo0?ooo`00o`00oooo003o00/0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000
o`@0oooo00<00?l00?ooo`3oool01`3oool01P000?l0oooo0?ooo`00o`00oooo0000o`/0oooo00@0
003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`030?ooo`030?l0003oool0003o00<0oooo
00<00?l00?ooo`000?l01@3oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo03`0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo
00<00?l00?ooo`00o`00303oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030000o`00o`000?l000D0oooo
00D0003o0?ooo`3oool0oooo0?l0000>0?ooo`030?l0003oool0oooo00<0oooo00P0003o0?ooo`3o
ool00?l00?ooo`00o`00oooo0000o`@0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?oo
o`090?ooo`05003o003oool0oooo0?ooo`00o`001`3oool00`00o`00oooo0?ooo`020?ooo`040?l0
003oool0o`00003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo
01`0oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`3o000;0?ooo`030?l0003oool0
0?l00080oooo00H0003o0?ooo`3oool0oooo0000o`00o`020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00D0oooo
00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3o00001@3oool010000?l00?l00?ooo`000?l30?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`000?l0103oool00`000?l0o`000?ooo`070?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000@0
oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo00@0
oooo00<0003o0?ooo`000?l07@3oool00`00o`00oooo0?ooo`040?ooo`03003o003o0000oooo00h0
oooo00D0o`000?ooo`3oool0003o003o00020?ooo`04003o003oool0oooo0000o`80oooo00<0o`00
0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00P0o`000?ooo`3oool0oooo
003o003oool0003o003o00H0oooo00<0o`000?ooo`3o00001`3oool00`00o`00oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<0o`00003o003oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`030?oo
o`030000o`3oool0o`0000P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0;0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`000?l40?ooo`03003o
003oool0oooo00L0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00<0oooo00<0o`000?oo
o`3oool0103oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0000o`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00<0oooo00<0o`00
0?ooo`000?l00`3oool00`00o`00oooo0000o`050?ooo`030?l0003oool0o`000080oooo00<00?l0
0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02P0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool00P3oool00`00o`00oooo003o000<0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00@0003o
003o003oool00?l0103oool010000?l0oooo0?ooo`3o000@0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`00o`000P3oool01000o`00oooo0?ooo`000?l30?ooo`030?l0003oool0oooo01D0
oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool00`00o`00
oooo0?ooo`030?ooo`040?l0003oool0o`00003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`05
0?ooo`80o`007@3oool00`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo0?l000/0oooo00<0
o`00003o003oool00P3oool01P000?l0oooo0?ooo`3oool0003o003o0080oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`00
0?l01@3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo0080oooo0P000?l70?oo
o`030?l0003oool0o`0000D0oooo00@0003o003o003oool0003o0`3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0003o00@0oooo00<0003o0?l0003oool01`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01h0oooo00<0
0?l00?ooo`3oool00`3oool00`000?l0oooo0000o`0H0?ooo`030?l0003oool0oooo0080oooo00<0
0?l00?ooo`3oool0103oool00`00o`00o`000?ooo`0>0?ooo`040?l0003oool0oooo0000o`<0oooo
00@00?l00?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?oo
o`3o0000203oool01P3o0000oooo0?ooo`3oool00?l00?ooo`80003o00<00?l00?ooo`3oool00`3o
ool0103o0000oooo0?ooo`3o00060?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3o0000
203oool01P3o0000oooo0?ooo`00o`00oooo003o00X0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000o`@0oooo00<00?l00?ooo`3oool01`3oool0
1`000?l0oooo0?ooo`3oool00?l00?ooo`000?l00`3oool00`3o0000oooo0?ooo`040?ooo`040000
o`3oool0oooo0000o`80oooo00<0o`000?ooo`3oool01`3oool00`3o0000003o0?ooo`030?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000000o`3oool00`3oool00`3o0000003o0?ooo`030?ooo`03
003o003oool0003o00D0oooo00H0o`000?ooo`3oool0o`000?ooo`00o`090?ooo`T0003o7P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo003o00X0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00`3o
ool010000?l0oooo0?ooo`00o`040?ooo`040000o`3oool0oooo0?l00100oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo003o00030?ooo`03003o003oool0003o00<0oooo00<0o`000?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3o
ool0oooo003o00040?ooo`050?l0003oool0oooo0?ooo`00o`001@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00005`3oool01@000?l0oooo0?ooo`3o
ool00?l000T0oooo00<00?l00?l0003oool02`3oool00`3o00000?l00?ooo`020?ooo`060000o`3o
ool0oooo0?ooo`000?l00?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`050?ooo`040000o`3oool0oooo0?l0
00D0oooo00<0o`000?ooo`3oool00P3oool20000o`L0oooo00<0o`000?ooo`3o00001@3oool01000
0?l00?l00?ooo`000?l20?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`000?l0103oool0
0`000?l0o`000?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00/0oooo1`00000J0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l0603oool0
1@3o0000oooo0?ooo`3oool00?l000L0oooo00<00?l00?l0003oool03P3oool0103o0000oooo0?oo
o`000?l30?ooo`04003o003oool0oooo0000o`80oooo00<0o`000?ooo`3oool01P3oool01@3o0000
oooo0?ooo`3oool0o`0000P0oooo00H0o`000?ooo`3oool0oooo003o003oool20000o`03003o003o
ool0oooo00<0oooo00@0o`000?ooo`3oool0o`001P3oool00`00o`00oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0o`0000P0oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0:0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool60?l000050000o`3o0000o`000?l000000?l0103oool0
0`00o`00oooo0?ooo`070?ooo`070000o`3oool0oooo0?ooo`00o`00oooo0000o`030?ooo`030?l0
003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<00?l00?ooo`000?l01@3oool0103o0000oooo0?ooo`3o00020?oo
o`04003o003oool0oooo0?ooo`D0003o2@3oool50000oaT0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool0
1000o`00oooo0?ooo`00o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool00?l0
1@3oool00`000?l0oooo0?l0000@0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`00o`00
0`3oool00`00o`00oooo0000o`030?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool00?l000D0oooo00D0o`000?ooo`3oool0
oooo003o00050?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`030?l0003oool0oooo01<0oooo0`000?l30?ooo`03003o003oool0oooo00L0oooo00<00?l00?l0
003oool02`3oool00`3o00000?l00?ooo`020?ooo`060000o`3oool0oooo0?ooo`000?l00?l00P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0000o`050?ooo`040000o`3oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0
oooo0P000?l60?ooo`040?l0003oool0oooo0?l000D0oooo00@0003o003o003oool0003o0P3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo03l0oooo1`00000I0?ooo`00803oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool0
0`00o`00oooo0?ooo`020?ooo`040000o`3oool0oooo0000oaH0oooo00<0o`000?ooo`3o00000P3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003o0000oooo00h0oooo00@0o`000?ooo`3oool0003o
0`3oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00H0oooo00D0o`000?ooo`3o
ool0oooo0?l000080?ooo`090?l0003oool0oooo0?ooo`00o`00003o0?ooo`000?l00?l000D0oooo
00@0o`000?ooo`3oool0o`001P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<00?l00?l0003oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000P0
oooo00H0o`000?ooo`3oool00?l00?ooo`00o`0:0?ooo`030000o`3oool0oooo00H0oooo00D0003o
0?ooo`3oool0oooo0?l000060?ooo`060000o`3oool0oooo0?l0003oool0003o0`3oool00`00o`00
oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`000?l00`3oool20?l000D0
oooo00@0003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0oooo
0080oooo00<00?l00?ooo`000?l01@3oool0103o0000oooo0?ooo`3o00020?ooo`05003o003oool0
oooo0?ooo`000?l04@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0o`0000X0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000003o0?ooo`0A0?ooo`030000o`3oool0oooo0080oooo00@0
0?l00?ooo`3oool00?l02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`050000o`00o`00oooo0?ooo`00
o`001@3oool00`000?l0oooo0?l0000@0?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01`00
o`00oooo0?ooo`3oool00?l00?ooo`000?l00`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`040?ooo`050?l0003o
ool0oooo0?ooo`00o`001@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool00`3o0000oooo0?ooo`0A0?ooo`040000o`3oool0oooo0000o`<0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00o`000?ooo`0;0?ooo`030?l00000o`00oooo0080oooo00H0003o0?oo
o`3oool0oooo0000o`00o`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00D0oooo00@0003o0?ooo`3oool0o`00
1P3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00@0o`000?ooo`3oool0o`001@3oool01000
0?l00?l00?ooo`000?l20?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`000?l0103oool0
0`3o0000003o0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000`0oooo00<000000?ooo`3oool0803oool01@00o`00oooo0?ooo`3oool0003o0080oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l40?ooo`06003o003oool0oooo0000
o`3oool0o`00203oool0103o0000oooo0?ooo`3o00090?ooo`090?l0003oool0oooo0?ooo`00o`00
003o0?ooo`000?l00?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`03003o003oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00o`00o`000?ooo`020?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3o0000203oool0103o0000oooo0?ooo`00o`020?ooo`03003o003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00070?ooo`060000
o`3oool0oooo0?ooo`3o0000003o0P3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo
0080oooo00<00?l00?ooo`000?l00`3oool20?l000@0oooo00D0003o0?ooo`3oool0oooo0000o`02
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`000?l00`3oool00`000?l0o`000?ooo`03
0?ooo`04003o003oool0oooo0000o`@0oooo00@0o`000?ooo`3oool0o`000P3oool01@00o`00oooo
0?ooo`3oool0003o0180oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?l0000:0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00P0oooo0P3o00000`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080
oooo00@00?l00?ooo`3oool00?l01@3oool20?l000<0oooo00D0003o0?ooo`3oool0oooo003o0005
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?l0000@0?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`000?l00`3oool00`3o
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool03`3oool01P3o
0000oooo0?ooo`3oool0o`00003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0o`000?ooo`3oool03P3oool20000o`@0oooo00@0003o0?ooo`3oool0
0?l02P3oool00`00o`00oooo0?ooo`0:0?ooo`030?l00000o`00oooo0080oooo00H0003o0?ooo`3o
ool0oooo0000o`00o`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00D0oooo00@0003o0?ooo`3oool0o`001P3o
ool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l01@3oool0103o0000oooo0?ooo`3o00050?oo
o`040000o`3oool00?l00000o`80oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000o`04
0?ooo`030?l000000?l0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`15
0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000002P3oool2000000d0oooo00<000000?oo
o`3oool0803oool01000o`00oooo0?ooo`000?l30?ooo`030000o`3oool0oooo01@0oooo00<0o`00
0?ooo`3o00000P3oool00`00o`00oooo0?ooo`050?ooo`030?l00000o`00oooo00h0oooo00@0o`00
0?ooo`00o`00003o103oool01P00o`00oooo0?ooo`000?l0oooo0?l000P0oooo00@0o`000?ooo`3o
ool0o`002@3oool02@3o0000oooo0?ooo`00o`00oooo0000o`3oool0003o003o00040?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<00?l00?ooo`3o00000P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00L0
oooo00@0o`000?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3o0000203oool01P000?l0oooo0?ooo`3oool0o`000000o`80oooo00<0
0?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0003o00<0oooo0P3o
00040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o00002@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000
o`030?ooo`030000o`3o0000oooo00<0oooo00@00?l00?ooo`3oool0003o103oool0103o0000oooo
0?ooo`3o00030?ooo`04003o003oool0oooo0000oa80oooo00<0003o0?ooo`3oool05@3oool0103o
0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool4
0000oa80oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
003o01<0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`00o`030?ooo`80o`0000<0
oooo0?l0003oool00P3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`00o`00
oooo0?ooo`040?ooo`030000o`3o0000oooo00l0oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`05003o003oool0oooo0?ooo`00o`000P3oool010000?l0oooo0?ooo`3o000G0?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0403oool01P3o0000oooo0?ooo`3oool0o`00003o00@0
oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`00o`0:0?ooo`03003o003oool0
oooo00X0oooo00<00?l00?ooo`3oool00P3oool02@000?l0oooo0?ooo`3oool0003o0?ooo`00o`00
oooo0?l000060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
003o0?ooo`050?ooo`040000o`3oool0oooo0?l000H0oooo00L0o`000?ooo`3oool0oooo0000o`3o
ool0003o00D0oooo00@0o`000?ooo`3oool0o`001@3oool010000?l0oooo003o00000?l20?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`000?l0103oool00`3o0000003o0?ooo`070?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0240oooo00<00?l00?ooo`000?l00`3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0o`000080oooo00<00?l00?ooo`3oool01@3oool00`3o0000
0?l00?ooo`0>0?ooo`040?l0003oool00?l00000o`@0oooo00H00?l00?ooo`3oool0003o0?ooo`3o
00090?ooo`030?l0003oool0o`0000T0oooo00H0o`000?ooo`3oool00?l00?ooo`000?l20?ooo`03
0000o`00o`00oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?l000020?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?l0003oool01`3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`080?ooo`060000o`3oool0
oooo0?ooo`3o0000003o0P3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo
00<00?l00000o`3oool00P3oool20?l000@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?l000090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?l0003oool00`3oool01000o`00
oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0?l000<0oooo00@00?l00?ooo`3oool0003o4`3o
ool00`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00X0oooo1@000?l40?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0000oa<0
oooo00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l00080o`000`3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo0P00o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`80oooo00D00?l00?ooo`3oool0
oooo003o00020?ooo`040000o`3oool0oooo0?l001L0oooo00<0o`000?ooo`3oool01@3oool00`00
o`00oooo0?ooo`0@0?ooo`060?l0003oool0oooo0?ooo`3o00000?l00`3oool00`000?l0oooo0?oo
o`040?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool02@3oool20000o`L0oooo
00<0003o0?ooo`00o`002`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool010000?l00?l00?ooo`3o00060?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`050?ooo`040000o`3oool0oooo0?l0
00H0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00D0oooo00@0o`000?ooo`3oool0o`00
1@3oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3o
ool00`3oool00`3o0000003o0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0280
oooo00<00?l00000o`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0
oooo00L0o`000?ooo`3oool0oooo0?l0003oool00?l000L0oooo00<0o`00003o003oool03P3oool0
103o0000oooo003o00000?l40?ooo`06003o003oool0oooo0000o`3oool0o`002@3oool00`3o0000
oooo0?l000090?ooo`060?l0003oool0oooo003o003oool0003o0P3oool00`000?l00?l00?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`00o`00oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00@00?l00?ooo`3o0000o`00203oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?l0003oool01@3oool00`000?l0o`000?ooo`070?ooo`040?l0
003oool0oooo003o0080oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3o0000oooo00P0oooo00H0003o0?ooo`3oool0oooo0?l000000?l20?ooo`03003o003oool0
oooo00L0oooo00<0003o0?ooo`3oool00`3oool01`00o`00003o0?ooo`3oool0o`000?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0000T0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000oooo00<0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`000?l01`3oool02@3o0000
oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000040?ooo`04003o003oool0oooo0000o`@0oooo
00@0o`000?ooo`3oool0o`000`3oool01000o`00oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
00d0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`060?l0003oool0oooo
0?ooo`000?l0o`003`3oool40?l000050000o`3oool0oooo0?ooo`00o`000P3oool00`3o00000?l0
0?ooo`040?ooo`040?l0003oool0oooo0000o`<0oooo00<00?l00?ooo`00o`00103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00D0o`000?ooo`3oool00?l00000o`030?oo
o`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0403oool01P3o0000oooo0?ooo`000?l0
oooo003o00@0oooo00@00?l00?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`070?ooo`03003o
003oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0
003oool0oooo0080oooo00<0o`00003o003oool00P3oool00`000?l0oooo0?ooo`040?ooo`040000
o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool00?l000X0oooo00<0o`00003o003oool02`3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00@0003o003o003oool0o`001P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool00P3oool01000o`00oooo0?ooo`000?l2
0?ooo`030?l0003oool0oooo00@0oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00D0oooo
00D0o`000?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?oo
o`3oool01`3oool00`3o0000003o0?ooo`030?ooo`030?l000000?l0oooo00L0oooo00D0o`000?oo
o`3oool0oooo0000o`020?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool08P3oool00`00o`00003o0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool00`3oool01P3o0000oooo0?ooo`3oool0o`00003o00P0oooo00<0
o`00003o003oool03P3oool0103o00000?l00?ooo`000?l40?ooo`06003o003oool0oooo0000o`3o
ool0o`002@3oool00`3o0000oooo0?l000090?ooo`060?l0003oool0oooo003o003oool0003o0P3o
ool00`000?l00?l00?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`00o`00003o
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00@00?l00?ooo`3o0000o`001`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001@3oool00`000?l0
o`000?ooo`070?ooo`040?l0003oool0oooo003o0080oooo00<00?l00?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool01000
0?l0oooo0?ooo`00o`090?ooo`030000o`3oool0oooo00<0oooo00D00?l00000o`3oool0oooo0?l0
00020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?l000090?ooo`030000
o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo003o003oool00?l000@0oooo00<0003o0?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool01P3oool0
2@3o0000oooo0?ooo`3oool0003o0?ooo`000?l0oooo0?l000040?ooo`04003o003oool0oooo0000
o`@0oooo00@0o`000?ooo`3oool0o`00103oool00`00o`00003o0?ooo`0C0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?l0003oool03P3oool01@3o0000oooo0?ooo`3oool0003o00<0o`0000D0
0?l00?l0003o0000oooo003o00050?ooo`040?l0003oool0oooo0000o`<0oooo00<00?l00?ooo`00
o`001@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool01`3oool01@3o0000oooo0?ooo`00o`00003o00@0oooo00<00?l00?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0003o0080oooo00<00?l00?ooo`3oool00P3oool01000
o`00oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0303oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool0
1@3o00000?l00?ooo`3oool0003o00H0oooo00<0003o0?ooo`3o0000203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`00o`002P3oool00`3o0000oooo003o
000;0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool010000?l00?l00?oo
o`3o00060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o
0?ooo`020?ooo`07003o003oool0oooo0?ooo`000?l0oooo0?l000060?ooo`070?l0003oool0oooo
003o00000?l0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool020000?l0oooo
0?ooo`3oool0003o003o003oool0o`002@3oool00`3o0000003o0?ooo`030?ooo`030?l000000?l0
oooo00P0oooo00@0o`000?ooo`000?l0003o0P3oool00`3o0000oooo0?ooo`150?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`D000008@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00/0oooo0P000?l50?ooo`060?l0003oool0oooo0?ooo`3o00000?l0203oool00`3o00000?l0
0?ooo`0>0?ooo`040?l00000o`00oooo0000o`@0oooo00H00?l00?ooo`3oool0003o0?ooo`3o0009
0?ooo`030?l0003oool0o`0000T0oooo00H0o`000?ooo`3oool00?l00?ooo`000?l20?ooo`030000
o`00o`00oooo0080oooo00<0o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool00?l00?oo
o`000?l01@3oool00`3o0000oooo0?ooo`050?ooo`04003o003oool0oooo0?l000L0oooo00<0003o
0?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo003o00030?ooo`03003o003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000003o0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool00?l02@3oool00`000?l0oooo0?ooo`030?ooo`05003o003oool0003o0?ooo`3o0000
0P3oool0103o0000oooo0?ooo`000?l50?ooo`030000o`3oool0o`0000T0oooo00<0003o0?l0003o
ool0103oool020000?l0oooo0?ooo`3oool00?l00?ooo`00o`00o`000`3oool00`000?l0oooo0?oo
o`050?ooo`050000o`3oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?ooo`060?ooo`090?l0
003oool0oooo0?ooo`000?l0oooo0000o`3oool0o`0000@0oooo00@00?l00?ooo`3oool0003o103o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<00?l00000o`3oool0203oool00`00o`00oooo
0?ooo`090?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0?l0000?0?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool01@00o`00oooo0?ooo`3oool00?l000D0oooo00@0o`000?ooo`3oool0003o
0`3oool00`00o`00oooo003o00050?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool2003o00P0
oooo00D0o`000?ooo`3oool00?l00000o`040?ooo`03003o003oool0oooo00<0oooo00<0o`000000
o`3oool0403oool00`3o0000oooo0000o`020?ooo`03003o003oool0oooo00<0oooo00H00?l00?oo
o`3oool0003o0?ooo`3o00090?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00<0oooo00D0o`00003o003oool0oooo
0000o`070?ooo`030000o`3o0000oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`090?ooo`030000o`00o`00oooo00T0oooo00<0o`000?ooo`00o`002`3oool01@00o`00oooo
0?ooo`3oool0003o00D0oooo00@0003o003o003oool0o`001P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool00P3oool01`00o`00oooo0?ooo`3oool0
003o0?ooo`3o00001P3oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00<0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`080000o`3oool0oooo0?ooo`000?l00?l00?ooo`3o
00090?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`3oool0203oool01`3o0000oooo0000
o`3oool0003o0?ooo`3o0000@`3oool5000001T0oooo000l0?ooo`030000003oool0oooo0280oooo
00<0003o0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0003o00<0oooo
00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`060?ooo`030?l00000o`00oooo00h0oooo
00@0o`00003o003oool0003o103oool01@00o`00oooo0?ooo`000?l0o`0000X0oooo0P3o000;0?oo
o`050?l00000o`00oooo0?ooo`000?l00P3oool00`000?l00?l00?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo003o00020000o`D0oooo00<0o`000?ooo`3oool01@3o
ool01000o`00oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?l000050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`00o`00
103oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0
003o203oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo003o00T0oooo00<0003o0?oo
o`3oool00`3oool01@00o`00oooo0000o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o1@3o
ool00`000?l0o`000?ooo`090?ooo`030000o`3o0000oooo00@0oooo00P0003o0?ooo`3oool0oooo
003o003oool00?l00?l000<0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool2
003o00030?ooo`000?l0oooo00L0oooo00T0o`000?ooo`3oool0oooo0000o`3oool0003o0?ooo`3o
00000`3oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`03003o00000?l0oooo00L0oooo0P00o`0;0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo0P000?l@
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?l0000?
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@00o`00oooo0?ooo`3oool00?l000H0oooo
00<0o`000?ooo`000?l00`3oool01000o`00oooo0?ooo`00o`040?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool00`00o`00oooo003o00080?ooo`050?l0003oool0oooo003o00000?l0103oool0
0`00o`00oooo0?ooo`030?ooo`030?l000000?l0oooo0100oooo00<0o`000?ooo`000?l00P3oool0
0`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0000o`3o00002@3oool2003o00h0oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00D0
o`00003o003oool0oooo0000o`070?ooo`030000o`3o0000oooo00T0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`090?ooo`030000o`00o`00oooo00T0oooo00<0o`000?ooo`00o`00
2`3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00@0003o003o003oool0o`001P3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`02
0?ooo`800?l00P3oool00`000?l0oooo0?l000060?ooo`040?l0003oool0oooo0000o`80oooo00<0
003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00P0003o0?ooo`3oool0
oooo0000o`3oool00?l00?l000T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`08
0?ooo`070?l0003oool0003o0?ooo`000?l0oooo0?l000170?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`00o`00103oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?oo
o`060?ooo`030?l00000o`00oooo00h0oooo00@0o`00003o003oool0003o1@3oool01000o`00oooo
0000o`3o000;0?ooo`030000o`3oool0oooo00T0oooo00@0o`00003o003oool0003o103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo003o00020000o`D0oooo00<0
o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?l000050?ooo`030000o`3oool0oooo00P0oooo00<0
o`00003o003oool02P000?l60?ooo`<0o`000`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo00@0003o0?ooo`3oool00?l02@3oool00`000?l0oooo0?ooo`040?ooo`04003o
00000?l0oooo0?l00080oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0o`000?ooo`090?oo
o`030000o`3o0000oooo00@0oooo00T0003o0?ooo`3oool0o`00003o003oool00?l00?ooo`3o0000
0P3oool00`000?l0oooo0?ooo`050?ooo`080000o`3oool0oooo003o003oool00?l00?ooo`000?l8
0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0o`000`3oool01@00o`00oooo0?oo
o`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool01P3o0000oooo0?ooo`3oool00?l00000
o`H0oooo0P00o`020?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0@0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o
000?0?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00@0oooo00<0o`000?ooo`000?l00`3oool01000o`00oooo0?ooo`00o`040?ooo`05
0000o`3oool0oooo0?ooo`3o00001@3oool01000o`00oooo0?ooo`00o`070?ooo`050?l0003oool0
0?l00?ooo`000?l0103oool00`00o`00oooo0?ooo`030?ooo`030?l000000?l0oooo00L0oooo00<0
0?l00?ooo`3oool01P3oool00`3o0000oooo0000o`020?ooo`03003o003oool0oooo00<0oooo00D0
0?l00?ooo`3oool0003o0?l000090?ooo`03003o003oool00?l000d0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00D0o`00003o003oool0
oooo0000o`070?ooo`030000o`3o0000oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool00?l02@3oool00`00
o`00o`000?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o003o003o0000203oool0103o
0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool00P3oool2
003o0080oooo00<0003o0?l0003oool01P3oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`080000o`3oool0oooo0?ooo`00
0?l0oooo003o003o00090?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`3oool0203oool0
1`3o0000oooo0000o`3oool0003o0?ooo`3o0000A`3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo003o00<0oooo00<0003o0?ooo`3oool0
2@3oool010000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool01P3oool00`3o0000oooo003o000>0?ooo`04003o003oool0oooo0000o`D0oooo00@00?l00?oo
o`000?l0o`002`3oool00`000?l0oooo0?ooo`090?ooo`040?l00000o`00oooo0000o`@0oooo00D0
003o003o003oool0oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`00o`000P000?l50?ooo`03
0?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001@3oool00`000?l0oooo0?ooo`080?ooo`04
0?l00000o`00oooo0000o`80oooo00<00?l00?ooo`3oool01P3oool40?l000H0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3o0000oooo003o00T0oooo00<0003o
0?ooo`3oool0103oool01000o`00003o0?ooo`3o00020?ooo`040?l0003oool0oooo0000o`D0oooo
00<0003o0?l0003oool02@3oool00`000?l0o`000?ooo`040?ooo`090000o`3oool0oooo0?l00000
o`00oooo003o003oool0o`000080oooo00<0003o0?ooo`3oool01@3oool020000?l0oooo0?ooo`00
o`00oooo003o003oool0003o203oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l0
00<0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0403o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00@0003o0?ooo`3oool0o`00
103oool01@000?l0oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool00P3oool010000?l0
oooo0?ooo`00o`050?ooo`03003o003oool0oooo00<0oooo00<0o`000000o`3oool00P3oool01@00
o`00oooo0?ooo`3oool00?l000D0oooo00<0003o0?ooo`3o00001P3oool01@00o`00oooo0?ooo`3o
ool00?l000H0oooo00@0o`000?ooo`00o`00003o1@3oool00`00o`00oooo0?ooo`030?ooo`030?l0
00000?l0oooo00L0oooo00<00?l00?ooo`3oool01P3oool00`3o0000003o0?ooo`020?ooo`03003o
003oool0oooo00<0oooo00D00?l00?ooo`3oool0003o0?l000090?ooo`03003o003oool00?l000d0
oooo00D0o`000?ooo`3oool0oooo003o000D0?ooo`030?l0003oool0oooo00<0oooo00D0o`00003o
003oool0oooo0000o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool00?l02@3o
ool00`00o`00oooo0?l000020?ooo`030000o`3oool0oooo00<0oooo00<0003o003o003o0000203o
ool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00H0oooo00L0o`000000o`3oool0
oooo003o003oool00?l00080oooo00<0003o0?l0003oool01P3oool0103o0000oooo0?ooo`000?l2
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00@0003o0?ooo`00o`00o`002@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
00000?l0oooo00P0oooo00L0o`000000o`3oool0oooo0000o`3oool0o`0004L0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool00?l0
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo
0000o`80oooo00<0o`000?ooo`3oool00`3oool00`00o`00o`000?ooo`060?ooo`040?l0003oool0
oooo003o00h0oooo00<00?l00?ooo`000?l01P3oool01000o`00oooo0000o`3o000;0?ooo`030000
o`3oool0oooo00T0oooo00@0o`00003o003oool0003o103oool01@000?l00?l00?ooo`3oool0o`00
00@0oooo00D0o`000?ooo`3oool00?l00?ooo`020000o`D0oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00P0oooo00@0o`00003o003oool0003o
0P3oool00`00o`00oooo0?ooo`030?ooo`<0o`002P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?l0003oool00?l02@3oool00`000?l0oooo0?ooo`040?ooo`04
003o00000?l0oooo0?l000<0oooo00<0o`000?ooo`000?l01@3oool00`000?l0o`000?ooo`090?oo
o`030000o`3o0000oooo00@0oooo00L0003o0?ooo`3oool0o`00003o003oool00?l00080oooo00<0
o`000?ooo`000?l0203oool01`000?l0oooo003o003oool00?l00?ooo`000?l0203oool00`3o0000
oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0
oooo00@0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool04@3oool010000?l0oooo0?ooo`3oool20000o`d0oooo00<00?l00?ooo`3oool0
1@3oool00`000?l0o`000?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00003P3oool00`3o0000
oooo0?ooo`020?ooo`040000o`3oool0oooo003o00D0oooo00<00?l00?ooo`3oool00`3oool00`3o
0000003o0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`001@3oool00`000?l0oooo0?l00005
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool0103o0000oooo003o0000
0?l50?ooo`03003o003oool0oooo00<0oooo00<0o`000000o`3oool01`3oool00`00o`00oooo0?oo
o`060?ooo`050?l000000?l0oooo0?ooo`00o`001P3oool01@00o`00oooo0?ooo`000?l0o`0000T0
oooo00<00?l00?ooo`00o`003P3oool0103o0000oooo0?ooo`00o`0D0?ooo`030?l0003oool0oooo
00<0oooo00D0o`000?ooo`00o`00oooo0000o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00D0o`00
0?ooo`3oool0oooo003o00080?ooo`03003o003oool0o`000080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l00?l00?l000080?ooo`070?l0003oool0003o0?ooo`000?l0oooo0?l000080?ooo`07
0?l000000?l0oooo0?ooo`00o`00oooo003o00020?ooo`030000o`3o0000oooo00H0oooo00@0o`00
0?ooo`00o`00003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool00?l000T0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0000o`080?ooo`070?l000000?l0oooo0?ooo`000?l0oooo0?l0000`0?oo
o`03003o003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool08P3oool01@000?l0oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool00P3oool20?l0
00@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3o00001P3oool0103o0000oooo0?ooo`00o`0>0?ooo`03003o003oool0003o00H0oooo00@0
0?l00?ooo`3oool0003o2P3oool20000o`/0oooo00@0o`00003o003oool0003o103oool01@000?l0
0?l00?ooo`3oool0o`0000@0oooo00L0o`000?ooo`3oool00?l00000o`3oool0003o00@0oooo00<0
o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l000000?l0oooo00P0oooo
00@0o`00003o003oool0003o0P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool00?l000T0
oooo00<0003o0?ooo`3oool0103oool01000o`00003o0?ooo`3o00030?ooo`030?l000000?l0oooo
00H0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`040?ooo`070000o`3oool0o`00
0?ooo`00o`00oooo003o00020?ooo`030?l000000?l0oooo00P0oooo00L0003o0?ooo`00o`00oooo
003o003oool0003o00P0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool00?l0
00<0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P00o`070?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0000oa00oooo00D0003o0?ooo`3oool0oooo
0000o`0E0?ooo`030000o`3oool0003o00l0oooo00<00?l00?ooo`3oool01@3oool00`000?l0o`00
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo
0?ooo`020?ooo`040000o`3oool0oooo003o00D0oooo00<00?l00?ooo`3oool00`3oool00`3o0000
003o0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`000?l0
oooo0?l000050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool0103o0000
0?l00?ooo`000?l50?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`000?l01P3oool00`00
o`00oooo003o00070?ooo`050?l000000?l0oooo0?ooo`00o`001P3oool01@00o`00oooo0?ooo`3o
ool0003o00T0oooo00<00?l00?ooo`00o`003P3oool0103o0000oooo0?ooo`00o`0C0?ooo`030?l0
003oool0oooo00@0oooo00D0o`000?ooo`00o`00oooo0000o`070?ooo`030?l000000?l0oooo00/0
oooo00D0o`000?ooo`3oool0oooo0000o`0<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool00`3oool2003o00H0oooo00<00?l00?ooo`3o00000P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`00o`00o`0000P0oooo00L0o`000?ooo`000?l0oooo0000o`3oool0o`0000P0oooo00D0
003o0?l0003oool0oooo003o00020?ooo`04003o003oool0003o0?l000L0oooo00@0o`000?ooo`00
o`00003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030000o`3oool00?l000T0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0000o`080?ooo`060?l000000?l0oooo0?ooo`000?l0o`00<03oool00`00o`00oooo
0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000803oool00`000?l0oooo0?oo
o`020?ooo`04003o003oool0oooo0000o`<0oooo0P3o00040?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3o00001@3oool00`00o`00oooo0?l000060?ooo`040?l0003oool0oooo003o00d0
oooo00@00?l00?l0003oool0003o1P3oool01000o`00oooo0?ooo`000?l:0?ooo`030000o`3oool0
003o00X0oooo00@00?l00?ooo`3oool0003o103oool010000?l00?l00?ooo`3o00050?ooo`050?l0
003oool0oooo003o00000?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<00?l00?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo00@0003o0?oo
o`3oool0o`001@3oool00`3o0000003o0?ooo`080?ooo`030?l00000o`00003o00<0oooo00<00?l0
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo003o00090?ooo`030000o`3oool0oooo00@0oooo00@00?l0
0000o`3oool0o`000`3oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?l0003oool0103oool010000?l0oooo0?l00000o`030?ooo`04003o003oool0oooo0000o`T0
oooo00H0003o0?ooo`00o`00oooo003o00000?l80?ooo`030?l0003oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo003o00030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo
0?ooo`020?ooo`030000o`00o`000?l000X0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l0403oool010000?l0oooo
0?ooo`000?lG0?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`00o`001P3oool00`000?l0
o`000?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`020?ooo`040000o`3oool0oooo003o00D0oooo00<00?l00?ooo`3oool00`3oool00`3o
0000003o0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00
0?l0oooo0?l000050?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool0103o
00000?l00?ooo`000?l60?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`000?l01P3oool0
0`00o`00oooo003o00070?ooo`050?l000000?l0oooo0?ooo`00o`001P3oool01@00o`00oooo0?oo
o`3oool0003o00P0oooo00@00?l00?ooo`3oool00?l03P3oool00`3o0000oooo003o000D0?ooo`03
0?l0003oool0oooo00D0oooo00@0o`00003o003oool0003o1`3oool00`3o0000003o0?ooo`0;0?oo
o`040?l0003oool0oooo0000o`d0oooo00<00?l00000o`3oool0203oool00`3o0000oooo0?ooo`05
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o00000P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`00o`00o`0000P0oooo00L0o`000?ooo`000?l0oooo0000o`3oool0o`0000P0oooo
00D0003o0?l0003oool0oooo003o00020?ooo`04003o003oool0003o0?l000L0oooo00@0o`000?oo
o`00o`00003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`040000o`3oool0o`00003o00P0oooo00<0003o0?ooo`3oool0
0P3oool0103o0000oooo0?ooo`000?l80?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3o
ool0;03oool2003o01@0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo00<0oooo00@00?l00?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`3o00030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o00001@3oool00`00o`00oooo0?l000060?oo
o`040?l0003oool0oooo003o00d0oooo00@00?l00?l0003oool0003o1P3oool01000o`00oooo0?oo
o`000?l:0?ooo`030000o`3oool0003o00X0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0
oooo0?l000050?ooo`050?l0003oool0oooo003o00000?l00P3oool01@000?l0oooo0?ooo`3oool0
o`0000T0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0080oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000003o0?ooo`080?ooo`030?l00000
o`00003o00@0oooo00D00?l00?ooo`3oool0oooo0?l0000=0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0o`00003o00080?ooo`030000o`3oool0oooo00D0oooo
00@00?l00000o`3oool0o`000`3oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3o00001@3oool010000?l0oooo0?l00000o`030?ooo`04003o003oool0oooo
0000o`T0oooo00<0003o0?ooo`00o`000P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`050000o`3oool0oooo0?ooo`3o0000
1@3oool01P3o0000oooo0?ooo`3oool0003o003o00/0oooo00<00?l00?ooo`3oool0203oool01000
0?l0oooo0?ooo`00o`0<0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l0403oool0
0`000?l0oooo0000o`0X0?ooo`03003o003oool00?l000H0oooo00D0003o0?l0003oool0oooo0000
o`070?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`00o`050?ooo`03003o003oool0oooo00<0oooo00D0o`000000o`3oool0oooo003o00050?ooo`03
003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`000?l01P3oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0003o00H0oooo00<00?l00?ooo`00o`001`3oool01@3o0000003o0?ooo`3oool00?l0
00L0oooo00@00?l00?ooo`3oool0003o203oool01000o`00oooo0?ooo`00o`0>0?ooo`030?l0003o
ool00?l001@0oooo00<0o`000?ooo`3oool01@3oool0103o00000?l00?ooo`000?l70?ooo`030?l0
003oool0003o00`0oooo00<0o`000?ooo`000?l03@3oool00`00o`00003o0?ooo`080?ooo`030?l0
003oool0oooo00H0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?l000020?ooo`030000
o`3oool0oooo00@0oooo00<0003o003o003oool01`3oool01`3o0000oooo0000o`3oool0003o0?oo
o`3o0000203oool01@000?l0o`000?ooo`3oool00?l00080oooo00@00?l00?ooo`000?l0o`00203o
ool00`3o00000?l00000o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0003o0?ooo`3o00000?l0203oool00`000?l0
oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`P0oooo00<0o`000000o`3oool00P3oool00`00
0?l0oooo0?ooo`0[0?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0003o0080
oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o0000oooo
00D0oooo00<00?l00?ooo`3o00001P3oool0103o0000oooo0?ooo`00o`0=0?ooo`04003o003o0000
oooo0000o`H0oooo00@00?l00?ooo`3oool0003o2P3oool00`000?l0oooo0000o`0:0?ooo`04003o
003oool0oooo0000o`D0oooo00<0003o003o003o00001@3oool01@3o0000oooo0?ooo`00o`00003o
0080oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`03003o003oool0oooo00@0oooo00<0003o
0?ooo`3oool0403oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000D0oooo00<0
o`000000o`3oool0203oool00`3o00000?l00000o`040?ooo`05003o003oool0oooo0?ooo`3o0000
3P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?l00000o`00
203oool00`000?l0oooo0?ooo`060?ooo`03003o00000?l0o`0000<0oooo00<0o`000000o`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0o`0000H0oooo00<0003o0?ooo`00o`00
0`3oool01@00o`00oooo0?ooo`000?l0o`0000P0oooo00<0003o003o003oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool00?l00`3oool01@00
0?l0oooo0?ooo`3oool0o`0000D0oooo00D0o`000?ooo`3oool0oooo0000o`0<0?ooo`03003o003o
ool0oooo00T0oooo00@0003o003o003oool00?l02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo0100oooo0P000?lW0?ooo`04003o003oool0oooo003o00H0oooo00D0003o0?l0003o
ool0oooo0000o`070?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool01000
0?l0oooo0?ooo`00o`050?ooo`03003o003oool0oooo00<0oooo00D0o`000000o`3oool0oooo003o
00050?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?oo
o`060?ooo`08003o003oool0oooo0?ooo`00o`00o`000?ooo`000?l60?ooo`05003o003oool0oooo
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool00?l000L0oooo00D0003o
0?l0003oool0oooo003o00070?ooo`04003o003oool0oooo0000o`P0oooo00D00?l00?ooo`3oool0
oooo003o000=0?ooo`030?l00000o`00oooo01@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0000o`080?ooo`030?l0003oool0003o00`0oooo00<0o`000?ooo`000?l0303oool00`00o`00
oooo0000o`090?ooo`030?l0003oool0oooo00L0oooo0P00o`001@3oool00?l00?ooo`3oool0o`00
0080oooo00<0003o0?ooo`3oool0103oool00`000?l00?l00?ooo`070?ooo`030?l0003oool0003o
0080oooo00<0003o0?ooo`3oool01`3oool01@000?l0o`000?ooo`3oool00?l00080oooo00@00?l0
0?ooo`000?l0o`00203oool00`3o00000?l00000o`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3o0000
oooo003o00070?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o203oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02X0oooo00<00?l00?ooo`3oool06@3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0
oooo00<00?l00?ooo`000?l00P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l01@3oool0
0`000?l0o`000?ooo`050?ooo`04003o003oool0oooo0?l000D0oooo00@0o`000?ooo`3oool00?l0
3@3oool01000o`00oooo0?l000000?l70?ooo`03003o003oool0003o00T0oooo00@0003o0?ooo`3o
ool0003o2P3oool01000o`00oooo0?ooo`000?l50?ooo`030000o`00o`00o`0000H0oooo00<0o`00
003o00000?l00`3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<00?l00?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`00
1@3oool00`3o0000003o0?ooo`080?ooo`030?l00000o`00003o00@0oooo00D00?l00?ooo`3oool0
oooo0?l0000>0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
0?l00?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<00?l00000o`3o0000103oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00001P3oool00`000?l0
oooo003o00030?ooo`05003o003oool0oooo0000o`3o0000203oool00`000?l00?l00?ooo`020?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`00o`04
0?ooo`040000o`3oool0oooo0?l000D0oooo00@0o`000?ooo`3oool0003o3P3oool00`00o`00oooo
0?ooo`080?ooo`050000o`00o`00oooo0?ooo`00o`002@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo0100oooo00<0003o0?ooo`3oool03P3oool50?l001<0oooo00D00?l00?ooo`3o
ool0oooo003o00050?ooo`040000o`3oool0oooo0000o`P0oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo003o00H0oooo00<00?l00?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`03003o003oool0oooo00L0oooo00L00?l00?ooo`3oool00?l00?l0003oool0003o
00H0oooo00D00?l00?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00@0oooo00<00?l0
0?ooo`00o`001`3oool01@000?l0o`000?ooo`3oool00?l000L0oooo00@00?l00?ooo`3oool0003o
203oool01@00o`00oooo0?ooo`3oool00?l000d0oooo00<0o`00003o003oool03`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l0203oool00`3o0000
oooo0000o`0=0?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`000?l02@3oool00`3o0000
oooo0?ooo`090?ooo`800?l00P3oool0103o0000oooo0?ooo`000?l60?ooo`030000o`00o`00oooo
00L0oooo00H0o`000?ooo`000?l00?l00?ooo`000?l90?ooo`050000o`3o0000oooo0?ooo`00o`00
0`3oool00`00o`00003o0?l000080?ooo`03003o00000?l0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@000?l0
o`000?ooo`3oool00?l000L0oooo00<0003o0?l0003oool00P3oool0103o0000oooo0?ooo`000?l8
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`0H
0?ooo`800?l0703oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo00D0oooo00D00?l00?ooo`000?l0oooo0?l000040?ooo`030?l000000?l0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000D0oooo00@0
o`000?ooo`3oool00?l0303oool01@00o`00oooo0?ooo`3o0000003o00L0oooo00<00?l00?ooo`00
0?l02@3oool010000?l0oooo0?ooo`000?l:0?ooo`03003o003oool0003o00H0oooo00<0003o003o
003o00001P3oool00`3o00000?l00000o`030?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool0
0`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo00D0003o0?ooo`3oool0oooo0000
o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000000o`3oool0203oool00`00o`00oooo0000
o`040?ooo`05003o003oool0oooo0?ooo`3o00003P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0003o003o003oool0203oool00`000?l0oooo0?ooo`060?ooo`03003o
00000?l0o`0000<0oooo00<0003o0?l0003oool01P3oool00`000?l0oooo0?ooo`070?ooo`040000
o`3oool0oooo0?l000D0oooo00<0003o0?ooo`00o`000`3oool01P00o`00oooo0?ooo`000?l0oooo
0?l000P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00L0oooo00@0
o`000?ooo`3oool00?l0103oool010000?l0oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000
o`h0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo
00H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0o`000?ooo`0P0?ooo`030?l0003oool0oooo
00<0oooo1@3o000>0?ooo`05003o003oool0oooo0?ooo`00o`001@3oool00`3o0000003o0000o`09
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo003o0006
0?ooo`03003o003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`06003o003o
ool00?l00?l0003oool0003o1P3oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0003o0?oo
o`3oool0103oool01000o`00oooo0?ooo`00o`060?ooo`050000o`3o0000oooo0?ooo`00o`001`3o
ool01@00o`00oooo0?ooo`3o0000003o00L0oooo00D00?l00?ooo`3oool0oooo003o000=0?ooo`03
0?l00000o`00oooo00h0oooo0P000?l40?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`00
0?l0203oool00`3o0000oooo0000o`0=0?ooo`030000o`3o0000oooo00/0oooo00<00?l00?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`0:0?ooo`04003o003oool0oooo0?l00080oooo00<0003o0?oo
o`3oool0103oool00`000?l00?l00?ooo`070?ooo`060?l000000?l0oooo003o003oool0003o2@3o
ool01@000?l0o`000?ooo`3oool00?l000<0oooo00<00?l00000o`3o0000203oool00`00o`00003o
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0003o0?l0003oool00P3oool00`00o`00oooo0?ooo`040?ooo`03
0000o`3o0000oooo0080oooo00@0o`000?ooo`3oool0003o203oool01P000?l0o`000?ooo`00o`00
oooo0000o`l0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`0L0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool0
1@00o`00oooo0000o`3oool0o`0000@0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?oo
o`040?ooo`05003o003oool0oooo0?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool00?l000/0
oooo00D00?l00?ooo`3oool0o`000000o`070?ooo`03003o003oool0003o00T0oooo00@0003o0?oo
o`3oool0003o2P3oool00`00o`00oooo0000o`060?ooo`030000o`00o`00o`0000H0oooo00<0o`00
003o00000?l00`3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<00?l00?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0?ooo`030?ooo`030?l000000?l0oooo00P0oooo00<00?l00?ooo`000?l0103oool01@00o`00oooo
0?ooo`3oool0o`0000h0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0000o`00o`00o`0000P0oooo00<0003o0?ooo`3oool01P3oool00`00o`00003o0?l000030?ooo`03
0000o`3o0000oooo00H0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00040?oo
o`040?l000000?l0oooo003o00<0oooo00H00?l00?ooo`3oool0003o0?ooo`3o00080?ooo`050000
o`3oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo003o
00@0oooo00@0003o0?ooo`3oool0o`001@3oool0103o0000oooo0?ooo`000?l?0?ooo`03003o003o
ool0oooo00L0oooo00<00?l00000o`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?l0003oool0803oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`030?l00000
0?l0003o00T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool00?l000H0oooo00<00?l00?ooo`3oool00P3oool01@000?l0o`000?ooo`3oool00?l000H0oooo
00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo
0P00o`00103oool0o`000?ooo`000?l60?ooo`05003o003oool0oooo0?ooo`3o00000P3oool00`00
0?l0oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00o`001P3oool010000?l0o`000?ooo`00
o`080?ooo`05003o003oool0oooo0?l000000?l01`3oool01@00o`00oooo0?ooo`3oool00?l000h0
oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`000?l01`3oool01@3o0000oooo0?ooo`3oool0003o00/0oooo00<0003o0?oo
o`3o0000303oool01000o`00oooo0?ooo`000?l70?ooo`030?l0003oool0oooo00h0oooo00@0o`00
0?ooo`3oool0003o1P3oool00`000?l00?l00?ooo`070?ooo`060?l000000?l00?l0003o003oool0
003o2@3oool010000?l0o`000?ooo`00o`040?ooo`03003o00000?l0o`0000P0oooo00<00?l00000
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030000o`3o0000oooo0080oooo00<00?l00?ooo`3oool0103oool0
0`000?l0o`000?ooo`020?ooo`040?l0003oool0oooo0000o`P0oooo00H0003o0?l0003oool00?l0
0?ooo`000?l?0?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool0703oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00L0oooo
00@00?l00000o`3oool0o`00103oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0oooo00@0
oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<00?l00?oo
o`3oool02@3oool01@00o`00oooo0?ooo`3o0000003o00L0oooo00<00?l00?ooo`000?l02@3oool0
10000?l0oooo0?ooo`000?l90?ooo`04003o003o0000oooo0000o`H0oooo00<0003o003o003o0000
1P3oool00`3o00000?l00000o`030?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00<0o`000000o`3oool0203oool00`00o`00003o0?ooo`040?oo
o`05003o003oool0oooo0?ooo`3o00003P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00H0oooo00<0003o003o003o0000203oool00`000?l0oooo0?ooo`060?ooo`03003o00000?l0
oooo00<0oooo00<0003o0?l0003oool01@3oool00`3o0000003o0?ooo`080?ooo`040000o`3oool0
oooo0?l000@0oooo00@0o`000000o`3oool00?l00`3oool01000o`00oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo00D0oooo00H0003o0?ooo`3oool0oooo0000o`00o`070?ooo`030?l0003oool0
oooo00L0oooo00@0o`000?ooo`3oool00?l0103oool010000?l0oooo0?ooo`3o00050?ooo`040?l0
003oool0oooo0000o`l0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`050?ooo`03
003o003oool0003o0080003o00<0oooo0?l0003oool02`3oool00`000?l0oooo0?l0000P0?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo0080oooo00<0o`000000o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`00o`001P3oool00`00o`00oooo0?ooo`020?ooo`04
0000o`3o0000oooo003o00L0oooo00H00?l00?ooo`3oool0oooo0?l000000?l40?ooo`03003o003o
ool0oooo00X0oooo00D00?l00?ooo`3o0000oooo0000o`060?ooo`05003o003oool0oooo0?ooo`3o
00000`3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`001@3oool01@00
0?l0oooo0?l0003oool00?l000P0oooo00D00?l00?ooo`3oool0o`000000o`060?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool02`3oool00`00o`00o`000?ooo`0<0?ooo`040000o`3o
ool0oooo0000o`<0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0000o`00o`060?ooo`05
0?l0003oool0oooo0?ooo`000?l02`3oool010000?l0oooo0?ooo`3o000;0?ooo`04003o003oool0
oooo0000o`L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0000o`070?ooo`030000o`00
o`00oooo00P0oooo00D0003o003o0000o`00oooo0000o`090?ooo`040000o`3o0000oooo003o00@0
oooo00<00?l00?ooo`000?l0203oool00`00o`00003o0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3o0000oooo00<0oooo00<00?l0
0?ooo`3oool00`3oool00`000?l0o`000?ooo`020?ooo`040?l0003oool0oooo0000o`L0oooo00P0
003o0?ooo`3o0000oooo003o003oool0o`000000o`h0oooo0P00o`0G0?ooo`03003o003oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000N0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?l0003oool0103oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0oooo00@0
oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<00?l00?oo
o`3oool0203oool01P00o`00oooo0?ooo`3oool0o`000000o`L0oooo00<00?l00?ooo`000?l0203o
ool01@000?l0oooo0?ooo`3oool0003o00T0oooo00@00?l00?l0003oool0003o1`3oool00`000?l0
0?l00?ooo`050?ooo`03003o00000?l0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?oo
o`05003o003oool0oooo0?ooo`000?l05@3oool010000?l0oooo0?ooo`000?l40?ooo`070?l0003o
ool0oooo0?ooo`3o0000oooo0000o`090?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3o
00003`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o003o003o
0000203oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003o
ool01@3oool00`3o0000003o0?ooo`080?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000000
o`00o`001@3oool00`00o`00oooo0000o`020?ooo`030?l0003oool0oooo00D0oooo00H0003o0?oo
o`3oool0003o0?ooo`00o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`00o`001@3o
ool010000?l0oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000oa00oooo00<00?l00?ooo`3o
ool01@3oool01000o`00oooo0?ooo`000?l20?ooo`@0003o0P3oool00`000?l0o`000?ooo`0<0?oo
o`030000o`3oool0o`0001l0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo003o00060?oo
o`03003o003oool0oooo0080oooo00@0003o0?l0003oool00?l0203oool01P00o`00oooo0?ooo`3o
0000oooo0000o`<0oooo00<00?l00?ooo`3oool0303oool00`3o0000003o0?ooo`060?ooo`05003o
003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`05003o003oool0oooo0?oo
o`00o`001@3oool01@000?l0oooo0?l0003oool00?l000P0oooo00D00?l00?ooo`3o0000oooo0000
o`060?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool00`00o`00o`000?oo
o`0;0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
00000?l00?l000H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`040000
o`3oool0oooo0?l000X0oooo00D00?l00?ooo`3oool0oooo0000o`070?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`000?l01`3oool00`000?l00?l00?ooo`080?ooo`060000o`00o`00oooo
003o003o0000003o203oool010000?l0o`000?ooo`00o`050?ooo`03003o00000?l0oooo00H0oooo
00<00?l00?l000000?l0103oool010000?l0oooo0?ooo`3o00060?ooo`040?l0003oool0oooo0000
o`@0oooo00<0003o0?l0003oool00`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3o0000oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`080000o`3oool0o`000?ooo`00o`00oooo
0?l000000?l=0?ooo`03003o003oool00?l001L0oooo00<00?l00?ooo`3oool06@3oool5000001T0
oooo000l0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0203oool00`00o`00003o
0?ooo`030?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`000?l01@3oool00`00o`00
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`00o`00oooo0?ooo`080?oo
o`06003o003oool0oooo0?ooo`3o0000003o1`3oool00`00o`00oooo0000o`080?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool01000o`00oooo0?l000000?l70?ooo`030000
o`00o`00oooo00D0oooo00<00?l00000o`3oool00`3oool010000?l0oooo0?ooo`3o000;0?ooo`05
003o003oool0oooo0?ooo`000?l05@3oool010000?l0oooo0?ooo`000?l40?ooo`070?l0003oool0
oooo0?ooo`3o0000oooo0000o`090?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3o0000
3`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00@0003o003o003oool0
o`001`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003o
ool01@3oool00`3o0000oooo0000o`080?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000000
o`00o`001@3oool00`00o`00003o0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00H0003o0?oo
o`3oool0003o0?ooo`00o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`00o`001@3o
ool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0003o0100oooo00<00?l00?ooo`3oool0
103oool01000o`00oooo0?ooo`3oool30000o`@0oooo00@00?l00?ooo`3oool0003o3@3oool01000
0?l0oooo0?ooo`3o000>0?ooo`<00?l03@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00L0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`00o`00
oooo00L0oooo00P00?l00?ooo`3oool0oooo0000o`3o0000oooo003o00P0oooo00H00?l00?ooo`3o
ool0o`000?ooo`000?l20?ooo`03003o003oool0oooo00d0oooo00<0o`000000o`3oool01`3oool0
1000o`00oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`020?ooo`050000o`3oool0o`000?ooo`00o`002@3oool01000o`00o`00
0?ooo`000?l60?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool00`00o`00
o`000?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`002@3oool00`3o
0000003o003o00060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00D00?l00?ooo`3oool0oooo0000o`07
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`000?l01`3oool00`000?l00?l00?ooo`08
0?ooo`060000o`00o`00oooo003o003o0000003o203oool010000?l0o`000?ooo`00o`050?ooo`03
003o00000?l0oooo00H0oooo00<00?l00?l000000?l0103oool010000?l0oooo0?ooo`3o00060?oo
o`040?l0003oool0oooo0000o`@0oooo00<0003o0?l0003oool00`3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`3o0000oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`080000o`3o
ool0o`00003o003oool00?l00?l000000?l=0?ooo`03003o003oool00?l001H0oooo00<00?l00?oo
o`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00@0o`000?ooo`3oool0003o103oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`3o0000103oool00`00o`00oooo0?ooo`080?ooo`06003o003oool0oooo0?ooo`3o0000
003o1`3oool01000o`00oooo0?l000000?l70?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01P3oool01000o`00oooo0?l000000?l70?ooo`030000o`00o`00oooo00D0oooo00<00?l0
0000o`3oool00`3oool010000?l0oooo0?ooo`3o000;0?ooo`04003o003oool0oooo0000oaH0oooo
00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3o
ool01P3oool00`00o`00003o0?ooo`050?ooo`03003o003oool0o`000100oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`060?ooo`040000o`00o`00oooo0?l000L0oooo00<0003o0?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0000o`080?ooo`040000o`3oool0oooo0?l000<0oooo00@0o`000?ooo`000?l00?l0
1@3oool00`00o`00003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo00L00?l00?ooo`000?l0
oooo0000o`3oool00?l000H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo003o00050?oo
o`030000o`3oool0o`0000L0oooo00<0o`000?ooo`000?l0403oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00X0oooo00<00?l00?ooo`000?l03@3oool010000?l0oooo0?ooo`3o000:
0?ooo`@00?l00`3oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`3o0000303o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0003o003o003oool01`3o
ool02000o`00oooo0?ooo`000?l0oooo0?l0003oool00?l0203oool01P00o`00oooo0?ooo`3o0000
oooo0000o`80oooo00<00?l00?ooo`3oool03@3oool00`3o0000003o0?ooo`070?ooo`04003o003o
ool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo0080oooo00D0003o0?ooo`3o0000oooo003o00090?ooo`05003o003o0000oooo0?oo
o`000?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00<00?l00?l0
003oool02@3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l000T0oooo00<0o`00
0000o`00o`001P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`05003o003oool0oooo0?ooo`000?l01`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0003o00L0oooo00<0003o003o003oool0203o
ool01P000?l0oooo0?ooo`00o`00o`000000o`P0oooo00@0003o0?l0003oool00?l01@3oool00`00
o`00003o0?ooo`060?ooo`03003o003o0000003o00@0oooo00@0003o0?ooo`3oool0o`001P3oool0
103o0000oooo0?ooo`000?l40?ooo`030000o`3o0000oooo00@0oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0o`000?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool020000?l0oooo
0?l00000o`00oooo003o003o0000003o3@3oool00`00o`00oooo003o000F0?ooo`03003o003oool0
oooo01h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00002
0?ooo`040?l0003oool0oooo0000o`<0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?oo
o`3o00040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o0000003o
0?ooo`060?ooo`04003o003oool0o`000000o`L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`04003o003oool0o`000000o`L0oooo00<0003o003o003oool01@3oool00`00
o`00003o0?ooo`030?ooo`040000o`3oool0oooo0?l000/0oooo00@00?l00?ooo`3oool0003o5P3o
ool00`000?l0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo
0?ooo`060?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3o0000403oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00001`3oool00`000?l0oooo
0?ooo`070?ooo`05003o00000?l0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0003o00P0oooo00@0003o0?ooo`3oool0o`000`3oool0103o0000oooo0000o`00o`05
0?ooo`03003o00000?l0oooo00D0oooo00/0o`000?ooo`3oool0oooo003o003oool0003o0?ooo`00
0?l0oooo003o00060?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00o`001@3oool00`00
0?l0oooo0?l000070?ooo`030?l0003oool0003o0140oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`0;0?ooo`03003o00000?l00?l000800?l02@3oool01@000?l0oooo0?ooo`3oool0
o`0000L0oooo0`00o`070?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00H0oooo00D00?l00?ooo`3oool0oooo0?l0
000<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000?l00?l00?oo
o`070?ooo`08003o003oool0oooo0000o`3oool0o`000?ooo`00o`090?ooo`05003o003oool0o`00
0?ooo`000?l00P3oool00`00o`00oooo0?ooo`0=0?ooo`030?l000000?l0oooo00L0oooo00@00?l0
0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool00P3oool01@000?l0oooo0?l0003oool00?l000T0oooo00D00?l00?l0003oool0
oooo0000o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool01000o`00
oooo0?ooo`3o00080?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`002@3oool0
0`3o0000003o003o00060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`000?l01`3oool0
0`000?l00?l00?ooo`070?ooo`070000o`00o`00oooo0?ooo`00o`00o`000000o`070?ooo`050000
o`3oool0o`000?ooo`00o`001@3oool00`00o`00003o0?ooo`060?ooo`03003o003o0000003o00@0
oooo00@0003o0?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3o0000
oooo00@0oooo00L00?l00?ooo`3oool0oooo0000o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0
oooo0000o`060?ooo`080000o`3oool0o`00003o003oool00?l00?l000000?l=0?ooo`03003o003o
ool00?l001D0oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00T0oooo00D0003o003o003oool0oooo0000
o`050?ooo`030?l0003oool0o`000080oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`040?l0
003oool0oooo0?l000@0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`03
0?l000000?l0oooo00L0oooo00<00?l00?l000000?l01P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00D00?l00?ooo`3oool0o`000000o`070?ooo`030000o`00o`00oooo
00@0oooo00<00?l00000o`3o0000103oool010000?l0oooo0?ooo`3o000;0?ooo`03003o003oool0
003o01L0oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0
003o0?ooo`3oool01P3oool00`00o`00003o0?ooo`050?ooo`03003o003oool0o`000100oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0o`0000L0oooo00<0
003o0?ooo`3oool01`3oool01@00o`00003o0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0000o`080?ooo`040000o`3oool0oooo0?l000<0oooo00@0o`000?ooo`00
0?l00?l01@3oool00`00o`00003o0?ooo`060?ooo`080?l0003oool0oooo003o003oool0003o0?oo
o`000?l20?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
003o00050?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`000?l04@3oool01@00o`00oooo
0?ooo`3oool00?l000h0oooo00<0o`000?ooo`000?l00P3oool5003o00@0oooo00D0003o0?ooo`3o
ool0oooo0?l000060?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool01000
o`00oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool0
0`000?l00?l00?ooo`070?ooo`07003o003oool0oooo0000o`3oool0o`00003o000:0?ooo`05003o
003oool0o`000?ooo`000?l00P3oool00`00o`00oooo0?ooo`0=0?ooo`030?l000000?l0oooo00L0
oooo00@00?l00?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<00?l0
0?ooo`3oool00P3oool01@000?l0oooo0?l0003oool00?l000T0oooo00D00?l00?l0003oool0oooo
0000o`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool01000o`00oooo
0?ooo`3o00070?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0o`002@3oool0103o
0000003o0?ooo`00o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`000?l01`3oool0
0`000?l0o`00003o00070?ooo`080000o`00o`00oooo0?ooo`00o`00o`000?ooo`000?l60?ooo`05
0000o`3oool0o`000?ooo`00o`001P3oool00`000?l0oooo0?ooo`050?ooo`03003o003o0000003o
00@0oooo00@0003o0?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3o
0000oooo00@0oooo00L00?l00?ooo`3oool0oooo0000o`3oool0o`0000<0oooo00D0o`000?ooo`3o
ool0oooo0000o`050?ooo`090000o`3oool0oooo0?l00000o`00oooo003o003o0000003o00d0oooo
00<00?l00?ooo`00o`005@3oool00`00o`00oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool02P3oool01@3o0000003o0?oo
o`3oool0003o00D0oooo0P3o00030?ooo`050000o`3oool0oooo0?ooo`00o`001P3oool0103o0000
oooo0?ooo`3o00040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000003o0?ooo`070?ooo`03003o003o0000003o00H0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`04003o003oool0oooo0000o`P0oooo00<0o`000000o`3oool0103oool0
0`00o`00003o0?l000040?ooo`040000o`3oool0oooo0?l000/0oooo00<00?l00?ooo`000?l05`3o
ool00`000?l0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo
0?ooo`060?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3o0000403oool01@000?l0oooo
0?ooo`3oool0003o00X0oooo00@0003o0?ooo`3oool0o`001P3oool00`000?l0oooo0?ooo`070?oo
o`05003o00000?l0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
003o00P0oooo00@0003o0?ooo`3oool0o`000P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo
00<00?l00000o`3oool01`3oool01`3o0000oooo003o003oool0003o0?ooo`000?l00P3oool00`00
o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00o`001@3oool00`00
0?l0oooo0?l000070?ooo`030?l0003oool0003o0180oooo00@00?l00?ooo`3oool00?l03@3oool0
103o0000oooo0?ooo`000?l70?ooo`05003o003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`030?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?l0000=0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`000?l00?l0
0?ooo`070?ooo`07003o003oool0oooo0000o`3oool0o`00003o000:0?ooo`07003o003oool0o`00
0?ooo`000?l0oooo003o000@0?ooo`030?l000000?l0oooo00L0oooo00@00?l00?ooo`3oool0o`00
0`3oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00D00?l00?ooo`3oool0oooo0000o`020?oo
o`030?l00000o`00oooo00T0oooo00D00?l00?l0003oool0oooo0000o`040?ooo`03003o003oool0
oooo00@0oooo00<00?l00?ooo`3oool02@3oool01000o`00oooo0?ooo`3o00050?ooo`80003o2@3o
ool010000?l0oooo0?ooo`3o00090?ooo`040?l000000?l0oooo003o00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0000o`080?ooo`030000o`00o`00oooo00H0oooo00P0003o003o003o
ool0oooo003o003o0000oooo0000o`H0oooo00D0003o0?ooo`3o0000oooo003o00050?ooo`030?l0
00000?l0oooo00D0oooo00<00?l00?ooo`000?l01@3oool010000?l0oooo0?ooo`3o00060?ooo`04
0?l0003oool0oooo0000o`@0oooo00<0003o0?l0003oool0103oool01`00o`00oooo0?ooo`3oool0
003o0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00X0003o0?ooo`3oool0
o`00003o003oool00?l00?l0003oool0003o303oool01000o`00oooo0?ooo`00o`0C0?ooo`03003o
003oool0oooo0200oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07`3o
ool00`000?l0oooo0?ooo`090?ooo`050?l0003oool0003o003o00000?l01`3oool01@3o0000oooo
0?ooo`3oool0003o0080oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?l000050?ooo`03
003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`3o0000003o0?ooo`070?ooo`03
003o003oool0003o00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`04
003o003oool0oooo0000o`P0oooo00<0o`000000o`00o`00103oool00`00o`00003o0?l000050?oo
o`030000o`3oool0o`0000/0oooo00<00?l00?ooo`000?l05`3oool00`000?l0oooo0000o`050?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0
o`0000L0oooo00<00?l00?ooo`3oool03`3oool01@000?l0oooo003o003oool0003o00X0oooo00@0
003o0?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`080?ooo`050?l000000?l0oooo0?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0003o00P0oooo00@0003o0?ooo`3o
ool0o`000P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<00?l00000o`3oool01`3oool0
1`3o0000oooo003o003oool0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`030?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`00o`001@3oool00`000?l0oooo0?l000070?ooo`030?l0
00000?l0oooo0180oooo00<00?l00?ooo`00o`00303oool20?l000@0oooo00<0003o0?ooo`3oool0
103oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0;0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool0503oool01@3o0000
oooo0?ooo`3oool00?l000X0oooo00<00?l00?ooo`3o00003@3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00D0oooo00<0003o003o003oool01`3oool01`00o`00oooo0?ooo`000?l0
oooo0?l00000o`002P3oool01`00o`00oooo0?l0003oool0003o0?ooo`00o`00403oool00`3o0000
003o0?ooo`070?ooo`03003o003oool0o`0000D0oooo00@0003o0?ooo`3oool00?l01P3oool01000
o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo00P0oooo00D00?l00?l0003oool0oooo0000
o`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?oo
o`3oool0o`000080oooo0P000?l;0?ooo`030000o`3oool0o`0000/0oooo00<0003o0?ooo`00o`00
103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0003o00P0oooo00<0003o003o003oool0
1P3oool020000?l0o`000?ooo`3oool0o`00003o003oool0003o1P3oool01@000?l0oooo0?l0003o
ool00?l000D0oooo00<0o`000000o`3oool01@3oool00`00o`00oooo0000o`050?ooo`040000o`3o
ool0oooo0?l000H0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`040?ooo`06
003o003oool0oooo0000o`3oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00L0003o0?ooo`3oool0o`00003o003oool00?l00080oooo00<0003o0?ooo`3oool0
2P3oool01000o`00oooo0?ooo`00o`0C0?ooo`03003o003oool0oooo0200oooo00<000000?ooo`3o
ool05`3oool003`0oooo1@00000M0?ooo`030000o`3oool0oooo00T0oooo00D0o`000?ooo`000?l0
oooo0000o`0<0?ooo`030000o`00o`00oooo00P0oooo0P3o00060?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0003o00H0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`04003o003oool0oooo0000
o`P0oooo00<0o`000000o`00o`00103oool00`00o`00003o0?l000050?ooo`030000o`3oool0o`00
00`0oooo00<0003o0?ooo`3oool05`3oool20000o`D0oooo00D0o`000?ooo`3oool0oooo0?l00002
0?ooo`030000o`3oool0oooo00D0oooo00<00?l00000o`3o00001`3oool00`00o`00oooo0?ooo`0?
0?ooo`050000o`3oool00?l00?ooo`000?l02P3oool010000?l0oooo0?ooo`3o00050?ooo`030000
o`3oool0oooo00P0oooo00D0o`000000o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0o`000080
oooo00<00?l00000o`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l00000o`00oooo0080
003o0`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00
o`001@3oool00`000?l0oooo0?l000070?ooo`030?l000000?l0oooo01<0oooo0P00o`0;0?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0000o`050?ooo`05
0?l0003oool0oooo0?ooo`00o`003`3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo
01@0oooo00D0o`000?ooo`3oool0oooo003o000;0?ooo`03003o003o0000oooo00`0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030000o`00o`00oooo00P0oooo00H00?l0
0000o`3oool0oooo0?l00000o`0;0?ooo`06003o003oool0oooo0?ooo`000?l00?l04@3oool00`00
0?l0oooo0?ooo`060?ooo`03003o003oool0o`0000D0oooo00@0003o0?ooo`3oool00?l01P3oool0
1000o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo00P0oooo00<00?l00?l0003oool00P3o
ool01@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo
0?ooo`3oool0o`000080003o3@3oool00`000?l0oooo0?l0000:0?ooo`040000o`3o0000oooo003o
00@0oooo00<0o`000?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00D0o`00
0?ooo`3oool0oooo003o00070?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0403o
ool00`3o0000003o0?ooo`070?ooo`030000o`00o`00oooo00H0oooo00P0003o0?l0003oool0oooo
0?l00000o`00oooo0000o`H0oooo00@0003o0?ooo`3o00000?l01P3oool00`3o0000003o0?ooo`05
0?ooo`03003o003oool0003o00D0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0000
o`060?ooo`030000o`3oool0oooo00@0oooo00H00?l00?ooo`3oool0003o0?ooo`3o00020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool01`000?l0oooo0?ooo`3o00000?l0
0?ooo`00o`000P3oool00`000?l0oooo0?ooo`0:0?ooo`04003o003oool0oooo003o0180oooo00<0
0?l00?ooo`3oool07@3oool5000001T0oooo000l0?ooo`030000003oool0oooo01l0oooo00<0003o
0?ooo`3oool02@3oool01P3o0000oooo0000o`3oool0003o003o00/0oooo00<0003o003o003oool0
203oool20?l000H0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`030?ooo`030000
o`3oool0oooo00L0oooo00<00?l00?ooo`000?l01@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00@00?l00?ooo`3oool0003o203oool00`3o0000003o003o00040?ooo`03
0000o`3oool0o`0000D0oooo00<0003o0?ooo`3o0000303oool00`000?l0oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo
00D0oooo00<00?l00000o`3o00001`3oool00`00o`00oooo0?ooo`0?0?ooo`050000o`3oool00?l0
0?ooo`000?l02P3oool010000?l0oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00P0oooo00@0
o`000000o`3oool0003o103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o00L0oooo
00<0003o0?ooo`3oool00P3oool20?l000<0oooo00<00?l00000o`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`04003o003oool0oooo0000o`<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool00?l000D0oooo00<0003o0?ooo`3o0000203oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`03003o00000?l0oooo00@0oooo00D0o`000?ooo`3oool0oooo003o000?0?oo
o`03003o003oool0oooo00<0o`00603oool0103o0000oooo0?ooo`00o`0;0?ooo`03003o003o0000
oooo00`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030000o`00o`00
oooo00P0oooo00<00?l00000o`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0
oooo0?ooo`000?l04P3oool00`000?l0oooo0?ooo`070?ooo`03003o003o0000oooo00@0oooo00@0
003o0?ooo`3oool00?l01P3oool01000o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo00T0
oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool01`3oool01000o`00oooo0?ooo`3oool20000o`l0oooo00<0003o0?ooo`3o00002P3oool0
1@000?l0o`000?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo003o
00000?l90?ooo`050?l0003oool0oooo0?ooo`00o`00203oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0100oooo00<0o`000000o`3oool01`3oool00`000?l00?l00?ooo`060?ooo`08
0000o`3oool0o`000?ooo`3o00000?l00?ooo`000?l60?ooo`040000o`3oool0o`00003o00H0oooo
00<0o`000000o`00o`001@3oool01000o`00oooo0000o`3o00040?ooo`040000o`3oool0oooo0?l0
00H0oooo00<0o`000?ooo`000?l01P3oool00`000?l0oooo0?ooo`040?ooo`04003o003oool0oooo
0000o`80oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0
oooo003o0080oooo00@00?l00?ooo`3oool0003o2`3oool01@00o`00oooo0?ooo`3oool00?l00180
oooo00<00?l00?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`0O0?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0003o0P3oool00`00o`00
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo0P3o00060?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0003o00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`05003o003oool0oooo0?oo
o`000?l0203oool00`3o0000003o003o00030?ooo`04003o00000?l0oooo0?l000D0oooo00<0003o
0?ooo`3o0000303oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo00@0oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00D0oooo00<00?l00000o`3o00001`3o
ool00`00o`00oooo0?ooo`0?0?ooo`050000o`3oool00?l00?ooo`000?l02P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0203oool0103o0000003o0?ooo`000?l40?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo0P3o00030?ooo`03003o00000?l0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
1@00o`00oooo0?l0003oool0003o00<0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool00?l000D0oooo00<0003o0?ooo`3o0000203oool00`000?l0oooo0?oo
o`0L0?ooo`80o`002@3oool00`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00D0oooo00<0
o`000?ooo`00o`003`3oool20?l00003003o003o0000oooo01/0oooo00<0o`00003o003oool02`3o
ool00`00o`00o`000?ooo`0=0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`06003o00000?l0oooo0?ooo`00o`00o`002`3oool01@00o`00
oooo0?ooo`3oool0003o0140oooo00<0003o0?l0003oool0203oool00`00o`00o`000?ooo`040?oo
o`040000o`3oool0oooo003o00H0oooo00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?oo
o`090?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo00L0oooo00@00?l00?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3o0000oooo00T0oooo00D0003o0?l0003oool0oooo003o00030?ooo`030?l0003oool0oooo
00T0oooo00<0003o003o00000?l02@3oool0103o0000oooo0?ooo`00o`090?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool0403oool00`3o0000003o0?ooo`070?ooo`030000o`00o`00
oooo00D0oooo00L0003o003o003oool0o`000?ooo`3o00000?l00080oooo00<0003o0?ooo`3oool0
0`3oool010000?l0oooo0?l00000o`060?ooo`030?l000000?l00?l000D0oooo00@00?l00?ooo`00
0?l0o`00103oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0003o00H0oooo00<0003o
0?ooo`3oool0103oool01000o`00oooo0?ooo`000?l20?ooo`030?l0003oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool02`000?l0oooo0?ooo`3oool00?l00?l0003oool0o`00003o003oool0
003o00/0oooo00D00?l00?ooo`3oool0oooo003o000A0?ooo`03003o003oool0oooo0280oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`3o0000003o0?ooo`0;
0?ooo`040?l0003oool0oooo0000o`<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00003o0?oo
o`0:0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`040?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`000?l01@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`080?ooo`030?l0
003oool0003o00<0oooo00@00?l00000o`3oool0o`001@3oool00`000?l0o`000?ooo`0<0?ooo`03
0000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo00<0003o0?ooo`3oool01@3oool00`00o`00003o0?l000070?ooo`03003o003oool0oooo
0100oooo00@0003o0?ooo`00o`00003o2P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool0203oool0103o0000003o0?ooo`000?l40?ooo`050?l0003oool0oooo0?ooo`3o
00000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`03
003o00000?l0oooo00@0oooo00<0003o003o003oool0203oool01@00o`00oooo0?ooo`3o0000003o
00@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l00000o`00oooo
00D0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01@3oool00`000?l00?l00?ooo`050?ooo`030?l00000o`00oooo
00`0oooo0`3o00030?ooo`03003o003oool0oooo01X0oooo00<0o`00003o003oool0303oool00`00
o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`06003o00000?l0oooo0?ooo`00o`00o`002`3oool01@00o`00oooo0?oo
o`3oool0003o0140oooo00<0003o0?l0003oool0203oool00`00o`00o`000?ooo`040?ooo`030000
o`3oool00?l000L0oooo00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?ooo`090?ooo`05
003o003oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo
00L0oooo00@00?l00?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o0000
oooo00T0oooo00D0003o0?l0003oool0oooo003o00020?ooo`030?l0003oool0oooo00X0oooo0P00
0?l00`3oool00?l00?ooo`080?ooo`030?l00000o`00oooo00T0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l000000?l0oooo00H0oooo00<0o`000000o`00o`001P3o
ool01`000?l0oooo0?ooo`3o0000oooo0?l00000o`000P3oool00`000?l0oooo0?ooo`030?ooo`04
0000o`3oool0o`00003o00H0oooo00<0o`000000o`00o`00103oool01@00o`00oooo0?ooo`000?l0
o`0000@0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0000o`060?ooo`030000o`3oool0
oooo00D0oooo00<00?l00?ooo`000?l00P3oool00`3o0000oooo0?l000050?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool01`00o`00o`000?ooo`3o00000?l00?ooo`000?l02`3oool01@00o`00
oooo0?ooo`3oool00?l00140oooo00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?oo
o`006`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000d0oooo00<000000?ooo`3o
ool07@3oool00`3o0000003o0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00oooo0000o`0;0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0o`00003o0000
0?l01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3o
ool0oooo0000o`080?ooo`040?l0003oool0003o003o0080oooo00@00?l00000o`3oool0o`001@3o
ool00`000?l0o`000?ooo`0<0?ooo`030000o`3oool0oooo01h0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`030000o`3oool0oooo00@0oooo00<00?l00000o`3o00001`3oool00`00o`00oooo
0?ooo`0@0?ooo`030000o`3oool0003o00X0oooo00<00?l00000o`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00@0o`00003o00000?l0003o103oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<00?l00000o`3oool0103oool00`000?l00?l00?ooo`080?oo
o`05003o003oool0oooo0?ooo`3o0000103oool01@00o`00oooo0?ooo`3oool0o`0000`0oooo00<0
0?l00?ooo`3oool01@3oool00`000?l0o`000?ooo`070?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool00?l000D0oooo00<0
0?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo01X0oooo00<0
0?l00?ooo`3oool0303oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`06003o00000?l0oooo0?ooo`00o`00
o`002`3oool01@3o00000?l00?ooo`00o`00003o0140oooo00<0003o0?l0003oool0203oool00`00
o`00o`000?ooo`040?ooo`030000o`3oool00?l000P0oooo00<00?l00000o`3oool00P3oool00`00
o`00o`000?ooo`0:0?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?ooo`06
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`000?l00`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3o0000oooo00T0oooo00D0003o0?l0003oool0oooo003o00020?ooo`030?l0003o
ool0oooo00X0oooo00D00?l00000o`3oool0oooo003o00080?ooo`030?l00000o`00oooo00T0oooo
00D0003o0?ooo`3oool0oooo0?l0000C0?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`00
o`001P3oool01`000?l0oooo0?ooo`3o0000oooo0?l00000o`000P3oool00`000?l0oooo0?ooo`03
0?ooo`040000o`3oool0oooo003o00H0oooo00<0o`000?ooo`000?l0103oool01@00o`00oooo0?oo
o`000?l0o`0000@0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0000o`060?ooo`030000
o`3oool0oooo00D0oooo00<00?l00?ooo`000?l00P3oool00`3o0000oooo0?l000050?ooo`050000
o`3oool0oooo0?ooo`000?l00`3oool01`00o`00o`000?ooo`3o00000?l00?ooo`000?l02`3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00d0oooo00<00?l00?ooo`3oool08`3oool0
0`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0M0?ooo`030?l0
00000?l0oooo00X0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`05003o
003oool0oooo0?ooo`000?l04@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00D0
oooo00<0003o0?ooo`3oool01`3oool0103o00000?l00?ooo`000?l40?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0003o00P0oooo00@0o`00
0?ooo`000?l00?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?l0003oool0
303oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool0
103oool00`00o`00003o0?l000060?ooo`030?l0003oool00?l00140oooo00<0003o0?ooo`000?l0
2P3oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
203oool0103o0000oooo0000o`000?l50?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<00?l00000
o`3oool0103oool00`000?l00?l00?ooo`080?ooo`03003o003oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo003o00030?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0o`000?ooo`070?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool00?l000D0oooo00<00?l00?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo01T0oooo00<00?l00?ooo`3oool0303oool0
0`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`060000o`00o`00oooo0?ooo`00o`00o`002`3oool01@3o00000?l0
0?ooo`00o`00003o0140oooo00<0003o0?l0003oool0203oool00`00o`00o`000?ooo`040?ooo`03
0000o`3oool00?l000P0oooo00<00?l00000o`3oool00P3oool00`00o`00o`000?ooo`090?ooo`03
0?l00000o`00oooo00<0oooo00<0003o0?ooo`00o`00203oool00`00o`00oooo0?ooo`060?ooo`04
003o003oool0oooo0000o`@0oooo00<0o`000?ooo`3oool0303oool00`000?l0o`000?ooo`090?oo
o`030000o`3o0000oooo0080oooo00<00?l00?ooo`3o0000303oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo00D0oooo00<00?l00?l0003oool02@3oool01@000?l0oooo0?ooo`3oool0
o`0001<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o003o00060?ooo`070000o`3oool0
oooo0?l0003oool0o`00003o00020?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0
0?l01P3oool0103o0000oooo0000o`00o`030?ooo`05003o003oool0oooo0000o`3o0000103oool0
0`000?l0oooo0?l000070?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool01@3oool0
0`00o`00oooo0000o`020?ooo`030?l0003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000
o`030?ooo`05003o003o0000oooo0?l00000o`000P3oool00`000?l0oooo0?ooo`080?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`0S0?ooo`030000
003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`L000006P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo00l0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00@0o`00003o003oool0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00<0oooo00D00?l00?ooo`3oool0003o0?l000070?ooo`080?l0003oool0oooo0000o`00o`00oooo
003o00000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?l0003oool02`3oool00`000?l0
0?l00?ooo`0P0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?l000060?ooo`030?l0003oool00?l00140oooo00<0003o0?ooo`000?l02P3oool00`00o`00
003o0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool0103o0000oooo0?ooo`000?l6
0?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`070?ooo`03003o00000?l0oooo00@0oooo00<0003o003o003oool0203oool00`00o`00oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o
003oool0oooo00D0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`00o`030?ooo`03
003o003oool0o`0000`0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0F0?ooo`80
0?l000<0oooo0?l0003oool02`3oool00`3o0000oooo003o000=0?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01@3oool00`00o`00003o0?ooo`080?ooo`060000o`00o`00oooo003o
003oool0o`002`3oool01P3o00000?l00?ooo`00o`00oooo0000oa00oooo00<0003o0?l0003oool0
203oool00`00o`00o`000?ooo`050?ooo`030000o`00o`00oooo00L0oooo00<00?l00000o`3oool0
0P3oool00`00o`00o`000?ooo`090?ooo`030?l00000o`00oooo00<0oooo00<0003o0?ooo`00o`00
203oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0003o00D0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`000080oooo00<00?l00?ooo`3o0000
2`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00D0oooo00<00?l00?l0003oool0
2@3oool01@000?l0oooo0?ooo`3oool0o`0001<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
003o003o00050?ooo`0;003o00000?l0oooo0?ooo`3o0000oooo0?l0003oool00?l00?ooo`000?l0
103oool01@000?l0oooo0?ooo`3oool00?l000H0oooo00@0o`000?ooo`000?l00?l00`3oool01@00
o`00oooo0000o`3oool0o`0000@0oooo00<0003o0?ooo`3o0000203oool00`3o0000003o0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`000?l00P3oool00`3o0000oooo0?l00005
0?ooo`040000o`3oool0oooo0000o`@0oooo00D00?l00?l0003oool0o`00003o00020?ooo`030000
o`3oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`03003o
003oool0oooo01h0oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo0?ooo`8000003@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo0100
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00@0o`00003o003oool0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0080oooo00L00?l00?ooo`3oool0oooo0000o`3oool0o`0000H0oooo00P0o`000?ooo`3oool0003o
003o003oool00?l00000o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`0;0?oo
o`030000o`00o`00oooo0200oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0o`0000H0oooo00<0o`000?ooo`00o`004@3oool00`000?l0oooo0000o`0:0?oo
o`03003o003oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`040?l0003oool0
oooo0000o`T00?l000D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00H0oooo
00<00?l00?ooo`000?l01@3oool00`000?l0oooo003o00080?ooo`03003o003oool0oooo00<0oooo
00@0o`000?ooo`3oool00?l00`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo00D0
oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool00?l00080
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo01@0
oooo0P00o`030?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`00o`003@3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<00?l00000o`3oool0203oool01P000?l0
0?l00?ooo`00o`00oooo0?l000/0oooo00H0o`00003o003oool00?l00?ooo`000?l@0?ooo`030000
o`3o0000oooo00P0oooo00<00?l00?l0003oool01@3oool00`000?l00?l00?ooo`070?ooo`03003o
00000?l0oooo0080oooo00<00?l00?l0003oool02@3oool00`3o00000?l00?ooo`030?ooo`030000
o`3oool00?l000P0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`050?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?l000030?ooo`03003o
003o0000oooo00X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0o`0000/0oooo00@0003o0?ooo`3oool0o`004`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l000000?l00?l000D0oooo00T00?l00000o`3oool0oooo0?l0003oool0o`000?ooo`00o`000P3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo
0000o`00o`030?ooo`05003o003oool0003o0?ooo`3o0000103oool00`000?l0oooo0?l000080?oo
o`030?l000000?l0oooo00@0oooo00<0o`000000o`3oool01`3oool01`00o`00003o0?ooo`3oool0
o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l40?ooo`05003o003o0000oooo0?l00000
o`000P3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool0303oool00`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool01@00o`00oooo0?ooo`3oool0
0?l000P0oooo00<0003o0?l0003oool01`3oool0103o00000?l00?ooo`000?l30?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool01`00o`00oooo0?ooo`3oool0003o0?ooo`3o
00001P3oool0203o0000oooo0?ooo`3oool0003o0?ooo`00o`00003o0`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3o0000oooo00/0oooo00<0003o0?ooo`00o`00803oool00`3o00000?l00?l0
00040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo003o
000A0?ooo`030000o`3oool0003o00X0oooo00<00?l00?ooo`000?l00`3oool01@3o0000oooo0?oo
o`3oool0003o00T0oooo00@0o`000?ooo`3oool0003o1P3oool0103o0000oooo0?ooo`00o`030?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool01000o`00oooo0?ooo`000?l4
0?ooo`030000o`3oool00?l000L0oooo00<00?l00?ooo`3oool0103oool01@3o0000oooo0?ooo`3o
ool00?l00080oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3o
0000oooo00L0oooo00<0003o0?l0003oool05@3oool20?l00180oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`03003o003oool00?l00080oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo0140oooo0P00o`050?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`00o`003@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00000o`3oool0203oool01P000?l00?l00?ooo`00o`00oooo0?l000X0
oooo00@0o`000?ooo`3oool00?l00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o0000oooo
00T0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`03003o00000?l0oooo
0080oooo00<00?l00?l0003oool02@3oool00`3o0000oooo003o00030?ooo`030000o`00o`00oooo
00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00003o0?ooo`060?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?l000030?ooo`03003o003o0000oooo
00X0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo
0?l000X0oooo00@0003o0?ooo`3oool0o`004`3oool00`000?l0oooo0?ooo`060?ooo`040?l0003o
ool0003o003o00@0oooo00T0003o0?ooo`3oool0oooo0?l0003oool0o`000?ooo`00o`000P3oool0
1@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0000
o`00o`020?ooo`06003o003oool0oooo0000o`3oool0o`00103oool00`000?l0oooo0?l000080?oo
o`030?l000000?l0oooo00@0oooo00<0o`000000o`3oool01`3oool01`00o`00003o0?ooo`3oool0
o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l40?ooo`05003o003o0000oooo0?l00000
o`000P3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo000K0?ooo`800000
2P3oool2000000@0oooo0`00000<0?ooo`030000003oool0oooo01d0oooo00<0003o0?l0003oool0
2P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo00D00?l00?ooo`3oool0
oooo003o00080?ooo`030000o`3o0000oooo00L0oooo00@0o`00003o003oool0003o0`3oool00`00
0?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`00o`000`3oool00`000?l0oooo0?l00006
0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?l0003oool02`3oool00`000?l0oooo003o000P0?ooo`030?l00000o`00o`0000@0oooo
00<0003o0?ooo`3oool00`3oool01000o`00003o0?ooo`3o00060?ooo`030?l0003oool00?l00100
oooo00D00?l00000o`3oool0003o003o00090?ooo`03003o003oool0003o00<0oooo00D0o`000?oo
o`3oool0oooo0000o`090?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0o`00003o
00020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool01000o`00oooo0?oo
o`000?l40?ooo`030000o`3oool00?l000L0oooo00<00?l00?ooo`3oool01@3oool0103o0000oooo
0?ooo`00o`020?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool01@3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3o0000oooo01@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l0000;0?oo
o`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool03P3oool2003o00L0oooo00<0o`000?oo
o`3oool02P3oool0103o0000oooo0?ooo`00o`0<0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`00o`00003o0?ooo`080?ooo`060000o`00o`00oooo003o003oool0o`00
2P3oool0103o0000oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00h0oooo00<0003o0?l0003o
ool02@3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00H0003o0?ooo`3o
ool0oooo003o003o000:0?ooo`030?l0003oool00?l000<0oooo00<0003o003o003oool02@3oool0
0`00o`00oooo0?ooo`050?ooo`03003o00000?l0oooo00H0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0o`0000<0oooo00<0o`00003o003oool02@3oool0
0`00o`00oooo0?ooo`070?ooo`04003o003oool0oooo003o00<0oooo00<0o`000?ooo`3oool0203o
ool010000?l0oooo0?ooo`3o000C0?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`000?l0
0?l0103oool02@000?l0oooo0?ooo`3oool0o`000?ooo`3o0000oooo003o00020?ooo`050000o`3o
ool0oooo0?ooo`000?l00P3oool00`00o`00o`000?ooo`050?ooo`070?l0003oool0003o0?ooo`00
o`00oooo003o00020?ooo`030000o`3oool0o`0000D0oooo00<0003o0?l0003oool01`3oool00`3o
0000003o0?ooo`040?ooo`030?l000000?l0oooo00L0oooo00L00?l00000o`3oool0oooo0?l0003o
ool0o`0000D0oooo00@0003o0?ooo`3oool0003o0`3oool01P00o`00oooo0?l0003oool0o`00003o
0080oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
00/0oooo00<00?l00?ooo`3oool09@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0M0?ooo`030000o`3oool0o`0000T0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0?0?ooo`05003o003oool0oooo0?ooo`00o`00203oool00`000?l0o`000?ooo`070?oo
o`040?l00000o`00oooo0000o`80oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`00
o`040?ooo`030000o`3oool0o`0000H0oooo00L0o`000?ooo`3oool0oooo0000o`00o`00003o00@0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`0;0?ooo`030000o`3oool00?l00200
oooo00<0o`00003o0000o`00103oool00`000?l0oooo0?ooo`030?ooo`04003o00000?l0oooo0?l0
00H0oooo00<0o`000?ooo`00o`00403oool01@00o`00oooo0000o`3oool00?l000T0oooo00<00?l0
0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool0203o
ool01`3o0000oooo0?l0003oool00?l00?ooo`000?l01P3oool00`000?l0oooo0?ooo`060?ooo`04
003o003oool0oooo0000o`@0oooo00<0003o0?ooo`00o`001`3oool00`00o`00oooo0?ooo`060?oo
o`030?l0003oool00?l00080oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000503oool00`3o0000oooo0?ooo`0D0?oo
o`050000o`3oool0oooo0?ooo`000?l02@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0
oooo00X0oooo00@0o`000?ooo`3oool00?l03@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00000o`3oool0203oool01P000?l00?l00?ooo`00o`00oooo0?l000X0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o0000oooo00P0
oooo00<0o`00003o003oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`00o`00oooo0080
oooo00<00?l00?ooo`3o00002@3oool00`3o0000oooo003o00040?ooo`030000o`3oool0oooo00P0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0000o`070?ooo`030?l0003oool0oooo00/0
oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?l000030?ooo`030?l00000o`00oooo00T0
oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo003o00040?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3o0000503oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0003o003o
00<0oooo00<00?l00000o`3oool00P3oool20?l00080oooo00@00?l00?ooo`3oool0003o0`3oool0
1@000?l0oooo0?ooo`00o`00o`0000H0oooo00L0o`000?ooo`000?l0oooo003o003oool00?l00080
oooo00<0003o0?ooo`3o00001@3oool00`000?l0o`000?ooo`070?ooo`030?l000000?l0oooo00@0
oooo00<0o`000000o`3oool01`3oool01`00o`00003o0?ooo`3oool0o`000?ooo`3o00001@3oool0
10000?l0oooo0?ooo`000?l30?ooo`09003o003oool0o`000?ooo`3o0000oooo003o003oool0003o
00T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo
02D0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`000?l0
oooo0?l000090?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool01000o`00
oooo0?ooo`00o`090?ooo`030000o`3o0000oooo00L0oooo00@0o`000?ooo`00o`00003o0P3oool0
0`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo003o00@0oooo00<0003o0?ooo`3o00001P3o
ool01`3o0000oooo0?ooo`3oool0003o003o00000?l0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3o0000oooo00/0oooo00<0003o0?ooo`00o`00803oool00`3o00000?l0003o00040?ooo`03
0000o`3oool0oooo00<0oooo00@00?l00000o`3oool0o`001@3oool01@3o0000oooo0?ooo`3oool0
0?l000l0oooo00D00?l00?ooo`000?l0oooo003o00090?ooo`03003o003oool0003o00<0oooo00D0
o`000?ooo`3oool0oooo0000o`090?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o0000
0P3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00@00?l00?ooo`3oool0
003o103oool00`000?l0oooo003o00070?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`00
o`000P3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?l0000C0?ooo`030?l0003oool0oooo01D0oooo00@0003o0?ooo`3o
ool0003o2`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<00?l00?oo
o`3oool02`3oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00@0o`000?oo
o`3oool00?l03@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<00?l0
0000o`3oool01`3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o0000oooo00P0oooo00<0
o`00003o003oool01@3oool00`000?l0oooo0?ooo`070?ooo`050000o`00o`00oooo0?ooo`00o`00
0P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool00?l000@0oooo00<0003o0?ooo`3oool0
203oool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo00P0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000003o0?ooo`080?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`00003o003o
ool02@3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?l0000D0?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`00
0?l00?l00`3oool00`00o`00003o0?ooo`030?ooo`040?l0003oool0oooo003o00<0oooo00@0003o
0?ooo`3oool0003o0P3oool00`00o`00o`000?ooo`050?ooo`070?l0003oool0003o0?ooo`00o`00
oooo003o00020?ooo`030000o`3oool0o`0000D0oooo00<0003o0?l0003oool01`3oool00`3o0000
003o0?ooo`040?ooo`030?l000000?l0oooo00L0oooo00L0003o003o003oool0oooo0?l0003oool0
o`0000D0oooo00<0003o0?ooo`000?l0103oool01`00o`00oooo0?l0003oool0o`000?ooo`00o`00
0P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0
2@3oool00`00o`00003o0?ooo`0V0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo01l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00l0oooo00@00?l00?ooo`3oool00?l02@3oool00`000?l0o`000?ooo`070?ooo`040?l0
003oool00?l00000o`80oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo003o00050?ooo`03
0000o`3oool0o`0000H0oooo00L0o`000?ooo`3oool0oooo0000o`00o`00003o00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool00?l00200oooo00<00?l0
0?ooo`00o`00103oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000D0oooo00D0
o`000?ooo`3oool0oooo003o000?0?ooo`05003o003oool0003o0?ooo`00o`002@3oool00`00o`00
oooo0000o`040?ooo`030?l0003oool0003o00X0oooo00<0o`000?ooo`3oool0203oool20?l000@0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`04003o003oool0oooo0000
o`<0oooo00@0003o0?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`070?ooo`050?l00000o`00
oooo0?ooo`3o0000303oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3o00004`3oool00`3o0000oooo0?ooo`0E0?ooo`040000o`3oool0oooo0000o`/0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo00X0oooo
00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`00
o`00303oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<00?l00000o`3o
ool01`3oool010000?l0oooo0?ooo`00o`030?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0o`0000T0oooo00<0o`00003o
003oool01@3oool00`000?l0oooo0?ooo`070?ooo`050000o`00o`00oooo0?ooo`00o`000P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool00?l000@0oooo00<0003o0?ooo`3oool0203oool0
0`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0000o`090?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`00o`00203o
ool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?l0003oool04`3o
ool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0003o003o00<0oooo00<00?l00000o`3oool0
0`3oool01@3o0000oooo0?ooo`3oool00?l00080oooo00@0003o0?ooo`3oool0003o0P3oool00`00
o`00o`000?ooo`050?ooo`070?l0003oool0003o0?ooo`00o`00oooo003o00020?ooo`030000o`3o
ool0o`0000D0oooo00<0003o0?l0003oool01`3oool00`3o0000003o0?ooo`040?ooo`030?l00000
0?l0oooo00L0oooo00@0003o003o003oool0oooo0P3o00060?ooo`030000o`3oool0003o00@0oooo
00L00?l00?ooo`3o0000oooo0?l0003oool00?l00080oooo00<0003o0?ooo`3oool01P3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0oooo00T0oooo0P000?lW0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`D000007@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool03`3oool01000o`00oooo0?ooo`00o`090?ooo`030000o`3o0000oooo
00L0oooo00@0o`000?ooo`00o`00003o0P3oool00`000?l0oooo0?ooo`080?ooo`030000o`00o`00
oooo00D0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0?ooo`0;0?ooo`030000o`3oool0
0?l00200oooo00<00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
oooo0?l000D0oooo00D0o`000?ooo`3oool0oooo003o000?0?ooo`05003o003oool0003o0?ooo`00
o`002@3oool00`00o`00oooo0000o`040?ooo`030?l0003oool0003o00X0oooo00<0o`000?ooo`3o
ool0203oool20?l000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`04
003o003oool0oooo0000o`<0oooo00@0003o0?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`08
0?ooo`030?l00000o`00o`0000d0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0o`000180oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0000o`0;
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`09
0?ooo`03003o003oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool01@3o0000oooo0?ooo`3o
ool00?l000`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03003o0000
0?l0oooo00L0oooo00@0003o0?ooo`3oool00?l00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00080?ooo`03
0?l00000o`00oooo00D0oooo00<00?l00000o`3oool01`3oool01@000?l0oooo003o003oool00?l0
0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo003o00030?ooo`03003o00000?l0oooo
00T0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`000?l02@3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`00
0?ooo`00o`00203oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?l0003oool04`3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0003o003o00<0oooo00<0
0?l00000o`3oool00`3oool01@3o0000oooo0?ooo`3oool00?l00080oooo00@0003o0?ooo`3oool0
003o0P3oool00`00o`00o`000?ooo`050?ooo`030?l0003oool0003o0080oooo00L00?l00?ooo`3o
ool0oooo0000o`3oool0o`0000D0oooo00<0003o0?l0003oool01`3oool00`3o0000003o0?ooo`04
0?ooo`030?l000000?l0oooo00L0oooo00<0003o003o003oool00P3oool00`3o0000oooo0?ooo`05
0?ooo`80003o103oool01000o`00oooo0?l0003o00020?ooo`04003o003oool0oooo0000o`P0oooo
00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`090?ooo`80003o8`3oool5000001T0oooo
000l0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`00o`002P3oool00`000?l0o`000?oo
o`070?ooo`060?l0003oool00?l00000o`3oool0003o2`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0o`0000H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`06
0?l0003oool0oooo0?ooo`3o0000003o303oool00`000?l0oooo003o000P0?ooo`04003o003oool0
o`00003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0o`000?ooo`3oool0oooo003o000?0?ooo`05003o003oool0oooo0?ooo`00o`002@3oool00`00
o`00oooo0000o`040?ooo`030?l0003oool0003o00X0oooo00<0o`000?ooo`3oool0203oool20?l0
00D0oooo00<0003o003o003oool00P3oool00`000?l0oooo0?ooo`070?ooo`04003o003oool0oooo
0000o`<0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o003oool0oooo00P0oooo00<0
o`00003o003o00003@3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3o00004P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0003o00/0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0
0?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
0?l00?ooo`000?l01`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000P0oooo
00<0o`00003o003oool0103oool00`00o`00oooo0000o`080?ooo`050000o`3oool00?l00?ooo`00
o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool00?l000<0oooo00<00?l00000o`3o
ool02P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0000o`090?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0103o
0000oooo0?ooo`00o`060?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0o`000?ooo`0C0?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`000?l00?l00P3o
ool00`00o`00003o0?ooo`040?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool010000?l0oooo
0?ooo`000?l20?ooo`03003o003o0000oooo00D0oooo00<0o`000?ooo`000?l00P3oool01`00o`00
oooo0?ooo`3oool0003o0?ooo`3o00001@3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0
oooo00@0oooo00<0o`000000o`3oool01`3oool00`000?l00?l00?ooo`020?ooo`030?l0003oool0
oooo00D0oooo0P000?l40?ooo`04003o003oool0oooo0?l00080oooo00@00?l00?ooo`3oool0003o
203oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo00<00?l00000o`000?l0
9`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0?0?ooo`800?l02@3o
ool00`000?l0oooo0?l000080?ooo`040?l0003oool00?l00?ooo`80003o2`3oool00`000?l0oooo
0?ooo`040?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`040?ooo`060?l0003oool0oooo0?ooo`3o0000003o2`3oool010000?l0oooo0?ooo`00
o`0P0?ooo`04003o003oool0o`00003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0o`000?ooo`3oool0oooo003o000>0?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`040?ooo`030?l0003oool0003o
00X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool00?l0
0080oooo00<0003o0?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00D0003o
0?ooo`3oool0oooo003o00050?ooo`03003o003oool0oooo00X0oooo00<00?l00?l0003oool02`3o
ool00`00o`00o`000?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00004@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0303o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`000?l01`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`00003o003oool0
103oool00`00o`00oooo0000o`080?ooo`050000o`3oool00?l00?ooo`00o`000P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool00?l000<0oooo00<00?l00?ooo`000?l02P3oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0000o`090?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000030?ooo`03003o003oool0
oooo00@0oooo00<00?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000
oooo01<0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0000o`00o`020?ooo`03003o0000
0?l0oooo00@0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`040000o`3oool0oooo0000o`80
oooo00<00?l00?l0003oool0103oool0103o0000oooo0?ooo`000?l20?ooo`04003o003oool0oooo
0000o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0
oooo00@0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo003o00020?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool01000o`00oooo0?ooo`3o00020?ooo`04003o003o
ool0oooo0000o`P0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`040000
o`3oool0oooo0000obH0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
803oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
3`3oool2003o00T0oooo00<0003o0?ooo`3o00001`3oool01@3o0000oooo0?ooo`00o`00oooo0080
003o2P3oool00`00o`00003o0?ooo`050?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?oo
o`3oool02@3oool01P3o0000oooo0?ooo`3oool0o`000000o`/0oooo00@0003o0?ooo`3oool00?l0
803oool01000o`00oooo0?l00000o`040?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`00o`003P3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`000?l0103oool00`3o0000oooo0000o`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool01P000?l0oooo0?ooo`00
o`00oooo0000o`P0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`050000o`3oool0oooo0?oo
o`00o`001@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003o0000oooo00/0oooo00<00?l00?l0
003oool01P3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l00100oooo00<0o`00
0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00d0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0003o00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00080?ooo`030?l0003oool00?l000@0oooo00<0
0?l00?ooo`000?l01`3oool01P000?l0oooo0?ooo`00o`00oooo003o0080oooo00<0o`000?ooo`3o
ool01`3oool0103o0000oooo0?ooo`00o`020?ooo`03003o003oool0003o00X0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`000?l02@3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o0000103oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o0?oo
o`0B0?ooo`030000o`3o0000oooo00L0oooo00@0o`000?ooo`000?l00?l00P3oool00`00o`00003o
0?ooo`080?ooo`07003o003oool0oooo0?ooo`000?l0oooo0000o`020?ooo`03003o003o0000oooo
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`000?l01`3o
ool00`000?l0oooo003o00020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
ool01@00o`00oooo0?ooo`3oool0o`000080oooo00@00?l00?ooo`3oool0003o203oool00`00o`00
oooo0?ooo`050?ooo`03003o003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o9P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0oooo00P0
oooo00<0003o0?ooo`3o00001`3oool01@3o0000oooo0?ooo`00o`00oooo0080003o2@3oool01000
o`00oooo0?ooo`000?l50?ooo`040000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool02P3o
ool01P3o0000oooo0?ooo`3oool0o`000000o`/0oooo00D0003o0?ooo`3oool0oooo003o000O0?oo
o`04003o003oool0o`00003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`040?ooo`030?l0003o
ool0003o00X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`060000o`3o
ool0oooo003o003oool0003o203oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00D0003o0?oo
o`3oool0oooo003o00050?ooo`03003o003oool0oooo00X0oooo00<00?l00?l0003oool02`3oool0
0`00o`00o`000?ooo`060?ooo`030?l000000?l0oooo00H0oooo00@0003o0?ooo`3oool0o`00403o
ool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04@3o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`070?ooo`03003o003oool0003o00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0303o
ool010000?l0oooo0?ooo`3o00080?ooo`030?l0003oool00?l000@0oooo00<00?l00?ooo`000?l0
1`3oool00`000?l0oooo0?ooo`02003o00<0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo
0?ooo`3oool00?l00080oooo00<00?l00?ooo`000?l02P3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0000o`090?ooo`07
0000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo0180oooo00<0003o
0?l0003oool01`3oool0103o0000oooo0000o`00o`020?ooo`03003o00000?l0oooo00P0oooo00@0
0?l00?ooo`3oool0oooo0P000?l20?ooo`03003o003oool0o`0000D0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`070?oo
o`030?l000000?l0oooo00@0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo003o00020?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0
o`000080oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool01P3oool01@00o`00003o0?ooo`3oool0003o02H0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`080?ooo`030000o`3o
ool0o`0000L0oooo00H0o`000?ooo`3oool00?l00?ooo`000?l90?ooo`05003o003oool0oooo0?oo
o`000?l01@3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo00X0oooo00H0o`00
0?ooo`3oool0oooo0?l000000?l;0?ooo`050000o`3oool0oooo0?ooo`00o`007`3oool01@00o`00
o`000?ooo`3oool00?l000<0oooo00H0003o0?ooo`3oool0oooo003o00000?l30?ooo`050?l0003o
ool0oooo0?ooo`3o00001@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool01P3oool01000o`00oooo0?ooo`000?l30?ooo`030?l0003oool0003o00X0
oooo00<0o`000?ooo`3oool03`3oool01P000?l0oooo0?ooo`3oool00?l00000o`P0oooo00<00?l0
0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l30?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0o`0000H0oooo00<0
o`000000o`3oool01P3oool010000?l0oooo0?ooo`3o000?0?ooo`030?l0003oool0oooo02P0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0A0?ooo`05003o003oool0oooo0?ooo`00
o`004@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`3o
ool0003o1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`00
0?ooo`00o`00103oool00`00o`00oooo0000o`070?ooo`050000o`3oool0oooo0?ooo`00o`000`3o
ool00`3o0000oooo0?ooo`060?ooo`070?l0003oool0oooo0?ooo`00o`00oooo003o00020?ooo`03
0000o`3oool0oooo00P0oooo00H00?l00?ooo`3oool0oooo0000o`00o`0=0?ooo`030?l0003oool0
oooo00L0oooo00@0o`000?ooo`3oool0003o203oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o
0000103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01D0oooo103o00040?ooo`03
0?l000000?l0oooo0180oooo00<0003o0?ooo`3o00001`3oool0103o0000oooo0000o`3oool2003o
00030?ooo`000?l0oooo00P0oooo00@00?l00?ooo`3oool0oooo0P000?l20?ooo`03003o003oool0
o`0000D0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`000?l0
1`3oool00`000?l0oooo003o00020?ooo`030?l0003oool0oooo00X0oooo00D00?l00?ooo`3oool0
oooo0?l000030?ooo`04003o003oool0oooo0000o`H0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l09P3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool5000001l0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3o00001`3oool01P3o0000oooo0?ooo`3oool0
0?l00000o`T0oooo00D00?l00?ooo`3oool0oooo0000o`050?ooo`040000o`3oool0oooo0?l000D0
oooo00<0o`000?ooo`3oool02P3oool01P3o0000oooo0?ooo`3oool0o`000000o`/0oooo00D0003o
0?ooo`3oool0oooo003o000O0?ooo`05003o003o0000oooo0?ooo`00o`000`3oool01@000?l0oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo
00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo
0?ooo`000?l00`3oool00`3o0000oooo0000o`0:0?ooo`030?l0003oool0oooo00l0oooo00H0003o
0?ooo`3oool0oooo003o00000?l80?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool0
003o0`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3o
ool02P3oool00`00o`00oooo0?l000060?ooo`030?l000000?l0oooo00H0oooo00@0003o0?ooo`3o
ool0o`003`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool04`3oool01000o`00oooo0?ooo`00o`0A0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool01P3oool01000o`00oooo0?ooo`000?l60?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00@0
003o0?ooo`3oool0o`00203oool00`3o0000oooo003o00040?ooo`03003o003oool0003o00L0oooo
00D0003o0?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo00H0oooo00L0o`000?ooo`3o
ool0oooo003o003oool00?l00080oooo00<0003o0?ooo`3oool0203oool01@00o`00oooo0?ooo`3o
ool0003o00h0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000D0oooo00D00?l00?ooo`3oool0oooo003o000K
0?ooo`D0o`0000<0oooo0000o`3oool04@3oool00`000?l0oooo0?l000070?ooo`040?l0003oool0
oooo0000o`800?l000<0oooo0000o`3oool02@3oool00`00o`00oooo0?ooo`020000o`80oooo00<0
0?l00?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0000o`070?ooo`040000o`3oool0oooo003o00h0oooo00D00?l00?ooo`3oool0oooo0?l00003
0?ooo`04003o003oool0oooo0000o`H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?oo
o`060?ooo`050000o`3oool0oooo0?ooo`000?l08P3oool5000001T0oooo000l0?ooo`030000003o
ool0oooo0240oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo01P0oooo00<0003o0?ooo`3o00001`3oool01P3o0000oooo0?ooo`3oool00?l00000o`P0
oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`3o0000oooo0?ooo`0:0?ooo`060?l0003oool0oooo0?ooo`3o0000003o2`3o
ool01@000?l0oooo0?ooo`3oool00?l001h0oooo00<00?l00?ooo`3o00000P3oool01@00o`00oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`00
00D0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
00D0oooo00D00?l00?ooo`3oool0oooo0000o`040?ooo`030?l000000?l0oooo00P0oooo00<0o`00
0?ooo`3oool0403oool01P000?l0oooo0?ooo`3oool00?l00000o`P0oooo00<00?l00?ooo`3oool0
0P3oool00`000?l0oooo0000o`040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
2`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0o`0000H0oooo00<0o`000000o`3oool0
1@3oool01@000?l0oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01<0oooo00<00?l00?ooo`00o`004P3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0203oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`3oool0003o1P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?l000L0oooo00@0o`000?ooo`3oool00?l00`3o
ool01@00o`00oooo0?ooo`3oool0003o00H0oooo00D0003o0?ooo`3oool0oooo003o00030?ooo`03
0?l0003oool0oooo00H0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l000<0oooo00<0003o
0?ooo`3oool01`3oool01@00o`00oooo0?ooo`000?l00?l000l0oooo00<0o`000?ooo`3oool01@3o
ool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool20?l000D0oooo
00@00?l00?ooo`3oool00?l08P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0o`0000L0
oooo00@0o`000?ooo`3oool0003o0P00o`000`000?l0oooo0?ooo`090?ooo`05003o003oool0oooo
0?ooo`000?l00P3oool00`00o`00oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0003o00L0oooo00@0003o0?ooo`3oool00?l03P3oool00`00o`00
oooo0?ooo`050?ooo`04003o003oool0oooo0000o`H0oooo00<00?l00?ooo`3oool01P3oool00`00
o`00oooo0?ooo`050?ooo`03003o00000?l0oooo0080oooo00<0003o0?ooo`3oool0903oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0o`0000L0
oooo00D0o`000?ooo`3oool0oooo003o00080?ooo`03003o003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool02P3oool0
1P3o0000oooo0?ooo`3o0000oooo0000o`/0oooo00D0003o0?ooo`3oool0oooo003o000N0?ooo`03
003o003oool0o`000080oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`000?l0103o
ool00`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`000?l01@3o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool02P3o
ool00`00o`00oooo0?l000060?ooo`030?l000000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo
0?l0000>0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0D0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`050?ooo`03003o003oool0oooo00P0oooo00@0o`000?ooo`3oool00?l00P3oool00`3o0000
oooo0?ooo`060?ooo`04003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool01000
0?l0oooo0?ooo`3o00070?ooo`040?l0003oool0oooo003o00<0oooo00D00?l00?ooo`3oool0oooo
0000o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool01`3o0000oooo
0?ooo`3oool00?l00?ooo`00o`000`3oool00`000?l0oooo0?ooo`080?ooo`04003o003oool0003o
003o00l0oooo103o00040?ooo`050?l0003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`00o`008P3oool00`000?l0oooo0?oo
o`0@0?ooo`030000o`3oool0o`0000L0oooo00@0o`000?ooo`3oool0003o0P00o`000`000?l0oooo
0?ooo`090?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`00o`00oooo0?l000050?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00L0oooo00@0003o
0?ooo`3oool00?l03P3oool00`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo0000o`H0oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?oo
o`0R0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0G0?ooo`030000o`3oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo003o00070?ooo`03003o
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?l0003oool0003o00/0oooo00D0003o0?oo
o`3oool0oooo003o000N0?ooo`03003o003oool0o`0000<0oooo00D00?l00?ooo`3oool0oooo0000
o`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`03003o
003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`05003o
003oool0oooo0?ooo`000?l0103oool00`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo0140
oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`03003o003oool0oooo00<0oooo00<0003o0?oo
o`000?l01@3oool01@00o`00oooo0?ooo`3oool00?l000h0oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?l000050?ooo`030?l0003oool0003o00H0oooo00D0003o0?ooo`3oool0oooo0?l0
000>0?ooo`030?l0003oool0oooo02X0oooo00D0o`000?ooo`3oool0oooo0?l0000/0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`070?ooo`040?l0
003oool00?l0003o0080oooo00<0o`000?ooo`3oool01P3oool01000o`00oooo0?ooo`000?l50?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`040?l0003oool0
oooo003o00<0oooo00D00?l00?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`00o`000`3oool00`00
0?l0oooo0?ooo`080?ooo`04003o00000?l0oooo003o01<0oooo1@3o00030?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0
0?l002<0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?l000070?ooo`070?l0003oool0
oooo0000o`00o`00oooo0000o`0;0?ooo`05003o003oool0oooo0?ooo`000?l00P3oool00`00o`00
oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0
003o00L0oooo00@0003o0?ooo`3oool00?l03P3oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo0000o`H0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo
003o00060?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo
0?l0003oool0003o00/0oooo00D0003o0?ooo`3oool0oooo003o000N0?ooo`03003o003oool0o`00
00<0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo0080oooo00@0o`00
0?ooo`3oool0o`001`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00<0o`000000o`3oool0
203oool00`3o0000oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`00o`00
oooo0?ooo`030?ooo`030000o`3oool0003o00D0oooo00D00?l00?ooo`3oool0oooo003o000>0?oo
o`03003o003oool0oooo00X0oooo00<00?l00?ooo`3o00001@3oool00`3o0000oooo0000o`060?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0/0?oo
o`040?l0003oool0oooo0?l002`0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`03003o003oool0oooo00L0oooo00@0o`00003o003oool00?l00P3oool00`3o0000oooo0?oo
o`060?ooo`04003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo
0?ooo`3oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`05003o003oool0oooo
0?ooo`000?l01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool2003o00<0oooo00<0003o0?ooo`3oool0203oool01000o`00003o0?ooo`00
o`0K0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`060?ooo`03003o003oool0oooo0280oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?l0
00070?ooo`070?l0003oool0oooo0000o`00o`00oooo0000o`0;0?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0003oool0103oool0
0`3o0000oooo0000o`070?ooo`050000o`3oool0oooo0?ooo`00o`00303oool00`00o`00oooo0?oo
o`060?ooo`05003o003oool0oooo0?ooo`000?l01@3oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo00<0oooo00<00?l00000o`3oool00`3oool00`000?l0oooo0?ooo`0T0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3o00001`3o
ool01@3o0000oooo0?ooo`3oool00?l000D0oooo00<00?l00?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`05
0?l0003oool0o`000?ooo`000?l02`3oool01@000?l0oooo0?ooo`3oool00?l001h0oooo00<00?l0
0?ooo`3o00000`3oool01@00o`00oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?ooo`3o00070?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`000?l0103oool00`3o0000
003o0?ooo`080?ooo`030?l0003oool0oooo0140oooo00H0003o0?ooo`3oool0oooo0000o`00o`06
0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3o
ool00?l000l0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?l000050?ooo`030?l0003o
ool0003o00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo02`0oooo00@0o`000?ooo`3oool0o`00;03oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<00?l00?ooo`3oool01P3oool01P3o00000?l00?ooo`00o`00oooo0?l0
00T0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0
oooo0?ooo`3o00001`3oool01@3o0000oooo0?ooo`3oool00?l00080oooo00D00?l00?ooo`3oool0
oooo0000o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`00o`00
003o003o000L0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0303oool00`00o`00
oooo0?ooo`0R0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3o00001P3oool01@3o0000
oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`040?oo
o`04003o003oool0oooo0?l000@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3o
ool0oooo0080oooo00H0o`000?ooo`3oool0oooo0?l000000?l90?ooo`030000o`3o0000oooo00<0
oooo00@0o`000?ooo`3oool0003o1`3oool01@000?l0oooo0?ooo`3oool00?l000`0oooo00<00?l0
0?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<00?l00?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0903o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0
o`0000L0oooo00D0o`000?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo00P0oooo00D0
003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
2`3oool01@3o0000oooo0?l0003oool0003o00X0oooo00<0003o0?ooo`3oool00P3oool00`00o`00
oooo0?ooo`0L0?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`020?oo
o`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`00203oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3o
ool0003o00@0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0A0?ooo`060000o`3o
ool0oooo0?ooo`000?l00?l01P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0003o00D0
oooo00D00?l00?ooo`3oool0oooo003o000?0?ooo`03003o003oool0oooo00T0oooo00<00?l00?oo
o`3o00001@3oool00`3o0000oooo0000o`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0o`0002d0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo00H0oooo00H00?l00?l0
003oool0oooo003o003o00090?ooo`04003o003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0
oooo003o00020?ooo`05003o003oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`00o`00703oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?l000060?oo
o`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool0
oooo00<0oooo00@00?l00?ooo`3oool0o`00103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00<0003o0?ooo`3oool00P3oool01P3o0000oooo0?ooo`3oool0o`000000o`T0oooo00<0003o0?l0
003oool00`3oool0103o0000oooo0?ooo`000?l70?ooo`050000o`3oool0oooo0?ooo`00o`00303o
ool00`00o`00oooo0?ooo`060?ooo`05003o003oool0oooo0?ooo`000?l0103oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D000008@3oool01@3o0000oooo0?oo
o`3oool0o`0001`0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?l000070?ooo`030?l0
003oool0oooo0080oooo00@00?l00?ooo`3oool00?l02`3oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`00
0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo
01/0oooo00<00?l00?ooo`3oool0103oool01`00o`00oooo0?ooo`000?l0oooo0000o`00o`00103o
ool0103o0000oooo0?ooo`3o00080?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`000?l0103oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo0140oooo00H0003o0?ooo`3oool0003o0?ooo`00o`06
0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3o
ool00?l000l0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?l000050?ooo`030?l0003o
ool0003o00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo02d0oooo00<0o`000?ooo`3o0000;@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?l000020?ooo`03003o003o
0000oooo00P0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`070?l0003oool0oooo0?ooo`00
o`00oooo003o00040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool00?l001d0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o00001P3oool01`3o
0000oooo0?ooo`3oool0003o0?ooo`000?l03@3oool00`00o`00oooo0?ooo`020?ooo`05003o003o
ool0oooo0?ooo`3o0000103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3o
ool00P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l0203oool00`000?l0o`000?ooo`03
0?ooo`040?l0003oool0oooo0000o`L0oooo00D0003o0?ooo`3oool0oooo003o000<0?ooo`03003o
003oool0oooo00L0oooo00@00?l00?ooo`3oool0003o103oool00`00o`00oooo0?ooo`080?ooo`03
003o003oool0oooo0080oooo00<00?l00000o`3oool01@3oool00`000?l0oooo0?ooo`0O0?ooo`D0
00006@3oool003`0oooo00<000000?ooo`3oool08`3oool01@3o0000oooo0?ooo`3oool0o`0001`0
oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?l000070?ooo`030?l0003oool0oooo0080
oooo00<00?l00?ooo`00o`00303oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0?l0000>0?ooo`030?l0003oool0o`000080oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo01X0oooo00<00?l00?ooo`3oool01@3oool0
1`00o`00oooo0?ooo`000?l0oooo0000o`00o`00103oool0103o0000oooo0?ooo`3o00080?ooo`03
003o003oool0oooo00L0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`05
003o003oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
0140oooo00@0003o0?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00<0oooo00<0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3oool00?l000l0oooo00<0
0?l00?ooo`3oool0203oool01000o`00oooo0?ooo`3o00050?ooo`030?l0003oool0003o00H0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo02h0oooo
0P3o000]0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo
0?ooo`030?ooo`04003o003oool0oooo0?l00080oooo00<00?l00?l0003oool0203oool01@00o`00
oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00@0oooo00L0o`000?ooo`3oool0oooo003o003oool00?l000D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool00?l0003o01d0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3o00001P3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l03@3oool00`00
o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o0000103oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00
0?l0203oool00`000?l0o`000?ooo`030?ooo`040?l0003oool0oooo0000o`H0oooo00<0003o0?oo
o`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00L0oooo00@00?l00?oo
o`3oool0003o103oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00<00?l0
0000o`3oool01@3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo02<0oooo00@0o`000?ooo`3oool0o`007P3oool00`000?l0oooo0?ooo`0D
0?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool2003o00d0oooo00D0
003o0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`3o00003P3oool00`3o0000
oooo0?l000020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`0J0?ooo`03003o003oool0oooo00D0oooo00H00?l00?ooo`3oool0003o0?ooo`000?l5
0?ooo`040?l0003oool0oooo0?l000T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?oo
o`070?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`040?ooo`030000
o`3o0000oooo00P0oooo00<0o`000?ooo`3oool04@3oool010000?l0oooo0?ooo`000?l20?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool20000o`H0oooo00<00?l00?ooo`00
o`00403oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo0?l000D0oooo00<0o`000?oo
o`000?l01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o00000P3oool0
0`00o`00o`000?ooo`080?ooo`05003o003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool01`3o0000oooo0?oo
o`3oool00?l00?ooo`00o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`00o`007P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03<0
oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00060?ooo`070?l0003oool0oooo
0?ooo`000?l0oooo0000o`0=0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo
0?l000040?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o103oool01`3o0000
oooo0?ooo`3oool0o`000?ooo`000?l0203oool00`000?l0o`000?ooo`030?ooo`040?l0003oool0
oooo0000o`H0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003o
ool0oooo00L0oooo00@00?l00?ooo`3oool0003o103oool00`00o`00oooo0?ooo`090?ooo`05003o
003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`030000003oool0oooo02<0oooo00@0o`000?ooo`3oool0o`007P3oool00`000?l0
oooo0?ooo`0D0?ooo`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3o
ool0o`0000h0oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo00<0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`060?ooo`05003o003o
ool0003o0?ooo`000?l01@3oool00`3o0000oooo0?l0000:0?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo
00H0003o0?ooo`3oool0oooo0000o`3o00090?ooo`030?l0003oool0oooo0140oooo00@0003o0?oo
o`3oool0003o0`3oool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<0003o0?ooo`3oool01@3o
ool00`00o`00oooo003o000A0?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0o`00
1@3oool00`3o0000oooo0000o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0:0?ooo`04003o003oool0oooo003o00@0oooo00D0o`000?ooo`3o
ool00?l00?l000090?ooo`05003o003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool01`3o0000oooo0?ooo`3o
ool00?l00?ooo`00o`001@3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool00?l07P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03<0oooo00<0003o0?oo
o`3oool0303oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo0080oooo0P000?l=
0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0003o1@3oool01P3o0000oooo0?ooo`3o0000oooo0000
o`P0oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l60?ooo`030000o`3oool0
oooo00<0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`070?ooo`05003o003oool0
oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo003o00000?l0
1`3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo02@0oooo00<0o`000?ooo`3o00007`3oool00`000?l0oooo0?ooo`0C0?ooo`040000o`3o
ool0oooo0?l000H0oooo00<0o`000?ooo`3oool04@3oool01@000?l0oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool0
0`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo01X0oooo00<00?l00?ooo`3oool01P3oool0
1@00o`00oooo0000o`3oool0003o00H0oooo0P3o000:0?ooo`03003o003oool0oooo00H0oooo00<0
0?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00H0
003o0?ooo`3oool0oooo0000o`3o00090?ooo`030?l0003oool0oooo0140oooo00@0003o0?ooo`3o
ool0003o0`3oool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<0003o0?ooo`3oool01@3oool0
0`00o`00oooo003o000A0?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0o`001@3o
ool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00L0oooo0P3o00050?ooo`030?l0003o
ool0oooo05l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`04003o003o
ool0oooo003o00@0oooo00D0o`000?ooo`3oool00?l00?l000080?ooo`03003o003oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool01`3o0000oooo0?ooo`3oool00?l00?ooo`00o`001@3oool01@000?l0oooo0?oo
o`3oool0003o00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00@0oooo00@0003o0?ooo`3oool00?l07P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00060?oo
o`030?l0003oool0oooo0080oooo0P000?l=0?ooo`03003o003oool0oooo0080oooo00D00?l00?oo
o`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0003o1@3o
ool01P3o0000oooo0?ooo`3o0000oooo0000o`P0oooo00<0003o0?l0003oool00`3oool01@3o0000
oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`070?oo
o`03003o003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`03003o003oool0
oooo00T0oooo00D00?l00?ooo`3oool00?l00000o`070?ooo`030000o`3oool0oooo02<0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?l0000O
0?ooo`030000o`3oool0oooo0180oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003o
ool0oooo0140oooo00@0003o0?ooo`3oool0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000l0
oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo00<0oooo00<00?l00?oo
o`3oool06P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080003o1P3oool20?l0
00/0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00P3oool01P000?l0oooo0?ooo`3oool0003o0?l000T0oooo00<0
o`000?ooo`3oool04@3oool010000?l0oooo0?ooo`000?l30?ooo`05003o003oool0oooo0?ooo`00
o`001`3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool00?l00140oooo00<00?l00?ooo`3o
ool01`3oool01000o`00oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o
0?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0o`000680oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0<0?ooo`800?l01@3oool01@3o0000oooo0?ooo`3oool00?l000P0oooo
00<00?l00?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`800?l01@3oool01@000?l0
oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`3o0006
0?ooo`030?l0003oool0oooo0080oooo0P000?l>0?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00@0003o0?ooo`3oool0003o1@3oool01P3o0000
oooo0?ooo`3o0000oooo0000o`P0oooo00<0003o0?l0003oool00`3oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo00P0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo00T0oooo
00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`D000008P3oool00`3o0000oooo0?l0000P0?ooo`030000o`3oool0oooo0140oooo
00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`00
0?l01@3oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00D0o`000?ooo`3oool0oooo0000o`09
0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool06P3oool00`00o`00oooo0?ooo`06
0?ooo`05003o003oool0oooo0000o`00o`001P3oool20?l000/0oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3o
ool01P000?l0oooo0?ooo`3oool0003o0?l000T0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0000o`040?ooo`04003o003oool0oooo003o00L0oooo00<0003o0?ooo`3oool01@3oool00`00
o`00oooo003o000A0?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0o`001@3oool0
103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0o`00
HP3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0
103oool01@3o0000oooo0?ooo`3o00000?l000P0oooo00<00?l00?ooo`3oool00P3oool010000?l0
oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`0:
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0d
0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00d0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool010000?l0oooo0?ooo`000?l50?ooo`060?l0003oool0oooo
0?l0003oool0003o203oool00`000?l0o`000?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0
1@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0
203oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool02@3oool01000o`00
oooo003o00000?l80?ooo`030000o`3oool0oooo01l0oooo1@00000I0?ooo`00?03oool00`000000
oooo0?ooo`0T0?ooo`030?l0003oool0o`000200oooo00<0003o0?ooo`3oool04@3oool01@000?l0
oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0000o`050?oo
o`050?l0003oool0oooo0?ooo`3o00003`3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0
003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool0oooo00L0oooo00@0
0?l00?ooo`000?l00?l01P3oool20?l000/0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool01P000?l0oooo
0?ooo`3oool0003o0?l000T0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0000o`040?oo
o`04003o003oool0oooo003o00L0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo003o000A
0?ooo`03003o003oool0oooo00L0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`040?l0003o
ool0oooo0000o`@0oooo00<0003o0?ooo`3oool02`3oool20?l006<0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0D0?ooo`040?l0003oool0o`00003o00P0oooo00<00?l00?ooo`3o
ool00P3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo0000o`0;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0o`001P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0000o`060?ooo`06
0?l0003oool0oooo0?l0003oool0003o203oool00`000?l0oooo0?l000030?ooo`050?l0003oool0
oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3oool02@3oool01`00o`00oooo0?ooo`3oool0003o0?ooo`00o`00303oool01000o`00
oooo003o00000?l80?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0100
oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`000?l01P3oool0103o0000oooo0?ooo`3o000?0?ooo`050?l0003oool0oooo0?ooo`000?l0203o
ool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo01X0oooo00<00?l00?ooo`3oool01`3o
ool01000o`00oooo0000o`00o`060?ooo`80o`002`3oool00`00o`00oooo0?ooo`040?ooo`03003o
003oool0oooo00T0oooo00D00?l00?ooo`3oool0oooo003o00050?ooo`060000o`3oool0oooo0?oo
o`000?l0o`00203oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o00@0oooo00@00?l0
0?ooo`3oool00?l03`3oool00`00o`00oooo003o000B0?ooo`03003o003oool0oooo00H0oooo00D0
0?l00?ooo`3oool0oooo0?l000040?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0503oool0103o0000oooo0?l00000o`080?ooo`03003o003oool0oooo0080oooo00@0003o0?oo
o`3oool0003o303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`050?ooo`040000o`3oool0oooo0000o`/0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`000?l0
903oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0
2P3oool010000?l0oooo0?ooo`3o00060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool03@3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D0o`000?ooo`3oool0oooo0?l00005
0?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030000o`3o
ool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`090?ooo`03003o003o
ool0oooo0080oooo00<0003o003o003oool0303oool00`00o`00003o0?ooo`090?ooo`030000o`3o
ool0oooo0280oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`0P0?ooo`D0003o3P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0000o`060?ooo`040?l0003oool0oooo0?l001<0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo01P0oooo
00<00?l00?ooo`3oool0203oool01000o`00oooo0000o`00o`060?ooo`030?l0003oool0oooo00/0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?oo
o`00o`001@3oool01P000?l0oooo0?ooo`3oool0003o0?l000P0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0000o`050?ooo`03003o003oool00?l00100oooo00<00?l00?ooo`3oool04@3o
ool00`00o`00oooo0?ooo`060?ooo`05003o003oool0oooo0?ooo`3o0000103oool0103o0000oooo
0?ooo`000?l40?ooo`030000o`3oool0oooo0740oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0D0?ooo`040?l0003oool0o`00003o00P0oooo00<00?l00?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0003o00`0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`000?l0903oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?oo
o`3o00060?ooo`030?l0003oool0oooo0180oooo00@00?l00?ooo`3oool00?l0103oool01@3o0000
oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?l000020?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0
003o00D0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`03003o00000?l0
oooo00T0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo02D0oooo1@000?l90?ooo`050000o`3oool0oooo
0?ooo`3o00001@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o00H0oooo00@0o`00
0?ooo`3oool0o`004`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
0?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo003o00H0oooo
00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo
00D00?l00?ooo`3oool0oooo003o00050?ooo`060000o`3oool0oooo0?ooo`000?l0o`00203oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o00D0oooo0P00o`0A0?ooo`03003o003oool0
oooo0140oooo00<00?l00?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool0o`0000<0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0740oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0D0?ooo`040?l0003oool0o`00003o00P0oooo00<00?l00?ooo`3o
ool00P3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0003o00`0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000obD0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo00X0oooo00D0003o
0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo0180oooo00@00?l00?ooo`3oool00?l0
103oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`000?l01P3oool00`3o0000
oooo0?l000020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00000`3oool01@3o0000
oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`060?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00003o0000o`0;0?oo
o`03003o00000?l0oooo00T0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?oo
o`008@3oool2000000@0oooo0P0000050?ooo`<000002`3oool00`000000oooo0?ooo`1A0?ooo`03
0000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`000?l01P3oool0103o0000oooo0?ooo`3o000C0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0H0?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool00?l000D0oooo00@0
003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?ooo`000?l01@3oool2003o0140oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo
0?ooo`060?ooo`05003o003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00<0003o0?ooo`3oool0L@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
01@0oooo00D0o`000?ooo`3o0000oooo003o00070?ooo`03003o003oool0oooo0080oooo00<0003o
0?ooo`000?l03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0000o`0<0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool02`3oool010000?l0oooo0?ooo`000?lU0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o0000
1@3oool00`3o0000oooo0?ooo`0B0?ooo`04003o003oool0oooo003o00@0oooo00D0o`000?ooo`3o
ool0oooo0?l000050?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o00000P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0000o`05
0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:
0?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0003o2P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool05`3oool00200oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0580oooo00<0
003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0o`0001@0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool0
2@3oool2003o00L0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00T0oooo00D00?l00?ooo`3oool0oooo003o00050?ooo`040000o`3oool0oooo0000
o`80oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0003o
00H0oooo00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1a0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0503oool01@3o0000oooo0?l0003oool00?l000L0oooo00<00?l00?ooo`3oool00`3o
ool20000o`d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`000?l0303oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`000?l09P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo03L0oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo
00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o00040?ooo`050?l0003oool0oooo0?ooo`3o
00001@3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0o`000080oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`00
0?l0oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool02P3oool00`00
o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`000?l0203oool20000o`/0oooo00<0003o
0?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`000008
0?ooo`D000002`3oool7000004h0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3o
ool0o`0000D0oooo00<0o`000?ooo`3oool04`3oool20000o`L0oooo00<0o`000?ooo`3o00005@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool0603o
ool00`00o`00oooo0?ooo`090?ooo`800?l05P3oool01@00o`00oooo0?ooo`3oool00?l000`0oooo
00D00?l00?ooo`3oool0oooo003o00050?ooo`040000o`3oool0oooo0000o`80oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0C0?ooo`80003o1`3oool00`00o`00oooo0?ooo`0T0?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1a0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool05@3oool01@3o0000oooo0?l0003oool00?l000L0oooo00<0
0?l00?ooo`3oool00`3oool20000o`d0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`000?l0303oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00`0oooo0P000?lV0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
=`3oool00`000?l0oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000
oooo0?ooo`0C0?ooo`03003o003oool00?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0
oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool40000o`d0oooo00<0
003o0?ooo`3oool0703oool7000001T0oooo000P0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo00D0oooo
00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo00T0oooo0P00o`0F0?ooo`05
003o003oool0oooo0?ooo`00o`003@3oool01000o`00oooo0?ooo`00o`060?ooo`030000o`3oool0
003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0C0?ooo`80003o;P3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0L@3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo01D0oooo0P3o00020?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool00`3oool20000o`d0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`000?l0303oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo03P0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o00040?ooo`050?l0
003oool0oooo0?ooo`3o00001P3oool20000o`H0oooo00<0o`000?ooo`3o00000P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0000o`050?oo
o`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool30000oa40oooo00<0003o0?oo
o`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000090?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`050?oo
o`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3o00005@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0
oooo01D0oooo00@00?l00?ooo`3oool00?l03@3oool01000o`00oooo0?ooo`00o`060?ooo`030000
o`3oool0003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo02`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o07@0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0F0?ooo`040?l0003oool0oooo003o00L0oooo00<00?l0
0?ooo`3oool00`3oool20000o`d0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`050000o`3o
ool0oooo0?ooo`000?l02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03P0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o00040?ooo`050?l0003oool0oooo0?ooo`3o
00001P3oool20000o`H0oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0o`000080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`05
003o003oool0oooo0?ooo`00o`006P3oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo
01L0oooo000Q0?ooo`8000002`3oool2000000`0oooo00<000000?ooo`3oool0E03oool00`000?l0
oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00005@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`0;0?oo
o`03003o003oool0oooo01D0oooo00@00?l00?ooo`3oool00?l03@3oool01000o`00oooo0?ooo`00
o`060?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo02`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o07D0
oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`040?l0003oool0oooo003o00H0oooo00<00?l0
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00003P3o
ool01@000?l0oooo0?ooo`3oool0003o00/0oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0f0?ooo`05
0000o`3oool0oooo0?ooo`000?l0>`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool00?l0
00@0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`000080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`05003o003oool0oooo0?ooo`00o`006P3o
ool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo05@0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0001D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo01L0oooo00<0
0?l00?ooo`3oool08`3oool01000o`00oooo0?ooo`00o`0=0?ooo`04003o003oool0oooo003o00H0
oooo00<0003o0?ooo`000?l00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool0;03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`000?l0M@3oool0
1@3o0000oooo0?ooo`3oool0o`0001P0oooo00@0o`000?ooo`3oool00?l01P3oool00`00o`00oooo
0?ooo`040?ooo`030000o`3oool0oooo00d0oooo00@0o`000?ooo`3oool0o`003P3oool010000?l0
oooo0?ooo`000?l<0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0=P3oool01@000?l0oooo0?ooo`3o
ool0003o03/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool2003o00H0oooo00@0o`000?ooo`3oool0o`00
1P3oool00`000?l0oooo0?ooo`060?ooo`80o`000`3oool00`000?l0oooo0?ooo`040?ooo`040000
o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00P0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0;0?ooo`05
003o003oool0oooo0?ooo`00o`006`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?l0000E0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`0G0?oo
o`03003o003oool0oooo02@0oooo00<00?l00?ooo`00o`003@3oool01000o`00oooo0?ooo`00o`06
0?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02d0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o07D0oooo
00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`050?l0003oool0oooo0?ooo`00o`001@3oool00`00
o`00oooo0?ooo`040?ooo`030000o`3oool0oooo00d0oooo00@0o`000?ooo`3oool0o`003P3oool0
10000?l0oooo0?ooo`000?l<0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00`000?l0oooo
0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool01@000?l0oooo0?ooo`3oool0003o
03`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo
0?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00@0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00/0oooo00D00?l00?ooo`3oool0oooo003o000K0?ooo`030000o`3oool0oooo0240oooo
00<000000?ooo`3oool05`3oool003`0oooo1@00001C0?ooo`030000o`3oool0oooo00<0oooo00D0
003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3o0000
5@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool0
5P3oool00`00o`00oooo0?ooo`0T0?ooo`800?l03P3oool01000o`00oooo0?ooo`00o`060?ooo`03
0000o`3oool0003o00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo02d0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`000?me0?ooo`050?l0003oool0
oooo0?ooo`3o0000703oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01@0oooo00@0
o`000?ooo`3oool0o`003P3oool010000?l0oooo0?ooo`000?l<0?ooo`050?l0003oool0oooo0?oo
o`3o00007P3oool01@3o0000oooo0?ooo`3oool0o`0003P0oooo00@0003o0?ooo`3oool0003o?@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0000o`0;0?ooo`05003o003oool0oooo0?ooo`00o`003P3oool01@00o`00oooo0?ooo`3o
ool00?l001/0oooo00<0003o0?ooo`3oool07@3oool5000001T0oooo000l0?ooo`030000003oool0
oooo05H0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0
o`000?ooo`3oool0703oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo02@0oooo0P00
o`0?0?ooo`03003o003oool00?l000H0oooo00<0003o0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo04@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`000?me0?ooo`05
0?l0003oool0oooo0?ooo`3o0000703oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
01@0oooo00@0o`000?ooo`3oool0o`003`3oool20000o`d0oooo00D0o`000?ooo`3oool0oooo0?l0
000N0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool010000?l0oooo0?ooo`000?ln0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo01D0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?ooo`3o00060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0003o00/0oooo00D00?l00?ooo`3oool0oooo003o000>0?ooo`05003o003oool0oooo0?ooo`00
o`006`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo05H0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool07@3oool20?l001D0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`070?ooo`03003o003oool0oooo01H0oooo00<00?l00?ooo`3oool09@3oool00`00o`00
oooo0?ooo`0=0?ooo`03003o003oool00?l000H0oooo00<0003o0?ooo`000?l00`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo04@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000@0oooo00@0003o0?ooo`3oool0003oM@3oool0
1@3o0000oooo0?ooo`3oool0o`0001`0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`0D0?ooo`030?l0003oool0o`000100oooo0P000?l=0?ooo`050?l0003oool0oooo0?ooo`3o0000
7P3oool01@3o0000oooo0?ooo`3oool0o`0003P0oooo00@0003o0?ooo`3oool0003o?P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0E0?ooo`03003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`003`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0?l0
003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`04003o003oool0oooo003o
00h0oooo00D00?l00?ooo`3oool0oooo003o000K0?ooo`030000o`3oool0oooo0240oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E`3oool010000?l0oooo0?ooo`000?l5
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0F
0?ooo`03003o003oool0oooo02D0oooo00<00?l00?ooo`3oool03@3oool2003o00L0oooo00<0003o
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo04D0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000@0oooo00@0
003o0?ooo`3oool0003oM@3oool0103o0000oooo0?ooo`3o000M0?ooo`03003o003oool0oooo00<0
oooo00<00?l00?ooo`3oool0503oool00`3o0000oooo0?l0000@0?ooo`030000o`3oool0oooo00`0
oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool0
10000?l0oooo0?ooo`000?lo0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3o0000403o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`04003o003oool0oooo
003o00h0oooo00D00?l00?ooo`3oool0oooo003o000K0?ooo`030000o`3oool0oooo0240oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0E`3oool010000?l0oooo0?ooo`00
0?l50?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?oo
o`0F0?ooo`03003o003oool0oooo03D0oooo0P00o`070?ooo`030000o`3oool0003o00<0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`160?ooo`05003o003oool0oooo0?ooo`00o`00
1P3oool00`3o0000oooo0?l000050?ooo`040000o`3oool0oooo0000ogD0oooo00@0o`000?ooo`3o
ool0o`007@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01@0oooo00<0o`000?oo
o`3o0000403oool00`000?l0oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00007P3oool0
1@3o0000oooo0?ooo`3oool0o`0003P0oooo00@0003o0?ooo`3oool0003o?`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0L0?ooo`030?l0003oool0o`000100oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000050?ooo`050000o`3oool0oooo
0?ooo`000?l0303oool01000o`00oooo0?ooo`00o`0?0?ooo`03003o003oool00?l001`0oooo00<0
003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1H
0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0M
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`07
0?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool0=P3oool2003o00L0oooo0P000?l4
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0AP3oool01@00o`00oooo0?ooo`3o
ool00?l000H0oooo00<0o`000?ooo`3o00001@3oool010000?l0oooo0?ooo`000?mf0?ooo`030?l0
003oool0o`0001h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0
003oool0o`0001l0oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`050?l0003oool0oooo0?oo
o`3o0000>@3oool00`000?l0oooo0000o`100?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01`0oooo00<0o`000?oo
o`3o00005@3oool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0
00050?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool00`00o`00oooo003o000?0?ooo`03003o
003oool00?l001`0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0003o00D0oooo00D0o`000?ooo`3oool0oooo
0?l0000P0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`070?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool0=P3oool2003o00P0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo04H0oooo
00D00?l00?ooo`3oool0oooo003o00060?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`00
0?l0M`3oool00`3o0000oooo0?l0000N0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool0503oool00`3o0000oooo0?l0000P0?ooo`040?l0003oool0oooo0?l001h0oooo00D0o`000?oo
o`3oool0oooo0?l0000i0?ooo`030000o`3oool0003o0400oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0703oool0
0`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0?l0
003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000o`0=0?ooo`03003o003oool00?l000l0
oooo00<00?l00?ooo`00o`00703oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`D00000E`3oool20000o`D0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`03
003o003oool0oooo01D0oooo00<00?l00?ooo`3oool0=`3oool00`00o`00oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`160?ooo`05
003o003oool0oooo0?ooo`00o`001P3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o
07L0oooo00<0o`000?ooo`3o00007P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
01@0oooo00<0o`000?ooo`3o0000803oool0103o0000oooo0?ooo`3o000N0?ooo`050?l0003oool0
oooo0?ooo`3o0000>@3oool00`000?l0oooo0000o`110?ooo`040000o`3oool0oooo0000o`D0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0o`0001D0oooo
00<0003o0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00001@3oool01@00
0?l0oooo0?ooo`3oool0003o00d0oooo0P00o`0@0?ooo`03003o003oool00?l001`0oooo00<0003o
0?ooo`3oool07@3oool5000001T0oooo000l0?ooo`030000003oool0oooo05T0oooo0P000?l50?oo
o`050?l0003oool0oooo0?ooo`3o0000803oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0
oooo03L0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0AP3oool01@00o`00oooo0?ooo`3oool00?l000H0oooo00<0
o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1g0?ooo`030?l0003oool0o`0001h0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0E0?ooo`80o`00803oool00`3o0000oooo0?l0
000O0?ooo`040?l0003oool0oooo0?l003X0oooo00<0003o0?ooo`000?l0@@3oool010000?l0oooo
0?ooo`000?l60?ooo`050?l0003oool0oooo0?ooo`3o00007P3oool00`3o0000oooo0?l0000E0?oo
o`030000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000D0oooo00D0
003o0?ooo`3oool0oooo0000o`0=0?ooo`800?l0403oool00`00o`00oooo003o000M0?ooo`030000
o`3oool0oooo0200oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0FP3o
ool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool0503oool00`00o`00oooo
0?ooo`0g0?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo04L0oooo00@00?l00?ooo`3oool00?l01P3oool00`3o0000
oooo0?l000050?ooo`030000o`3oool0003o07L0oooo00<0o`000?ooo`3o00007P3oool01@00o`00
oooo0?ooo`3oool00?l001P0oooo0P3o000P0?ooo`030?l0003oool0o`0001l0oooo00@0o`000?oo
o`3oool0o`00>P3oool00`000?l0oooo0000o`120?ooo`030000o`3oool0003o00H0oooo00D0o`00
0?ooo`3oool0oooo0?l0000N0?ooo`030?l0003oool0o`0001D0oooo00<0003o0?ooo`3oool0103o
ool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00001@3oool01@000?l0oooo0?ooo`3oool0003o
00h0oooo00<00?l00?ooo`3oool03P3oool00`00o`00oooo003o000M0?ooo`030000o`3oool0oooo
0200oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0H03oool01@3o0000
oooo0?ooo`3oool0o`0003P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?oo
o`03003o003oool0oooo01@0oooo00<00?l00?ooo`3oool0=`3oool00`00o`00oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?oo
o`04003o003oool0oooo003o00H0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1g
0?ooo`030?l0003oool0o`0001h0oooo00D00?l00?ooo`3oool0oooo003o000H0?ooo`030?l0003o
ool0oooo01l0oooo00<0o`000?ooo`3o0000803oool00`3o0000oooo0?l0000j0?ooo`030000o`3o
ool0003o0480oooo00<0003o0?ooo`000?l01P3oool01@3o0000oooo0?ooo`3oool0o`0001h0oooo
00<0o`000?ooo`3o00005@3oool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?ooo`3o
0000oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`00o`00oooo0?ooo`0>
0?ooo`03003o003oool00?l001d0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`1P0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool0503oool0
0`00o`00oooo0?ooo`100?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`170?ooo`04003o003oool0oooo003o00H0oooo00<0o`000?ooo`3o00001@3o
ool00`000?l0oooo0000o`1g0?ooo`80o`007`3oool01@00o`00oooo0?ooo`3oool00?l001P0oooo
00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?l0000P0?ooo`030?l0003oool0o`0003X0oooo
00<0003o0?ooo`000?l0@`3oool20000o`H0oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`03
0?l0003oool0o`0001D0oooo00<0003o0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool0o`00
0?ooo`3o00001@3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo00<00?l00?ooo`00o`007@3o
ool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo0600oooo00D0o`000?ooo`3oool0oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003oool0oooo04H0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?ooo`04003o003oool0oooo003o00H0oooo
00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1h0?ooo`030?l0003oool0oooo01h0oooo
00@00?l00?ooo`3oool00?l0603oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0o`000200
oooo00<0o`000?ooo`3o0000>P3oool20000od@0oooo0P000?l60?ooo`050?l0003oool0oooo0?oo
o`3o00007P3oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0oooo00@0oooo00L0003o0?oo
o`3oool0oooo0?l0003oool0o`0000D0oooo00D0003o0?ooo`3oool0oooo0000o`0P0?ooo`03003o
003oool0oooo01`0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool5000005h0oooo00D0o`000?ooo`3oool0oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo04L0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?ooo`04003o003oool0oooo003o00H0
oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`1h0?ooo`030?l0003oool0oooo01h0
oooo00@00?l00?ooo`3oool00?l0603oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0o`00
0200oooo00<0o`000?ooo`3o0000>`3oool00`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo
00@0oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`030?l0003oool0o`0001D0oooo00<0003o
0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00001@3oool01@000?l0oooo
0?ooo`3oool0003o0200oooo00<00?l00?ooo`3oool0703oool00`000?l0oooo0?ooo`0L0?ooo`D0
00006@3oool003`0oooo00<000000?ooo`3oool0H03oool01@3o0000oooo0?ooo`3oool0o`0003P0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo01<0
oooo00<00?l00?ooo`3oool0A`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo04P0
oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo0?l000060?ooo`80003oN03oool00`3o0000
oooo0?ooo`0N0?ooo`04003o003oool0oooo003o03X0oooo00<0o`000?ooo`3o0000803oool00`3o
0000oooo0?l0000k0?ooo`030000o`3oool0oooo04X0oooo00D0o`000?ooo`3oool0oooo0?l0000N
0?ooo`030?l0003oool0o`0001H0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o
ool20?l000H0oooo00@0003o0?ooo`3oool0003o8@3oool00`00o`00oooo0?ooo`0L0?ooo`030000
o`3oool0oooo0200oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0H03o
ool01@3o0000oooo0?ooo`3oool0o`0003P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo01<0oooo00<00?l00?ooo`3oool0A`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo04P0oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo
0?l000060?ooo`80003oN03oool00`3o0000oooo0?ooo`0N0?ooo`04003o003oool0oooo003o03X0
oooo00<0o`000?ooo`3o0000803oool00`3o0000oooo0?l0000k0?ooo`030000o`3oool0oooo04X0
oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`030?l0003oool0o`0001H0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`3oool20?l000L0oooo00<0003o0?ooo`000?l08@3oool0
0`00o`00oooo0?ooo`0L0?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0H03oool01@3o0000oooo0?ooo`3oool0o`0003P0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo01<0oooo00<00?l0
0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo04P0oooo0P00o`07
0?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3oool0V03oool01000o`00oooo0?ooo`00
o`0j0?ooo`030?l0003oool0o`000200oooo00<0o`000?ooo`3o0000>`3oool00`000?l0oooo0?oo
o`1:0?ooo`050?l0003oool0oooo0?ooo`3o00007P3oool00`3o0000oooo0?l0000F0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0003o0400oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1P0?ooo`050?l0003oool0oooo0?ooo`3o0000>03oool01@000?l0oooo
0?ooo`3oool0003o00`0oooo00<00?l00?ooo`3oool04`3oool00`00o`00oooo0?ooo`180?ooo`04
0?l0003oool0oooo0?l004/0oooo0P00o`080?ooo`80o`001P3oool00`000?l0oooo0?ooo`2H0?oo
o`04003o003oool0oooo003o03X0oooo00<0o`000?ooo`3o0000803oool00`3o0000oooo0?l0000k
0?ooo`030000o`3oool0oooo04X0oooo00D0o`000?ooo`3oool0oooo0?l0000N0?ooo`030?l0003o
ool0o`0001H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`000?l0@@3oool00`000?l0oooo0?ooo`0O0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo0600oooo00D0o`000?ooo`3oool0oooo0?l0
000h0?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool00`00o`00oooo0?ooo`0B0?ooo`03003o
003oool0oooo04P0oooo00@0o`000?ooo`3oool0o`00B`3oool2003o00P0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`2I0?ooo`03003o003oool00?l003/0oooo0P3o000P0?ooo`03
0?l0003oool0o`0008P0oooo00D0o`000?ooo`3oool0oooo0?l0000O0?ooo`80o`005P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0000o`110?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0H03oool01@3o0000oooo0?ooo`3oool0o`0003P0oooo00D0003o0?oo
o`3oool0oooo0000o`0=0?ooo`03003o003oool0oooo0180oooo00<00?l00?ooo`3oool0B03oool0
103o0000oooo0?ooo`3o001<0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`2I0?ooo`03003o003oool00?l003/0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?l000280?ooo`050?l0003oool0oooo0?ooo`3o00007`3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0003o0440oooo00<0003o0?ooo`3oool07`3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool5000005h0oooo00D0o`000?ooo`3oool0oooo0?l0000h0?ooo`050000
o`3oool0oooo0?ooo`000?l03@3oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo04T0
oooo00@0o`000?ooo`3oool0o`00C03oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0V@3oool00`00o`00oooo003o000k0?ooo`030?l0003oool0oooo
01l0oooo0P3o00290?ooo`050?l0003oool0oooo0?ooo`3o00007`3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0003o0440oooo00<0003o0?ooo`3oool06`3oool5000001T0oooo000l0?oo
o`030000003oool0oooo0640oooo00@0o`000?ooo`3oool0o`00>@3oool010000?l0oooo0?ooo`00
0?l=0?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3oool0B@3oool0103o0000oooo0?oo
o`3o001<0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`2I0?ooo`800?l0?03oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo08L0oooo
00@0o`000?ooo`3oool0o`00803oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0003o0440
oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`1Q0?ooo`040?l0003oool0oooo0?l003T0oooo00@0003o0?ooo`3oool0003o3@3oool00`00
o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo04T0oooo00@0o`000?ooo`3oool0o`00E@3oool0
0`3o0000oooo0?ooo`2Q0?ooo`800?l0?03oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0
oooo08L0oooo00@0o`000?ooo`3oool0o`00803oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0003o0440oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`1Q0?ooo`030?l0003oool0o`0003X0oooo00@0003o0?ooo`3oool0003o3@3o
ool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo04T0oooo00@0o`000?ooo`3oool0o`00
E@3oool00`3o0000oooo0?ooo`2Q0?ooo`800?l0?03oool00`3o0000oooo0?ooo`0P0?ooo`030?l0
003oool0oooo08L0oooo00@0o`000?ooo`3oool0o`00803oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0000o`110?ooo`03
0000o`3oool0oooo01l0oooo00<000000?ooo`3oool05`3oool001/0oooo0P0000040?ooo`800000
1@3oool300000080oooo0P00000=0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3o0000
>P3oool010000?l0oooo0?ooo`000?l=0?ooo`03003o003oool0oooo0140oooo00<00?l00?ooo`3o
ool0B@3oool0103o0000oooo0?ooo`3o001E0?ooo`030?l0003oool0oooo0:80oooo00<00?l00?oo
o`3oool0>P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo08L0oooo00@0o`000?oo
o`3oool0o`00803oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0000o`110?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1Q0?ooo`030?l0003oool0o`0003X0oooo00@0003o0?ooo`3oool0003o3@3oool00`00o`00oooo
0?ooo`0A0?ooo`03003o003oool0oooo04X0oooo00<0o`000?ooo`3o0000nP3oool00`00o`00oooo
0?ooo`1M0?ooo`030?l0003oool0oooo08L0oooo00@0o`000?ooo`3oool0o`00803oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0000o`110?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0503oool00`000000
oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`D00000103oool00`000000
oooo0?ooo`0:0?ooo`L00000G@3oool00`3o0000oooo0?l0000j0?ooo`030000o`3oool0003o00h0
oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?ooo`1:0?ooo`030?l0003oool0o`000?X0
oooo00<00?l00?ooo`3oool0G@3oool00`3o0000oooo0?ooo`280?ooo`030?l0003oool0o`000200
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`000?l0@P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00l0
oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo0P00000=0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3o0000>P3oool00`00
0?l0oooo0000o`0?0?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool0BP3oool00`3o
0000oooo0?l0003j0?ooo`03003o003oool0oooo0>P0oooo00<0o`000?ooo`3o0000803oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0000o`120?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05@3oool00`00
0000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000090?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0o`00
03X0oooo00<0003o0?ooo`000?l03`3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo
04/0oooo00<0o`000?ooo`3o0000o`3ooooV0?ooo`030?l0003oool0o`0003P0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0003o0480oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo000K0?ooo`80
00002`3oool2000000<0oooo0`00000<0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3o
0000>P3oool00`000?l0oooo0000o`0?0?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3o
ool0B`3oool00`3o0000oooo0?l0003o0?ooonH0oooo00<0o`000?ooo`3o0000>03oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`000?l0@P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000j0?ooo`030000o`3oool0003o00l0oooo
00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`1;0?ooo`030?l0003oool0o`000?l0oooo
iP3oool00`3o0000oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1Q0?ooo`030?l0003o
ool0o`0003X0oooo00<0003o0?ooo`000?l03`3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003o
ool0oooo04/0oooo0P3o003o0?ooonL0oooo00<0o`000?ooo`3o0000>@3oool01@000?l0oooo0?oo
o`3oool0003o00h0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0H@3o
ool00`3o0000oooo0?l0000j0?ooo`030000o`3oool0003o00l0oooo00<00?l00?ooo`3oool03P3o
ool00`00o`00oooo0?ooo`1<0?ooo`80o`00o`3ooooW0?ooo`030?l0003oool0o`0003T0oooo00D0
003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000G`3o
ool00`3o0000oooo0?l0000j0?ooo`030000o`3oool0003o00l0oooo00<00?l00?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`1>0?ooo`030?l0003oool0oooo0?l0ooooi@3oool00`3o0000oooo0?l0
000i0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`110?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool5000001T0oooo000l0?ooo`030000003o
ool0oooo0640oooo00<0o`000?ooo`3o0000>`3oool20000o`l0oooo00<00?l00?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`1>0?ooo`030?l0003oool0oooo0?l0ooooi@3oool00`3o0000oooo0?l0
000i0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`110?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0o`0003/0oooo0P000?l?0?ooo`03003o003o
ool0oooo00`0oooo00<00?l00?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooonD0oooo00<0
o`000?ooo`3o0000>@3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool0
@@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000k0?ooo`030000o`3o
ool0oooo00l0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0?l0ooooi@3oool00`3o0000oooo0?l0000i0?ooo`050000o`3oool0oooo0?ooo`000?l0
3P3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
603oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1Q0?ooo`030?l0003o
ool0o`0003/0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?ooo`090?ooo`03003o003o
ool0oooo0540oooo00<0o`000?ooo`3oool0o`3ooooU0?ooo`030?l0003oool0o`0003T0oooo00D0
003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0640oooo00<0o`000?ooo`3o0000>`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo00P0oooo00<00?l00?ooo`3oool0o`3ooooo0?oooc/0oooo00<0o`000?ooo`3o0000>@3o
ool01@000?l0oooo0?ooo`3oool0003o05<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000G`3oool00`3o0000oooo0?l0
000k0?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?oo
o`3o0?ooool0oooo?03oool00`3o0000oooo0?l0000i0?ooo`050000o`3oool0oooo0?ooo`000?l0
D`3oool01@000?l0oooo0?ooo`3oool0003o01L0oooo1@00000I0?ooo`00?03oool00`000000oooo
0?ooo`1R0?ooo`80o`00>`3oool00`000?l0oooo0?ooo`0?0?ooo`800?l0203oool00`00o`00oooo
0?ooo`3o0?ooool0oooo?03oool00`3o0000oooo0?l0000i0?ooo`050000o`3oool0oooo0?ooo`00
0?l0D`3oool01@000?l0oooo0?ooo`3oool0003o01/0oooo00<000000?ooo`3oool05`3oool003`0
oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`1>0?ooo`@00?l00`3oool00`00o`00
oooo0?ooo`3o0?ooool0oooo?@3oool00`3o0000oooo0?l0000i0?ooo`040000o`3oool0oooo0000
oe@0oooo00D0003o0?ooo`3oool0oooo0000o`0K0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo0680oooo00<0o`000?ooo`3oool0DP3oool3003o0?l0ooooo`3ooom00?oo
o`80o`00>P3oool010000?l0oooo0?ooo`000?mD0?ooo`040000o`3oool0oooo0000oa`0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`3o
0?ooool0ooooU@3oool20?l003X0oooo00@0003o0?ooo`3oool0003oE03oool010000?l0oooo0?oo
o`000?lL0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0
o`000?ooo`3oool0o`3ooooo0?oooiH0oooo00<0o`000?ooo`3oool0>03oool010000?l0oooo0?oo
o`000?mD0?ooo`040000o`3oool0oooo0000oa`0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`3o0?ooool0ooooUP3oool00`3o0000oooo
0?ooo`0h0?ooo`040000o`3oool0oooo0000oeD0oooo0P000?lM0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`D00000H03oool00`3o0000oooo0?ooo`3o0?ooool0ooooUP3oool00`3o0000oooo
0?ooo`0h0?ooo`040000o`3oool0oooo0000oeD0oooo0P000?lI0?ooo`D000006@3oool003`0oooo
00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`3o0?ooool0ooooUP3oool00`3o0000oooo
0?ooo`0h0?ooo`040000o`3oool0oooo0000oeD0oooo0P000?lM0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`030000003oool0oooo0680oooo00<0o`000?ooo`3oool0o`3ooooo0?oooiH0oooo
00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0000o`1E0?ooo`030000o`3oool0oooo01`0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?oo
o`3o0?ooool0ooooUP3oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0003o05D0oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o
0?ooool0oooon`3oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0003o07@0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?oooo/0oooo00<0o`000?oo
o`3oool0>@3oool00`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooook0?ooo`030?l0003oool0oooo03T0oooo00<0003o0?ooo`00
0?l0M03oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000?l0ooooo`3ooooo0?ooocH0oooo
00<0003o0?ooo`000?l0L03oool5000001T0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooocP0oooo00<0003o0?ooo`000?l0M03oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000o`3oool0003o07@0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>03oool00`00
0?l0oooo0000o`1d0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`800000103oool2000000@0
oooo0P00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocP0oooo00<0003o0?ooo`00
0?l0M03oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>03oool00`00
0?l0oooo0000o`1d0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool02P3oool700000?l0ooooo`3ooooo0?oooc@0oooo00<0003o0?oo
o`000?l0KP3oool7000001T0oooo000P0?ooo`040000003oool0oooo000000T0oooo0P00000=0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooocP0oooo00<0003o0?ooo`000?l0M03oool00`00
0000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>03oool00`000?l0oooo0000o`1d0?oo
o`030000003oool0oooo01L0oooo000Q0?ooo`8000002P3oool3000000`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo>03oool00`000?l0oooo0000o`1d0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocP0oooo0P000?me0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocP0oooo0P00
0?me0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooocT0oooo00<0003o0?ooo`3oool0L`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool50000
0?l0ooooo`3ooooo0?ooocL0oooo00<0003o0?ooo`3oool0K`3oool5000001T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooocT0oooo00<0003o0?ooo`3oool0L`3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooli0?ooo`030000
o`3oool0oooo07<0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo>@3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooocT0oooo00<0003o0?ooo`3oool0L`3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooli0?oo
o`030000o`3oool0oooo07<0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00003o0?ooool0
ooooo`3ooolg0?ooo`030000o`3oool0oooo06l0oooo1@00000I0?ooo`00?03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo
0?ooo`120?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000l0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00
?03ooooo00000?l00000o`00002c000001T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 1028.63}, {256.375, 0}} -> {-9.5703, 0.137433, \
0.114764, 0.00153005}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Raw Tapping Data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowMetricCycles[fractions4b];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00924642 -0.124528 0.706414 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20874 -0.0125 -6 -9 ]
[.20874 -0.0125 6 0 ]
[.39367 -0.0125 -6 -9 ]
[.39367 -0.0125 6 0 ]
[.57859 -0.0125 -6 -9 ]
[.57859 -0.0125 6 0 ]
[.76352 -0.0125 -6 -9 ]
[.76352 -0.0125 6 0 ]
[.94845 -0.0125 -9 -9 ]
[.94845 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01675 -18 -4.5 ]
[-0.0125 .01675 0 4.5 ]
[-0.0125 .05208 -24 -4.5 ]
[-0.0125 .05208 0 4.5 ]
[-0.0125 .0874 -18 -4.5 ]
[-0.0125 .0874 0 4.5 ]
[-0.0125 .12272 -24 -4.5 ]
[-0.0125 .12272 0 4.5 ]
[-0.0125 .15804 -18 -4.5 ]
[-0.0125 .15804 0 4.5 ]
[-0.0125 .19336 -24 -4.5 ]
[-0.0125 .19336 0 4.5 ]
[-0.0125 .22868 -18 -4.5 ]
[-0.0125 .22868 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .25 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20874 0 m
.20874 .00625 L
s
[(20)] .20874 -0.0125 0 1 Mshowa
.39367 0 m
.39367 .00625 L
s
[(40)] .39367 -0.0125 0 1 Mshowa
.57859 0 m
.57859 .00625 L
s
[(60)] .57859 -0.0125 0 1 Mshowa
.76352 0 m
.76352 .00625 L
s
[(80)] .76352 -0.0125 0 1 Mshowa
.94845 0 m
.94845 .00625 L
s
[(100)] .94845 -0.0125 0 1 Mshowa
.125 Mabswid
.07004 0 m
.07004 .00375 L
s
.11627 0 m
.11627 .00375 L
s
.16251 0 m
.16251 .00375 L
s
.25497 0 m
.25497 .00375 L
s
.3012 0 m
.3012 .00375 L
s
.34743 0 m
.34743 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.48613 0 m
.48613 .00375 L
s
.53236 0 m
.53236 .00375 L
s
.62483 0 m
.62483 .00375 L
s
.67106 0 m
.67106 .00375 L
s
.71729 0 m
.71729 .00375 L
s
.80975 0 m
.80975 .00375 L
s
.85599 0 m
.85599 .00375 L
s
.90222 0 m
.90222 .00375 L
s
.99468 0 m
.99468 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01675 m
.00625 .01675 L
s
[(0.2)] -0.0125 .01675 1 0 Mshowa
0 .05208 m
.00625 .05208 L
s
[(0.25)] -0.0125 .05208 1 0 Mshowa
0 .0874 m
.00625 .0874 L
s
[(0.3)] -0.0125 .0874 1 0 Mshowa
0 .12272 m
.00625 .12272 L
s
[(0.35)] -0.0125 .12272 1 0 Mshowa
0 .15804 m
.00625 .15804 L
s
[(0.4)] -0.0125 .15804 1 0 Mshowa
0 .19336 m
.00625 .19336 L
s
[(0.45)] -0.0125 .19336 1 0 Mshowa
0 .22868 m
.00625 .22868 L
s
[(0.5)] -0.0125 .22868 1 0 Mshowa
.125 Mabswid
0 .02382 m
.00375 .02382 L
s
0 .03088 m
.00375 .03088 L
s
0 .03795 m
.00375 .03795 L
s
0 .04501 m
.00375 .04501 L
s
0 .05914 m
.00375 .05914 L
s
0 .0662 m
.00375 .0662 L
s
0 .07327 m
.00375 .07327 L
s
0 .08033 m
.00375 .08033 L
s
0 .09446 m
.00375 .09446 L
s
0 .10152 m
.00375 .10152 L
s
0 .10859 m
.00375 .10859 L
s
0 .11565 m
.00375 .11565 L
s
0 .12978 m
.00375 .12978 L
s
0 .13685 m
.00375 .13685 L
s
0 .14391 m
.00375 .14391 L
s
0 .15097 m
.00375 .15097 L
s
0 .1651 m
.00375 .1651 L
s
0 .17217 m
.00375 .17217 L
s
0 .17923 m
.00375 .17923 L
s
0 .18629 m
.00375 .18629 L
s
0 .20042 m
.00375 .20042 L
s
0 .20749 m
.00375 .20749 L
s
0 .21455 m
.00375 .21455 L
s
0 .22162 m
.00375 .22162 L
s
0 .00969 m
.00375 .00969 L
s
0 .00263 m
.00375 .00263 L
s
0 .23574 m
.00375 .23574 L
s
0 .24281 m
.00375 .24281 L
s
0 .24987 m
.00375 .24987 L
s
.25 Mabswid
0 0 m
0 .25 L
s
.02381 .24375 m
.02381 .25 L
s
.20874 .24375 m
.20874 .25 L
s
.39367 .24375 m
.39367 .25 L
s
.57859 .24375 m
.57859 .25 L
s
.76352 .24375 m
.76352 .25 L
s
.94845 .24375 m
.94845 .25 L
s
.125 Mabswid
.07004 .24625 m
.07004 .25 L
s
.11627 .24625 m
.11627 .25 L
s
.16251 .24625 m
.16251 .25 L
s
.25497 .24625 m
.25497 .25 L
s
.3012 .24625 m
.3012 .25 L
s
.34743 .24625 m
.34743 .25 L
s
.4399 .24625 m
.4399 .25 L
s
.48613 .24625 m
.48613 .25 L
s
.53236 .24625 m
.53236 .25 L
s
.62483 .24625 m
.62483 .25 L
s
.67106 .24625 m
.67106 .25 L
s
.71729 .24625 m
.71729 .25 L
s
.80975 .24625 m
.80975 .25 L
s
.85599 .24625 m
.85599 .25 L
s
.90222 .24625 m
.90222 .25 L
s
.99468 .24625 m
.99468 .25 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
.99375 .01675 m
1 .01675 L
s
.99375 .05208 m
1 .05208 L
s
.99375 .0874 m
1 .0874 L
s
.99375 .12272 m
1 .12272 L
s
.99375 .15804 m
1 .15804 L
s
.99375 .19336 m
1 .19336 L
s
.99375 .22868 m
1 .22868 L
s
.125 Mabswid
.99625 .02382 m
1 .02382 L
s
.99625 .03088 m
1 .03088 L
s
.99625 .03795 m
1 .03795 L
s
.99625 .04501 m
1 .04501 L
s
.99625 .05914 m
1 .05914 L
s
.99625 .0662 m
1 .0662 L
s
.99625 .07327 m
1 .07327 L
s
.99625 .08033 m
1 .08033 L
s
.99625 .09446 m
1 .09446 L
s
.99625 .10152 m
1 .10152 L
s
.99625 .10859 m
1 .10859 L
s
.99625 .11565 m
1 .11565 L
s
.99625 .12978 m
1 .12978 L
s
.99625 .13685 m
1 .13685 L
s
.99625 .14391 m
1 .14391 L
s
.99625 .15097 m
1 .15097 L
s
.99625 .1651 m
1 .1651 L
s
.99625 .17217 m
1 .17217 L
s
.99625 .17923 m
1 .17923 L
s
.99625 .18629 m
1 .18629 L
s
.99625 .20042 m
1 .20042 L
s
.99625 .20749 m
1 .20749 L
s
.99625 .21455 m
1 .21455 L
s
.99625 .22162 m
1 .22162 L
s
.99625 .00969 m
1 .00969 L
s
.99625 .00263 m
1 .00263 L
s
.99625 .23574 m
1 .23574 L
s
.99625 .24281 m
1 .24281 L
s
.99625 .24987 m
1 .24987 L
s
.25 Mabswid
1 0 m
1 .25 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03306 .0705 m
.0423 .12959 L
.05155 .0715 L
.0608 .10019 L
.07004 .07384 L
.07929 .14809 L
.08853 .08678 L
.09778 .06114 L
.10703 .18752 L
.11627 .05143 L
.12552 .08397 L
.13477 .05456 L
.14401 .16216 L
.15326 .03702 L
.16251 .13152 L
.17175 .07249 L
.181 .11266 L
.19025 .02335 L
.19949 .05627 L
.20874 .06122 L
.21798 .09491 L
.22723 .01819 L
.23648 .13235 L
.24572 .07436 L
.25497 .08575 L
.26422 .08798 L
.27346 .12387 L
.28271 .12304 L
.29196 .19522 L
.3012 .1136 L
.31045 .12411 L
.31969 .05148 L
.32894 .11673 L
.33819 .09831 L
.34743 .12421 L
.35668 .11575 L
.36593 .171 L
.37517 .10384 L
.38442 .09681 L
.39367 .09623 L
.40291 .08881 L
.41216 .10812 L
.42141 .11358 L
.43065 .09789 L
.4399 .10949 L
.44914 .11931 L
.45839 .14338 L
.46764 .10404 L
.47688 .08384 L
.48613 .12067 L
Mistroke
.49538 .12573 L
.50462 .11046 L
.51387 .10475 L
.52312 .08591 L
.53236 .08947 L
.54161 .08436 L
.55086 .09534 L
.5601 .08976 L
.56935 .08691 L
.57859 .07694 L
.58784 .15521 L
.59709 .09468 L
.60633 .08614 L
.61558 .1169 L
.62483 .14304 L
.63407 .08395 L
.64332 .09598 L
.65257 .08662 L
.66181 .12791 L
.67106 .10081 L
.68031 .10838 L
.68955 .0827 L
.6988 .134 L
.70804 .09987 L
.71729 .13123 L
.72654 .04229 L
.73578 .11502 L
.74503 .08176 L
.75428 .10133 L
.76352 .09931 L
.77277 .08869 L
.78202 .07723 L
.79126 .08019 L
.80051 .07204 L
.80975 .23056 L
.819 .05464 L
.82825 .10896 L
.83749 .05955 L
.84674 .11791 L
.85599 .01806 L
.86523 .14618 L
.87448 .02333 L
.88373 .12491 L
.89297 .01956 L
.90222 .18779 L
.91147 .00595 L
.92071 .14295 L
.92996 .04159 L
.9392 .10269 L
.94845 .04462 L
Mistroke
.9577 .06773 L
.96694 .01153 L
.97619 .06149 L
Mfstroke
0 1 0 r
.03306 .12577 m
.0423 .11536 L
.05155 .10918 L
.0608 .11604 L
.07004 .14349 L
.07929 .08696 L
.08853 .11142 L
.09778 .10946 L
.10703 .07561 L
.11627 .14584 L
.12552 .06861 L
.13477 .15281 L
.14401 .08857 L
.15326 .15366 L
.16251 .09608 L
.17175 .0775 L
.181 .03266 L
.19025 .10671 L
.19949 .04956 L
.20874 .13787 L
.21798 .0871 L
.22723 .14396 L
.23648 .08915 L
.24572 .11913 L
.25497 .1294 L
.26422 .13004 L
.27346 .0989 L
.28271 .12161 L
.29196 .08253 L
.3012 .09448 L
.31045 .13288 L
.31969 .08487 L
.32894 .09518 L
.33819 .1308 L
.34743 .10369 L
.35668 .10926 L
.36593 .08341 L
.37517 .09362 L
.38442 .15215 L
.39367 .10976 L
.40291 .12839 L
.41216 .11985 L
.42141 .11862 L
.43065 .12671 L
.4399 .1124 L
.44914 .10874 L
.45839 .0871 L
.46764 .15259 L
.47688 .12377 L
.48613 .12253 L
Mistroke
.49538 .0987 L
.50462 .11631 L
.51387 .12404 L
.52312 .16332 L
.53236 .09479 L
.54161 .11037 L
.55086 .13573 L
.5601 .13366 L
.56935 .11141 L
.57859 .09472 L
.58784 .12752 L
.59709 .13145 L
.60633 .10534 L
.61558 .07766 L
.62483 .14463 L
.63407 .13325 L
.64332 .09728 L
.65257 .09392 L
.66181 .15284 L
.67106 .10772 L
.68031 .09739 L
.68955 .09007 L
.6988 .10504 L
.70804 .15139 L
.71729 .13169 L
.72654 .08284 L
.73578 .11808 L
.74503 .08498 L
.75428 .12419 L
.76352 .09777 L
.77277 .14255 L
.78202 .1143 L
.79126 .10374 L
.80051 .10596 L
.80975 .06106 L
.819 .14294 L
.82825 .10765 L
.83749 .16891 L
.84674 .11512 L
.85599 .16502 L
.86523 .11624 L
.87448 .06546 L
.88373 .0751 L
.89297 .15855 L
.90222 .05843 L
.91147 .14978 L
.92071 .11115 L
.92996 .13797 L
.9392 .02763 L
.94845 .14383 L
Mistroke
.9577 .06611 L
.96694 .1376 L
.97619 .03376 L
Mfstroke
0 0 1 r
.03306 .13657 m
.0423 .08789 L
.05155 .15215 L
.0608 .1166 L
.07004 .1155 L
.07929 .09778 L
.08853 .13463 L
.09778 .16223 L
.10703 .0697 L
.11627 .13556 L
.12552 .18025 L
.13477 .12545 L
.14401 .0821 L
.15326 .14216 L
.16251 .10523 L
.17175 .18284 L
.181 .18751 L
.19025 .20278 L
.19949 .227 L
.20874 .13374 L
.21798 .15082 L
.22723 .17068 L
.23648 .11133 L
.24572 .13934 L
.25497 .11769 L
.26422 .11481 L
.27346 .11007 L
.28271 .08818 L
.29196 .05508 L
.3012 .12475 L
.31045 .07584 L
.31969 .19648 L
.32894 .12093 L
.33819 .10372 L
.34743 .10493 L
.35668 .10782 L
.36593 .07842 L
.37517 .13537 L
.38442 .08388 L
.39367 .12685 L
.40291 .11564 L
.41216 .10486 L
.42141 .10063 L
.43065 .10823 L
.4399 .11094 L
.44914 .10478 L
.45839 .10235 L
.46764 .07621 L
.47688 .12522 L
.48613 .08963 L
Mistroke
.49538 .1084 L
.50462 .10606 L
.51387 .10404 L
.52312 .0836 L
.53236 .14858 L
.54161 .1381 L
.55086 .10176 L
.5601 .10941 L
.56935 .13451 L
.57859 .16117 L
.58784 .0501 L
.59709 .1067 L
.60633 .14135 L
.61558 .13827 L
.62483 .04516 L
.63407 .11564 L
.64332 .13956 L
.65257 .15229 L
.66181 .05208 L
.67106 .12431 L
.68031 .12706 L
.68955 .16006 L
.6988 .09379 L
.70804 .08157 L
.71729 .06991 L
.72654 .20769 L
.73578 .09973 L
.74503 .1661 L
.75428 .10732 L
.76352 .13576 L
.77277 .10159 L
.78202 .1413 L
.79126 .14891 L
.80051 .15483 L
.80975 .04121 L
.819 .13526 L
.82825 .11622 L
.83749 .10438 L
.84674 .0998 L
.85599 .14974 L
.86523 .07041 L
.87448 .24405 L
.88373 .13282 L
.89297 .15472 L
.90222 .08661 L
.91147 .17709 L
.92071 .07873 L
.92996 .15328 L
.9392 .20251 L
.94845 .14438 L
Mistroke
.9577 .19899 L
.96694 .1837 L
.97619 .23757 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1029.63, 257.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@500010B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3oool90?ooo`00DP3oool200000:P0oooo100000030?ooo`800000Y`3oool30000
0080oooo0P00002V0?ooo`<00000103oool200000:H0oooo0P0000040?ooo`800000XP3oool50000
0080oooo0P0000040?ooo`800000A03oool00540oooo00@000000?ooo`3oool00000Y`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000:L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000Y03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000:<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
@@3oool00540oooo00@000000?ooo`3oool00000Z03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000:@0oooo1@0000001@3oool000000?ooo`3oool000000:D0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3oool010000000oooo0?ooo`00002Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2R0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000Y@3oool3000000<0oooo00@000000?ooo`3o
ool00000Y@3oool2000000<0oooo00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00D@3o
ool010000000oooo0?ooo`00002W0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000Y@3oool00`000000oooo000000020?ooo`040000003oool0oooo00000:H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00002T0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000X`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`110?ooo`00DP3oool200000:T0oooo0P0000040?oo
o`800000Y`3oool2000000<0oooo0P00002W0?ooo`<000000`3oool200000:H0oooo0P0000040?oo
o`800000X`3oool2000000@0oooo0P0000040?ooo`800000A03oool00?l0ooooo`3ooooo0?ooool0
oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3o
ool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0
ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3o
oooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?oo
ool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo
2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool00?l0ooooo`3ooooo0?ooool0oooo2@3oool0
03`0ooooo`00003o00000?l00000/`00000I0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000B0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`H00000
6@3oool003`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Z`3oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0R03oool00`3o0000
oooo0?ooo`0P0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooF`3oool00`3o0000oooo0?ooo`1A0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooe/0oooo00<0
o`000?ooo`3oool0D@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000?l0ooooo`3ooooo
0?oooeT0oooo00<0o`000?ooo`3oool0C@3oool5000001T0oooo000l0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?oooe/0oooo00<0o`000?ooo`3oool0D@3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooomK0?ooo`030?l0003oool0oooo0380
oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooomK0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3oool0
703oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oomK0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?oo
o`0G0?ooo`008@3oool2000000@0oooo0P0000030?ooo`@00000303oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3ooomK0?ooo`80o`00<P3oool00`3o0000oooo0?l0000M0?ooo`030000003oool0
oooo01L0oooo000P0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooo`3ooomK0?ooo`80o`00<P3oool00`3o0000oooo0?l0000M
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0303oool700000?l0ooooo`3ooooo0?oooeL0oooo0P3o000b0?ooo`030?l0003oool0
o`0001L0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0e03oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool0
0`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0o`000380oooo00<0o`000?ooo`3o00007@3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000`0oooo00<000000?ooo`3oool0e03oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3o
ool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o0000<P3o
ool00`3o0000oooo0?l0000M0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000002P3oool2
000000d0oooo00<000000?ooo`3oool0e03oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool0
0`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o0000<P3oool0
0`3o0000oooo0?l0000M0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0=@0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooodl0oooo00<0o`000?ooo`3oool0803oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0o`000340oooo00D0o`000?ooo`3oool0oooo0?l0000L
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0=<0oooo0P3o003o0?oo
ool0ooooD@3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3o0000<@3oool01@3o0000oooo0?ooo`3oool0o`0001`0oooo00<000000?ooo`3oool05`3oool0
03`0oooo1@00002_0?ooo`030?l0003oool0oooo01l0oooo0P3o003o0?ooool0ooooD@3oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?l0000a0?ooo`050?l0003oool0oooo0?ooo`3o0000603oool5000001T0oooo000l0?oo
o`030000003oool0oooo0;40oooo00<0o`000?ooo`3oool07`3oool20?l00?l0ooooo`3ooom@0?oo
o`80o`004@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3o0000<@3oool01@3o0000oooo0?ooo`3oool0o`0001`0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0/@3oool20?l00200oooo00<0o`000?ooo`3o0000o`3ooooo0?oo
odl0oooo00<0o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`0=0?ooo`80o`003`3oool00`3o
0000oooo0?l0000a0?ooo`050?l0003oool0oooo0?ooo`3o0000703oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`2a0?ooo`80o`00803oool00`3o0000oooo0?l0003o0?oo
ool0ooooC`3oool00`3o0000oooo0?l0000@0?ooo`030?l0003oool0oooo00d0oooo0P3o000?0?oo
o`030?l0003oool0o`000340oooo00D0o`000?ooo`3oool0oooo0?l0000L0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0;40oooo0P3o000P0?ooo`030?l0003oool0o`00
0?l0ooooo`3ooom?0?ooo`030?l0003oool0o`000100oooo00<0o`000?ooo`3oool03@3oool20?l0
00l0oooo00<0o`000?ooo`3o00006@3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`2`0?ooo`030?l0003oool0o`000200oooo00<0o`000?ooo`3o0000o`3ooooo0?ooodl0
oooo00<0o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0o`0000h0
oooo00<0o`000?ooo`3o00006@3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`2`0?ooo`040?l0003oool0oooo0?l001l0oooo00<0o`000?ooo`3o0000o`3ooooo0?ooodl0
oooo00<0o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0o`0000h0
oooo00@0o`000?ooo`3oool0o`00603oool00`00o`00oooo0?ooo`0D0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool500000:h0
oooo00@0o`000?ooo`3oool0o`007P3oool0103o0000oooo0?ooo`3o003o0?ooool0ooooC`3oool0
0`3o0000oooo0?l0000?0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3o00003P3oool0
103o0000oooo0?ooo`3o000H0?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0E0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0/03oool0
103o0000oooo0?ooo`3o000N0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3ooom?0?ooo`030?l0
003oool0o`0000l0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?l0000>0?ooo`040?l0
003oool0oooo0?l001P0oooo00<00?l00?ooo`3oool0503oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0
Z03oool00`00o`00oooo0?ooo`050?ooo`040?l0003oool0oooo0?l001h0oooo00@0o`000?ooo`3o
ool0o`00o`3ooooo0?ooodl0oooo00<0o`000?ooo`3o00003`3oool00`3o0000oooo0?l0000>0?oo
o`030?l0003oool0o`0000h0oooo00@0o`000?ooo`3oool0o`00603oool00`00o`00oooo0?ooo`0D
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`2X0?ooo`03003o003oool0oooo00D0oooo00D0o`000?oo
o`3oool0oooo0?l0000M0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3ooom?0?ooo`030?l0003o
ool0o`0000l0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?l0000>0?ooo`040?l0003o
ool0oooo0?l001L0oooo0P00o`0E0?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3oool0
oooo003o000F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0:P0oooo
00<00?l00?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0o`0001d0oooo00@0o`000?ooo`3o
ool0o`00o`3ooooo0?ooodh0oooo00@0o`000?ooo`3oool0o`003`3oool00`3o0000oooo0?l0000>
0?ooo`030?l0003oool0o`0000h0oooo00@0o`000?ooo`3oool0o`005`3oool00`00o`00oooo003o
000D0?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo003o000F0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0:L0oooo0P00o`070?ooo`050?l0003o
ool0oooo0?ooo`3o00007@3oool0103o0000oooo0?ooo`3o003o0?ooool0ooooCP3oool0103o0000
oooo0?ooo`3o000?0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3o00003P3oool0103o
0000oooo0?ooo`3o000G0?ooo`03003o003oool00?l001@0oooo00<0o`000?ooo`3oool01@3oool0
1@3o0000oooo0?ooo`3oool00?l001H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<00000
0?ooo`3oool0SP3oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool00?l000H0oooo00D0o`00
0?ooo`3oool0oooo0?l0000M0?ooo`040?l0003oool0oooo0?l00?l0ooooo`3ooom>0?ooo`040?l0
003oool0oooo0?l000l0oooo00<0o`000?ooo`3o00003@3oool0103o0000oooo0?ooo`3o000>0?oo
o`040?l0003oool0oooo0?l001L0oooo00<00?l00?ooo`00o`00503oool00`3o0000oooo0?ooo`05
0?ooo`050?l0003oool0oooo0?ooo`00o`005P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool5
000008`0oooo00<0o`000?ooo`3oool05P3oool00`00o`00oooo003o00050?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool06P3oool0103o0000oooo0?ooo`3o003o0?ooool0ooooCP3o
ool0103o0000oooo0?ooo`3o000?0?ooo`030?l0003oool0o`0000d0oooo00@0o`000?ooo`3oool0
o`003P3oool0103o0000oooo0?ooo`3o000G0?ooo`03003o003oool00?l001@0oooo00<0o`000?oo
o`3oool01@3oool01@3o0000oooo0?ooo`3oool00?l00180oooo1@00000I0?ooo`00?03oool00`00
0000oooo0?ooo`2>0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`00o`001@3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo01T0oooo00D0o`000?ooo`3oool0oooo0?l0003o
0?ooool0ooooCP3oool0103o0000oooo0?ooo`3o000?0?ooo`030?l0003oool0o`0000d0oooo00@0
o`000?ooo`3oool0o`003P3oool0103o0000oooo0?ooo`3o000G0?ooo`03003o003oool00?l001@0
oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool00?l001H0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0SP3oool00`3o0000oooo0?ooo`0E0?ooo`04
003o003oool0oooo003o00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0I0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooooo0?oood/0oooo00D0o`000?oo
o`3oool0oooo0?l0000>0?ooo`030?l0003oool0o`0000d0oooo00@0o`000?ooo`3oool0o`003P3o
ool0103o0000oooo0?ooo`3o000G0?ooo`03003o003oool00?l001<0oooo00<0o`000?ooo`3oool0
1`3oool0103o0000oooo0?ooo`00o`0F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo08h0oooo00<0o`000?ooo`3oool05@3oool01000o`00oooo0?ooo`00o`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0?l0ooooo`3ooolR0?ooo`030000o`3oool0oooo02H0oooo00D0o`000?ooo`3o
ool0oooo0?l0000>0?ooo`030?l0003oool0o`0000d0oooo00@0o`000?ooo`3oool0o`003@3oool0
1@3o0000oooo0?ooo`3oool0o`0000l0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo003o
000C0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`00o`005`3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`2>0?ooo`80o`005P3oool01000o`00oooo0?ooo`00
o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0?l0oooodP3oool00`3o0000oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo02H0oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`030?l0003oool0o`0000d0oooo
00@0o`000?ooo`3oool0o`003@3oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00<0o`000?oo
o`3oool01@3oool00`00o`00oooo003o000C0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`00o`005`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2>0?ooo`80
o`005P3oool01000o`00oooo0?ooo`00o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0603oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooodP3oool00`3o
0000oooo0?ooo`1<0?ooo`030000o`3oool0oooo02H0oooo00D0o`000?ooo`3oool0oooo0?l0000>
0?ooo`040?l0003oool0oooo0?l000`0oooo00@0o`000?ooo`3oool0o`003@3oool01@3o0000oooo
0?ooo`3oool0o`0000l0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo003o000C0?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`00o`005`3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool5000008/0oooo00<0o`000?ooo`3o00005P3oool01000o`00oooo0?ooo`00o`050?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0?l0ooooLP3oool00`000?l0oooo0?ooo`1M0?ooo`030?l0003oool0oooo04`0
oooo00<0003o0?ooo`3oool09P3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo00D0o`000?oo
o`3oool0oooo0?l0000<0?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`00o`001P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`00o`004`3o
ool5000001T0oooo000l0?ooo`030000003oool0oooo08d0oooo00<0o`000?ooo`3o00005@3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooomb
0?ooo`030000o`3oool0oooo05d0oooo00<0o`000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0V
0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo
00@0o`000?ooo`3oool0o`003@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0
oooo0P3o00060?ooo`03003o003oool00?l000H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool00?l001L0oooo00<000000?ooo`3oool05`3oool003`0oooo
00<000000?ooo`3oool0S@3oool00`3o0000oooo0?l0000E0?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01L0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooog80oooo00<0003o0?ooo`3oool0
G@3oool20?l004d0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`040?l0003oool0oooo0?l0
00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`80o`001@3oool01000
o`00oooo0?ooo`00o`060?ooo`80o`002P3oool00`3o0000oooo0?ooo`090?ooo`030?l00000o`00
oooo01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0S@3oool00`3o
0000oooo0?l0000E0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`3o0?ooog80oooo00<0003o0?ooo`3oool0G03oool00`3o0000oooo0?l0001<0?oo
o`030000o`3oool0003o02H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?oo
o`050?l0003oool0oooo0?ooo`3o0000303oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0000D0oooo00@0
0?l00?ooo`3oool00?l01P3oool20?l000X0oooo00<0o`000?ooo`3oool02@3oool00`3o00000?l0
0?ooo`0F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo08d0oooo00<0
o`000?ooo`3o00005@3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`3o0000
203oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
o`3ooomb0?ooo`80003oG@3oool00`3o0000oooo0?l0001<0?ooo`030000o`3oool0003o02H0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o
00002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0000D0oooo00@00?l00?ooo`3o
ool00?l01@3oool0103o0000oooo0?ooo`3o00090?ooo`030?l0003oool0oooo00T0oooo00<0o`00
003o003oool05P3oool00`000000oooo0?ooo`0G0?ooo`006`3oool2000000@0oooo0P0000030?oo
o`@000000`3oool2000000d0oooo00<000000?ooo`3oool0S@3oool00`3o0000oooo0?l0000E0?oo
o`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0
0?l001H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooodl0oooo00<0003o
0?ooo`3oool0803oool20000oed0oooo00<0o`000?ooo`3o0000C03oool00`000?l0oooo0000o`0V
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3o
ool0o`0000/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?l000050?ooo`05003o003o
ool0oooo0?ooo`00o`00103oool0103o0000oooo0?ooo`3o00090?ooo`030?l0003oool0oooo00T0
oooo00<0o`00003o003oool05P3oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`1[0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3o0000503oool00`00
o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`3o00002@3oool00`3o00000?l00?ooo`0E
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`3i
0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`000?l0G@3oool00`3o0000oooo0?l0001<
0?ooo`030000o`3oool0003o02H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;
0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0o`0000D0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`040?l0003oool0oooo0?l000T0
oooo00<0o`000?ooo`3oool02@3oool00`3o00000?l00?ooo`0F0?ooo`030000003oool0oooo01L0
oooo000J0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`L00000I`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0o`0001@0
oooo00<00?l00?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000T0oooo00<0o`00003o
003oool05@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0580oooo00<0o`000?oo
o`3oool0n@3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0003o0240oooo00<0003o0?oo
o`3oool0>@3oool00`3o0000oooo0?l0001<0?ooo`030000o`3oool0003o02H0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000@0oooo00D00?l00?ooo`3oool0oooo
003o00040?ooo`050?l0003oool0oooo0?ooo`3o0000203oool00`3o0000oooo0?ooo`090?ooo`03
0?l00000o`00oooo0100oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo06/0oooo0P3o000P0?ooo`04
0?l0003oool0oooo0?l001<0oooo00<00?l00?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0
o`0000T0oooo00<0o`00003o003oool05@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0580oooo00<0o`000?ooo`3oool0n@3oool20000ob00oooo00<0003o0?ooo`000?l08@3oool0
0`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0o`0004`0oooo00<0003o0?ooo`000?l09P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0
000;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00103oool01@00o`00oooo
0?ooo`3oool00?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000070?ooo`030?l0003oool0oooo
00/0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1[0?ooo`80o`003`3oool00`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0
oooo0?l001<0oooo00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`3o00090?ooo`800?l0
5P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0540oooo00<0o`000?ooo`3oool0
n@3oool20000ob00oooo00<0003o0?ooo`000?l08@3oool00`000?l0oooo0?ooo`0i0?ooo`030?l0
003oool0o`0004`0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool0o`0000/0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`3o00040?ooo`05003o003oool0oooo
0?ooo`00o`00103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool02P3oool00`00o`00o`000?ooo`0F0?ooo`030000003oool0oooo01L0oooo000K0?oo
o`8000002P3oool2000000@0oooo0`00000<0?ooo`030000003oool0oooo06/0oooo0P3o000?0?oo
o`030?l0003oool0oooo00h0oooo00@0o`000?ooo`3oool0o`004P3oool00`00o`00oooo0?ooo`05
0?ooo`04003o003oool0oooo0?l000T0oooo00<00?l00?l00000o`005@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo03L0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?l0
003j0?ooo`80003o803oool00`000?l0oooo0000o`0Q0?ooo`030000o`3oool0oooo03T0oooo00@0
o`000?ooo`3oool0o`00B`3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0oooo01d0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`3o
00002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000@0oooo00D00?l00?oo
o`3oool0oooo003o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0:0?ooo`03003o003o0000oooo01H0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0J`3oool20?l000h0oooo0P3o000@0?ooo`040?l0003oool0oooo
0?l00180oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`3o00090?ooo`03003o003o
00000?l001@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3o0000nP3oool20000ob00oooo00<0003o0?ooo`000?l08@3o
ool20000ocX0oooo00@0o`000?ooo`3oool0o`00B`3oool00`000?l0oooo0000o`060?ooo`030?l0
003oool0oooo01d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0
003oool0oooo0?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`03003o003o0000oooo
01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0J`3oool00`3o0000
oooo0?l0000=0?ooo`80o`00403oool0103o0000oooo0?ooo`3o000B0?ooo`03003o003oool0oooo
00D0oooo00@00?l00?ooo`3oool0o`002@3oool01000o`00oooo003o003o000C0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool0=P3oool20000oaP0oooo00<0o`000?ooo`3o0000n@3o
ool00`000?l0oooo0000o`0P0?ooo`040000o`3oool0oooo0000ob00oooo0P000?li0?ooo`050?l0
003oool0oooo0?ooo`3o0000B`3oool00`000?l0oooo0000o`060?ooo`80o`007@3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00103oool01@00
o`00oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?l0003oool05P3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`1[0?ooo`030?l0003oool0o`0000d0oooo0P3o000?0?oo
o`050?l0003oool0oooo0?ooo`3o00004P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
o`0000X0oooo00@00?l00?ooo`00o`00oooo0P3o000A0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0=P3oool20000oaP0oooo00<0o`000?ooo`3o0000n@3oool00`000?l0oooo0000
o`0P0?ooo`040000o`3oool0oooo0000oal0oooo00<0003o0?ooo`000?l0>@3oool01@3o0000oooo
0?ooo`3oool0o`0004/0oooo00<0003o0?ooo`000?l01P3oool20?l001d0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00D0o`000?ooo`3o
ool0oooo0?l000030?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l00006
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`00o`00o`000?ooo`0F
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000J03oool0103o0000oooo0?ooo`3o000=
0?ooo`80o`003`3oool01@3o0000oooo0?ooo`3oool0o`000180oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?l0000:0?ooo`03003o003oool00?l000<0oooo0P3o000?0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool0=P3oool20000oaP0oooo00<0o`000?ooo`3o0000n@3o
ool010000?l0oooo0?ooo`000?lO0?ooo`040000o`3oool0oooo0000oal0oooo00<0003o0?ooo`00
0?l0>@3oool01@3o0000oooo0?ooo`3oool0o`0004/0oooo00@0003o0?ooo`3oool0003o1@3oool2
0?l00100oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0
oooo003o00@0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`050?l0003oool0oooo0?ooo`3o
00003@3oool00`00o`00oooo0?l0000B0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0
JP3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00@0o`000?ooo`3oool0o`003P3oool01@3o
0000oooo0?ooo`3oool0o`000140oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?l00009
0?ooo`04003o003oool0oooo003o00D0oooo0P3o000=0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0=P3oool00`000?l0oooo0000o`0G0?ooo`030?l0003oool0o`000?T0oooo00@0
003o0?ooo`3oool0003o7`3oool010000?l0oooo0?ooo`000?lO0?ooo`030000o`3oool0003o03T0
oooo00D0o`000?ooo`3oool0oooo0?l0001:0?ooo`050000o`3oool00?l00?ooo`000?l01@3oool2
0?l00100oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0
oooo003o00@0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`050?l0003oool0oooo0?ooo`3o
00003@3oool00`00o`00oooo0?l0000F0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo05X0oooo00<0o`000?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0o`0000/0
oooo00@0o`000?ooo`3oool0o`003P3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00<00?l0
0?ooo`3oool01`3oool00`00o`00o`000?ooo`080?ooo`04003o003oool0oooo003o00L0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo03D0oooo00@0
003o0?ooo`3oool0003o5`3oool00`3o0000oooo0?l0003i0?ooo`040000o`3oool0oooo0000oal0
oooo00@0003o0?ooo`3oool0003o7`3oool00`000?l0oooo0000o`0i0?ooo`050?l0003oool0oooo
0?ooo`3o0000BP3oool01@000?l0oooo003o003oool0003o00D0oooo0P3o000@0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`040?ooo`05003o
003oool0oooo0?ooo`3o0000203oool0103o0000oooo0?ooo`3o000=0?ooo`03003o003oool0o`00
01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0FP3oool00`3o0000
oooo0?ooo`0=0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool0103o0000oooo0?ooo`3o000>
0?ooo`050?l0003oool0oooo0?ooo`3o00004@3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
0000oooo00P0oooo00@00?l00?ooo`3oool00?l01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0=@3oool010000?l0oooo0?ooo`000?lG0?ooo`03
0?l0003oool0o`000?T0oooo00@0003o0?ooo`3oool0003o7P3oool01@000?l0oooo0?ooo`3oool0
003o01l0oooo00<0003o0?ooo`000?l0>@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo04L0oooo00D0003o0?ooo`00o`00oooo0000o`050?ooo`80o`003`3oool20?l000`0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
0?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`040?ooo`05003o003oool0oooo0?ooo`3o
0000203oool0103o0000oooo0?ooo`3o000=0?ooo`03003o003oool0oooo01H0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0F@3oool20?l000l0oooo00D0o`000?ooo`3o
ool0oooo0?l0000:0?ooo`050?l0003oool0oooo0?ooo`3o00003P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool01`3oool00`00o`00o`000?ooo`08
0?ooo`04003o003oool0oooo003o00P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo03D0oooo00@0003o0?ooo`3oool0003o5P3oool01@3o0000oooo
0?ooo`3oool0o`000?P0oooo00@0003o0?ooo`3oool0003o7P3oool01@000?l0oooo0?ooo`3oool0
003o01l0oooo00<0003o0?ooo`000?l0>@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo04L0oooo00D0003o003o0000o`00oooo0000o`050?ooo`030?l0003oool0o`0000h0oooo00<0
o`000?ooo`3o00002`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo003o00@0oooo
00@00?l00?ooo`3oool0o`002@3oool0103o0000oooo0?ooo`3o000=0?ooo`03003o003oool0oooo
01H0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0F@3oool20?l000l0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?oo
o`3o00003P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00o`000?ooo`080?ooo`05003o003oool0oooo0?ooo`00o`001`3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0=03oool0
1@000?l0oooo0?ooo`3oool0003o01H0oooo00D0o`000?ooo`3oool0oooo0?l0003h0?ooo`040000
o`3oool0oooo0000oah0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0L0?ooo`04
0000o`3oool0oooo0000ocP0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?oo
o`050000o`00o`000?l00?ooo`000?l01@3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0
o`0000/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`00o`050?ooo`03003o003o
ool0o`0000X0oooo00<0o`000?ooo`3o00003@3oool00`00o`00oooo0?ooo`0F0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`D00000EP3oool00`3o0000oooo0?l0000?0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo00<0
0?l00?l0003oool0203oool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo03@0oooo00D0003o0?ooo`3oool0
oooo0000o`0F0?ooo`050?l0003oool0oooo0?ooo`3o0000n03oool01@000?l0oooo0?ooo`3oool0
003o01d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0L0?ooo`040000o`3oool0
oooo0000ocP0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?ooo`050000o`00
o`00oooo003o00000?l0103oool0103o0000oooo0?ooo`3o000>0?ooo`030?l0003oool0o`0000/0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo003o
0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo003o00050?ooo`03003o003oool0o`00
00X0oooo00<0o`00003o003oool03@3oool00`00o`00oooo0?ooo`0B0?ooo`D000006@3oool003`0
oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?l0000?0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo00<00?l00?l0
003oool0203oool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo03@0oooo00D0003o0?ooo`3oool0oooo0000
o`0F0?ooo`050?l0003oool0oooo0?ooo`3o0000n03oool01@000?l0oooo0?ooo`3oool0003o01d0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0L0?ooo`040000o`3oool0oooo0000
ocP0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`170?ooo`050000o`00o`00oooo
003o00000?l0103oool0103o0000oooo0?ooo`3o000>0?ooo`030?l0003oool0o`0000/0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00800?l000<0
oooo0?l0003oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0
0?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo003o00050?ooo`03003o003oool0o`0000/0oooo00<0
0?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3o00003`3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0d
0?ooo`050000o`3oool0oooo0?ooo`000?l05P3oool01@3o0000oooo0?ooo`3oool0o`000?P0oooo
00D0003o0?ooo`3oool0oooo0000o`0M0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0703oool010000?l0oooo0?ooo`000?lg0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0A`3oool01@000?l00?l00?ooo`00o`00003o00@0oooo00@0o`000?ooo`3oool0o`003@3o
ool0103o0000oooo0?ooo`3o000:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
2@3oool01`3o0000oooo0?ooo`00o`00oooo003o003o00002@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo003o00050?oo
o`03003o003oool0o`0000/0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo05L0oooo00@0o`000?ooo`3o
ool0o`003`3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo0?ooo`3o0000n03oool01@000?l0oooo0?oo
o`3oool0003o01d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`050000
o`3oool0oooo0?ooo`000?l0=`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo04L0
oooo00D0003o0?ooo`3oool00?l00000o`040?ooo`040?l0003oool0oooo0?l000d0oooo00@0o`00
0?ooo`3oool0o`002P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`00o`000`3oool00`00o`00o`000?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo003o00030?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool00?l000D0oooo00<0
0?l00?ooo`3o00002`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo01L0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0g
0?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo
00<00?l00?ooo`3oool02@3oool00`3o00000?l00?ooo`070?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo
00D0o`000?ooo`3oool0oooo0?l0003h0?ooo`050000o`3oool0oooo0?ooo`000?l07@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00D0003o0?ooo`3oool0oooo0000o`0a
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`17
0?ooo`050000o`3oool0oooo003o00000?l0103oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo
00@0o`000?ooo`3oool0o`002P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo003o00040?ooo`03003o003oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l000<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`00o`001@3oool00`00o`00oooo0?l0000;0?ooo`800?l0303oool00`00o`00
oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01d0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0V0?ooo`050?l0003oool0oooo0?ooo`3o
00001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3o
ool00?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo00T0oooo00<0o`00003o
003oool01`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0380oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo0?ooo`3o0000m`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0K0?ooo`050000o`3oool0oooo0?ooo`000?l0<03oool20000o`D0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`160?ooo`060000o`3oool0oooo003o003oool0
003o0`3oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00D0o`000?ooo`3oool0oooo0?l00009
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool00?l000@0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o00000?l00?ooo`05
0?ooo`03003o003o0000oooo00X0oooo00<00?l00?ooo`00o`00303oool00`00o`00oooo0?ooo`0G
0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01d0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00@0o`000?oo
o`3oool00?l00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l00000o`00oooo00X0oooo00<0o`00
003o003oool01`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0340oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0m03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0;@3oool20000o`D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0o
0?ooo`030?l0003oool0oooo00@0oooo00H0003o0?ooo`3oool00?l00?ooo`000?l30?ooo`050?l0
003oool0oooo0?ooo`3o0000303oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3oool00?l0103oool00`3o00000?l00?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool00`00o`00oooo003o00030?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l00000o`00oooo00D0oooo00<00?l0
0?l0003oool02P3oool00`00o`00oooo003o000<0?ooo`03003o003oool0oooo01L0oooo00<00000
0?ooo`3oool05`3oool003`0oooo1@00000K0?ooo`030?l0003oool0oooo00h0oooo0P3o000?0?oo
o`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo003o0000o`02
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00/0oooo00<0o`00003o003oool02P3oool00`3o00000?l00?ooo`07
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3d
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0/
0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0n
0?ooo`80o`001@3oool01`000?l0oooo0?ooo`3oool00?l00?ooo`000?l00`3oool01@3o0000oooo
0?ooo`3oool0o`0000`0oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo
003o00@0oooo00<0o`000?ooo`00o`001@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`00o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`03003o003o0000
oooo00X0oooo00<00?l00?ooo`00o`00303oool00`00o`00oooo0?ooo`0C0?ooo`D000006@3oool0
03`0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0=0?ooo`80o`003`3oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool20000
o`D0oooo00<0o`000?ooo`3oool01@3oool01`3o0000oooo003o003oool00?l00?ooo`3o00001P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3o
ool00`3o00000?l00?ooo`0:0?ooo`030?l00000o`00oooo00L0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0m03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:`3o
ool010000?l0oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
?03oool20?l000030?ooo`3o0000oooo00@0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo003o00050?ooo`040?l0003oool0oooo003o00@0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool00?l000<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00o`000?ooo`0:0?ooo`03003o003oool00?l000`0oooo00<0
0?l00?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3o00003P3oool20?l001D0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`80003o1@3oool00`3o0000oooo0?ooo`06
0?ooo`050?l00000o`00oooo003o003o00001`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`00o`00o`000?ooo`0:0?ooo`030?l00000
o`00oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`80o`00903o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02X0oooo00D0003o0?ooo`3oool0oooo
0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0>`3oool01@3o0000oooo
0?ooo`3oool0o`0000D0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00<0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`80003o103oool00`3o0000oooo
003o00050?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`00o`000P3oool01@00o`00oooo0?ooo`3oool0o`0000L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?l0003oool02P3oool00`00o`00oooo003o000<0?ooo`03003o003oool0oooo01L0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0<0?oo
o`040?l0003oool0oooo0?l000d0oooo0P3o000E0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l00?l00000o`050?ooo`030?l0003oool0oooo00H0oooo00D0o`00
003o003oool00?l00?l000070?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`090?ooo`030?l00000o`00o`0000/0oooo00<0o`00003o003oool01P3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o00008`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08D0oooo00<0003o0?ooo`3oool0IP3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0Z0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo03X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<00?l00000o`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`03
0?l0003oool00?l000D0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo
00D0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?l000L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<0
0?l00?l0003oool02P3oool00`00o`00oooo003o000<0?ooo`03003o003oool0oooo01L0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0<
0?ooo`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3o00004`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o003o00000?l01@3oool00`3o0000oooo0?oo
o`060?ooo`050?l00000o`00oooo003o003o00001`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o00000?l00?l0000;0?ooo`030?l0
0000o`00oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0o`0002<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`250?ooo`030000
o`3oool0oooo06D0oooo0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
503oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
;@3oool30?l000P0oooo0P3o00050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool0103o0000oooo0?ooo`3oool20000o`@0oooo00<0o`000?ooo`00o`001@3oool01@3o0000
oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
0?l000<0oooo00@00?l00?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0:0?ooo`03003o003o
ool00?l000`0oooo00<00?l00?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`00303o
ool0103o0000oooo0?ooo`3o000C0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l00?l00000o`050?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`00o`00
203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
2@3oool00`3o00000?l00?l0000:0?ooo`040?l0003oool0oooo003o00H0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`3o00008P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo0P000?l50?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1L0?ooo`80003oIP3oool00`3o
0000oooo0?l000050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool0103oool01@00
0?l0oooo0?ooo`3oool0o`0000L0oooo00<0o`000?ooo`3oool0;03oool0103o0000oooo0?ooo`3o
ool40?l000<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`03003o0000
0?l0oooo00<0oooo00<00?l00000o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`030?l0003oool00?l000D0oooo
00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3o
ool0oooo003o00030?ooo`04003o003oool0oooo0?l000L0oooo00D0o`000?ooo`3oool0oooo0000
o`050?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`3o00000?l00?oo
o`0:0?ooo`04003o003oool0oooo003o00/0oooo00<00?l00?ooo`3oool05`3oool00`000000oooo
0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00`0oooo00D0
o`000?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0?l001<0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3o
ool01`3oool00`00o`00oooo003o00080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`090?ooo`04003o003oool0oooo0?l000T0oooo00@0o`000?oo
o`3oool00?l01P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool02P3oool20000o`@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo05`0oooo00<0003o0?ooo`000?l0I03oool0103o0000oooo0?ooo`3o
00050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool2003o00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o0000
203oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00H0oooo0`3o00080?ooo`030?l0
003oool0oooo0080oooo00<00?l00000o`3oool00`3oool00`00o`00003o0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool20000o`@0
oooo00<0o`000?ooo`00o`001@3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00<0o`000?oo
o`3oool01@3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0o`001`3o
ool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool00`00o`00o`00
0?ooo`040?ooo`030?l00000o`00oooo00T0oooo00D00?l00?ooo`3oool0oooo003o000:0?ooo`03
003o003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo1@00000L0?ooo`030?l0
003oool0oooo00`0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0?l0
0180oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o
00D0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo003o00080?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`04003o003oool0oooo
0?l000T0oooo00@0o`000?ooo`3oool00?l01P3oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool20000o`@0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0S0?ooo`80003oG@3oool010000?l0oooo0?ooo`000?mS0?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180
oooo0P00o`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0603oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool01@3oool01@000?l0
oooo0?ooo`3oool0o`0000P0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0080oooo00<00?l00000o`3oool00`3oool00`00o`00003o0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool01`3o0000oooo0?ooo`3oool0
003o0?ooo`000?l00`3oool00`3o00000?l00?ooo`050?ooo`030?l0003oool0oooo0080oooo00@0
0?l00?ooo`3oool0o`001`3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3o
ool0o`001`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00o`000?ooo`040?ooo`030?l00000o`00oooo00T0oooo00D00?l00?ooo`3oool0oooo003o
000:0?ooo`03003o003oool0oooo01@0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`08
0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0080oooo00D00?l00000o`3oool00?l00000o`040?ooo`030?l0003oool0oooo00H0oooo
00@00?l00?l0003oool00?l0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`05003o003o0000oooo0?oo
o`3o00002@3oool0103o0000oooo0?ooo`00o`050?ooo`03003o003oool0oooo00D0oooo00<00?l0
0?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0:0?ooo`80003o103oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo02<0oooo00<0003o0?ooo`000?l0G03oool010000?l0oooo0?ooo`000?mR0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0180oooo00<00?l00?ooo`00o`000`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000
o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0C0?ooo`060?l0003oool0oooo0?oo
o`00o`00003o103oool00`00o`00003o0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`3o00000?l0
0?ooo`060?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool00`3o0000oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3o00070?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`060?ooo`03003o003o0000oooo00@0oooo00<0
o`00003o003oool02@3oool01@00o`00oooo0?ooo`3oool00?l000X0oooo00<00?l00?ooo`3oool0
603oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`050?l0003o
ool0oooo0?ooo`3o00004@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo
00D00?l00000o`3oool00?l00000o`040?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`3o
00000?l0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`080?ooo`05003o003o0000oooo0?ooo`3o00002@3oool0
103o0000oooo0?ooo`00o`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3o
ool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool01@3oool01000o`00oooo
0?ooo`000?l<0?ooo`030000o`3oool0003o00<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0S0?ooo`030000o`3oool0003o05`0oooo00@0003o0?ooo`3oool0003oHP3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0A0?ooo`04003o003oool0oooo003o00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo01@0oooo00H0o`000?ooo`3oool0oooo003o00000?l40?ooo`03
003o003oool0003o0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`06
0?l0003oool0oooo0000o`3oool0003o0`3oool00`3o00000?l00?ooo`060?ooo`050?l0003oool0
oooo0?ooo`00o`000P3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`00o`00
0`3oool01000o`00oooo0?ooo`3o00070?ooo`040?l0003oool0oooo0?ooo`80003o0`3oool00`3o
0000oooo0?ooo`050?ooo`03003o003oool0o`0000D0oooo00<0o`00003o003oool02@3oool01@00
o`00oooo0?ooo`3oool00?l000X0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00004@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00D00?l00000o`3oool00?l00000
o`040?ooo`030?l0003oool0oooo00H0oooo00@00?l00?ooo`3o00000?l0203oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`070?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo
0?ooo`00o`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool01@3o0000
oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool01@3oool2003o00030?ooo`000?l0oooo
00X0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo02<0oooo00<0003o003o00000?l0403oool00`000?l0oooo0?ooo`180?ooo`050000o`3oool0
oooo0?ooo`000?l01`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0A0?ooo`04003o003oool0oooo003o00<0oooo
00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`0001H0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool0203oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool00P3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0o`0001/0oooo00<0o`000?ooo`3oool05@3oool01P3o
0000oooo0?ooo`00o`00oooo0000o`@0oooo00<00?l00?ooo`000?l00P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l00P3oool01P000?l0oooo0?oo
o`3oool0o`00003o00L0oooo00D0o`000?ooo`3oool0oooo003o00020?ooo`030?l0003oool0oooo
00D0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?l000L0oooo00@0
o`000?ooo`3oool0oooo0P000?l30?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o0000
1@3oool00`3o00000?l00?ooo`090?ooo`05003o003oool0oooo0?ooo`00o`002P3oool00`00o`00
oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`800000103oool2000000@0oooo
0P00000=0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool01@00o`00003o
0?ooo`00o`00003o00@0oooo00<0o`000?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool00?l0
00P0oooo00<0o`000?ooo`3oool00P3oool20000o`D0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3oool01P3oool0103o
0000oooo0?ooo`00o`050?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0203oool0
1@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool01@3oool2003o00030?ooo`00
0?l0oooo00X0oooo00@0003o0?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool00?l000<0
oooo00<0o`000?ooo`3oool08P3oool010000?l0oooo003o00000?l@0?ooo`030000o`3oool0oooo
04P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
02P0oooo00<0003o0?ooo`3oool03@3oool20?l000030?ooo`3o0000oooo01T0oooo00<0o`000?oo
o`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0403oool0
1000o`00oooo0?ooo`00o`030?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo
0P3o000E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool20?l000l0oooo
00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo0P00o`030?ooo`03
0?l0003oool0oooo00T0oooo00<0o`00003o003o00006P3oool00`3o0000oooo0?ooo`0F0?ooo`06
0?l0003oool0oooo003o003oool0003o103oool00`00o`00oooo0000o`020?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0000o`020?ooo`060000o`3oool0
oooo0?l0003oool00?l01`3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`3o00002@3oool0103o
0000oooo0?ooo`00o`030?ooo`04003o003oool0oooo0?l000L0oooo00H0o`000?ooo`3oool0003o
0?ooo`000?l30?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o0000103oool00`3o0000
oooo003o000:0?ooo`05003o003oool0oooo0?ooo`00o`002P3oool00`00o`00oooo0?ooo`0H0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`090?l0003oool0oooo003o003oool0003o
0?ooo`00o`00003o00@0oooo00<0o`000?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool00?l0
00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?l000040?ooo`030?l0003oool0oooo
00H0oooo00D0o`000?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool02@3oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool20?l001T0oooo00<0003o0?ooo`3oool0103oool01P00o`00oooo0?oo
o`00o`00oooo0000o`X0oooo00@0003o0?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`3oool2
003o0080oooo00<0o`000?ooo`3oool08P3oool01@000?l00?l00?ooo`000?l00?l000l0oooo00<0
003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3o0000:03oool20000o`030?l0003oool0oooo00X0oooo0P3o00040?ooo`030?l0003o
ool0oooo01H0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00
o`000P3oool00`000?l0oooo0?ooo`060?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l0000D
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?l0000=
0?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`03003o003o
ool00?l000<0oooo00<0o`000?ooo`3oool02@3oool0103o00000?l00?ooo`3o000I0?ooo`030?l0
003oool0oooo01H0oooo00D0o`000?ooo`3oool00?l00000o`050?ooo`03003o003oool0003o0080
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0003o0080
oooo00D0003o0?ooo`3oool0o`00003o00080?ooo`070?l0003oool0oooo0?ooo`00o`00oooo0?l0
00090?ooo`040?l0003oool0oooo003o00<0oooo00<00?l00?ooo`3o0000203oool01P3o0000oooo
0?ooo`000?l0oooo0000o`<0oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0?ooo`3o0003
0?ooo`030?l0003oool00?l000X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`07
0?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`L000006`3oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`08
0?ooo`090?l0003oool0oooo003o003oool0003o0?ooo`00o`00003o00@0oooo00<0o`000?ooo`3o
ool01P3oool01@00o`00oooo0?ooo`3oool00?l000P0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0000o`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
o`00oooo0?l000040?ooo`030?l0003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo003o0004
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool02@3oool0103o0000oooo003o003o
000<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool40?l001@0oooo00<0
003o0?ooo`3oool01@3oool01P00o`00oooo0?ooo`3oool00?l00000o`X0oooo00@0003o0?ooo`3o
ool0003o0`3oool02@3o0000oooo0?ooo`3oool00?l00?ooo`00o`00oooo0?l0000T0?ooo`060000
o`00o`00oooo0000o`3oool00?l03@3oool00`000?l0oooo0000o`130?ooo`03003o003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`00
02P0oooo0P000?l0103oool0o`000?l0003o00070?ooo`80o`001P3oool00`3o0000oooo0?ooo`0C
0?ooo`<0o`002@3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0203o
ool20?l000D0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`030000o`3oool0oooo00H0oooo
00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o0000303oool00`00
0?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l000<0oooo00<00?l00?ooo`00o`00103oool0
0`3o0000oooo0?ooo`080?ooo`800?l000<0oooo0?l0003oool05`3oool00`3o0000oooo0?ooo`0G
0?ooo`050?l0003oool0oooo003o00000?l01P3oool01@00o`00003o0?ooo`3oool0o`0000D0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0000o`020?ooo`050000o`3oool0oooo0?l00000
o`00203oool01`3o0000oooo0?ooo`3oool00?l00?ooo`3o00002@3oool00`3o0000oooo003o0002
0?ooo`050000o`3oool0oooo003o003o0000203oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0
oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0?ooo`3o00030?ooo`030?l0003oool00?l0
00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
0180oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00D0o`000?ooo`3oool00?l00000o`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01P3oool01@00o`00oooo0?ooo`3oool00?l000P0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l00?l00000o`030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103o
ool01000o`00oooo0?ooo`3o00050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
2@3oool0103o0000oooo003o003o000<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool03P3oool30?l00140oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0003o0P3oool01@3o0000oooo0?ooo`3oool0
0?l00080oooo00@00?l00?ooo`3oool0o`008P3oool00`000?l0oooo003o00020?ooo`030000o`3o
ool00?l000`0oooo00<0003o0?ooo`000?l0@`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o000W0?ooo`040000
o`3o0000oooo0000o`<0oooo0`3o00020?ooo`80o`002@3oool00`3o0000oooo0?ooo`0>0?ooo`@0
o`00303oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool01`3oool0103o
0000oooo0?ooo`3o00040?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`3oool02P3oool20?l000D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0A0?ooo`040?l0003oool0oooo0?l000/0oooo
00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`3o00030?ooo`03003o003oool00?l000@0
oooo00<0o`000?ooo`3oool01`3oool01P3o00000?l00?ooo`00o`00oooo0?l001H0oooo00<0o`00
0?ooo`3oool0603oool01@3o0000oooo0?ooo`00o`00003o00H0oooo00@00?l00000o`3oool0o`00
1`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0003o0080oooo00D0003o0?ooo`3oool0
o`00003o00080?ooo`070?l0003oool0oooo0?ooo`00o`00oooo0?l000090?ooo`030?l0003oool0
0?l00080oooo00D0003o0?ooo`3oool00?l00?l000080?ooo`060?l0003oool0oooo0000o`3oool0
003o0`3oool00`3o0000oooo0?ooo`050?ooo`04003o003oool0oooo0?l000<0oooo00<0o`000?oo
o`00o`002@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool0603oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool2003o00L0oooo00<0o`00
0?ooo`3oool0203oool01@3o0000oooo0?ooo`00o`00003o00<0oooo00D00?l00000o`3oool0oooo
0?l000090?ooo`05003o003oool0oooo0?ooo`00o`00203oool0203o0000oooo0?ooo`3oool0003o
0?ooo`00o`00003o0`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00@0
0?l00?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00D00?l00?ooo`3oool0oooo003o00090?ooo`03003o003oool0oooo00X0oooo00<0o`00003o003o
0000303oool0103o0000oooo0?ooo`00o`060?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo003o
00030?ooo`03003o003oool0o`000280oooo00<0003o003o003oool00P3oool010000?l0oooo0?oo
o`00o`0;0?ooo`030000o`3oool0003o00l0oooo00<0o`000?ooo`3oool0<03oool2003o00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000L0
oooo00<0003o0?ooo`3oool07@3oool010000?l0o`000?ooo`000?l60?ooo`80o`00303oool00`3o
0000oooo0?ooo`0:0?ooo`<0o`00403oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o
0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<00?l00?ooo`3oool00P3o
ool01000o`00oooo0?ooo`000?l90?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?l000050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
403oool0103o0000oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3o
ool0o`000`3oool01000o`00oooo0?ooo`00o`030?ooo`030?l0003oool0oooo00L0oooo00H0o`00
003o003oool00?l00?ooo`3o000E0?ooo`030?l0003oool0oooo01T0oooo00D0o`000?ooo`00o`00
oooo0000o`060?ooo`04003o00000?l0oooo0?l000L0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0000o`020?ooo`050000o`3oool0oooo0?l00000o`00203oool01`3o0000oooo0?ooo`3o
ool00?l00?ooo`3o00002@3oool00`3o0000oooo003o00020?ooo`050000o`3oool0oooo003o003o
0000203oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0oooo00<0o`000?ooo`3oool01@3oool0
1000o`00oooo0?ooo`3o00030?ooo`030?l0003oool00?l000T0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01P0oooo00<000000?ooo`3oool05`3o
ool00240oooo0P00000:0?ooo`8000003@3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
0?l000L0oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo003o003oool0003o00<0oooo00D0
0?l00000o`3oool0oooo0?l000080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
1P3oool0203o0000oooo0?ooo`3oool0003o0?ooo`00o`00003o0`3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0?l000050?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l000T0oooo
00<00?l00?ooo`3oool02P3oool2003o00d0oooo00@0o`000?ooo`3oool00?l01P3oool00`3o0000
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool00`00o`00
oooo0?ooo`030?ooo`030000o`00o`00oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`050?l0003oool0oooo0?ooo`00o`00103oool00`00o`00o`000?ooo`0Q0?ooo`030000o`00o`00
oooo0080oooo00D0003o0?ooo`3oool0oooo003o000:0?ooo`030000o`3oool0003o00h0oooo0P3o
000b0?ooo`800?l00`3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`050000o`3o0000oooo0?ooo`00
0?l05@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0140oooo00D0o`000?ooo`3o
ool0oooo0000o`080?ooo`030000o`3oool0oooo00@0oooo0P3o00040?ooo`050?l0003oool0oooo
0?ooo`00o`001@3oool00`00o`00oooo0000o`090?ooo`030000o`3oool0o`0000D0oooo00<0o`00
0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0@0?ooo`040?l0003oool00?l00?l000T0oooo00<0003o0?ooo`3oool0
3@3oool010000?l0oooo0?ooo`3o00030?ooo`04003o003oool0oooo003o00<0oooo00<0o`000?oo
o`3oool01`3oool0103o00000?l00?ooo`00o`020?ooo`030?l0003oool0oooo0140oooo00<0o`00
0?ooo`3oool06P3oool01@3o0000oooo003o003oool0003o00H0oooo00@00?l00000o`3oool0o`00
1`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o0080oooo00D0003o0?ooo`3oool0
o`00003o00080?ooo`030?l0003oool0oooo0080oooo00<00?l00?l0003oool0203oool00`3o0000
oooo003o00020?ooo`050000o`3oool0oooo003o003o00002@3oool01@3o0000oooo0000o`3oool0
003o00<0oooo00<0o`000?ooo`3oool01@3oool01000o`00oooo0?ooo`3o00030?ooo`030?l0003o
ool00?l000T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0803oool0
103o0000oooo0?ooo`3oool20000o`D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool01000o`00oooo0?oo
o`00o`050?ooo`030?l0003oool0oooo00T0oooo00D0o`000?ooo`00o`00oooo0000o`030?ooo`05
003o00000?l0oooo0?ooo`3o0000203oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00H0oooo00P0o`000?ooo`3oool0oooo0000o`3oool00?l00000o`<0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0oooo0?l000H0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`002@3oool00`00
o`00oooo0?ooo`0:0?ooo`03003o003o00000?l000`0oooo00<0o`000?ooo`3oool00P00o`040?oo
o`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`050?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`00o`001`3oool01@000?l0oooo0?ooo`3oool0
003o0080oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`03003o003oool0oooo0200oooo00<0
003o003o003oool00P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00L0oooo00<0
003o0?ooo`000?l0303oool20?l00080oooo00<0o`000?ooo`3oool0;P3oool01000o`00oooo0?oo
o`00o`020?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0003o01d0oooo00D0003o0?l0003oool0oooo0000o`0F0?oo
o`030?l0003oool0oooo00D0oooo0P3o000E0?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool00?l000H0oooo00<00?l0
0?ooo`000?l02@3oool00`000?l0oooo0?l000060?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool03`3o
ool01@3o0000oooo003o003oool00?l000T0oooo00<0003o0?ooo`3oool03@3oool010000?l0oooo
0?ooo`3o00020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`3o0000oooo0?ooo`060?oo
o`050?l00000o`00oooo0?ooo`00o`000P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo01/0oooo00D0o`000?ooo`00o`00oooo0000o`060?ooo`04003o00000?l0oooo0?l000L0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0000o`020?ooo`040000o`3oool0oooo003o00T0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00o`000?ooo`080?ooo`040?l0003oool00?l00?oo
o`80003o0P3oool00`00o`00o`000?ooo`080?ooo`030?l0003oool0003o0080oooo00@0003o0?oo
o`3oool0o`001`3oool01000o`00oooo0?ooo`3o00030?ooo`030?l0003oool00?l000T0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01P0oooo00<0
00000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0803oool01`3o0000oooo0?ooo`3o
ool0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o
00001`3oool00`3o0000oooo0?ooo`030?ooo`04003o003oool0oooo003o00D0oooo00<0o`000?oo
o`3oool02@3oool01@3o0000oooo003o003oool0003o00<0oooo00D00?l00000o`3oool0oooo0?l0
00080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool02@3o0000oooo0?oo
o`3oool0003o003o003oool00?l00000o`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`002@3oool00`00o`00oooo0?oo
o`0:0?ooo`03003o003o00000?l000`0oooo00<0o`000?ooo`3oool00P00o`040?ooo`030?l0003o
ool0oooo0180oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`03003o003o
ool0oooo00<0oooo00@0003o0?ooo`3oool00?l01P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`030?l00000o`00oooo01l0oooo00<0003o003o
003oool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo00D0oooo00D0003o0?oo
o`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;P3oool0
1P00o`00oooo0?ooo`00o`00oooo0000o`P0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0003o01d0oooo00D0003o0?ooo`3oool0oooo0000o`0G0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3oool0103o0000oooo0?ooo`000?l90?oo
o`050000o`3oool0oooo0?ooo`3o0000203oool00`3o0000oooo003o00060?ooo`03003o003oool0
003o00T0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00l0oooo00H0
o`00003o003oool0oooo003o003o00070?ooo`030000o`3oool0oooo00h0oooo00@0003o0?ooo`3o
ool0o`000P3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3oool01P3oool0
0`3o00000?l00?ooo`020?ooo`03003o003oool0o`000140oooo00<0o`000?ooo`3oool0703oool0
1@3o0000oooo003o003oool0003o00H0oooo00@00?l00000o`3oool0o`001`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`090?ooo`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool00?l02@3oool00`3o0000
oooo0?ooo`020?ooo`03003o003o0000oooo00P0oooo00@0o`000?ooo`00o`00oooo0P000?l20?oo
o`03003o003o0000oooo00P0oooo00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?l000080?oo
o`04003o003oool0oooo0?l00080oooo00@0o`000?ooo`3oool00?l02@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?ooo`070?l0003oool0oooo0?ooo`000?l0oooo
0000o`040?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l000070?ooo`03
0?l0003oool0oooo00<0oooo00@00?l00?ooo`3oool00?l01@3oool00`3o0000oooo0?ooo`090?oo
o`050?l0003oool00?l00?ooo`000?l00`3oool01@00o`00003o0?ooo`3oool0o`0000P0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`090?l0003oool0oooo0?ooo`000?l0
0?l00?ooo`00o`00003o0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?oo
o`05003o003oool0oooo0?ooo`3o00001`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00D00?l00?ooo`3oool0oooo003o00090?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?l00000o`00303oool01@3o0000oooo003o003oool00?l000@0oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0
0`3oool010000?l0oooo0?ooo`00o`060?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0103o
0000oooo0?ooo`00o`060?ooo`030?l00000o`00oooo01l0oooo00<0003o003o003oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000
o`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0;@3oool01P00o`00oooo0?oo
o`00o`00oooo0000o`P0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`030?ooo`04
0000o`3oool0oooo0000oa/0oooo00<0003o0?l0003oool00P3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool05P3oool0103o0000oooo0?ooo`000?l9
0?ooo`040000o`3oool0oooo0?l000T0oooo00<0o`000?ooo`00o`001P3oool00`00o`00oooo0000
o`090?ooo`030000o`3oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`03003o
003o0000oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0?0?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0o`000080oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00080?ooo`03
0?l00000o`00oooo0080oooo00@00?l00?ooo`3oool0o`003`3oool00`3o0000oooo0?ooo`0M0?oo
o`050?l0003oool00?l00?ooo`000?l01P3oool01000o`00003o0?ooo`3o00070?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000000o`3oool00P3oool010000?l0oooo0?ooo`00o`090?ooo`030?l0
003oool0oooo0080oooo00<00?l00?l0003oool0203oool02P3o0000oooo003o003oool0003o0?oo
o`000?l0oooo003o003o00090?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3o0000203o
ool01`00o`00oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`060?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0I0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`D000007P3oool01`3o0000oooo0?ooo`3oool0003o0?oo
o`000?l00`3oool00`3o0000oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o0000203oool0
0`3o0000oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`3o0000oooo0?oo
o`090?ooo`050?l00000o`00oooo0?ooo`000?l00`3oool01@00o`00003o0?ooo`3oool0o`0000P0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`090?l0003oool0oooo0000
o`3oool00?l00?ooo`00o`00003o0080oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?oo
o`3oool00?l000@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00@00?l00?ooo`3oool00?l02P3oool00`00o`00oooo0?ooo`090?ooo`03
003o003o00000?l000`0oooo00<0o`000?ooo`00o`000P3oool01@00o`00oooo0?ooo`3oool0o`00
01D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo
00D0oooo00@0003o0?ooo`3oool00?l0103oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
oooo0?l00080oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo003o000O0?ooo`030000o`00
o`00oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`050000o`3o
ool0oooo0?ooo`000?l01`3oool20?l000L0oooo00<0o`000?ooo`3oool0;03oool01`00o`00oooo
0?ooo`3oool00?l00?ooo`000?l0203oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3oool0003o6`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00D0oooo00<00?l00?ooo`3oool03P3oool0103o0000oooo0?l0003o000G0?ooo`03003o003o
ool0o`000080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l0000:0?ooo`030?l00000
o`00oooo00H0oooo00<00?l00?ooo`000?l02@3oool00`000?l0o`000?ooo`080?ooo`030?l0003o
ool0o`0000@0oooo0`00o`001@3oool0o`000?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0
3@3oool2003o00D0oooo00<0o`00003o003oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0o`000080oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00080?ooo`03
003o003oool0oooo0080oooo00@00?l00?ooo`3oool0o`003`3oool00`3o0000oooo0?ooo`0M0?oo
o`050?l00000o`00oooo0?ooo`000?l01P3oool01000o`00oooo0000o`3o00080?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000000o`3oool00P3oool010000?l0oooo0?ooo`00o`0:0?ooo`060?l0
003oool0oooo0?ooo`00o`00o`002@3oool02P3o0000oooo003o003oool0003o0?ooo`000?l0oooo
003o003o00090?ooo`030?l0003oool0003o0080oooo00<0003o0?ooo`3o0000203oool01`00o`00
oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo00@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0E0?ooo`D000006@3oool0
03`0oooo00<000000?ooo`3oool0803oool01`3o0000oooo0?ooo`3oool0003o0?ooo`000?l00`3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0o`0000T0oooo00<0o`000?ooo`3oool00P3o
ool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<0o`000?ooo`3oool02@3oool01@3o00000?l0
0?ooo`3oool0003o00@0oooo00@0003o0?ooo`3oool0o`00203oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00D0oooo00T0o`000?ooo`3oool0003o0?ooo`00o`00oooo003o00000?l0
0P3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo003o00@0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@00?l00?ooo`3o
ool00?l02P3oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo003o00`0oooo00<0o`00
0?ooo`00o`000P3oool01@00o`00oooo0?ooo`3oool0o`0001D0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool00?l0
103oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l00080oooo00<00?l00?ooo`3o
ool0103oool0103o0000oooo0?ooo`00o`0M0?ooo`030000o`00o`00oooo00D0oooo00<0003o0?oo
o`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo02/0oooo00H00?l00?ooo`3oool0oooo003o
00000?l:0?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0000o`3oool0oooo01L0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`040?ooo`80
0?l0403oool00`3o0000oooo0?ooo`0F0?ooo`800?l000D0oooo0?l0003oool0oooo0000o`090?oo
o`030000o`3oool0o`0000/0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0000o`090?oo
o`030000o`3o0000oooo00T0oooo00@0o`000?ooo`3oool0oooo0P00o`020?ooo`03003o003oool0
o`000080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0
o`0000D0oooo00<0o`00003o003oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
o`000080oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool0o`0000H0oooo00<0
o`00003o003oool00`3oool01@00o`00oooo0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`3oool0
7P3oool01@3o00000?l00?ooo`3oool0003o00H0oooo00@00?l00?ooo`000?l0o`00203oool01@3o
0000oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`09
0?ooo`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool00?l02P3oool01P3o0000oooo0?oo
o`3oool00?l00?l000T0oooo00X0o`000?ooo`00o`00oooo0000o`3oool0003o0?ooo`00o`00o`00
2@3oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`0000L0oooo00<00?l00?ooo`3oool0
0P3oool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool08@3oool01P3o0000oooo0?ooo`000?l0oooo0000o`<0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l000090?ooo`050?l0003oool0oooo0?oo
o`00o`001@3oool01@00o`00oooo0?ooo`3oool0o`0000/0oooo00D0o`00003o003oool0oooo0000
o`040?ooo`04003o00000?l0oooo0?l000P0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`060?ooo`080?l0003oool0003o0?ooo`00o`00oooo003o00000?l20?ooo`030?l0003oool0
oooo00L0oooo00@0o`000?ooo`3oool00?l0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo003o000;0?ooo`03003o003o
ool0oooo00P0oooo00@00?l00?ooo`3oool00?l0303oool00`3o0000oooo003o00020?ooo`05003o
003oool0oooo0?ooo`3o00005@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0
oooo00<00?l00?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?l0003oool00P3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool00?l0
01d0oooo00<0003o003o003oool01@3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo
00@0oooo00D0003o0?ooo`3o0000o`000000o`060?l000/0oooo00<0o`000?ooo`3oool0:P3oool0
0`00o`00oooo0?ooo`020?ooo`03003o00000?l0oooo00P0oooo00<0o`000000o`3oool01P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool05`3oool00`000?l0o`000?oo
o`040?ooo`030000o`3oool0oooo00@0oooo0P00o`0Y0?ooo`04003o003oool00?l00?l00080oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l0000;0?ooo`03003o003oool0oooo00D0oooo
00<00?l00?ooo`000?l02P3oool00`000?l0oooo0?ooo`0:0?ooo`800?l0103oool00`00o`00oooo
0?l000020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool01000o`00oooo
0?ooo`3o00050?ooo`030?l0003oool00?l000@0oooo00<0003o0?ooo`3oool0403oool01@000?l0
oooo0?l0003oool00?l000H0oooo00@00?l00?ooo`3oool0o`001P3oool00`3o00000?l00?ooo`03
0?ooo`05003o003oool0oooo0?ooo`3o0000303oool00`3o0000oooo0?ooo`0O0?ooo`050?l00000
o`00oooo0?ooo`000?l01P3oool01000o`00oooo0000o`3o00080?ooo`050?l0003oool0oooo0?oo
o`3o00002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00P0003o0?oo
o`3oool0oooo0000o`3oool00?l00?l000X0oooo00D0o`000?ooo`3oool0oooo003o000:0?ooo`0:
0?l0003oool00?l00?ooo`000?l0oooo0000o`3oool00?l00?l000T0oooo00<0o`000000o`3oool0
0P3oool00`000?l0oooo0?l000070?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o0000
0`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0240oooo00<0o`000?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000/0oooo
00<0o`000?ooo`3o00002@3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`000?l00`3oool01000
o`00oooo0?ooo`3o000<0?ooo`050?l00000o`00oooo0?ooo`000?l0103oool01000o`00003o0?oo
o`3o00080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool0203o0000oooo
0000o`3oool00?l00?ooo`00o`00003o0P3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0
oooo003o00@0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo
00<00?l00?ooo`00o`002`3oool00`00o`00oooo0?ooo`080?ooo`05003o003oool0oooo0?ooo`00
o`00303oool00`3o00000?l00?ooo`020?ooo`03003o003oool0o`0001H0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00D0oooo00D0003o0?ooo`3o
ool0oooo003o00030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool00P3oool00`00
o`00oooo0?ooo`050?ooo`040?l0003oool0oooo003o01`0oooo00<0003o003o003oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0003o0?l0003oool00P3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool04`3oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`000000o`3oool01P3oool0
1@3o0000oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`009`3oool01@00o`00oooo0?oo
o`00o`00o`000080oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`090?ooo`03003o
003o0000oooo00H0oooo00<00?l00000o`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`800?l0
1`3oool01@00o`00o`000?ooo`3oool0003o00T0oooo00<0003o0?ooo`3oool02@3oool01000o`00
oooo0?ooo`3o00070?ooo`030?l00000o`00oooo0080oooo00<0003o0?ooo`3oool04@3oool01@00
0?l0o`000?ooo`3oool00?l000H0oooo00@00?l00?ooo`3oool0o`001P3oool00`3o00000?l00?oo
o`040?ooo`05003o003oool0oooo0?ooo`3o00002@3oool00`00o`00o`000?ooo`0Q0?ooo`050?l0
0000o`00oooo0?ooo`000?l01`3oool00`00o`00003o0?l000080?ooo`050?l0003oool0oooo0?oo
o`3o00002`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00P0003o0?oo
o`3oool0oooo0000o`3oool00?l00?l000X0oooo00D0o`000?ooo`3oool0oooo003o000:0?ooo`0:
0?l00000o`00oooo0?ooo`000?l0oooo0000o`3oool00?l00?l000T0oooo00<0o`000000o`3oool0
0P3oool00`000?l0oooo0?l000070?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o0000
0`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003o
ool0oooo0240oooo00<0o`000?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`0000`0oooo
00<0o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool00?l00080003o0`3oool01000o`00
oooo0?ooo`3o000<0?ooo`05003o003oool0oooo0?ooo`000?l0103oool01000o`00003o0?ooo`3o
00070?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool02`3o0000003o0?oo
o`3oool00?l00?ooo`00o`00oooo0000o`3oool0o`0000T0oooo00@0o`000?ooo`3oool00?l00`3o
ool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`00o`00oooo
003o000;0?ooo`03003o003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo003o000<0?ooo`03
0?l00000o`00oooo0080oooo00<00?l00?ooo`3o00005`3oool00`3o0000oooo0?ooo`030?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`060?ooo`05
0000o`3oool0oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3o0000oooo
0?ooo`00o`00203oool0103o0000oooo0?ooo`00o`070?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0
003o0?l0003oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0
o`000?ooo`3o0000503oool00`00o`00oooo0?ooo`020?ooo`030000o`00o`00oooo00L0oooo00<0
o`000?ooo`000?l0203oool0103o0000oooo0?ooo`000?l50?ooo`050000o`3oool0oooo0?ooo`00
o`004`3oool00`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo00<0oooo00@00?l00?ooo`3o
ool00?l09`3oool01`00o`00oooo0?ooo`00o`00o`000?ooo`000?l02`3oool00`000?l0oooo0?oo
o`090?ooo`03003o003oool0o`0000L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`080?ooo`03003o003oool0oooo00H0oooo00D00?l00?ooo`3o0000oooo0000o`090?ooo`030000
o`3oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo0?l000070?ooo`030?l0003oool00?l00080
oooo00<0003o0?ooo`3oool04@3oool01@000?l0o`000?ooo`3oool00?l000H0oooo00@00?l00?oo
o`3oool0o`001@3oool00`3o00000?l00?ooo`050?ooo`05003o003oool0oooo0?ooo`3o00001`3o
ool20?l00003003o003oool0oooo0240oooo00@00?l00?l0003oool0003o203oool00`00o`00003o
0?l000080?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00X0oooo00L0003o0?ooo`3oool0oooo0000o`3oool00?l000/0oooo00H0o`00
0?ooo`3oool0oooo0?l00000o`090?ooo`040?l00000o`00oooo0000o`80oooo00@0003o0?ooo`3o
ool00?l02@3oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0o`0000L0oooo00<00?l00?oo
o`3oool00P3oool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01T0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0000o`030?ooo`04
0000o`3oool0oooo0?l000`0oooo00<0o`000?ooo`3oool0203oool0203o0000oooo0?ooo`3oool0
0?l00000o`3oool0003o0`3oool00`00o`00oooo0?l0000<0?ooo`04003o003oool0oooo0000o`D0
oooo00@00?l00000o`3oool0o`001`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
00H0oooo00@0o`000000o`3oool00?l00`3oool00`00o`00003o0?l0000:0?ooo`030?l0003oool0
0?l000@0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo00<0
0?l00?ooo`00o`002`3oool00`00o`00oooo0?ooo`080?ooo`05003o003oool0oooo0?ooo`00o`00
303oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0o`0001L0oooo00<0o`000?ooo`3oool0
0`3oool01@00o`00oooo0?ooo`3oool0003o00T0oooo00<00?l00?ooo`3oool01P3oool01@000?l0
oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool0103oool01@000?l0o`000?ooo`3oool0
0?l000P0oooo00@0o`000?ooo`3oool00?l01P3oool20?l001<0oooo00<0003o003o003oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`06003o003oool0oooo0?ooo`3o0000003o1@3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo00@0o`000?ooo`3oool0o`004P3oool00`00
o`00oooo0?ooo`030?ooo`030000o`00o`00oooo00L0oooo00<0o`000?ooo`000?l0203oool00`3o
0000oooo0000o`060?ooo`040000o`3oool0oooo0?ooo`800?l04P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o000U0?ooo`08003o003o
ool0oooo0?ooo`00o`00o`000?ooo`000?l;0?ooo`030000o`3oool0oooo00T0oooo00<00?l00?oo
o`3o00001`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<00?l00?oo
o`3oool01`3oool01@00o`00oooo0?l0003oool0003o00T0oooo00<0003o0?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00H0o`000?ooo`3oool00?l00?oo
o`000?l90?ooo`030?l0003oool0oooo00L0oooo00D0003o0?l0003oool0oooo003o00060?ooo`06
003o003oool0oooo0?l0003oool0003o0`3oool00`3o00000?l00?ooo`050?ooo`03003o003oool0
oooo0080oooo00<0o`000?ooo`3oool0103o00000`3oool00?l0003o000S0?ooo`04003o003o0000
oooo0000o`P0oooo00<00?l00000o`3o0000203oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo
00D0o`000?ooo`000?l0oooo0?l0000<0?ooo`030000o`3oool0oooo0080oooo00<0003o003o003o
ool02P3oool01P3o0000oooo0?ooo`3oool0o`00003o00T0oooo00@0o`00003o003oool0003o0P3o
ool010000?l0oooo0?ooo`00o`090?ooo`030?l000000?l0oooo00<0oooo00<0003o0?l0003oool0
1P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030?l0003o
ool0003o00<0oooo00<0003o0?ooo`3o0000603oool01@3o0000oooo0?ooo`3oool0003o0080oooo
00L0003o0?ooo`3oool0oooo003o003oool0o`0000`0oooo00@00?l00?ooo`3oool0003o1@3oool0
1000o`00003o0?ooo`3o00070?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3o
ool0103o0000003o0?ooo`00o`030?ooo`03003o00000?l0o`0000X0oooo00<0o`000?ooo`00o`00
103oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`00o`00
oooo003o000;0?ooo`03003o003oool0oooo00P0oooo00D00?l00?ooo`3oool0oooo003o000<0?oo
o`03003o003oool0oooo00<0oooo00<00?l00?l0003oool05P3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool00?l00080oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3o0000
oooo0?ooo`00o`00203oool0103o0000oooo0?ooo`00o`060?ooo`030?l0003oool0o`000180oooo
00<0003o003o003oool01`3oool00`000?l0oooo0?ooo`030?ooo`06003o003oool0oooo0?l0003o
ool0003o1@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo0P000?l50?oo
o`050?l0003oool0oooo0?ooo`3o00004P3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0
0?l000L0oooo00@0o`000?ooo`3oool0003o203oool00`3o0000oooo0000o`070?ooo`050000o`3o
ool00?l00?ooo`00o`004@3oool00`000?l0o`000?ooo`060?ooo`030000o`3oool0oooo00<0oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0R0?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`000?l02`3oool00`000?l0oooo0?ooo`080?ooo`04003o003oool0oooo0?l000L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo00L0
oooo00D00?l00?ooo`3o0000oooo0000o`090?ooo`040000o`3oool0oooo0?l000D0oooo00<00?l0
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`060?l0003oool0oooo003o003oool0003o
2@3oool00`3o0000oooo0?ooo`070?ooo`050000o`3o0000oooo0?ooo`00o`001`3oool01@00o`00
oooo0?l0003oool0003o00<0oooo00<0o`00003o003oool01@3oool00`00o`00oooo0?ooo`020?oo
o`<0o`001@3oool00`00o`00oooo003o000R0?ooo`04003o003o0000oooo0000o`P0oooo00<00?l0
0000o`3o00002@3oool0103o0000oooo0?ooo`3o000<0?ooo`<0003o00<0oooo0?l0003oool02`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`00o`00oooo00X0oooo00H0o`000?ooo`3oool0oooo
0?l00000o`090?ooo`040?l00000o`00oooo0000o`80oooo00@0003o0?ooo`3oool00?l02@3oool0
0`3o0000003o0?ooo`030?ooo`030000o`3o0000oooo00H0oooo00<00?l00?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool0
03`0oooo1@00000O0?ooo`030?l0003oool0003o00<0oooo00<0003o0?ooo`3o0000603oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00L0003o0?ooo`3oool0oooo003o003oool0o`0000`0oooo
00@00?l00?l0003oool0003o1@3oool01000o`00003o0?ooo`3o00070?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool01P3oool0103o0000003o0?ooo`00o`030?ooo`03003o00000?l0
o`0000X0oooo00<0o`000?ooo`00o`00103oool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0
oooo0?l000H0oooo00<00?l00?ooo`00o`002`3oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
0000oooo01H0oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo003o003oool0003o00X0oooo
00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0003o00H0oooo
00D0003o0?l0003oool0oooo003o00080?ooo`050?l0003oool0oooo0?ooo`00o`00103oool0103o
0000oooo0?ooo`3o000B0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00o`000?l000020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`060?ooo`80003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`020?ooo`80003o00<0oooo
003o003oool01P3oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`000?l01`3o
ool00`000?l0oooo003o00020?ooo`03003o003oool0oooo00h0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo00<0oooo00<00?l00?l000000?l02`3o
ool00`000?l0oooo0?ooo`080?ooo`05003o003oool0oooo0?ooo`3o00001P3oool00`000?l0oooo
0?ooo`080?ooo`030?l000000?l0oooo00P0oooo00<00?l00?ooo`3oool01`3oool01000o`00oooo
0?l000000?l:0?ooo`030000o`3oool0oooo0080o`000`3oool00`00o`00oooo0?ooo`030?ooo`03
0?l0003oool0oooo00H0oooo00H0o`000?ooo`3oool0oooo003o00000?l80?ooo`030?l0003oool0
o`0000P0oooo00@0003o0?l0003oool00?l0203oool01@00o`00oooo0?l0003oool0003o0080oooo
00<0o`00003o003oool01P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool00?l000L0oooo
00<0003o0?ooo`3oool0603oool01000o`00o`000?ooo`000?l80?ooo`03003o00000?l0o`0000T0
oooo00<0o`000?ooo`3o00002`3oool20000o`040?l0003oool0003o0?l000`0oooo00<0003o0?l0
003oool00`3oool00`000?l0o`000?ooo`0:0?ooo`060?l0003oool0oooo0?ooo`3o00000?l02@3o
ool0103o00000?l00?ooo`000?l20?ooo`040000o`3oool0oooo003o00T0oooo00<0o`000000o`3o
ool00`3oool00`000?l0o`000?ooo`060?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`0E0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0
8@3oool00`3o0000oooo0000o`030?ooo`030000o`3oool0o`0001T0oooo00<0o`000?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000oooo00X0oooo00D00?l00?ooo`3o0000
oooo0000o`060?ooo`030000o`3oool0o`0000L0oooo00<00?l00?ooo`3oool0103oool00`00o`00
oooo0?ooo`060?ooo`040?l000000?l0oooo003o00<0oooo00<00?l00000o`3o00002P3oool00`3o
0000oooo003o00040?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3oool0o`001`3oool0
0`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo00<0oooo00<00?l00?l0003oool05`3oool0
1@3o0000oooo0?ooo`3oool00?l00080oooo00<00?l00000o`3oool0203oool00`00o`00oooo0?oo
o`080?ooo`070000o`3oool0oooo0?ooo`00o`00oooo0000o`060?ooo`050000o`3o0000oooo0?oo
o`00o`00203oool01@3o0000oooo0?ooo`3oool00?l000@0oooo00@0o`000?ooo`3oool0o`004@3o
ool00`000?l00?l00?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0103o
ool20000o`D0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`0=0?ooo`03003o
003oool0oooo0080003o0`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`070?ooo`050000o`00o`00oooo0?ooo`00
o`003`3oool00`000?l0o`000?ooo`080?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo0?ooo`0:0?ooo`80003o4`3oool00`00o`00oooo0?ooo`040?ooo`03
003o003o0000003o00/0oooo00<0003o0?ooo`3oool0203oool01@00o`00oooo0?ooo`3oool0o`00
00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000003o0?ooo`080?ooo`03003o003oool0oooo
00L0oooo00@00?l00?ooo`3oool0003o2P3oool00`000?l0oooo0?l000020?ooo`80o`0000<00?l0
0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l0203o
ool00`3o0000oooo0?l000080?ooo`040000o`3o0000oooo003o00P0oooo00D00?l00?ooo`3oool0
o`000000o`020?ooo`030?l00000o`00oooo00L0oooo00<00?l00?ooo`3oool0203oool01000o`00
oooo0?ooo`00o`070?ooo`030000o`3oool0oooo01P0oooo00@00?l00?l0003oool0003o203oool0
0`00o`00003o0?l000090?ooo`030?l0003oool0o`0000T0oooo0P000?l20?ooo`040?l0003oool0
oooo0000o``0oooo00<0003o0?l0003oool00`3oool00`000?l0o`000?ooo`0:0?ooo`060?l0003o
ool0oooo0?ooo`3o00000?l02@3oool0103o00000?l00?ooo`000?l20?ooo`040000o`3oool0oooo
003o00T0oooo00<0o`000000o`3oool00`3oool00`000?l0o`000?ooo`060?ooo`03003o003oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
oooo00H0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?l0000I0?ooo`030?l0003oool0003o00@0oooo00D0003o0?ooo`3oool0oooo003o000<
0?ooo`05003o003oool0o`000?ooo`000?l01P3oool00`00o`00003o0?l000070?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool010000?l0oooo0?ooo`00o`030?ooo`03003o
00000?l0o`0000X0oooo00<0o`000?ooo`00o`00103oool00`3o0000oooo0?ooo`080?ooo`040?l0
003oool0oooo0?l000L0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`060?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo01L0oooo00@0o`000?ooo`3oool00?l00`3oool00`00o`00003o0?ooo`080?oo
o`03003o003oool0oooo00P0oooo00L0003o0?ooo`3oool0oooo003o003oool0003o00H0oooo00@0
003o0?ooo`3oool00?l02@3oool01@3o0000oooo0?ooo`3oool00?l000<0oooo00<0o`000?ooo`3o
ool01@000?l40?ooo`03003o003oool0oooo00L0oooo00<0003o003o003oool0203oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool00?l00080oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0A0?ooo`040?l0003oool0oooo0?ooo`80003o203oool00`000?l0oooo0?l000070?oo
o`030?l0003oool0oooo00`0oooo0`000?l50?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0:0?ooo`<0003o2P3oool00`000?l0oooo0?ooo`020?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool010000?l0oooo0?ooo`000?lB
0?ooo`03003o003oool0oooo00@0oooo00<00?l00?l000000?l02`3oool00`3o0000003o0?ooo`07
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0003o00L0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0000o`0:
0?ooo`030000o`3oool0o`0000<0oooo00<00?l00?l0003oool0103oool00`3o0000oooo0?ooo`08
0?ooo`050?l0003oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?l000080?ooo`040000o`3o
0000oooo003o00P0oooo00@00?l00?ooo`3oool0o`000P000?l00`3oool0o`00003o00080?ooo`03
003o003oool0oooo00P0oooo00@00?l00?ooo`3oool00?l01P3oool20000oa00oooo0`00o`060?oo
o`05003o003oool0o`000?ooo`000?l0203oool00`00o`00003o0?l000090?ooo`030?l0003oool0
o`0000L0oooo0P000?l40?ooo`040?l0003oool0oooo0000o``0oooo00<0003o0?l0003oool00`3o
ool00`000?l0o`000?ooo`0:0?ooo`060?l0003oool0oooo0?ooo`3o00000?l02P3oool00`00o`00
oooo0000o`030?ooo`030000o`3oool00?l000T0oooo00<0o`000000o`3oool00`3oool00`000?l0
oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool06@3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3o00006@3oool00`3o0000003o003o00040?ooo`060000o`3oool0oooo0?ooo`3o
00000?l02`3oool01@00o`00oooo0?l0003oool0003o00H0oooo00<00?l00000o`3oool01`3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00@0003o0?ooo`3oool00?l00`3o
ool00`00o`00003o0?l0000:0?ooo`040?l0003oool00?l00000o`<0oooo00<0o`000?ooo`3oool0
203oool0103o0000oooo0?ooo`3o00070?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3o
ool01P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3o
ool00`3oool00`3o00000?l00?ooo`0G0?ooo`040?l0003oool0oooo003o00<0oooo00<0003o0?oo
o`3oool0203oool00`00o`00oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`00o`00oooo0000
o`060?ooo`040000o`3oool0oooo003o00X0oooo00@0o`000?ooo`3oool00?l00`3oool00`3o0000
oooo0000o`020?ooo`030?l0003oool0oooo00H0003o00<00?l00?ooo`3oool01@3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`00o`000P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00@0o`000?ooo`000?l0003o2`3oool20000
o`P0oooo00<0o`000?ooo`3oool02@3oool20000o`P0oooo00<00?l00?ooo`3oool0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`00
o`00003o0?ooo`020?ooo`03003o003oool0oooo00H0oooo10000?l20?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo
00P0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`03003o003oool0oooo00H0oooo00<00?l0
0000o`3oool02@3oool00`3o0000oooo0000o`080?ooo`03003o003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0003o00L0oooo00<00?l0
0?ooo`3oool02@3oool00`00o`00oooo0000o`0;0?ooo`050000o`3o0000oooo0?ooo`00o`000P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00H0o`000?ooo`3oool0003o
0?ooo`00o`070?ooo`030?l0003oool0o`0000P0oooo00@0003o0?l0003oool00?l02@3oool00`00
o`00oooo0?l000020000o`030?ooo`00o`00oooo00P0oooo00<00?l00?ooo`3oool01`3oool01@00
o`00oooo0?ooo`3oool00?l000H0oooo00<0003o0?ooo`000?l03P3oool01000o`00oooo0?ooo`3o
ool4003o0080oooo00D00?l00?ooo`3o0000oooo0000o`080?ooo`03003o00000?l0o`0000T0oooo
00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0000o``0
oooo00<0003o0?l0003oool00`3oool00`000?l0o`000?ooo`0:0?ooo`060?l0003oool0oooo0?oo
o`3o00000?l02P3oool00`00o`00oooo0000o`030?ooo`030000o`3oool00?l000T0oooo00<0o`00
0000o`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0R0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool0603oool00`3o0000003o003o00040?oo
o`060000o`3oool0oooo0?ooo`3o00000?l02`3oool01@00o`00oooo0?l0003oool0003o00H0oooo
00<00?l00000o`3oool01`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo
00<0003o0?ooo`00o`00103oool00`00o`00oooo0000o`0;0?ooo`03003o003oool0003o0080oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l000070?ooo`03003o003oool0oooo00/0oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo
00<00?l00?ooo`3oool00`3oool00`3o00000?l00?ooo`0G0?ooo`040?l0003oool0oooo003o00<0
oooo00<0003o003o003oool0203oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`0:0?ooo`070?l0003oool0oooo
0?ooo`00o`00oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00o`00oooo
0?ooo`030000o`D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool00?l00080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`060?ooo`80003o
00<0oooo003o003oool0203oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0003o00@0oooo
00<00?l00?ooo`3oool01@000?l40?ooo`80o`002`3oool01@000?l0oooo0?ooo`3oool00?l000P0
oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80003o3P3oool00`00o`00
oooo0?ooo`060?ooo`03003o00000?l0oooo00T0oooo00<0o`000?ooo`000?l0203oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0000o`070?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`000?l02`3oool010000?l0
oooo0?ooo`00o`040?ooo`80o`000P3oool00`3o0000oooo0?ooo`080?ooo`060?l0003oool0oooo
0000o`3oool00?l01P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo00@0003o0?l0003oool0
0?l02@3oool01`00o`00oooo0000o`3oool0003o0?l00000o`002@3oool00`00o`00oooo0?ooo`07
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0000o`0=
0?ooo`03003o003oool0oooo00H0oooo0`00o`00103oool0o`000?ooo`000?l80?ooo`03003o003o
ool0003o00T0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`050?ooo`040?l0003o
ool0oooo0000o``0oooo00<0003o0?l0003oool00`3oool00`000?l0o`000?ooo`0:0?ooo`060?l0
003oool0oooo0?ooo`3o00000?l02P3oool00`00o`00003o0?ooo`030?ooo`030000o`3oool00?l0
00T0oooo00<0003o0?l0003oool00`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo
00P0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0603oool00`000?l0
oooo003o00040?ooo`060000o`3oool0oooo0?ooo`3o00000?l02P3oool01P00o`00oooo0?ooo`3o
0000oooo0000o`H0oooo00<00?l00000o`3oool01P3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo00D0oooo00<0003o0?ooo`00o`001@3oool00`00o`00003o0?ooo`0:0?ooo`03003o
00000?l0003o0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l0000E0?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`080?ooo`03003o
003o0000oooo00@0oooo00<0o`00003o003oool0603oool00`3o0000oooo003o00020?ooo`030000
o`3oool00?l000P0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00@0003o0?ooo`3oool00?l02P3oool02@3o0000oooo0?ooo`3oool00?l0
0?ooo`3o0000oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool00`3o
ool30000o`030?ooo`000?l00?l000/0oooo00L0003o0?ooo`3oool0oooo0?l0003oool00?l00080
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o0000oooo00/0
oooo00D0o`000?ooo`3oool0oooo0000o`070?ooo`030?l0003oool0oooo00@0oooo0P000?l20?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00001`3oool01000o`00oooo0?ooo`000?l2
0?ooo`@0003o1`3oool20?l000d0oooo00D0003o0?ooo`3oool0oooo003o00080?ooo`03003o003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`03003o003o
ool0oooo00L0oooo00<00?l00000o`3oool02@3oool00`3o0000oooo0000o`070?ooo`03003o003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l00?l00?ooo`070?ooo`040?l0003o
ool0oooo0000o`L0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0000o`0;0?ooo`030000
o`3oool00?l000L0oooo0P3o000;0?ooo`060?l0003oool0oooo0000o`3oool00?l01P3oool01@3o
0000oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`00o`002P3oool01`00o`00oooo0000o`3o
ool0003o0?l00000o`002P3oool01000o`00oooo0?ooo`000?l50?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0000o`0<0?ooo`03003o003oool0oooo00/0
oooo00<0o`000?ooo`000?l02@3oool00`00o`00003o0?ooo`090?ooo`03003o003oool0oooo00@0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000o`0<0?ooo`030000o`3o0000oooo00<0
oooo00<0003o0?l0003oool02`3oool01@3o0000oooo0?ooo`3o00000?l000X0oooo00<00?l00000
o`3oool00`3oool00`000?l0oooo003o00090?ooo`030000o`3o0000oooo00<0oooo00<0003o0?oo
o`3oool01P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool01`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01X0oooo00<000000?oo
o`3oool05`3oool003`0oooo1@00000P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0603oool00`000?l0oooo003o00050?ooo`060000o`3oool0oooo0?l0003oool00?l02@3oool0
1P00o`00oooo0?ooo`3o0000oooo0000o`H0oooo00<00?l00000o`3oool01P3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`00o`001@3oool00`00o`00003o
0?ooo`0:0?ooo`03003o00000?l0003o0080oooo00<0o`000?ooo`3oool02P3oool20?l001H0oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo
00<00?l00?l0003oool0103oool00`3o0000oooo003o000H0?ooo`030?l00000o`00oooo0080oooo
00@0003o0?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00o`0:0?ooo`060?l0003oool0oooo
0?ooo`00o`00o`000P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
0?l00?ooo`3oool01@3oool00`00o`00003o0000o`0<0?ooo`040000o`3oool0oooo0?l00080oooo
00@00?l00?ooo`3oool0003o203oool00`000?l0oooo0?ooo`0?0?ooo`040000o`3oool0oooo0?l0
00/0oooo00<0o`000?ooo`3oool00P3oool30000o`D0oooo00@0o`000?ooo`3oool0oooo0P000?l3
0?ooo`800?l02P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?l000070?ooo`03003o003oool0oooo00<0003o0P3oool0
0`00o`00oooo0?ooo`040?ooo`80o`003`3oool01@000?l0oooo0?ooo`3oool00?l000T0oooo00<0
0?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0
0?l00?ooo`3oool01`3oool00`00o`00003o0?ooo`090?ooo`040?l0003oool0oooo0000o`H0oooo
00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`00o`00oooo00L0oooo
00@0o`000?ooo`3oool0003o1P3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0003o0?l0
00T0oooo00@0o`000000o`3oool00?l0203oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0
oooo0000o`80oooo00<00?l00?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo
00<0003o0?ooo`00o`002`3oool01P00o`00003o0?ooo`000?l0o`00003o00X0oooo00@00?l00?oo
o`3oool0003o103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00@0003o
0?ooo`3oool0003o2`3oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0003o00T0oooo00<0
0?l00000o`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00@0
o`000?ooo`3o0000003o2`3oool00`000?l0o`000?ooo`020?ooo`03003o00000?l0o`0000`0oooo
00<0o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o0000003o00@0oooo
00<0003o0?ooo`00o`002@3oool00`000?l0o`000?ooo`030?ooo`030?l000000?l0oooo00D0oooo
00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0F0?ooo`D000006@3oool003`0oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool04@3oool00`000?l0o`00003o00060?ooo`060000o`3oool0oooo0?l0003oool0
0?l01`3oool3003o0080oooo00<0o`000?ooo`000?l01P3oool00`00o`00003o0?ooo`060?ooo`03
003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?l00000o`050?oo
o`03003o00000?l0oooo00X0oooo00<00?l00000o`000?l00P3oool00`3o0000oooo0?ooo`0:0?oo
o`80o`005P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool0203oool00`00o`00o`000?ooo`040?ooo`030?l0003oool00?l001P0oooo00D0o`00003o
003oool0oooo0000o`030?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`00o`002`3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0003o00H0oooo00@0o`000?ooo`3oool00?l02P3o
ool00`00o`00oooo0?ooo`0:0?ooo`040000o`3oool0oooo0?l00080oooo00<00?l00?ooo`000?l0
2@3oool010000?l0oooo0?ooo`00o`0=0?ooo`030000o`3oool0oooo0080oooo0P3o00080?ooo`03
0?l0003oool0oooo00H0oooo10000?l20?ooo`030?l000000?l0003o00<0oooo0P00o`0<0?ooo`03
003o003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0o`0000H0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?ooo`80
o`004P3oool010000?l0oooo0?ooo`00o`090?ooo`03003o003oool0oooo00D0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00P0oooo00<0o`000000
o`3oool02@3oool0103o0000oooo0?ooo`000?l60?ooo`03003o003oool0oooo00D0oooo00L0o`00
0?ooo`3oool0oooo0000o`3oool00?l000P0oooo00@0o`000?ooo`3oool0003o1P3oool00`00o`00
oooo0?ooo`0:0?ooo`04003o003oool0003o0?l000T0oooo00@0o`000000o`3oool00?l05@3oool0
0`3o0000oooo0000o`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l00?l000/0oooo00D00?l00000o`3oool0003o003o
000;0?ooo`03003o003oool0oooo0080003o0`3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`03003o003oool0oooo00d0oooo
00<0o`000?ooo`000?l02@3oool00`00o`00003o0?ooo`080?ooo`800?l0103oool00`000?l0oooo
0?ooo`080?ooo`040?l0003oool0o`000000o`/0oooo00<0003o0?l0003oool00P3oool00`00o`00
003o0?l0000<0?ooo`030?l0003oool0o`000080oooo00<00?l00?ooo`3oool01P3oool00`00o`00
o`000000o`040?ooo`030000o`3o00000?l000T0oooo00<0003o0?l0003oool00`3oool00`3o0000
003o0?ooo`050?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool06P3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o0000oooo00@0oooo
00@0003o0?ooo`3oool0oooo0P00o`000`3oool00?l0003o000A0?ooo`030000o`3o00000?l000H0
oooo00@0003o0?ooo`3oool0o`000P3oool00`00o`00oooo0?ooo`04003o00D0oooo00<0o`000?oo
o`000?l01P3oool00`00o`00o`000000o`060?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`3oool0103oool010000?l0oooo0?l00000o`050?ooo`03003o00000?l0oooo00X0oooo00H00?l0
0000o`3oool0003o0?ooo`3o000=0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00L0oooo00<00?l00?l0003oool0
0`3oool0103o0000oooo0?ooo`00o`0I0?ooo`04003o003oool0003o0000o`<0oooo00<00?l00?oo
o`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o003o
003oool01@3oool00`3o0000003o003o000;0?ooo`080?l0003oool0oooo0?ooo`3o00000?l00?oo
o`000?l60?ooo`040?l0003oool0oooo003o01L0oooo00@0003o0?ooo`3oool0o`000`3oool00`00
o`00003o0?ooo`080?ooo`040000o`3oool0oooo003o00`0oooo00<0003o0?ooo`3oool01@3oool2
0?l000H0oooo00<0o`000?ooo`3oool02P3oool30000o`030?l0003oool0oooo00800?l03P3oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?l000060?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0o`00503o
ool010000?l0oooo0?ooo`00o`0:0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00P0oooo00<0o`000000o`3oool0
2@3oool0103o0000oooo0?ooo`000?l50?ooo`03003o003oool0oooo00H0oooo00L0o`000?ooo`3o
ool0oooo0000o`3oool00?l000P0oooo00@0o`000?ooo`3oool0003o1P3oool00`00o`00oooo0?oo
o`0;0?ooo`03003o00000?l0o`0000T0oooo00<0o`000000o`00o`005P3oool00`3o0000oooo0000
o`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030?l000000?l00?l000/0oooo00D00?l00000o`3oool0003o003o000;0?ooo`03003o
003oool0oooo0080003o0`3oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo0?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`00
0?l02@3oool00`00o`00003o0?ooo`080?ooo`800?l00`3oool00`000?l0oooo0?ooo`090?ooo`04
0?l0003oool0o`000000o`X0oooo00<0003o0?ooo`3o00000`3oool00`00o`00003o0?l0000<0?oo
o`030?l0003oool0o`000080oooo00<00?l00?ooo`3oool01P3oool00`00o`00o`000000o`040?oo
o`040000o`3o0000oooo003o00P0oooo00<0003o0?l0003oool00`3oool00`3o0000003o0?ooo`05
0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0o`0000@0oooo00@0003o0?oo
o`3oool00?l01@3oool00`00o`00oooo0?ooo`0=0?ooo`040000o`3oool0oooo003o00H0oooo00<0
003o0?ooo`3o00000`3oool3003o00T0oooo00<0o`000000o`3oool01`3oool00`00o`00003o0?oo
o`050?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?l0
0000o`050?ooo`03003o00000?l0oooo00X0oooo00H0003o0?ooo`3oool0003o0?ooo`3o000=0?oo
o`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0oooo00L0oooo00@00?l00?ooo`3o0000003o0P3oool01@3o0000oooo0?ooo`3o
ool00?l001L0oooo00<00?l00000o`000?l01P3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo00/0oooo00H0003o0?ooo`3oool0003o0?ooo`00o`060?ooo`030?l000000?l00?l000/0
oooo00L0o`000?ooo`3oool0oooo0?l00000o`00003o00L0oooo00<0o`000?ooo`00o`00603oool0
10000?l0oooo0?ooo`3o00030?ooo`03003o00000?l0oooo00P0oooo00<0003o0?ooo`3oool00P00
o`0;0?ooo`030000o`3oool0oooo00L0oooo0P3o00030?ooo`030?l0003oool0oooo00l0oooo0P00
o`0@0?ooo`05003o003oool0oooo0?ooo`3o00001`3oool00`000?l0oooo0?ooo`030?ooo`050000
o`3oool0oooo0?ooo`3o00001@3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0o`0001D0
oooo00@0003o0?ooo`3oool00?l02P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00L0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`03003o003oool0oooo00H0oooo00L0o`00
0?ooo`3oool0oooo0000o`3oool00?l000P0oooo00@0o`000?ooo`3oool0003o1@3oool00`00o`00
oooo0?ooo`0<0?ooo`03003o00000?l0o`0000P0oooo00@0o`000?ooo`000?l00?l05P3oool00`3o
0000oooo0000o`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030?l000000?l00?l000/0oooo00D00?l00000o`3o0000o`000000o`0;
0?ooo`05003o003oool0003o0?ooo`000?l00P3oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo0000o`@0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0
00000?l0oooo00T0oooo00<00?l00000o`3oool0203oool01@00o`00oooo003o003oool0003o00`0
oooo00@0o`000?ooo`3o0000003o2P3oool010000?l0oooo0?ooo`3o00020?ooo`03003o00000?l0
o`0000`0oooo00<0o`000?ooo`3o00000P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o0000
003o00@0oooo00@0003o0?l0003oool00?l0203oool010000?l0o`000?ooo`00o`020?ooo`030?l0
00000?l0oooo00D0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0J0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3o0000103o
ool00`000?l00?l0003o00070?ooo`800?l03@3oool010000?l0oooo0?ooo`00o`070?ooo`030000
o`3o0000oooo00h0oooo00<0o`000000o`3oool01`3oool00`00o`00003o0?ooo`050?ooo`03003o
003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?l00000o`050?ooo`03
003o003o0000003o00T0oooo00L00?l00000o`3oool0oooo0000o`3oool0o`0000d0oooo00<0o`00
0?ooo`3oool0503oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool01`3oool01000o`00oooo0?l000000?l20?ooo`050?l0003oool0oooo0?ooo`00o`00
5P3oool20000o`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`0;0?ooo`060000o`3oool0oooo0000o`3oool00?l01@3oool0103o0000oooo0000o`00o`0;
0?ooo`060?l0003oool0oooo0?l0003oool0003o2@3oool00`3o00000?l00?ooo`0G0?ooo`040000
o`3oool0oooo0?l000<0oooo00<00?l00000o`3oool0203oool01@000?l0oooo003o003oool00?l0
00X0oooo00<0003o0?ooo`3oool02P3oool20?l000030?ooo`3o0000oooo00h0oooo0P00o`000`3o
ool0o`000?ooo`0?0?ooo`05003o003oool0oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00o`00oooo0?ooo`090?ooo`03003o003o
0000oooo01@0oooo00@0003o0?ooo`3oool00?l02`3oool00`00o`00oooo0?ooo`020?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l000X0
oooo00H0o`000?ooo`3oool0003o0?ooo`00o`080?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool00`00o`00oooo0?ooo`0<0?ooo`04003o00000?l0oooo0?l000L0oooo00@0o`000?ooo`3oool0
003o5P3oool00`3o0000003o0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l00?l000`0oooo00@0003o0?l00000
o`00003o303oool01`00o`00003o0?ooo`3oool0003o0?ooo`00o`001`3oool01000o`00oooo0?oo
o`000?l40?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool03`3oool00`3o0000003o
0?ooo`090?ooo`03003o00000?l0oooo00P0oooo00@00?l00?ooo`00o`00003o3@3oool20?l00003
0?ooo`000?l0oooo00T0oooo00@0003o0?ooo`3oool0o`000P3oool00`00o`00003o0?ooo`0<0?oo
o`030?l0003oool0o`000080oooo00<00?l00?ooo`3oool01P3oool00`00o`00o`000000o`040?oo
o`040000o`3o0000oooo003o00P0oooo00@0003o0?l0003oool00?l00P3oool00`3o0000003o0?oo
o`050?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0o`0000<0oooo00<0o`00
003o00000?l02P3oool00`00o`00oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`00o`001`3o
ool00`000?l0o`000?ooo`0>0?ooo`030?l000000?l0oooo00L0oooo00<00?l00000o`3oool01@3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00<0oooo00@0003o0?ooo`3oool00?l0
1P3oool00`00o`00o`000000o`090?ooo`06003o00000?l0oooo0?ooo`000?l0o`009P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool01P3oool01000
o`00oooo0?ooo`3o00020000o`030?ooo`3o0000oooo0080oooo00<00?l00?ooo`3oool04P3oool2
0000o`030?ooo`00o`00o`0000P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0;
0?ooo`060000o`3o0000oooo0000o`3oool00?l01@3oool0103o0000oooo0000o`00o`0<0?ooo`06
0?l0003oool0o`000?ooo`000?l00?l0203oool00`3o00000?l00?ooo`0H0?ooo`030000o`3oool0
o`0000<0oooo00<00?l00000o`3oool02@3oool01@000?l00?l00?ooo`3oool00?l000P0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0080oooo00<0
o`000?ooo`3oool03P3oool01000o`00oooo0?ooo`3o00080?ooo`030000o`3oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3o
ool0503oool010000?l0oooo0?ooo`00o`0;0?ooo`03003o003oool0oooo0080oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00X0oooo00<0003o0?l0
0000o`00203oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00o`002P3oool0
1P3o0000oooo0?ooo`000?l0oooo003o00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`03003o003oool0oooo00`0oooo00@0003o0?ooo`3oool0o`001`3oool0103o0000
oooo0?ooo`000?lF0?ooo`030?l000000?l0oooo00<0oooo00@00?l00?ooo`3oool0o`001P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo00`0oooo00@0003o0?l00000o`00003o303o
ool01`00o`00003o0?ooo`3oool0003o0?ooo`00o`001`3oool01000o`00oooo0?ooo`000?l40?oo
o`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0403oool00`3o0000003o0?ooo`090?oo
o`03003o00000?l0oooo00L0oooo00D00?l00?ooo`3oool00?l00000o`0=0?ooo`80o`0000<0oooo
0000o`3oool02@3oool020000?l0oooo0?ooo`3o0000oooo003o003oool0003o3@3oool00`3o0000
oooo0?l000020?ooo`03003o003oool0oooo00H0oooo00<00?l00000o`3oool0103oool010000?l0
o`000?ooo`00o`080?ooo`080000o`3o00000?l00?ooo`00o`00oooo0?l000000?l60?ooo`03003o
003oool0oooo00X0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0o`000080oooo0P00o`000`3oool0003o0?oo
o`0:0?ooo`800?l02@3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00<0003o0?l0003oool0
3P3oool00`3o0000003o0?ooo`070?ooo`03003o00000?l0oooo00D0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`030?ooo`040000o`3oool0oooo003o00H0oooo00<0o`00003o0000
0?l02@3oool01P00o`00003o0?ooo`3oool0003o0?l002H0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool0o`000P00
0?l00`3oool0o`000?ooo`030?ooo`03003o003oool0oooo00h0oooo0`000?l20?ooo`04003o003o
ool0oooo0?l000L0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0;0?ooo`040000
o`3o0000o`000000o`80oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000o`0=0?ooo`80
o`0000@0oooo0000o`3oool00?l0203oool00`00o`00o`000?ooo`0H0?ooo`030000o`3oool0o`00
00<0oooo00<00?l00000o`3oool02@3oool01@000?l00?l00?ooo`3oool00?l000L0oooo00<0003o
0?ooo`3oool07P3oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00@00?l0
0?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool00?l001D0oooo00<0003o0?ooo`00o`00
303oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3o00000?l000P0oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool00?l000X0oooo00H0o`000?ooo`3oool0003o0?ooo`00o`07
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0<
0?ooo`040000o`3oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0000o`0G0?ooo`030000
o`3oool0oooo0080oooo00@00?l00?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l000000?l0oooo00`0oooo00@0003o0?l00000o`00003o303oool01P00o`00003o0?ooo`3oool0
003o003o00P0oooo00@00?l00?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`020?ooo`03003o
003oool0oooo0140oooo00<0o`000000o`3oool02@3oool00`00o`00003o0?ooo`070?ooo`04003o
003oool0oooo0000o`l0oooo00@00?l00?ooo`3oool0003o2@3oool020000?l0oooo0?ooo`3o0000
oooo003o003oool0003o3@3oool00`3o0000oooo0?l000020?ooo`03003o003oool0oooo00H0oooo
00<00?l00000o`3oool0103oool010000?l0o`000?ooo`00o`080?ooo`080000o`3o00000?l00?oo
o`00o`00oooo0?l000000?l60?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool06P3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool5000001h0oooo00X0003o0?ooo`3oool0o`000?oo
o`00o`00oooo0?l0003oool0003o3@3oool00`00o`00oooo0?ooo`020?ooo`@0003o0`3oool00`00
o`00o`000?ooo`060?ooo`030000o`3o0000oooo00h0oooo00<0o`000000o`3oool01`3oool00`00
o`00003o0?ooo`040?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool01000
0?l0oooo0?ooo`00o`060?ooo`030?l00000o`00003o00T0oooo00H0003o0?l0003oool0oooo0000
o`3o000V0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo
0?ooo`060?ooo`08003o003oool0oooo0000o`3oool0003o0?ooo`3o00040?ooo`03003o003oool0
oooo00`0oooo0P000?l50?ooo`04003o003oool0oooo0?l000P0oooo00@00?l00?ooo`3oool00?l0
3P3oool010000?l0o`000?ooo`000?l20?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`00
0?l03@3oool20?l000040?ooo`000?l0oooo003o00P0oooo00<00?l00?l0003oool02P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3o0000oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l00?l00?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool07P3oool00`00
o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3o00002@3oool01@00
0?l0oooo0?ooo`3oool0003o00D0oooo00@0o`000?ooo`3oool00?l02`3oool00`3o0000oooo003o
000E0?ooo`030000o`3oool00?l000d0oooo00D00?l00?ooo`3oool0oooo0000o`0<0?ooo`030000
o`3oool0oooo0080oooo00<00?l00?ooo`3oool02`3oool00`000?l0o`00003o00080?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool00?l0303oool00`3o0000oooo0000o`020?ooo`03
003o003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l0
00l0oooo00@0003o0?ooo`3oool0o`001P3oool01@3o0000oooo0?ooo`00o`00003o01L0oooo00<0
003o0?ooo`3oool00P3oool01000o`00oooo0?ooo`3o00070?ooo`030?l0003oool0oooo00<0oooo
00<0o`000000o`3oool0303oool010000?l0oooo003o00000?l<0?ooo`03003o00000?l0oooo0080
oooo00<0003o0?ooo`3oool01`3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<00?l00?ooo`3oool04@3oool00`3o0000003o0?ooo`090?ooo`03003o00000?l0oooo00L0
oooo00@00?l00?ooo`000?l00?l03`3oool01000o`00oooo0?ooo`000?l90?ooo`080000o`3oool0
oooo0?l0003oool00?l00?ooo`000?l=0?ooo`030?l0003oool0o`000080oooo00<00?l00?ooo`3o
ool01P3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool00?l000P0oooo00P0003o0?l00000
o`00oooo003o003o0000oooo0000o`H0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0F0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0803oool01@000?l0oooo0?ooo`3o
00000?l00080oooo00<0o`000?ooo`000?l03@3oool50000o`L0oooo00<00?l00?l0003oool01`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l000000?l0oooo00L0oooo00<00?l00000o`3oool0103o
ool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool00?l0
1P3oool00`3o00000?l00000o`090?ooo`060000o`3oool0o`000?ooo`000?l0o`009P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool01@3oool01000
o`00oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool02@3oool3
0000o`L0oooo00@00?l00?ooo`3oool0o`00203oool01000o`00oooo0?ooo`00o`0>0?ooo`070000
o`3o0000003o0?ooo`3o0000oooo003o00040?ooo`030?l0003oool0003o00d0oooo00<0o`000?oo
o`000?l00P3oool00`00o`00oooo0?ooo`060?ooo`03003o003o0000oooo00T0oooo0P3o000=0?oo
o`030000o`3o0000oooo00<0oooo00<0003o003o003oool02@3oool00`000?l00?l00?ooo`020?oo
o`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool07P3oool00`00o`00oooo0?ooo`070?oo
o`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3o00002@3oool01@000?l0oooo0?ooo`3oool0
003o00D0oooo00@0o`000?ooo`3oool00?l02P3oool01@3o0000oooo0?ooo`3oool00?l001D0oooo
00<0003o003o003oool0303oool01000o`00oooo0?ooo`000?l>0?ooo`050000o`3oool0oooo0?oo
o`00o`003@3oool00`000?l0o`00003o00080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`00o`00303oool00`3o0000oooo0000o`020?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l000l0oooo00D0003o003o003oool0oooo0?l0
00050?ooo`050?l0003oool0oooo003o00000?l05`3oool00`000?l0oooo0?ooo`020?ooo`03003o
003oool0o`0000P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0000o`0=0?ooo`040000
o`00o`00oooo0000o``0oooo00<00?l00000o`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`03
003o00000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo003o000E0?ooo`030000o`3oool0oooo
00P0oooo00<00?l00000o`3oool01`3oool01000o`00003o0?ooo`00o`0?0?ooo`04003o003oool0
oooo0000o`T0oooo00P0003o0?ooo`3oool0o`000?ooo`00o`00oooo0000o`d0oooo00<0o`000?oo
o`3o00000P3oool00`00o`00oooo0?ooo`060?ooo`03003o00000?l0oooo00D0oooo00<0003o0?oo
o`00o`00203oool00`000?l0o`00003o00020?ooo`04003o003oool0oooo0000o`D0oooo00<00?l0
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00T0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo0200oooo00@0003o0?ooo`3oool00?l00`3oool00`3o0000oooo0000o`0=
0?ooo`030000o`00o`00oooo00T0oooo00<00?l00?l0003oool01P3oool00`3o0000003o0?ooo`0?
0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`000?l0103oool00`00o`00oooo0?ooo`08
0?ooo`03003o003oool0oooo0080oooo00@0003o0?ooo`3oool00?l01P3oool00`3o00000?l00000
o`090?ooo`060000o`3oool0o`000?ooo`000?l0o`009P3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00L0oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`000?l20?oo
o`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool20000o`T0oooo00D00?l00?oo
o`3oool0oooo0?l000080?ooo`04003o003oool0oooo003o00h0oooo00<0003o0?l000000?l00P3o
ool00`3o00000?l00?ooo`030?ooo`030?l0003oool0003o00l0oooo00D0003o0?ooo`3oool0oooo
003o00060?ooo`04003o003oool0oooo0?l000P0oooo00<0o`000?ooo`3o00003@3oool00`000?l0
o`000?ooo`030?ooo`030000o`00o`00oooo00T0oooo00<0003o0?ooo`3oool00`3oool01000o`00
oooo0?ooo`000?lQ0?ooo`03003o003oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`00
o`00oooo0?l0000:0?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`00o`002P3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0180oooo00<0003o003o003oool03@3oool0
0`00o`00oooo0000o`0>0?ooo`040000o`3oool0oooo003o00h0oooo00@0003o0?l0003oool00?l0
1`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool00?l000`0oooo00<0o`000?ooo`000?l0
0P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0
0?l03`3oool01@000?l00?l00?ooo`3oool0o`0000@0oooo00H0o`000?ooo`3oool0oooo003o0000
0?lG0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3o00002@3oool01`3o0000oooo0?oo
o`3oool0o`000?ooo`000?l0303oool01@000?l0oooo003o003oool0003o00d0oooo00D0003o0?oo
o`3oool00?l00000o`090?ooo`03003o00000?l0oooo00D0oooo00D0003o0?ooo`3oool0oooo003o
000E0?ooo`030000o`3oool0oooo00P0oooo00<0o`00003o00000?l01P3oool00`00o`00oooo0000
o`020?ooo`03003o003oool0oooo00`0oooo0P00o`000`3oool0003o0?ooo`080?ooo`080000o`3o
ool0oooo0?l0003oool00?l00?ooo`000?l=0?ooo`030?l0003oool0o`0000<0oooo00<00?l00?oo
o`3oool01@3oool00`00o`00003o0?ooo`050?ooo`030000o`3oool00?l000L0oooo00<0003o0?oo
o`00o`000`3oool01000o`00oooo0?ooo`000?l50?ooo`03003o003oool0oooo00X0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0P0?oo
o`050000o`3oool00?l00?ooo`3o00000P3oool00`3o0000oooo0000o`0<0?ooo`030000o`3oool0
0?l000X0oooo00<00?l00?ooo`3o00001P3oool00`3o0000003o0?ooo`0?0?ooo`030000o`3oool0
oooo00H0oooo00<0o`00003o00000?l0103oool00`00o`00oooo0?ooo`080?ooo`05003o003oool0
oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`040?ooo`040?l00000o`00oooo0000o`L0oooo
00L00?l00000o`3oool0o`000?ooo`000?l0o`0002H0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`080?ooo`03003o003oool0oooo00D0oooo00@00?l00?ooo`3oool0003o0P3oool0
0`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`00o`003P3oool0
0`000?l0oooo0000o`020?ooo`030?l0003oool00?l000<0oooo00<0o`000?ooo`000?l03P3oool0
0`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00@00?l00?ooo`3oool0o`001`3o
ool0103o0000oooo0?ooo`3o000=0?ooo`030000o`3o0000oooo00<0oooo00<0003o003o003oool0
2@3oool00`00o`00003o0?ooo`030?ooo`03003o003oool0003o0100oooo1@00o`0<0?ooo`03003o
003oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?l0000:0?ooo`040000
o`3oool0oooo0000o`D0oooo00<0o`000?ooo`00o`002P3oool00`3o0000oooo0?ooo`040?ooo`80
0?l04P3oool00`000?l00?l00?ooo`0=0?ooo`03003o003oool0003o00h0oooo00@0003o0?ooo`3o
ool00?l03P3oool010000?l0o`000?ooo`00o`060?ooo`030?l0003oool0oooo00@0oooo00<0003o
003o003oool03@3oool01@3o0000003o0?ooo`3oool00?l000H0oooo00<0o`000?ooo`3oool00`3o
ool010000?l0oooo0?ooo`00o`0?0?ooo`050000o`00o`00oooo0?ooo`3o0000103oool01P3o0000
oooo0?ooo`3oool00?l00000oaL0oooo00<0003o0?ooo`3oool00`3oool00`00o`00o`000?ooo`08
0?ooo`070?l0003oool0oooo0?ooo`3o00000?l00000o`0<0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02@3oool01`000?l00?l00?ooo`3oool00?l00?ooo`000?l0203oool00`00
0?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00o`005@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l00000o`00003o00H0oooo00<00?l00000o`3oool00P3oool00`00o`00oooo0?ooo`0;
0?ooo`05003o003oool00?l00?ooo`000?l0203oool01P000?l0oooo0?ooo`3oool0o`00003o0080
oooo00<0o`000000o`3oool02`3oool00`3o0000oooo0?l000030?ooo`03003o003oool0oooo00D0
oooo00<00?l00000o`3oool01@3oool00`000?l0oooo003o00070?ooo`030000o`3oool00?l000<0
oooo00@0o`00003o003oool0003o1@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0M0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0200oooo00L0003o003o003oool0oooo0?l0003o
ool0o`000080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo003o000:0?ooo`03003o003o
ool0o`0000H0oooo00<0o`000000o`3oool03`3oool00`000?l0oooo0?ooo`050?ooo`040?l0003o
ool00?l00000o`@0oooo00<00?l00?ooo`3oool0203oool01@00o`00oooo0?ooo`3oool0003o00<0
oooo00<00?l00?ooo`3oool0103oool0103o00000?l00?ooo`000?l70?ooo`040000o`3oool0oooo
0?l00080oooo00<0003o0?ooo`3oool0903oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo00P0oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`000?l20?ooo`030?l00000
0?l0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`03003o003o
ool0oooo0080oooo00<0o`000?ooo`3oool01P3oool2003o00l0oooo00<0o`000000o`000?l00`3o
ool00`3o00000?l00?ooo`020?ooo`030?l00000o`00003o00h0oooo00<0003o0?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`040?ooo`04003o003oool0oooo0?l000D0oooo0P3o00040?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`000?l00?l00?ooo`090?ooo`03003o
00000?l0oooo00@0oooo00<0003o0?ooo`3oool02P3oool5003o00D0oooo00<00?l00?ooo`3oool0
203oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?l0003oool0
2P3oool00`000?l0oooo0000o`070?ooo`030?l00000o`00oooo00P0oooo00<0o`000?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`00o`00oooo00d0oooo00<00?l00000o`3oool0
3`3oool00`000?l0oooo003o000>0?ooo`040000o`3o0000oooo003o00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0<0?ooo`050?l000000?l0oooo0?ooo`00o`001P3oool00`3o
0000oooo0?ooo`040?ooo`030000o`00o`00oooo00l0oooo00D0003o003o003oool0oooo0?l00004
0?ooo`060?l0003oool0oooo003o003oool0003o5P3oool00`000?l0oooo0?l000040?ooo`03003o
003o0000oooo00P0oooo00L0o`000?ooo`3oool0oooo0?l00000o`00003o00`0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`040000o`00o`00oooo003o0080oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool00?l001H0oooo00<0003o
0?ooo`3oool0203oool00`3o00000?l00000o`060?ooo`03003o00000?l0oooo0080oooo00<00?l0
0?ooo`3oool02`3oool00`00o`00oooo003o00020?ooo`030000o`3oool0oooo00D0oooo00H0003o
0?ooo`3oool0oooo0?l00000o`020?ooo`030?l000000?l0oooo00`0oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0003o00H0oooo00<0003o0?ooo`00o`00
1`3oool00`000?l0oooo003o00030?ooo`040?l00000o`00oooo0000o`@0oooo00<00?l00?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3o
ool00?l07@3oool00`000000oooo0?ooo`0G0?ooo`006`3oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000d0oooo00<000000?ooo`3oool0803oool01`000?l00?l00?ooo`3oool0o`00
0?ooo`3o00000`3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo003o00T0oooo00<0
0?l00?ooo`3o00001P3oool00`3o0000oooo0000o`0?0?ooo`030000o`3oool0oooo00D0oooo00@0
o`000?ooo`00o`00003o103oool00`00o`00oooo0?ooo`080?ooo`05003o003oool0oooo0?ooo`00
0?l00P3oool00`00o`00oooo0?l000050?ooo`040?l00000o`00oooo0000o`L0oooo00L0003o0?oo
o`3oool0o`000?ooo`3o0000003o02H0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`080?ooo`03003o003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo0000o`020?ooo`030?l0
00000?l0oooo00H0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`03003o
003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0
00000?l0003o00@0oooo00L00?l00?ooo`3oool0o`000?ooo`00o`00003o00d0oooo00<0003o0?oo
o`3oool0103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0?l000060?ooo`030?l0003oool0oooo00/0oooo00L0003o0?ooo`3oool0oooo0000
o`3oool00?l000X0oooo00<00?l00000o`3oool00`3oool00`000?l00?l00?ooo`0:0?ooo`03003o
003oool0oooo00T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00T0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0000o`070?ooo`03003o
003oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00o`00oooo0?ooo`0>0?ooo`030000
o`00o`00oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l00?l00?ooo`0>0?ooo`040000
o`3oool0o`00003o00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<0?ooo`05
0000o`3oool0oooo0?ooo`00o`001@3oool00`3o0000oooo0?ooo`050?ooo`030000o`00o`00oooo
00l0oooo00<0003o003o003oool00P3oool0103o0000oooo0?ooo`3o00030?ooo`04003o003oool0
oooo0000oaD0oooo00<0003o0?ooo`3o0000103oool00`00o`00oooo0?ooo`080?ooo`070?l0003o
ool0oooo0?ooo`3o00000?l00000o`0<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool02@3oool010000?l00?l00?ooo`00o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o003o
003oool01P3oool00`000?l0oooo003o000F0?ooo`030000o`3oool0oooo00P0oooo00<0o`00003o
00000?l01P3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo00<00?l00?oo
o`00o`000P3oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0?ooo`3o00000?l00P3o
ool00`3o0000003o0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0103o
ool00`00o`00003o0?l000060?ooo`030000o`3oool00?l000L0oooo00@0003o0?ooo`00o`00o`00
0P3oool0103o00000?l00?ooo`000?l40?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo003o01d0oooo00<000000?oo
o`3oool05`3oool001X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool07`3oool00`000?l00?l00?oo
o`020?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?oo
o`00o`080?ooo`04003o003oool0oooo0?l000H0oooo00<0o`000?ooo`000?l03P3oool00`000?l0
o`000?ooo`060?ooo`040?l0003oool00?l00000o`@0oooo00<00?l00?ooo`3oool0203oool01@00
o`00oooo0?ooo`3oool0003o0080oooo00<00?l00?ooo`3o00001@3oool0103o0000oooo003o0000
0?l70?ooo`070000o`3oool0oooo0?l0003oool0o`000000o`0V0?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`040?ooo`05003o003oool0oooo0?oo
o`000?l00P3oool00`3o0000003o0?ooo`070?ooo`05003o003oool0oooo0?ooo`000?l02`3oool0
0`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool03@3oool0
0`3o0000003o0?ooo`040?ooo`07003o003o0000oooo0?l0003oool00?l00000o`0=0?ooo`030000
o`3oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`040?l0
003oool0oooo0?l000L0oooo00<0o`000?ooo`3oool02`3oool01`000?l0oooo0?ooo`3oool0003o
0?ooo`00o`002P3oool00`00o`00003o0?ooo`030?ooo`030000o`3oool00?l000T0oooo00<00?l0
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00d0oooo00<0o`00
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0003o00D0oooo0`00o`02
0?l000L0oooo00<0o`000?ooo`3oool02P3oool2003o00h0oooo00<0003o0?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`00o`00oooo00h0oooo00D0003o0?ooo`3o0000oooo003o
00050?ooo`030?l0003oool0oooo00@0oooo00<00?l00000o`3oool03@3oool01@000?l0o`000?oo
o`3oool00?l000D0oooo00<0o`000?ooo`3oool01@3oool00`000?l00?l00?ooo`0?0?ooo`030000
o`00o`00oooo0080oooo00@0o`000?ooo`3oool0o`000`3oool01000o`00oooo0?ooo`000?lE0?oo
o`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool02@3oool01P3o0000oooo0?ooo`3o0000
0?l00000o``0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`040000o`3o
ool00?l0003o00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l00?l00?ooo`060?ooo`030000
o`3oool00?l001H0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00000o`050?ooo`03003o
00000?l0oooo00<0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo003o00020?ooo`030000
o`3oool0oooo00D0oooo00H0003o0?ooo`3oool0oooo0?l00000o`020?ooo`030?l000000?l0oooo
00`0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0o`00
00H0oooo00@0003o0?ooo`3oool00?l01P3oool010000?l00?l00?ooo`3o00020?ooo`040?l0003o
ool00?l00000o`@0oooo00<00?l00?ooo`3oool0303oool01000o`00oooo0?ooo`00o`0=0?ooo`04
003o003oool0oooo003o01d0oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo1`00000K0?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`080?oo
o`050000o`3oool0oooo0?ooo`00o`00203oool01000o`00oooo0?ooo`3o00060?ooo`030?l0003o
ool0003o00h0oooo00<0003o0?l0003oool01P3oool0103o0000oooo003o00000?l40?ooo`03003o
003oool0oooo00P0oooo00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?l000050?ooo`04
0?l0003oool00?l00000o`L0oooo00L0003o0?ooo`3oool0o`000?ooo`3o0000003o02H0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo00<0oooo00L0
0?l00?ooo`3oool0003o0?l0003oool0o`000080oooo00<0003o0?ooo`3oool01P3oool01000o`00
oooo0?ooo`000?l;0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool50?l0
00l0oooo00<0o`000000o`3oool01@3oool01`00o`00o`000?l0003oool00?l00?ooo`000?l0303o
ool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3o
ool20?l000P0oooo00<0o`000?ooo`3oool02P3oool00`3o0000003o0?ooo`020?ooo`040000o`3o
ool0oooo003o00P0oooo00<00?l00?ooo`000?l00`3oool010000?l0oooo0?ooo`00o`080?ooo`03
003o003oool0oooo00d0oooo0P00o`040?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3o
ool02@3oool00`00o`00oooo0?ooo`0:0?ooo`80003o00<0oooo003o0000o`000P00o`050?ooo`80
o`00103oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`03003o00000?l0oooo00h0oooo00D0003o0?ooo`3o
0000oooo003o00050?ooo`030?l0003oool0oooo00@0oooo00<00?l00000o`3oool03@3oool01@00
0?l0o`000?ooo`3oool00?l000D0oooo00<0o`000?ooo`3oool01@3oool00`00o`00003o0?ooo`0?
0?ooo`030000o`00o`00oooo0080oooo00<0o`000?ooo`3o0000103oool01000o`00oooo0?ooo`00
0?lE0?ooo`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3oool02@3oool01P3o0000oooo0?oo
o`3o00000?l00000o``0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool00?l000@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo003o00070?ooo`03
0000o`3oool00?l001H0oooo00<0003o0?ooo`3oool0203oool00`3o00000?l00000o`050?ooo`03
0000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool02`3oool01P00o`00oooo0?ooo`00o`00oooo
0000o`L0oooo00H0003o0?ooo`3oool0oooo0?l00000o`020?ooo`030?l000000?l0oooo00`0oooo
00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`04003o00000?l0oooo0?l000D0
oooo00@0003o0?ooo`3oool00?l01P3oool010000?l00?l00?ooo`3o00020?ooo`040?l0003oool0
0?l00000o`@0oooo00<00?l00?ooo`3oool0303oool01000o`00oooo0?ooo`00o`0=0?ooo`04003o
003oool0oooo003o01L0oooo1`00000I0?ooo`006P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000003@3oool00`000000oooo0?ooo`0N0?ooo`03003o00000?l0oooo
00<0oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo
0?ooo`00o`00203oool01000o`00oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0000o`h0oooo
00<0003o0?l0003oool01P3oool0103o0000oooo003o00000?l30?ooo`03003o003oool0oooo00T0
oooo00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?l000050?ooo`040?l0003oool00?l0
0000o`H0oooo00P0003o003o003oool0oooo0?l0003oool0o`000000obL0oooo00@00?l00?ooo`3o
ool00?l0303oool00`00o`00oooo0?ooo`030?ooo`07003o003oool0oooo0000o`3o0000oooo0?l0
00020?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`000?l0303oool00`00o`00oooo0?oo
o`040?ooo`D0o`00103oool00`3o0000oooo0?ooo`0=0?ooo`030?l000000?l0oooo00D0oooo00L0
0?l00?ooo`3o0000oooo003o003oool0003o00`0oooo00<0003o0?ooo`3oool0103oool01@00o`00
oooo0?ooo`3oool00?l000H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?oo
o`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool00?l0203oool01P00o`00oooo0?ooo`00
0?l0oooo0000o`@0oooo00<00?l00?ooo`3oool00`3oool2003o0180oooo00@00?l00?ooo`3oool0
0?l04P3oool00`3o0000oooo0?ooo`070?ooo`030?l00000o`00oooo00/0oooo00<0003o003o0000
o`002`3oool20?l00080oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0:0?ooo`03
003o00000?l0oooo00d0oooo00<0003o0?ooo`00o`003`3oool00`00o`00003o0?ooo`0>0?ooo`05
0000o`3oool0o`000?ooo`00o`001@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0003o
00d0oooo00<0003o0?l0003oool00P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo
00D0oooo00<00?l00000o`3oool03P3oool010000?l0oooo0?ooo`00o`020?ooo`030?l0003oool0
o`0000@0oooo00<00?l00?ooo`3oool00P000?lD0?ooo`030000o`3oool0o`0000@0oooo00<0o`00
003o003oool02@3oool0103o0000oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool00?l000@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo003o00080?ooo`030000o`3oool0oooo01@0oooo00<0
003o0?l0003oool02@3oool00`3o00000?l00000o`050?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool02`3oool01P00o`00oooo0?ooo`00o`00oooo0000o`L0oooo00D0003o0?ooo`3o
ool0oooo003o00030?ooo`030?l000000?l0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo0?ooo`040?ooo`04003o00000?l0oooo0?l000D0oooo00@0003o0?ooo`3oool00?l01P3o
ool010000?l00?l00?ooo`3o00020?ooo`050?l0003oool00?l00?ooo`000?l00`3oool00`00o`00
oooo0?ooo`0<0?ooo`04003o003oool0oooo003o00d0oooo00@00?l00?ooo`3oool00?l07@3oool0
0`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0M0?ooo`03003o003o
ool0003o00@0oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0080oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`3o00050?ooo`050?l0
003oool0oooo0?ooo`000?l03@3oool00`000?l0o`000?ooo`060?ooo`050?l0003oool00?l00?oo
o`000?l00P3oool00`00o`00oooo0?ooo`090?ooo`04003o003oool0oooo0000o`<0oooo00<00?l0
0?ooo`3o00001@3oool0103o0000oooo003o00000?l60?ooo`080000o`3oool0oooo0?ooo`3o0000
oooo0?l000000?lW0?ooo`04003o003oool0oooo003o00`0oooo00<00?l00?ooo`3oool00`3oool0
1`00o`00oooo0?ooo`000?l0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`070?ooo`03003o
00000?l0oooo00X0oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00D0oooo00@00?l00?ooo`3oool00?l00P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00D0oooo00@00?l00?ooo`3oool00?l0403oool00`3o0000oooo0?ooo`0:0?oo
o`030?l000000?l0oooo0080oooo00@0003o0?ooo`3oool00?l0203oool00`00o`00oooo0?ooo`02
0000o`D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0C0?ooo`03003o003oool0
0?l00180oooo00<0o`000?ooo`3oool01`3oool00`3o00000?l00?ooo`0;0?ooo`030000o`3oool0
oooo00d0oooo0P3o000A0?ooo`03003o003oool0oooo00X0oooo00<00?l00000o`3oool03@3oool0
0`000?l0oooo003o000>0?ooo`04003o003oool0oooo0000o`h0oooo00D0003o0?ooo`3o0000oooo
003o00040?ooo`030?l0003oool0oooo00@0oooo00@00?l00?ooo`3oool0003o3@3oool00`000?l0
oooo0?l000020?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00o`00
oooo0000o`0>0?ooo`040000o`3oool0oooo003o00<0oooo0P3o00030?ooo`03003o003oool0oooo
00<0oooo0`000?lA0?ooo`030000o`3oool0o`0000<0oooo00<0o`000?ooo`00o`002P3oool0103o
0000oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`00o`070?ooo`030000o`3oool0oooo01@0oooo00<0003o0?l0003oool02@3o
ool00`3o00000?l00000o`040?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool02@3o
ool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3oool0103oool01P000?l0oooo
0?ooo`3oool00?l00?l00080oooo00<0o`000000o`3oool0303oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo00@0oooo00@00?l00000o`3oool0o`001@3oool010000?l0oooo0?ooo`00
o`060?ooo`040000o`00o`00oooo0?l00080oooo00D0o`000?ooo`3oool00?l00000o`030?ooo`03
003o003oool0oooo00`0oooo00@00?l00?ooo`3oool00?l03@3oool01000o`00oooo0?ooo`00o`0M
0?ooo`030000003oool0oooo01L0oooo000K0?ooo`8000002P3oool2000000@0oooo0`00000<0?oo
o`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?oo
o`04003o003oool0oooo0?l000D0oooo00D0o`000?ooo`3oool0oooo0000o`0=0?ooo`030000o`3o
0000oooo00H0oooo00D0o`000?ooo`3oool00?l00000o`020?ooo`03003o003oool0oooo00T0oooo
00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?l000050?ooo`050?l0003oool00?l00?oo
o`000?l01@3oool020000?l0oooo0?ooo`3oool0o`000?ooo`3o0000003o9`3oool01000o`00oooo
0?ooo`00o`0<0?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0003o0?ooo`020?l0
00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l00?l00?ooo`0:0?ooo`03003o003oool0oooo
00h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`050?ooo`04003o003oool0oooo
003o0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0
0?l00180oooo00<0o`000?ooo`3oool02@3oool01@3o0000oooo0000o`3oool0003o00<0oooo00<0
0?l00?ooo`3oool01P3oool01000o`00oooo0?ooo`000?l70?ooo`04003o003oool0oooo003o01L0
oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`070?ooo`030?l00000o`00oooo00X0
oooo00<00?l00?ooo`3oool08@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o00000?l0oooo00d0
oooo00@0003o0?ooo`3oool00?l03@3oool01000o`00oooo0?ooo`000?l>0?ooo`030000o`3oool0
o`000080oooo00D00?l00?ooo`3oool0oooo0?l000060?ooo`04003o003oool0oooo0000o`d0oooo
00<0003o0?ooo`3o00000P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo
00<00?l00?ooo`000?l03P3oool010000?l0oooo0?ooo`00o`030?ooo`030?l0003oool0oooo0080
oooo00<00?l00?ooo`3oool01P3oool30000o`h0oooo00@0003o0?ooo`3oool0o`000P3oool00`3o
0000oooo003o000;0?ooo`030?l0003oool00?l00080oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`030?ooo`040000o`3oool0oooo003o00L0oooo00<0003o0?ooo`3oool0503oool0
0`000?l0o`000?ooo`090?ooo`030?l00000o`00003o00@0oooo00<0003o0?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`000?l0oooo0?oo
o`040?ooo`0:0000o`3oool0oooo0?ooo`00o`00o`000?ooo`3o0000oooo0000oa<0oooo00<00?l0
0?ooo`3oool00`3oool01000o`00003o0?ooo`3o00050?ooo`040000o`3oool0oooo003o00H0oooo
00H0003o0?ooo`3oool0o`000?ooo`3o00030?ooo`03003o00000?l0oooo0080oooo00<00?l00?oo
o`3oool0303oool01000o`00oooo0?ooo`00o`0>0?ooo`03003o003oool00?l001d0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0?l000040?ooo`050?l0003oool0
oooo0?ooo`000?l03@3oool00`000?l0o`000?ooo`060?ooo`050?l0003oool0oooo003o00000?l0
0P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0003o00<0oooo00<00?l00?ooo`3o0000
1@3oool01@3o0000oooo003o003oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool20?l00003
0000o`3oool0oooo02D0oooo00@00?l00?ooo`3oool00?l0303oool00`00o`00oooo0?ooo`020?oo
o`06003o003oool0oooo0?ooo`000?l0oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`00o`002P3oool00`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool01P3oool00`00o`00oooo003o00020?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool01P3oool00`00o`00oooo003o000B0?ooo`030?l0003oool0oooo00T0oooo00D0
o`000?ooo`000?l0oooo0000o`030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
203oool00`00o`00oooo003o000]0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`00o`00
2P3oool00`00o`00oooo0?ooo`0R0?ooo`03003o003oool0oooo00T0oooo00<00?l00000o`3oool0
3@3oool010000?l0oooo0?ooo`00o`0=0?ooo`04003o003oool0oooo0000o`d0oooo00@0003o0?oo
o`3oool0o`000P3oool2003o0080oooo00<0o`000?ooo`3oool00`3oool01@00o`00oooo0?ooo`3o
ool0003o00d0oooo00<0003o0?ooo`3o00000P3oool01@00o`00oooo0?ooo`3oool0o`0000L0oooo
00@00?l00?ooo`3oool0003o3P3oool010000?l0oooo0?ooo`00o`030?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool02@3oool20000o`/0oooo00D0003o0?ooo`3oool0oooo0?l00002
0?ooo`030?l0003oool00?l000/0oooo0P3o00001000o`00oooo0?ooo`000?l;0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o00000?l0oooo01D0oooo
00<0003o0?l0003oool02@3oool00`3o00000?l00000o`030?ooo`030000o`00o`00oooo00H0oooo
00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3o
ool0103oool02P000?l0oooo0?ooo`3oool00?l00?l0003oool0o`000?ooo`000?lC0?ooo`03003o
003oool0oooo00<0oooo00@00?l00000o`3oool0o`001@3oool0103o0000003o0?ooo`00o`060?oo
o`060000o`3oool0oooo0?l0003oool0o`000`3oool00`00o`00003o0?ooo`020?ooo`03003o003o
ool0oooo00`0oooo00@00?l00?ooo`3oool00?l03P3oool00`00o`00oooo003o000M0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00d0oooo00<0003o0?l0003oool01P3oool01@3o0000oooo
0?ooo`00o`00003o0080oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0000o`020?ooo`04
003o003oool0oooo0?l000@0oooo00H0o`000?ooo`3oool0oooo003o00000?l40?ooo`030000o`00
o`00oooo00<0oooo00<0o`000?ooo`000?l09`3oool01000o`00oooo0?ooo`00o`0<0?ooo`03003o
003oool0oooo0080oooo00H00?l00?ooo`3oool0oooo0000o`3oool20?l000@0oooo00<0003o0?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool00?l000P0oooo00<00?l00?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`00o`000P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<00?l00?ooo`00o`004P3oool0
0`3o0000oooo0?ooo`090?ooo`050?l0003oool0003o0?ooo`000?l00`3oool00`00o`00oooo0?oo
o`050?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3oool0;03oool00`3o0000oooo0?oo
o`050?ooo`040?l0003oool0oooo003o00X0oooo00<00?l00?ooo`3oool08P3oool00`00o`00oooo
0?ooo`090?ooo`03003o00000?l0oooo00`0oooo00D0003o0?ooo`3oool0oooo003o000<0?ooo`03
003o003oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool010000?l0oooo0?ooo`3o00040?oo
o`800?l000<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo
00X0oooo00H0003o0?ooo`3oool0o`000?ooo`00o`030?ooo`030?l0003oool0oooo00D0oooo00D0
0?l00?ooo`3oool0oooo0000o`0=0?ooo`040000o`3oool0oooo003o00P0oooo00<00?l00?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l00002
0?ooo`03003o003oool0oooo00T0oooo0P3o00001000o`00oooo0?ooo`000?l;0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`050000o`3o
ool0oooo0?ooo`000?l00`3oool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo01D0oooo
00<0003o0?l0003oool02@3oool00`3o0000oooo0000o`030?ooo`030000o`00o`00oooo00H0oooo
00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`06003o003o0000oooo0?l0003oool0003o4`3oool0
0`00o`00oooo0?ooo`030?ooo`04003o00000?l0oooo0?l000D0oooo00@0o`000000o`3oool00?l0
1@3oool01`000?l00?l00?ooo`3oool0o`000?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
0?l000h0oooo00@00?l00?ooo`3oool00?l03P3oool00`00o`00oooo003o000M0?ooo`030000003o
ool0oooo01L0oooo000l0?ooo`D00000703oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`060?ooo`050?l0003oool0
oooo003o00000?l00P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o00000?l0oooo0080oooo00@0
0?l00?ooo`3oool0o`00103oool01P3o0000oooo0?ooo`3oool00?l00000o`@0oooo00<0003o003o
003oool00`3oool0103o0000oooo0?ooo`000?lV0?ooo`03003o003oool00?l000h0oooo00D00?l0
0?ooo`3oool0oooo003o00030?ooo`030000o`3oool0o`0000D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`T00?l04P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00L0oooo00<00?l00?ooo`00o`000P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo00L0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`090?ooo`050?l0003o
ool0003o0?ooo`000?l0103oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo03T0oooo
00<0o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`00o`090?ooo`03003o003oool0oooo02<0
oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0000o`0=0?ooo`030000o`3oool0oooo0080
oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00X0
oooo00@0003o0?ooo`3oool0o`001P3oool2003o00@0oooo00<00?l00?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0:0?ooo`060000o`3oool0oooo0?l0003oool00?l00`3oool00`3o0000oooo0?oo
o`050?ooo`05003o003oool0oooo0?ooo`000?l03@3oool010000?l0oooo0?ooo`00o`080?ooo`03
003o003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool01`000?l0oooo0?ooo`3oool0o`00
0?ooo`3o00000`3oool00`00o`00oooo0?ooo`080?ooo`030?l00000o`00oooo0080oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0000o`0E0?ooo`030000o`3o0000oooo00T0oooo00L0o`000?ooo`00o`00003o
0?ooo`000?l00?l000P0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0003o00D0oooo00/0003o0?ooo`3oool0oooo003o003oool0o`000?ooo`3o0000oooo
0000o`0C0?ooo`03003o003oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001@3oool0103o0000
003o0?ooo`00o`050?ooo`070000o`00o`00oooo0?ooo`3o0000oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`00o`003P3oool01000o`00oooo0?ooo`00o`0>0?ooo`03003o003oool00?l001T0
oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`060?ooo`050?l0003oool0oooo003o0000
0?l00P3oool00`00o`00oooo0?ooo`0:0?ooo`03003o00000?l0oooo0080oooo00@00?l00?ooo`3o
ool0o`00103oool01P3o0000oooo0?ooo`3oool00?l00000o`@0oooo00<0003o003o003oool00`3o
ool0103o0000oooo0?ooo`000?lV0?ooo`03003o003oool00?l000h0oooo00D00?l00?ooo`3oool0
oooo003o00020?ooo`040000o`3oool0oooo0?l000D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool2003o
00<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo
0140oooo00<0o`000?ooo`3oool0203oool01P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0j0?ooo`030?l0003oool0oooo00@0oooo00@0
o`000?ooo`3oool00?l02@3oool00`00o`00oooo0?ooo`0S0?ooo`03003o003oool0oooo00P0oooo
00<00?l00?ooo`000?l03@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo
00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`3o
00001@3oool01P3o0000oooo003o0000o`00oooo003o00D0oooo00<0003o0?ooo`3oool02P3oool0
1P000?l0oooo0?ooo`3o0000oooo003o00<0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo
0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03
003o003oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool01`000?l0oooo0?ooo`3oool0o`00
0?ooo`3o00000`3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`000?l02P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool010000?l0oooo0?ooo`000?l50?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0
003o5@3oool00`000?l0o`000?ooo`090?ooo`070?l0003oool00?l00000o`3oool0003o003o0008
0?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`00
0?l40?ooo`0;0000o`3oool0oooo0?ooo`00o`00oooo0?l0003oool0o`000?ooo`000?l04`3oool0
0`00o`00oooo0?ooo`020?ooo`05003o00000?l0oooo0?ooo`3o00001@3oool0103o0000003o0?oo
o`00o`050?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`00o`003P3oool00`00o`00oooo003o000?0?ooo`03003o003oool00?l001d0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?l0003oool01P3oool01@3o0000oooo0?ooo`00o`00003o0080oooo00<0
0?l00?ooo`3oool02P3oool00`00o`00003o0?ooo`020?ooo`04003o003oool0oooo0?l000@0oooo
00H0o`000?ooo`3oool0oooo003o00000?l40?ooo`030000o`3oool0oooo00<0oooo00@0o`000?oo
o`3oool0003o9P3oool00`00o`00oooo003o000>0?ooo`05003o003oool0oooo0?ooo`00o`000P3o
ool010000?l0oooo0?ooo`3o00060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo00D00?l00?ooo`3oool0
oooo0000o`0;0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0203oool01P3o0000
oooo0?ooo`000?l0oooo0000o`@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0j
0?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool00?l02@3oool00`00o`00oooo0?oo
o`0T0?ooo`03003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0003o303oool00`000?l0oooo
0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo
0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80
0?l01P3oool00`000?l0oooo0?ooo`090?ooo`060000o`3oool0oooo0?l0003oool00?l00`3oool0
0`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool0
1@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`03003o003oool0oooo00T0oooo00D0
0?l00?ooo`3oool0oooo0000o`0:0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0003o00D0oooo00<00?l00?ooo`3oool0
0P3oool01000o`00oooo0?ooo`000?lE0?ooo`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3o
ool00?l00P000?l00`3oool00?l00?ooo`080?ooo`03003o003oool0oooo00L0oooo00<00?l00?oo
o`3oool00`3oool01000o`00oooo0?ooo`000?l40?ooo`0;0000o`3oool0oooo0?ooo`00o`00oooo
0?l0003oool0o`000?ooo`000?l04`3oool00`00o`00oooo0?ooo`020?ooo`05003o00000?l0oooo
0?ooo`3o0000103oool01@3o0000oooo0000o`3oool00?l000D0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0o`0000@0oooo00D0003o003o003oool0oooo003o000>0?ooo`03003o003oool00?l0
00l0oooo0P00o`0N0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01h0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`3o00001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0o`0000H0oooo00L0o`000?oo
o`3oool00?l00?ooo`000?l00?l000d0oooo00<00?l00000o`3oool00P3oool01@00o`00oooo0?oo
o`3oool0o`0000<0oooo00L0o`000?ooo`3oool0oooo003o003oool0003o0080oooo00<0003o003o
003oool01`3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool00?l000h0oooo00D00?l00?oo
o`3oool0oooo003o00020?ooo`040000o`3oool0oooo0?l000H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0203o
ool01@00o`00oooo0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`080?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`00o`00oooo0?ooo`040?ooo`03
003o003oool0oooo03/0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool00?l0
00P0oooo00<00?l00?ooo`3oool09@3oool00`00o`00oooo0?ooo`070?ooo`04003o003oool0oooo
0000o`/0oooo00<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo00D0oooo00<0003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`00o`000P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo00<0
003o0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool00?l000H0oooo00<00?l00?ooo`3oool0
303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`000?l02P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0000o`050?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool0003o5@3oool00`00
0?l0o`000?ooo`080?ooo`040?l0003oool0oooo003o0080003o00<0oooo003o003oool0203oool0
0`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0003o103o
ool02`000?l0oooo0?ooo`3oool00?l00?ooo`3o0000oooo0?l0003oool0003o00d0oooo00<0003o
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`05003o00000?l0oooo0?ooo`3o0000103o
ool00`3o0000oooo0000o`020?ooo`03003o003oool0oooo0080oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0o`0000D0oooo00<0003o0?ooo`00o`003`3oool00`00o`00oooo003o000?0?ooo`80
0?l07P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0N0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000H0
oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00060?ooo`070?l0003oool0oooo
003o003oool0003o003o000=0?ooo`03003o00000?l0oooo0080oooo00D00?l00?ooo`3oool0oooo
0?l000030?ooo`070?l0003oool0oooo0?ooo`00o`00oooo0000o`020?ooo`030000o`00o`00oooo
00L0oooo00<0003o0?ooo`3oool09@3oool00`000?l00?l00?ooo`0=0?ooo`05003o003oool0oooo
0?ooo`00o`000P3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l08@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo
0000o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0?03oool00`3o0000oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00o`00203oool00`00o`00oooo0?ooo`0U0?ooo`03
003o003oool0oooo00L0oooo00@00?l00?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`040?oo
o`03003o003oool0oooo00D0oooo0P00o`080?ooo`030000o`3oool0oooo00P0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool00?l00?ooo`3o00001P3oool00`00o`00oooo0?oo
o`050?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o
003oool0oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`020?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`000?l01@3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?l000080?ooo`070?l0003oool0oooo003o
00000?l0oooo003o000:0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00`3oool0
1000o`00oooo0?ooo`000?l40?ooo`0;0000o`3oool0oooo0?ooo`00o`00oooo0?l0003oool0o`00
0?ooo`000?l03@3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00D00?l0
0000o`3oool0oooo0?l000040?ooo`030?l0003oool0003o0080oooo00<00?l00?ooo`3oool00P3o
ool01`000?l0oooo0?ooo`3oool0o`000?ooo`3o00001@3oool00`000?l00?l0003o000?0?ooo`03
003o003oool00?l000l0oooo0P00o`0N0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000
003oool0oooo01d0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00P0oooo00@00?l00?ooo`3oool00?l01@3oool01@3o0000oooo0?ooo`3oool0o`00
00H0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0
oooo0080oooo00<00?l00000o`00o`003@3oool00`00o`00003o0?ooo`020?ooo`05003o003oool0
oooo0?ooo`3o00000`3oool01`3o0000oooo0?ooo`3oool00?l00?ooo`000?l00P3oool00`000?l0
0?l00?ooo`070?ooo`030000o`3oool0oooo02D0oooo0P000?l>0?ooo`04003o003oool0oooo003o
00<0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`000?lQ0?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo01`0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0l0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo02D0oooo00<0
0?l00?ooo`3oool01`3oool01000o`00oooo0?ooo`000?l;0?ooo`030000o`3oool0oooo00D0oooo
00<00?l00?ooo`3oool01000o`0:0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool00?l00?ooo`3o00001@3oool00`00o`00oooo0?ooo`060?oo
o`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo003o00060?ooo`03003o003oool0
oooo00d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00@0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`030000o`3oool0oooo0180oooo00<0
003o0?ooo`3o0000203oool01`3o0000oooo0?ooo`00o`00003o0?ooo`00o`002P3oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`000?l0103oool010000?l0
oooo0?ooo`00o`020?ooo`050?l0003oool0o`000?ooo`000?l03@3oool20000o`@0oooo00<00?l0
0?ooo`3oool00P3oool01@00o`00003o0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`000?l00P3o
ool01P00o`00oooo0?ooo`3oool00?l00000o`<0oooo00<0o`000?ooo`3o00001@3oool00`000?l0
0?l0003o000?0?ooo`03003o003oool00?l00100oooo00<00?l00?ooo`3oool0703oool00`000000
oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`04003o003oool0oooo003o00H0
oooo00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo
0?l000D0oooo00<0o`000?ooo`3oool00P3oool00`00o`00003o003o000=0?ooo`050000o`3oool0
oooo0?ooo`00o`00103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00H00?l00000o`3oool0
oooo0000o`00o`080?ooo`030000o`3oool0oooo02D0oooo0P000?l?0?ooo`03003o003oool00?l0
00<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`0S0?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
01d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool0?@3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0V0?ooo`03003o003oool0oooo00L0oooo00@00?l0
0?ooo`3oool0003o2`3oool00`000?l0oooo0?ooo`050?ooo`<00?l03P3oool00`000?l0oooo0?oo
o`080?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool0103o00000?l00?ooo`3o00050?ooo`03
003o003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`030?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool01000o`00oooo0?ooo`00o`040?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o0000203oool0103o0000oooo0?ooo`00o`02
0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`04
0?ooo`04003o003oool0oooo0000o`<0oooo00@0003o0?ooo`3oool00?l00P3oool01@3o0000oooo
0?l0003oool0003o00d0oooo0P000?l50?ooo`06003o003oool0oooo0?ooo`00o`00003o0P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o0080oooo00H00?l00?ooo`3oool0oooo003o
00000?l40?ooo`80o`001@3oool00`000?l00?l0003o000?0?ooo`03003o003oool00?l00100oooo
00<00?l00?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`00?03oool5000001/0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00@0
0?l00?ooo`3oool00?l01P3oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo00L0
oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`020?ooo`03003o00000?l00?l0
00d0oooo00D0003o0?ooo`3oool0oooo003o00040?ooo`050?l0003oool0oooo0?ooo`3o0000103o
ool01P00o`00003o0?ooo`000?l0oooo003o00P0oooo00<0003o0?ooo`3oool09@3oool00`000?l0
oooo0000o`0>0?ooo`03003o003oool00?l000<0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0000o`0S0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0?@3oool0103o0000
oooo0?ooo`3o00050?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool09`3oool00`00
o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`000?l02P3oool00`000?l0oooo0?ooo`0H
0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`040?l00000
o`00oooo0?l000@0oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool01000o`00oooo0?ooo`00o`040?ooo`03
0000o`3oool0oooo0140oooo00@0003o0?ooo`3oool0o`00203oool0103o0000oooo0?ooo`00o`02
0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`04
0?ooo`04003o003oool0oooo0000o`80oooo00D0003o0?ooo`3oool0oooo003o00020?ooo`050?l0
003oool0o`000?ooo`000?l03@3oool00`000?l0oooo0000o`040?ooo`05003o003oool0oooo0?oo
o`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o0080oooo00H00?l00?oo
o`3oool0oooo003o00000?l40?ooo`80o`001@3oool00`000?l0oooo003o000@0?ooo`800?l0403o
ool00`00o`00oooo0?ooo`0H0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00@00?l00?ooo`3oool00?l01P3o
ool00`3o0000oooo0?l000080?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`00
1@3oool00`3o0000oooo0?ooo`020?ooo`03003o00000?l00?l000d0oooo00D0003o003o003oool0
oooo003o00040?ooo`050?l0003oool0oooo0?ooo`3o0000103oool01@00o`00003o0?ooo`000?l0
0?l000T0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0000o`0>0?ooo`03003o003oool0
0?l00080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo01d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool0?@3oool0103o0000oooo0?ooo`3o00050?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool01P3oool20000o`D0oooo00@0o`00003o003oool0o`000`3oool00`00o`00
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`090?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool00?l000D0oooo00<0003o0?ooo`3oool04@3oool010000?l0
oooo0?ooo`3o00080?ooo`060?l0003oool0oooo003o003oool00?l02`3oool00`00o`00oooo0?oo
o`070?ooo`03003o003oool0oooo00@0oooo00@00?l00?ooo`3oool0003o0P3oool01@000?l0oooo
0?ooo`3oool00?l00080oooo00<0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0003o00@0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00H0o`000?ooo`3oool0003o0?ooo`00o`030?ooo`03003o00000?l0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo003o000@0?ooo`800?l0403oool00`00o`00oooo0?oo
o`0L0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo02`0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool00?l000H0oooo00<0o`00
0?ooo`3o0000203oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000D0oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0000o`0=0?ooo`050000o`00o`00oooo0?ooo`00o`00
103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D00?l00?ooo`000?l0003o003o000:0?oo
o`030000o`3oool0oooo02<0oooo00D0003o0?ooo`3oool0oooo0000o`0=0?ooo`03003o003oool0
0?l00080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo01d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`05003o003oool0
oooo0?ooo`00o`00@@3oool00`3o0000oooo0?l000050?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0:03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo00L0oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
0`3oool30000o`P0oooo00<00?l00?ooo`3o00000P3oool00`00o`00oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`03003o
003oool00?l000H0oooo00<0003o0?ooo`3oool0403oool010000?l0oooo0?ooo`3o00080?ooo`04
0?l0003oool0oooo0?ooo`800?l0303oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
00D0oooo00@00?l00?ooo`3oool0003o0P3oool01@000?l0oooo0?ooo`3oool00?l00080oooo00<0
o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0oooo0000o`<0oooo
00D00?l00?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00H0o`000?ooo`3o
ool0003o0?ooo`00o`020?ooo`03003o00000?l0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00X0oooo00<00?l00?ooo`00o`001P3oool00`3o0000oooo0?l000090?ooo`030000o`3oool0oooo
00H0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
003o00d0oooo00D0003o003o003oool0oooo003o00040?ooo`050?l0003oool0oooo0?ooo`3o0000
103oool01@00o`00oooo0000o`000?l00?l000X0oooo00<0003o0?ooo`3oool08`3oool01@000?l0
oooo0?ooo`3oool0003o00d0oooo00<00?l00?ooo`00o`000P3oool00`000?l0oooo0?ooo`0_0?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?oo
o`05003o003oool0oooo0?ooo`00o`00@@3oool00`3o0000oooo0?l000050?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool0:03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
oooo00H0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`000?l00P000?l;0?ooo`05003o003o0000oooo0?ooo`00o`003`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool2003o00H0oooo
00<0003o0?ooo`3oool0403oool010000?l0oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0?oo
o`800?l0303oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`000?l00P3oool010000?l0oooo0?ooo`00o`040?ooo`050?l0003oool0oooo0?ooo`000?l02`3o
ool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0oooo0080oooo00H0o`000?ooo`3oool0003o0?ooo`00o`020?ooo`03003o00000?l0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`03003o003oool0
oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo0P00o`070?ooo`030?l0003oool0o`00
00T0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0
oooo0080oooo0P00o`000`000?l0oooo0?ooo`0;0?ooo`050000o`00o`00oooo0?ooo`00o`00103o
ool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D00?l00?ooo`000?l0oooo003o000:0?ooo`03
0000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`80
0?l00`3oool00`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`00o`00@@3oool20?l0
00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0X0?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
01`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo
0?l000l0oooo0P000?l>0?ooo`040?l00000o`00oooo003o0100oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00o`004P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0@0?ooo`040000o`3oool0oooo0?l000P0oooo00@0o`000?ooo`3oool0oooo0P00o`0<0?oo
o`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0000o`020?oo
o`040000o`3oool0oooo003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`0;0?ooo`050000o`3o
ool0oooo0?ooo`000?l00`3oool01@00o`00oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`030000o`3oool00?l00080oooo00<00?l00000o`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0]0?ooo`040000o`3oool0oooo0000
o`h0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?l000090?ooo`030000o`3oool0oooo
00H0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`030?ooo`03003o00000?l0
oooo00`0oooo00@0003o003o003oool00?l01@3oool0103o0000oooo0?ooo`3o00050?ooo`05003o
003oool0003o0?ooo`00o`002P3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool02`3oool01@00o`00oooo0?ooo`3oool0003o0340oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool07P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00@00?l00?oo
o`3oool00?l0@P3oool00`3o0000oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`00o`00;03o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?ooo`3o000P0?ooo`03003o003oool00?l00140oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00o`004`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<00?l00?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0?0?ooo`040000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3oool0oooo003o000=
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool01P00o`00oooo0?ooo`00
0?l0oooo0000o`80oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00/0
oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00o`020?ooo`03003o00000?l0oooo
00<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool00?l00080oooo00<00?l0
0000o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00l0oooo00<00?l0
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`0]0?oo
o`040000o`3oool0oooo0000o`h0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?l0000:
0?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?oo
o`030?ooo`03003o00000?l0oooo00/0oooo00D0003o0?ooo`00o`00oooo003o00050?ooo`040?l0
003oool0oooo0?l000H0oooo00@00?l00?ooo`3oool00?l02P3oool00`000?l0oooo0?ooo`0S0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool01@00o`00oooo0?ooo`3oool0
003o0380oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00X0oooo00@00?l00?ooo`3oool00?l0@P3oool00`3o0000oooo0?ooo`050?ooo`05003o003o
ool0oooo0?ooo`00o`00;03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o000P0?ooo`800?l04`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@00?l00?ooo`3oool00?l04`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01h0oooo0P000?l?0?ooo`040000o`3oool0oooo
0?l000P0oooo00D0o`000?ooo`3oool0oooo003o000=0?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool01P3oool01P00o`00oooo0?ooo`000?l0oooo0000o`80oooo00<00?l00?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`00o`020?ooo`03003o00000?l0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`070000o`3oool00?l00?ooo`00o`00oooo0000o`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo01L0
oooo000l0?ooo`D00000:`3oool010000?l0oooo0?ooo`000?lG0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo
00<0oooo00<00?l00?ooo`000?l02`3oool01@000?l0oooo003o003oool00?l000D0oooo00@0o`00
0?ooo`3oool0o`001P3oool00`00o`00oooo003o000;0?ooo`030000o`3oool0oooo02<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`05003o003oool0oooo0?ooo`000?l0
<P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
2P3oool00`00o`00oooo003o001;0?ooo`05003o003oool0oooo0?ooo`00o`00;03oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0O0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0103o0000
oooo0?ooo`3o000P0?ooo`03003o003oool0oooo0180oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`04003o003oool0oooo003o01<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`00o`002@3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0P0?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3oool0o`00203oool00`3o0000oooo
0?ooo`0?0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool01P00o`00oooo
0?ooo`000?l0oooo0000o`80oooo00<00?l00?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00/0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo003o00020?ooo`030000o`3oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00800?l000<0
oooo0000o`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo02X0oooo1@00
000I0?ooo`00?03oool00`000000oooo0?ooo`0]0?ooo`040000o`3oool0oooo0000oaL0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o0000
1@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0003o00/0oooo00D0003o0?ooo`00o`00
oooo003o00060?ooo`030?l0003oool0o`0000H0oooo00<00?l00?ooo`00o`002`3oool00`000?l0
oooo0?ooo`0S0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0a0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`0;0?ooo`03003o003oool00?l004/0oooo00@00?l00?ooo`3oool00?l0;@3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o8`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o0000=`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`00503oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00D00?l00?ooo`3oool0oooo003o
00090?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool02`3oool010000?l0oooo0?oo
o`3o00080?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`080?ooo`04003o003oool0003o0000o`<0oooo00<00?l00?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`00o`00
oooo0000o`D0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00800?l0
00<0oooo0000o`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo02h0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0000
o`0H0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`050000
o`3oool00?l00?ooo`00o`001P3oool00`3o0000oooo0?l000060?ooo`03003o003oool00?l000/0
oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo003o001;0?ooo`04003o003oool0oooo003o
02h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o
02@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`00
03P0oooo00@0003o0?ooo`3oool0003o1`3oool00`00o`00oooo003o000E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0303oool01000o`00oooo0?ooo`00o`0:0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0280oooo0P000?l;0?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`000?l0
003o0P3oool00`00o`00oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l02`3oool00`00
0?l0oooo0?ooo`040?ooo`050000o`3oool00?l00?ooo`000?l01@3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool00P00o`000`3oool0003o0?ooo`0<0?ooo`030000o`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool0
0`000000oooo0?ooo`0]0?ooo`030000o`3oool0003o01P0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`00o`00oooo003o00060?ooo`030?l0
003oool0o`0000H0oooo00<00?l00?ooo`00o`002`3oool00`000?l0oooo0?ooo`0S0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o
003oool00?l004/0oooo00@00?l00?ooo`3oool00?l0;P3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00@0oooo0P000?lU0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?l0000h0?ooo`040000o`3oool0oooo0000o`L0oooo00<00?l00?oo
o`00o`005@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo00@00?l00?oo
o`3oool00?l02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00D0003o
0?ooo`3oool0oooo0000o`0W0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`00
203oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
203oool01000o`00oooo0?ooo`000?l20?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool00?l00?ooo`000?l01@3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool00?l00P3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00l0oooo0P000?l_0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo02h0oooo0P000?lU0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`02003o00H0oooo00<0o`000?ooo`3o00001P3oool0
0`00o`00oooo003o000;0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo0P00o`1;0?ooo`03003o003oool0
0?l002l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
o`0003T0oooo00<0003o0?ooo`000?l01`3oool00`00o`00oooo003o000E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo003o000;0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o02P0oooo00<0
003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00080?ooo`030?l0003oool0oooo0100oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo0000o`80
oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00@0
oooo00D0003o0?ooo`00o`00oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool0
10000?l0oooo0?ooo`00o`020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0000o`0_0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo02h0oooo0P000?lV0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
1@000?l0oooo0?ooo`3oool00?l000L0oooo00<0o`000?ooo`3o00001P3oool00`00o`00oooo003o
000<0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0B`3oool2003o02l0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0/0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?l0000j0?ooo`80003o203oool2003o01D0oooo00D0
003o0?ooo`3oool0oooo0000o`0@0?ooo`800?l02`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?ooo`80003o1P3oool01@000?l0
oooo0?ooo`3oool0o`0000P0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo00P0oooo00@00?l00?ooo`3oool0003o0P3oool00`00o`00oooo0?ooo`07
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool010000?l00?l00?ooo`00
0?l50?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo003o00020?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0000o`0_0?ooo`030000
003oool0oooo01L0oooo000l0?ooo`D00000;03oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo
00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00<0o`000?ooo`3o
00001`3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0803oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3o
ool0B`3oool2003o02l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool20?l003X0oooo0P000?l80?ooo`03
003o003oool0oooo01D0oooo00@0003o0?ooo`3oool0003o403oool00`00o`00oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0
003o02/0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo00<0
o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool01@3oool010000?l00?l00?ooo`000?l50?ooo`050?l0003oool0oooo0?ooo`3o
00000`3oool01@000?l0oooo0?ooo`3oool0003o00l0oooo00<0003o0?ooo`3oool03@3oool00`00
0?l0oooo0000o`0[0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0;P3oool00`000?l0
oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
o`0000T0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00<0
o`000?ooo`3o00001`3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo0240oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0380oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<0
0?l00?ooo`3oool0B`3oool00`00o`00oooo0?ooo`0_0?ooo`05003o003oool0oooo0?ooo`00o`00
;`3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool0>P3oool00`000?l0
oooo0?ooo`060?ooo`03003o003oool0oooo01D0oooo00@0003o0?ooo`3oool0003o403oool00`00
o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool01@00
0?l0oooo0?ooo`3oool0003o02`0oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool00?l000X0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`80003o00<00?l00?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`0?0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`000?l0;`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`1G0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0o`00
00T0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool00?l000L0oooo00<0o`00
0?ooo`3o00001`3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo0240oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03<0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0803oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo05/0oooo00<00?l0
0?ooo`3oool0;`3oool01000o`00oooo0?ooo`00o`0`0?ooo`050000o`3oool0oooo0?ooo`000?l0
1P3oool00`3o0000oooo0?ooo`130?ooo`03003o003oool0oooo01D0oooo00@0003o0?ooo`3oool0
003o7@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3o
ool0oooo0000o`0^0?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0A0?ooo`05003o003oool0oooo0?ooo`00o`00303oool01@00o`00oooo0?oo
o`3oool00?l000X0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`80003o
1P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000o`0?0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`000?l0;`3oool00`000000oooo0?ooo`0G0?oo
o`00?03oool00`000000oooo0?ooo`1G0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0o`0000L0oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0c
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0240oooo00D0o`000?ooo`3oool0oooo0?l0002?0?ooo`04003o003o
ool0oooo003o0300oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo05/0
oooo00@0003o0?ooo`3oool0003o7@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00T0oooo00D0003o0?ooo`3oool0oooo0000o`0_0?ooo`<0003o103oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo0180oooo00D00?l00?ooo`3oool0oooo003o000<0?ooo`05003o003o
ool0oooo0?ooo`00o`002P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?oo
o`000?l03`3oool00`000?l0oooo0?ooo`0=0?ooo`040000o`3oool0oooo0000obh0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0F03oool010000?l0oooo0?ooo`000?l4
0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3o00005@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0280oooo00D0o`000?ooo`3oool0oooo0?l0002?0?ooo`04003o003oool0oooo003o0340
oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`1L0?ooo`030000o`3oool0003o01h0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o0380
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0180
oooo00D00?l00?ooo`3oool0oooo003o000<0?ooo`05003o003oool0oooo0?ooo`00o`002P3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool0
103o0000oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool00`000?l0oooo
0?ooo`0=0?ooo`040000o`3oool0oooo0000obh0oooo00<000000?ooo`3oool05`3oool00240oooo
0P0000040?ooo`8000001@3oool3000000/0oooo00<000000?ooo`3oool0F03oool010000?l0oooo
0?ooo`000?l40?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00T0oooo0P3o000F0?ooo`030000o`3oool0oooo0240oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03<0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool08P3oool01@3o0000oooo0?ooo`3oool0o`0008l0oooo00@00?l00?ooo`3oool00?l0<@3o
ool00`000?l0oooo0000o`1V0?ooo`030000o`3oool0003o01h0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o03L0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0B0?ooo`05003o003oool0oooo0?ooo`00o`00303oool01@00o`00oooo
0?ooo`3oool00?l000X0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
003o003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3oool0
003o0100oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o02h0oooo00<0
00000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`000?l01@3oool01@3o0000oooo0?oo
o`3oool0o`0000X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0R0?ooo`050?l0
003oool0oooo0?ooo`3o0000T03oool00`00o`00oooo003o000b0?ooo`80003oIP3oool20000oal0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0003o03L0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0B0?ooo`05003o003oool0oooo0?oo
o`00o`003@3oool00`00o`00oooo003o000;0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`00o`00oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000@0oooo00D0003o
0?ooo`3oool0oooo0000o`0@0?ooo`030000o`3oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo
0000o`0^0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000P0oooo
1@00000;0?ooo`L00000E@3oool20000o`D0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo0240oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo03<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool08P3oool01@3o0000oooo0?ooo`3oool0o`00
0900oooo00<00?l00?ooo`00o`00<P3oool20000ofH0oooo0P000?lO0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000o`0g0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool04P3oool01@00o`00oooo0?ooo`3oool00?l000d0oooo00<00?l0
0?ooo`00o`00303oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<00?l0
0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`000?l0
403oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`000?l0:03oool7000001T0
oooo000P0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`1I0?ooo`80003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo01D0oooo00<0003o
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0R0?ooo`050?l0003oool0oooo0?ooo`3o0000T03o
ool00`00o`00oooo003o000b0?ooo`80003oI`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000o`0g0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o000>0?ooo`03003o003o
ool00?l000`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003o
ool0oooo0?l000@0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`030000o`3oool0oooo00/0
oooo00D0003o0?ooo`3oool0oooo0000o`0^0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`1I0?oo
o`80003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0=@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0R0?ooo`040?l0003oool0oooo0?l00940oooo0P00o`0d0?ooo`030000o`3o
ool0oooo06D0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?ooo`000?l0=`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01<0oooo00<00?l00?ooo`00o`003P3oool00`00o`00oooo003o000<0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`000?l0403oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000/0oooo0P00
000<0?ooo`030000003oool0oooo05X0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo01D0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0S0?ooo`030?l0
003oool0o`000980oooo00<00?l00?ooo`3oool0<P3oool00`000?l0oooo0?ooo`250?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000o`0g0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo003o000>0?ooo`03003o
003oool00?l000`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0o`0000D0oooo00<0003o0?ooo`000?l04P3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0G0?ooo`00?03o
ool00`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0?l0000;0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo03D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo
0?l0002B0?ooo`03003o003oool0oooo0;X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0C0?ooo`03003o003oool00?l000l0oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo
0000o`0B0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0[0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0600oooo00D0
o`000?ooo`3oool0oooo0?l0000<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
903oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo00l0oooo00D0003o0?ooo`3oool0
oooo0000o`0g0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3o0000TP3oool00`00o`00
oooo0?ooo`2j0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0f0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`00o`00
oooo003o000?0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`000?l04P3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:`3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool5000005l0oooo00@0o`000?ooo`3oool0o`00303oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool07`3oool00`000?l0
oooo0?ooo`0?0?ooo`050000o`3oool0oooo0?ooo`000?l0=`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0T0?oo
o`030?l0003oool0o`000?l0ooooD03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`00o`003`3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o
0180oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
02L0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0o`0000d0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo01l0
oooo00<0003o0?ooo`3oool0403oool010000?l0oooo0?ooo`000?lg0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
02@0oooo00<0o`000?ooo`3o0000o`3ooom@0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0f0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0503oool00`00o`00oooo0?ooo`0L0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o0180oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02X0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000=0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo0100oooo00@0003o0?ooo`3oool0003o=`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0T0?oo
o`030?l0003oool0o`000?l0ooooD03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
04D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo
01`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0o`00
00D0oooo00<0003o0?ooo`000?l04P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`1Q0?ooo`030?l0003oool0o`0000d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0T0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool04@3oool20000ocT0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`3o0?ooodl0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`150?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0503oool00`00o`00oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?l000050?ooo`030000o`3oool0003o01<0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02X0oooo00<000000?ooo`3o
ool05`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000>0?ooo`050000
o`3oool0oooo0?ooo`000?l09`3oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo0140
oooo0P000?li0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0o`3ooom?0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0A@3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0703oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`0C0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3o0000
3P3oool01@000?l0oooo0?ooo`3oool0003o02L0oooo00<0003o0?ooo`3oool07P3oool00`000?l0
oooo0?ooo`0B0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool09@3oool00`3o0000
oooo0?ooo`3o0?oooe00oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`160?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0000o`0C0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3o0000
3P3oool010000?l0oooo0?ooo`000?lX0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool0o`3ooom@0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0AP3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo03<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`000?l04`3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0:P3oool00`000000
oooo0?ooo`0G0?ooo`00?03oool5000005l0oooo00<0o`000?ooo`3o00003P3oool010000?l0oooo
0?ooo`000?lX0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0C@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`3o0?ooogP0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`160?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0U0?ooo`D0
00006@3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000>0?ooo`040000
o`3oool0oooo0000obP0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool0003o
0?l0ooooN`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04H0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000?0?ooo`03
0000o`3oool0003o02P0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool0003o
0?l0ooooN`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04H0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000?0?ooo`03
0000o`3oool0003o02P0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool0003o
0?l0ooooN`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04H0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000?0?ooo`03
0000o`3oool0003o02P0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1>0?ooo`05
0?l0003oool0oooo0?ooo`3o00005@3oool01@000?l0oooo0?ooo`3oool0003o0?l0ooooN`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04H0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?l000060?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?l0000?0?ooo`80003o:@3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo04h0oooo00D0o`000?ooo`3oool0oooo0?l0000F
0?ooo`040000o`3oool0oooo0000ool0ooooN`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo04H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool04@3oool20?l000L0oooo00<0003o0?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0
o`000100oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0
oooo04h0oooo00D0o`000?ooo`3oool0oooo0?l0000F0?ooo`040000o`3oool0oooo0000ool0oooo
N`3oool01@000?l0oooo0?ooo`3oool0003o04T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0e0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04@3oool20?l001h0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo02P0
oooo00<000000?ooo`3oool05`3oool003`0oooo1@00001O0?ooo`030?l0003oool0o`000100oooo
00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo04h0oooo
00D0o`000?ooo`3oool0oooo0?l0000F0?ooo`040000o`3oool0oooo0000ool0ooooN`3oool01@00
0?l0oooo0?ooo`3oool0003o04T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0e
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0T
0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`1?0?oo
o`040?l0003oool0oooo0?l001L0oooo00@0003o0?ooo`3oool0003oo`3ooomk0?ooo`050000o`3o
ool0oooo0?ooo`000?l0B@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo03D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo02P0oooo
00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?oo
o`0j0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0C`3oool0103o0000oooo0?oo
o`3o000G0?ooo`040000o`3oool0oooo0000ool0ooooN`3oool01@000?l0oooo0?ooo`3oool0003o
04T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo
01L0oooo000l0?ooo`030000003oool0oooo0680oooo00<0o`000?ooo`3oool0>P3oool00`000?l0
oooo0?ooo`0K0?ooo`030000o`3oool0oooo04l0oooo00@0o`000?ooo`3oool0o`005`3oool00`00
0?l0oooo0000o`3o0?ooog`0oooo00D0003o0?ooo`3oool0oooo0000o`190?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`1R0?ooo`030?l0003oool0oooo03/0oooo0P000?lK0?ooo`030000o`3oool0oooo
0500oooo00<0o`000?ooo`3o00005`3oool00`000?l0oooo0000o`3o0?ooog`0oooo00D0003o0?oo
o`3oool0oooo0000o`190?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0=@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo
0680oooo00<0o`000?ooo`3oool0?@3oool20000oaT0oooo00<0003o0?ooo`3oool0D03oool00`3o
0000oooo0?l0000G0?ooo`030000o`3oool0003o0?l0ooooO03oool01@000?l0oooo0?ooo`3oool0
003o04T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`80003o7P3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool500000600oooo00<0o`000?ooo`3oool0?`3oool20000
oaL0oooo00<0003o0?ooo`3oool0D03oool00`3o0000oooo0?l0000G0?ooo`030000o`3oool0003o
0?l0ooooO@3oool010000?l0oooo0?ooo`000?m90?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool01`3oool20000oaX0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`1R0?oo
o`030?l0003oool0oooo0440oooo0P000?lE0?ooo`030000o`3oool0oooo0500oooo00<0o`000?oo
o`3o00005`3oool00`000?l0oooo0000o`3o0?ooogd0oooo00@0003o0?ooo`3oool0003oBP3oool0
1@3o0000oooo0?ooo`3oool0o`0003L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l07P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`1R0?ooo`030?l0003oool0oooo04<0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`1@0?ooo`030?l0003oool0o`0001L0oooo00<0003o
0?ooo`000?l0o`3ooomm0?ooo`040000o`3oool0oooo0000odX0oooo00D0o`000?ooo`3oool0oooo
0?l0000g0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l07@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool00`000000oooo0?ooo`2Y0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
D03oool00`3o0000oooo0?l0000G0?ooo`030000o`3oool0003o0?l0ooooO@3oool010000?l0oooo
0?ooo`000?m:0?ooo`050?l0003oool0oooo0?ooo`3o0000=`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo03@0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`030000o`3oool0
oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`0M0?ooo`030000003oool0oooo01L0oooo000l
0?ooo`030000003oool0oooo0:T0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1@
0?ooo`030?l0003oool0o`0001P0oooo0P000?oo0?ooogd0oooo00<0003o0?ooo`000?l0B`3oool0
1@3o0000oooo0?ooo`3oool0o`0003L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0d0?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`006`3o
ool2000000@0oooo0P0000050?ooo`<000000P3oool2000000d0oooo00<000000?ooo`3oool0ZP3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0540oooo0P3o000I0?ooo`80003oo`3o
oomm0?ooo`030000o`3oool0003o04/0oooo00D0o`000?ooo`3oool0oooo0?l0000g0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=03oool01@000?l0oooo0?ooo`3oool0003o00d0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01/0
oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool000002`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Z`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0580oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`3o0?ooog`0oooo00<0003o0?ooo`000?l0B`3oool01@3o0000oooo0?ooo`3oool0
o`0003L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0d0?ooo`040000o`3oool0
oooo0000o`h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool001X0oooo00@000000?ooo`3oool00000203o
ool5000000@0oooo00<000000?ooo`3oool02P3oool700000:L0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`1B0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0o`3o
ooml0?ooo`030000o`3oool0003o04/0oooo00D0o`000?ooo`3oool0oooo0?l0000g0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=03oool010000?l0oooo0?ooo`000?l>0?ooo`05
0000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0E0?ooo`L000006@3oool001X0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`8000003@3oool0
0`000000oooo0?ooo`2/0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0DP3oool0
0`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0?l0ooooO03oool00`000?l0oooo0000o`1;
0?ooo`050?l0003oool0oooo0?ooo`3o0000=`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo03@0oooo00@0003o0?ooo`3oool0003o3P3oool01@000?l0oooo0?ooo`3oool0003o00L0
oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2/0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0DP3oool00`3o0000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo0?l0ooooO03oool00`000?l0oooo0000o`1;0?ooo`05
0?l0003oool0oooo0?ooo`3o0000=`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
03D0oooo00<0003o0?ooo`000?l03P3oool010000?l0oooo0?ooo`000?l80?ooo`030000o`3oool0
oooo01X0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00000;0?ooo`8000000`3oool30000
00`0oooo00<000000?ooo`3oool0[@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
06`0oooo00<0003o0?ooo`3oool0o`3oooml0?ooo`030000o`3oool0003o04/0oooo00D0o`000?oo
o`3oool0oooo0?l0000h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=P3oool0
0`000?l0oooo0000o`0?0?ooo`80003o2@3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0
oooo01L0oooo000l0?ooo`030000003oool0oooo0:h0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`3o0?ooon/0oooo00<0003o0?ooo`000?l0B`3oool0103o0000oooo0?ooo`3o000i
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0000o`0?
0?ooo`80003o2@3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`030000003oool0oooo0:h0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`3o0?oo
on/0oooo00<0003o0?ooo`000?l0B`3oool0103o0000oooo0?ooo`3o000i0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0000o`0?0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`2_0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0o`3oooo[0?oo
o`030000o`3oool0003o04/0oooo00@0o`000?ooo`3oool0o`00>@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo03H0oooo0P000?lK0?ooo`030000o`3oool0oooo01X0oooo00<00000
0?ooo`3oool05`3oool003`0oooo1@00002^0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?oo
o`3oool0o`3oooo/0?ooo`80003oB`3oool0103o0000oooo0?ooo`3o000i0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo01D0oooo1@00000I0?ooo`00?03oool00`000000oooo0?ooo`2`0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool0o`3oooo]0?ooo`80003oB`3oool0103o0000oooo0?ooo`3o000i
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0J
0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0/@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0?l0ooook@3oool00`00
0?l0oooo0?ooo`1:0?ooo`040?l0003oool0oooo0?l003T0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool06@3oool0
0`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2a0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0o`3oooo]0?ooo`030000o`3oool0oooo04X0oooo00@0o`000?oo
o`3oool0o`00>@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05@0oooo00<0003o
0?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2b0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0o`3oooo]0?ooo`030000o`3oool0oooo
04/0oooo00<0o`000?ooo`3o0000>@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
05@0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000
oooo0?ooo`2b0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0o`3oooo]0?ooo`03
0000o`3oool0oooo04/0oooo00<0o`000?ooo`3o0000>@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo05@0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`00
?03oool500000;00oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`3o0?ooond0oooo
00<0003o0?ooo`3oool0B`3oool00`3o0000oooo0?l0000i0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0E03oool00`000?l0oooo0?ooo`0E0?ooo`D000006@3oool003`0oooo00<0
00000?ooo`3oool0/`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0?l0ooook@3o
ool00`000?l0oooo0?ooo`1;0?ooo`030?l0003oool0o`0003T0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1E0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3o
ool003`0oooo00<000000?ooo`3oool0/`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0?l0ooooo`3oooll0?ooo`030?l0003oool0o`0003T0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`1E0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool0
03`0oooo00<000000?ooo`3oool0/`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0?l0ooooo`3oooll0?ooo`030?l0003oool0o`0003T0oooo00D0003o0?ooo`3oool0oooo0000o`1H
0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?oo
o`3oool0]03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0?l0ooooo`3oooll0?oo
o`030?l0003oool0o`0003T0oooo00D0003o0?ooo`3oool0oooo0000o`1H0?ooo`030000o`3oool0
oooo01P0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0]03oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0?l0ooooo`3ooolm0?ooo`030?l0003oool0o`00
03T0oooo00D0003o0?ooo`3oool0oooo0000o`1H0?ooo`030000o`3oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0]03oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0?l0ooooo`3ooolm0?ooo`030?l0003oool0o`0003T0oooo00D0003o0?oo
o`3oool0oooo0000o`1H0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool0
03`0oooo1@00002c0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0o`3ooooo0?oo
ocd0oooo00<0o`000?ooo`3o0000>@3oool01@000?l0oooo0?ooo`3oool0003o05T0oooo00<0003o
0?ooo`3oool04`3oool5000001T0oooo000l0?ooo`030000003oool0oooo0;D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`3o0?ooool0oooo?@3oool00`3o0000oooo0?l0000j0?oo
o`040000o`3oool0oooo0000oeT0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0G
0?ooo`00?03oool00`000000oooo0?ooo`2f0?ooo`050000o`3oool0oooo0?ooo`000?l0o`3ooooo
0?ooocl0oooo00<0o`000?ooo`3o0000>P3oool010000?l0oooo0?ooo`000?mI0?ooo`030000o`3o
ool0oooo01L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0]P3oool0
1@000?l0oooo0?ooo`3oool0003o0?l0ooooo`3ooolo0?ooo`030?l0003oool0o`0003X0oooo00@0
003o0?ooo`3oool0003oF@3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo
000l0?ooo`030000003oool0oooo0;H0oooo00D0003o0?ooo`3oool0oooo0000o`3o0?ooool0oooo
?`3oool00`3o0000oooo0?l0000j0?ooo`040000o`3oool0oooo0000oeT0oooo00<0003o0?ooo`3o
ool05`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`2g0?ooo`040000
o`3oool0oooo0000ool0ooooo`3ooolo0?ooo`80o`00>`3oool010000?l0oooo0?ooo`000?mI0?oo
o`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3o
ool0]`3oool010000?l0oooo0?ooo`000?oo0?ooool0oooo?`3oool20?l003/0oooo00@0003o0?oo
o`3oool0003oF@3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo000l0?oo
o`D00000]@3oool010000?l0oooo0?ooo`000?oo0?ooool0oooo@03oool00`3o0000oooo0?ooo`0i
0?ooo`040000o`3oool0oooo0000oeX0oooo00<0003o0?ooo`3oool04P3oool5000001T0oooo000l
0?ooo`030000003oool0oooo0;P0oooo0P000?oo0?ooool0oooo@@3oool00`3o0000oooo0?ooo`0i
0?ooo`040000o`3oool0oooo0000oeX0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`2h0?ooo`80003oo`3ooooo0?oood40oooo00<0o`00
0?ooo`3oool0>@3oool00`000?l0oooo0000o`1K0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0^03oool20000ool0ooooo`3ooom10?oo
o`030?l0003oool0oooo03T0oooo00<0003o0?ooo`000?l0F`3oool00`000?l0oooo0?ooo`0F0?oo
o`030000003oool0oooo01L0oooo000Q0?ooo`800000103oool2000000@0oooo0P00000=0?ooo`03
0000003oool0oooo0;T0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooocl0oooo00<0o`000?ooo`3o
ool0>@3oool00`000?l0oooo0000o`1K0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000<0?oo
o`030000003oool0oooo0;T0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooocl0oooo00<0o`000?oo
o`3oool0>@3oool00`000?l0oooo0000o`1K0?ooo`030000o`3oool0oooo01H0oooo00<000000?oo
o`3oool05`3oool00200oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0:0?oo
o`L00000o`3ooooo0?ooooL0oooo00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0000o`1L0?oo
o`030000o`3oool0oooo00l0oooo1`00000I0?ooo`00803oool010000000oooo0?ooo`0000090?oo
o`8000003@3oool00`000000oooo0?ooo`3o0?ooool0oooon`3oool00`3o0000oooo0?ooo`0i0?oo
o`030000o`3oool0003o05`0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooo/0oooo00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0000o`1L0?oo
o`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool05`3oool00240oooo0P00000:0?ooo`<0
0000303oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000o`3oool0003o05`0
oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolh0?ooo`030000o`3oool0003o05`0oooo00<0003o0?ooo`3oool0
5@3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
oolh0?ooo`030000o`3oool0003o05`0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?oo
o`0G0?ooo`00?03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oooli0?ooo`80003oG@3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000o`3ooooo0?oo
ool0oooo=`3oool20000oed0oooo00<0003o0?ooo`3oool0403oool5000001T0oooo000l0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooocT0oooo0P000?mM0?ooo`030000o`3oool0oooo01@0
oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
>@3oool00`000?l0oooo0?ooo`1L0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0
5`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>@3oool00`000?l0oooo0?oo
o`1c0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooocT0oooo00<0003o0?ooo`3oool0L`3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3oooli0?ooo`030000o`3oool0oooo07<0oooo00<000000?oo
o`3oool05`3oool003`0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo>@3oool00`000?l0
oooo0?ooo`1c0?ooo`030000003oool0oooo01L0oooo000l0?ooo`D00000o`3ooooo0?ooool0oooo
=`3oool00`000?l0oooo0?ooo`1_0?ooo`D000006@3oool003`0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool05`3oool003`0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000l0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00?03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003`0ooooo`00
003o00000?l00000/`00000I0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 1028.63}, {256.375, 0}} -> {-9.5703, 0.145066, \
0.114764, 0.00150217}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1147}},
WindowSize->{1137, 740},
WindowMargins->{{192, Automatic}, {133, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 96, 3, 150, "Title"],
Cell[1838, 56, 86, 3, 93, "Subtitle"],
Cell[1927, 61, 649, 12, 128, "Text"],
Cell[2579, 75, 49, 0, 33, "Text"],
Cell[2631, 77, 147, 3, 50, "Input"],
Cell[2781, 82, 174, 3, 50, "Input"],
Cell[2958, 87, 135, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[3118, 93, 68, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[3211, 97, 65, 0, 47, "Subsection"],
Cell[3279, 99, 3315, 47, 236, "Input"],
Cell[6597, 148, 3253, 45, 236, "Input"],
Cell[9853, 195, 131, 3, 33, "Text"],
Cell[9987, 200, 714, 14, 130, "Input"],
Cell[10704, 216, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[10814, 222, 255, 5, 30, "Input"],
Cell[11072, 229, 50451, 1216, 186, 8286, 691, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[61538, 1448, 104, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[61667, 1455, 259, 5, 30, "Input"],
Cell[61929, 1462, 53664, 1284, 186, 8639, 724, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115630, 2751, 259, 5, 30, "Input"],
Cell[115892, 2758, 42532, 1119, 186, 8240, 691, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158461, 3882, 259, 5, 30, "Input"],
Cell[158723, 3889, 49600, 1154, 186, 7557, 631, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208360, 5048, 105, 2, 30, "Input"],
Cell[208468, 5052, 114701, 3750, 106, 32665, 2733, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323206, 8807, 104, 2, 30, "Input"],
Cell[323313, 8811, 516, 13, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323866, 8829, 177, 4, 50, "Input"],
Cell[324046, 8835, 1158, 24, 105, "Output"]
}, Open  ]],
Cell[325219, 8862, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[325384, 8869, 225, 5, 50, "Input"],
Cell[325612, 8876, 384, 10, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[326045, 8892, 69, 0, 47, "Subsection"],
Cell[326117, 8894, 2746, 38, 206, "Input"],
Cell[328866, 8934, 2736, 38, 206, "Input"],
Cell[331605, 8974, 131, 3, 33, "Text"],
Cell[331739, 8979, 731, 15, 130, "Input"],
Cell[332473, 8996, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[332583, 9002, 255, 5, 30, "Input"],
Cell[332841, 9009, 53276, 1210, 186, 7714, 643, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[386132, 10222, 104, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[386261, 10229, 259, 5, 30, "Input"],
Cell[386523, 10236, 53788, 1255, 186, 8205, 688, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[440348, 11496, 259, 5, 30, "Input"],
Cell[440610, 11503, 45202, 1111, 186, 7685, 643, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[485849, 12619, 259, 5, 30, "Input"],
Cell[486111, 12626, 48200, 1127, 186, 7441, 619, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[534348, 13758, 105, 2, 30, "Input"],
Cell[534456, 13762, 114212, 3621, 106, 30988, 2589, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[648705, 17388, 104, 2, 30, "Input"],
Cell[648812, 17392, 512, 13, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[649361, 17410, 177, 4, 50, "Input"],
Cell[649541, 17416, 1157, 24, 105, "Output"]
}, Open  ]],
Cell[650713, 17443, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[650878, 17450, 225, 5, 50, "Input"],
Cell[651106, 17457, 385, 10, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[651540, 17473, 69, 0, 47, "Subsection"],
Cell[651612, 17475, 2663, 37, 206, "Input"],
Cell[654278, 17514, 2670, 37, 206, "Input"],
Cell[656951, 17553, 131, 3, 33, "Text"],
Cell[657085, 17558, 629, 13, 110, "Input"],
Cell[657717, 17573, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[657827, 17579, 255, 5, 30, "Input"],
Cell[658085, 17586, 38251, 1005, 186, 7588, 622, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[696351, 18594, 104, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[696480, 18601, 259, 5, 30, "Input"],
Cell[696742, 18608, 41699, 1109, 186, 8220, 691, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[738478, 19722, 259, 5, 30, "Input"],
Cell[738740, 19729, 42180, 1109, 186, 8161, 685, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780957, 20843, 259, 5, 30, "Input"],
Cell[781219, 20850, 38802, 1112, 186, 8698, 736, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[820058, 21967, 105, 2, 30, "Input"],
Cell[820166, 21971, 98202, 3544, 106, 32610, 2730, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[918405, 25520, 104, 2, 30, "Input"],
Cell[918512, 25524, 515, 13, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[919064, 25542, 177, 4, 50, "Input"],
Cell[919244, 25548, 1147, 23, 105, "Output"]
}, Open  ]],
Cell[920406, 25574, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[920571, 25581, 225, 5, 50, "Input"],
Cell[920799, 25588, 385, 10, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[921233, 25604, 66, 0, 47, "Subsection"],
Cell[921302, 25606, 2727, 38, 206, "Input"],
Cell[924032, 25646, 2731, 38, 206, "Input"],
Cell[926766, 25686, 131, 3, 33, "Text"],
Cell[926900, 25691, 506, 10, 90, "Input"],
Cell[927409, 25703, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[927519, 25709, 255, 5, 30, "Input"],
Cell[927777, 25716, 50096, 1194, 186, 8038, 670, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[977888, 26913, 104, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[978017, 26920, 259, 5, 30, "Input"],
Cell[978279, 26927, 49991, 1149, 186, 7437, 619, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1028307, 28081, 259, 5, 30, "Input"],
Cell[1028569, 28088, 50356, 1243, 186, 8639, 724, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1078962, 29336, 259, 5, 30, "Input"],
Cell[1079224, 29343, 43078, 1102, 186, 7943, 664, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1122339, 30450, 105, 2, 30, "Input"],
Cell[1122447, 30454, 112908, 3676, 106, 32000, 2673, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1235392, 34135, 104, 2, 30, "Input"],
Cell[1235499, 34139, 512, 13, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1236048, 34157, 177, 4, 50, "Input"],
Cell[1236228, 34163, 1144, 23, 105, "Output"]
}, Open  ]],
Cell[1237387, 34189, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1237552, 34196, 225, 5, 50, "Input"],
Cell[1237780, 34203, 386, 10, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1238215, 34219, 102, 2, 47, "Subsection"],
Cell[1238320, 34223, 213, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[1238558, 34231, 259, 5, 30, "Input"],
Cell[1238820, 34238, 50615, 1156, 186, 7498, 619, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1289472, 35399, 263, 5, 30, "Input"],
Cell[1289738, 35406, 55594, 1286, 186, 8274, 697, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1345369, 36697, 263, 5, 30, "Input"],
Cell[1345635, 36704, 52490, 1265, 186, 8554, 718, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1398162, 37974, 263, 5, 60, "Input"],
Cell[1398428, 37981, 48241, 1099, 186, 7077, 586, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1446706, 39085, 126, 3, 30, "Input"],
Cell[1446835, 39090, 118610, 3698, 106, 31346, 2616, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1565482, 42793, 83, 1, 30, "Input"],
Cell[1565568, 42796, 553, 13, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1566158, 42814, 185, 4, 50, "Input"],
Cell[1566346, 42820, 1250, 26, 105, "Output"]
}, Open  ]],
Cell[1567611, 42849, 172, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1567808, 42856, 259, 5, 50, "Input"],
Cell[1568070, 42863, 487, 13, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1568618, 42883, 57, 0, 53, "Section"],
Cell[1568678, 42885, 264, 6, 48, "Text"],
Cell[1568945, 42893, 128, 2, 60, "Input"],

Cell[CellGroupData[{
Cell[1569098, 42899, 55, 1, 40, "Input"],
Cell[1569156, 42902, 36, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1569229, 42908, 66, 0, 40, "Subsection"],
Cell[1569298, 42910, 131, 3, 29, "Text"],
Cell[1569432, 42915, 575, 12, 100, "Input"],
Cell[1570010, 42929, 85, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[1570120, 42935, 415, 8, 100, "Input"],
Cell[1570538, 42945, 589751, 18269, 528, 154149, 12885, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2160304, 61217, 130, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2160459, 61224, 482, 9, 100, "Input"],
Cell[2160944, 61235, 598586, 18939, 521, 160882, 13530, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2759567, 80179, 482, 9, 90, "Input"],
Cell[2760052, 80190, 600010, 18903, 521, 160101, 13467, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3360099, 99098, 482, 9, 50, "Input"],
Cell[3360584, 99109, 581136, 18757, 520, 160873, 13563, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3941757, 117871, 147, 2, 30, "Input"],
Cell[3941907, 117875, 15941, 313, 1529, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3957885, 118193, 196, 4, 50, "Input"],
Cell[3958084, 118199, 45719, 876, 1529, "Output"]
}, Open  ]],
Cell[4003818, 119078, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[4003983, 119085, 636, 14, 110, "Input"],
Cell[4004622, 119101, 27993, 738, 809, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4032664, 119845, 71, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[4032760, 119849, 57, 0, 44, "Subsubsection"],

Cell[CellGroupData[{
Cell[4032842, 119853, 248, 4, 100, "Input"],
Cell[4033093, 119859, 55, 1, 49, "Output"],
Cell[4033151, 119862, 53, 1, 49, "Output"],
Cell[4033207, 119865, 54, 1, 49, "Output"],
Cell[4033264, 119868, 55, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4033356, 119874, 48, 1, 40, "Input"],
Cell[4033407, 119877, 53, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4033497, 119883, 239, 4, 100, "Input"],
Cell[4033739, 119889, 53, 1, 49, "Output"],
Cell[4033795, 119892, 54, 1, 49, "Output"],
Cell[4033852, 119895, 53, 1, 49, "Output"],
Cell[4033908, 119898, 54, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4033999, 119904, 47, 1, 40, "Input"],
Cell[4034049, 119907, 53, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4034139, 119913, 46, 1, 40, "Input"],
Cell[4034188, 119916, 54, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4034279, 119922, 112, 2, 40, "Input"],
Cell[4034394, 119926, 53, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4034496, 119933, 56, 0, 44, "Subsubsection"],
Cell[4034555, 119935, 23, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4034603, 119939, 198, 4, 100, "Input"],
Cell[4034804, 119945, 54, 1, 49, "Output"],
Cell[4034861, 119948, 53, 1, 49, "Output"],
Cell[4034917, 119951, 54, 1, 49, "Output"],
Cell[4034974, 119954, 54, 1, 49, "Output"]
}, Open  ]],
Cell[4035043, 119958, 23, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4035091, 119962, 197, 4, 100, "Input"],
Cell[4035291, 119968, 53, 1, 49, "Output"],
Cell[4035347, 119971, 53, 1, 49, "Output"],
Cell[4035403, 119974, 54, 1, 49, "Output"],
Cell[4035460, 119977, 53, 1, 49, "Output"]
}, Open  ]],
Cell[4035528, 119981, 23, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4035576, 119985, 101, 2, 60, "Input"],
Cell[4035680, 119989, 52, 1, 29, "Output"],
Cell[4035735, 119992, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4035825, 119998, 108, 2, 30, "Input"],
Cell[4035936, 120002, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4036026, 120008, 189, 3, 30, "Input"],
Cell[4036218, 120013, 53, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4036344, 120022, 47, 0, 53, "Section"],
Cell[4036394, 120024, 437, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[4036856, 120035, 65, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[4036946, 120039, 46, 0, 43, "Subsubsection"],
Cell[4036995, 120041, 394, 7, 70, "Input"],
Cell[4037392, 120050, 118, 2, 30, "Input"],
Cell[4037513, 120054, 439, 9, 110, "Input"],

Cell[CellGroupData[{
Cell[4037977, 120067, 221, 4, 30, "Input"],
Cell[4038201, 120073, 52269, 1247, 186, 8416, 701, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4090507, 121325, 214, 4, 40, "Input"],
Cell[4090724, 121331, 34409, 853, 194, 5844, 496, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4125170, 122189, 214, 4, 40, "Input"],
Cell[4125387, 122195, 32985, 871, 194, 6370, 538, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4158409, 123071, 214, 4, 40, "Input"],
Cell[4158626, 123077, 35473, 856, 194, 5729, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4194136, 123938, 122, 3, 40, "Input"],
Cell[4194261, 123943, 90151, 3007, 114, 26302, 2215, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4284449, 126955, 56, 1, 40, "Input"],
Cell[4284508, 126958, 104, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4284649, 126965, 58, 1, 40, "Input"],
Cell[4284710, 126968, 53, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4284800, 126974, 70, 1, 40, "Input"],
Cell[4284873, 126977, 337, 6, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4285247, 126988, 181, 4, 60, "Input"],
Cell[4285431, 126994, 1395, 29, 125, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4286875, 127029, 57, 0, 44, "Subsubsection"],
Cell[4286935, 127031, 380, 7, 70, "Input"],
Cell[4287318, 127040, 120, 2, 30, "Input"],
Cell[4287441, 127044, 422, 9, 70, "Input"],

Cell[CellGroupData[{
Cell[4287888, 127057, 223, 4, 30, "Input"],
Cell[4288114, 127063, 51619, 1239, 186, 8412, 701, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4339770, 128307, 216, 4, 30, "Input"],
Cell[4339989, 128313, 35629, 852, 186, 5668, 478, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4375633, 129168, 258, 10, 143, "Input"],
Cell[4375894, 129180, 33009, 877, 186, 6420, 544, "GraphicsData", \
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[4408928, 130061, 216, 4, 40, "Input"],
Cell[4409147, 130067, 34620, 856, 194, 5836, 496, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4443804, 130928, 126, 3, 40, "Input"],
Cell[4443933, 130933, 90961, 3018, 106, 26279, 2215, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4534931, 133956, 57, 1, 30, "Input"],
Cell[4534991, 133959, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4535133, 133966, 59, 1, 30, "Input"],
Cell[4535195, 133969, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4535285, 133975, 71, 1, 30, "Input"],
Cell[4535359, 133978, 336, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4535732, 133989, 184, 4, 50, "Input"],
Cell[4535919, 133995, 1407, 30, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4537387, 134032, 69, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[4537481, 134036, 46, 0, 43, "Subsubsection"],
Cell[4537530, 134038, 403, 7, 70, "Input"],
Cell[4537936, 134047, 118, 2, 30, "Input"],
Cell[4538057, 134051, 404, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[4538486, 134063, 221, 4, 30, "Input"],
Cell[4538710, 134069, 49224, 1158, 186, 7618, 640, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4587971, 135232, 214, 4, 40, "Input"],
Cell[4588188, 135238, 34217, 822, 186, 5478, 463, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4622442, 136065, 214, 4, 30, "Input"],
Cell[4622659, 136071, 32655, 844, 186, 6053, 511, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4655351, 136920, 214, 4, 30, "Input"],
Cell[4655568, 136926, 32942, 835, 186, 5844, 496, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4688547, 137766, 122, 3, 30, "Input"],
Cell[4688672, 137771, 87830, 2886, 106, 24936, 2106, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4776539, 140662, 56, 1, 30, "Input"],
Cell[4776598, 140665, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4776740, 140672, 70, 1, 40, "Input"],
Cell[4776813, 140675, 336, 6, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4777186, 140686, 58, 1, 40, "Input"],
Cell[4777247, 140689, 54, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4777338, 140695, 181, 4, 60, "Input"],
Cell[4777522, 140701, 1406, 30, 125, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4778977, 140737, 57, 0, 44, "Subsubsection"],
Cell[4779037, 140739, 389, 7, 80, "Input"],
Cell[4779429, 140748, 120, 2, 40, "Input"],
Cell[4779552, 140752, 422, 9, 80, "Input"],

Cell[CellGroupData[{
Cell[4779999, 140765, 223, 4, 60, "Input"],
Cell[4780225, 140771, 41133, 985, 194, 6712, 556, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4821395, 141761, 216, 4, 40, "Input"],
Cell[4821614, 141767, 33630, 833, 194, 5736, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4855281, 142605, 216, 4, 40, "Input"],
Cell[4855500, 142611, 32603, 843, 194, 6053, 511, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4888140, 143459, 216, 4, 40, "Input"],
Cell[4888359, 143465, 32390, 846, 186, 6093, 517, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4920786, 144316, 126, 3, 30, "Input"],
Cell[4920915, 144321, 82841, 2788, 106, 24537, 2064, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5003793, 147114, 57, 1, 30, "Input"],
Cell[5003853, 147117, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5003995, 147124, 59, 1, 30, "Input"],
Cell[5004057, 147127, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5004147, 147133, 71, 1, 30, "Input"],
Cell[5004221, 147136, 336, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5004594, 147147, 184, 4, 50, "Input"],
Cell[5004781, 147153, 1395, 29, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5006237, 147189, 69, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5006331, 147193, 46, 0, 43, "Subsubsection"],
Cell[5006380, 147195, 280, 5, 60, "Input"],
Cell[5006663, 147202, 118, 2, 40, "Input"],
Cell[5006784, 147206, 402, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[5007211, 147218, 221, 4, 30, "Input"],
Cell[5007435, 147224, 47834, 1146, 186, 7677, 646, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5055306, 148375, 214, 4, 30, "Input"],
Cell[5055523, 148381, 38766, 943, 186, 6346, 538, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5094326, 149329, 214, 4, 30, "Input"],
Cell[5094543, 149335, 39159, 947, 186, 6346, 538, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5133739, 150287, 214, 4, 30, "Input"],
Cell[5133956, 150293, 34448, 838, 194, 5679, 478, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5168441, 151136, 122, 3, 40, "Input"],
Cell[5168566, 151141, 93697, 3036, 114, 25991, 2196, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5262300, 154182, 56, 1, 40, "Input"],
Cell[5262359, 154185, 106, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5262502, 154192, 58, 1, 40, "Input"],
Cell[5262563, 154195, 53, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5262653, 154201, 70, 1, 40, "Input"],
Cell[5262726, 154204, 339, 6, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5263102, 154215, 181, 4, 60, "Input"],
Cell[5263286, 154221, 1388, 29, 125, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5264723, 154256, 57, 0, 44, "Subsubsection"],
Cell[5264783, 154258, 389, 7, 80, "Input"],
Cell[5265175, 154267, 120, 2, 40, "Input"],
Cell[5265298, 154271, 422, 9, 80, "Input"],

Cell[CellGroupData[{
Cell[5265745, 154284, 223, 4, 60, "Input"],
Cell[5265971, 154290, 35170, 958, 194, 7346, 610, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5301178, 155253, 216, 4, 40, "Input"],
Cell[5301397, 155259, 31510, 881, 186, 6736, 571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5332944, 156145, 216, 4, 30, "Input"],
Cell[5333163, 156151, 31698, 884, 186, 6736, 571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5364898, 157040, 216, 4, 30, "Input"],
Cell[5365117, 157046, 32551, 843, 186, 6053, 511, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5397705, 157894, 126, 3, 30, "Input"],
Cell[5397834, 157899, 80003, 2920, 106, 26814, 2259, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5477874, 160824, 57, 1, 30, "Input"],
Cell[5477934, 160827, 105, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5478076, 160834, 59, 1, 40, "Input"],
Cell[5478138, 160837, 53, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5478228, 160843, 71, 1, 40, "Input"],
Cell[5478302, 160846, 339, 6, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5478678, 160857, 184, 4, 60, "Input"],
Cell[5478865, 160863, 1396, 29, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5480322, 160899, 66, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5480413, 160903, 46, 0, 43, "Subsubsection"],
Cell[5480462, 160905, 276, 5, 50, "Input"],
Cell[5480741, 160912, 118, 2, 30, "Input"],
Cell[5480862, 160916, 402, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[5481289, 160928, 221, 4, 30, "Input"],
Cell[5481513, 160934, 50530, 1164, 186, 7507, 628, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5532080, 162103, 214, 4, 30, "Input"],
Cell[5532297, 162109, 38752, 935, 186, 6217, 529, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5571086, 163049, 214, 4, 40, "Input"],
Cell[5571303, 163055, 36981, 959, 194, 6846, 583, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5608321, 164019, 214, 4, 40, "Input"],
Cell[5608538, 164025, 37476, 948, 186, 6594, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5646051, 164978, 122, 3, 30, "Input"],
Cell[5646176, 164983, 96527, 3159, 106, 27107, 2298, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5742740, 168147, 56, 1, 30, "Input"],
Cell[5742799, 168150, 106, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5742942, 168157, 58, 1, 30, "Input"],
Cell[5743003, 168160, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5743094, 168166, 70, 1, 30, "Input"],
Cell[5743167, 168169, 340, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5743544, 168180, 181, 4, 50, "Input"],
Cell[5743728, 168186, 1391, 29, 105, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5745168, 168221, 57, 0, 43, "Subsubsection"],
Cell[5745228, 168223, 383, 7, 70, "Input"],
Cell[5745614, 168232, 120, 2, 30, "Input"],
Cell[5745737, 168236, 422, 9, 70, "Input"],

Cell[CellGroupData[{
Cell[5746184, 168249, 223, 4, 60, "Input"],
Cell[5746410, 168255, 47485, 1155, 194, 7858, 661, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5793932, 169415, 216, 4, 40, "Input"],
Cell[5794151, 169421, 36670, 956, 194, 6846, 583, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5830858, 170382, 216, 4, 40, "Input"],
Cell[5831077, 170388, 33610, 838, 194, 5782, 490, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5864724, 171231, 216, 4, 40, "Input"],
Cell[5864943, 171237, 37227, 957, 194, 6810, 577, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5902207, 172199, 126, 3, 40, "Input"],
Cell[5902336, 172204, 92583, 3118, 114, 27239, 2307, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5994956, 175327, 57, 1, 40, "Input"],
Cell[5995016, 175330, 107, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5995160, 175337, 59, 1, 30, "Input"],
Cell[5995222, 175340, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5995311, 175346, 71, 1, 30, "Input"],
Cell[5995385, 175349, 340, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5995762, 175360, 184, 4, 50, "Input"],
Cell[5995949, 175366, 1407, 30, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5997417, 175403, 32, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5997474, 175407, 48, 0, 43, "Subsubsection"],
Cell[5997525, 175409, 141, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[5997691, 175416, 50, 1, 30, "Input"],
Cell[5997744, 175419, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5997834, 175425, 132, 3, 30, "Input"],
Cell[5997969, 175430, 335, 6, 48, "Output"]
}, Open  ]],
Cell[5998319, 175439, 561, 11, 70, "Input"],

Cell[CellGroupData[{
Cell[5998905, 175454, 154, 3, 70, "Input"],
Cell[5999062, 175459, 52, 1, 29, "Output"],
Cell[5999117, 175462, 54, 1, 29, "Output"],
Cell[5999174, 175465, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5999265, 175471, 190, 3, 70, "Input"],
Cell[5999458, 175476, 337, 6, 48, "Output"],
Cell[5999798, 175484, 337, 6, 48, "Output"],
Cell[6000138, 175492, 336, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6000511, 175503, 224, 4, 30, "Input"],
Cell[6000738, 175509, 84243, 1810, 186, 11015, 902, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6085018, 177324, 209, 4, 30, "Input"],
Cell[6085230, 177330, 55818, 1297, 186, 8397, 707, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6141085, 178632, 209, 4, 30, "Input"],
Cell[6141297, 178638, 50980, 1276, 186, 8900, 752, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6192314, 179919, 209, 4, 30, "Input"],
Cell[6192526, 179925, 57846, 1309, 186, 8212, 692, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6250409, 181239, 133, 3, 30, "Input"],
Cell[6250545, 181244, 130539, 4214, 106, 36467, 3049, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6381133, 185464, 41, 0, 43, "Subsubsection"],
Cell[6381177, 185466, 148, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[6381350, 185473, 53, 1, 40, "Input"],
Cell[6381406, 185476, 54, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6381497, 185482, 136, 3, 40, "Input"],
Cell[6381636, 185487, 339, 6, 48, "Output"]
}, Open  ]],
Cell[6381990, 185496, 576, 11, 70, "Input"],

Cell[CellGroupData[{
Cell[6382591, 185511, 157, 3, 70, "Input"],
Cell[6382751, 185516, 53, 1, 29, "Output"],
Cell[6382807, 185519, 52, 1, 29, "Output"],
Cell[6382862, 185522, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6382952, 185528, 193, 3, 70, "Input"],
Cell[6383148, 185533, 337, 6, 48, "Output"],
Cell[6383488, 185541, 340, 6, 48, "Output"],
Cell[6383831, 185549, 341, 6, 48, "Output"]
}, Open  ]],
Cell[6384187, 185558, 35, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6384247, 185563, 230, 4, 30, "Input"],
Cell[6384480, 185569, 66579, 1651, 186, 11876, 971, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6451096, 187225, 211, 4, 30, "Input"],
Cell[6451310, 187231, 46336, 1102, 186, 7434, 617, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6497683, 188338, 211, 4, 30, "Input"],
Cell[6497897, 188344, 44706, 1092, 186, 7545, 629, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6542640, 189441, 211, 4, 30, "Input"],
Cell[6542854, 189447, 46106, 1099, 186, 7444, 617, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6588997, 190551, 139, 3, 30, "Input"],
Cell[6589139, 190556, 112262, 3797, 106, 34242, 2830, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6701474, 194361, 92, 2, 53, "Section"],
Cell[6701569, 194365, 974, 16, 150, "Input"],

Cell[CellGroupData[{
Cell[6702568, 194385, 77, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[6702670, 194389, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6702743, 194393, 66, 1, 30, "Input"],
Cell[6702812, 194396, 260122, 3935, 266, 11528, 862, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6962983, 198337, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6963049, 198341, 67, 1, 30, "Input"],
Cell[6963119, 198344, 235367, 3526, 266, 10174, 742, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7198547, 201877, 83, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[7198655, 201882, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7198728, 201886, 66, 1, 30, "Input"],
Cell[7198797, 201889, 234482, 3456, 266, 9132, 670, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7433328, 205351, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7433394, 205355, 67, 1, 30, "Input"],
Cell[7433464, 205358, 240261, 3590, 266, 9944, 742, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7673786, 208955, 83, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[7673894, 208960, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7673967, 208964, 66, 1, 30, "Input"],
Cell[7674036, 208967, 242506, 3565, 266, 9318, 682, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7916591, 212538, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7916657, 212542, 67, 1, 30, "Input"],
Cell[7916727, 212545, 256323, 3754, 266, 9388, 701, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8173111, 216306, 78, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[8173214, 216310, 48, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8173287, 216314, 66, 1, 30, "Input"],
Cell[8173356, 216317, 289307, 4221, 266, 10293, 772, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8462712, 220544, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8462778, 220548, 67, 1, 30, "Input"],
Cell[8462848, 220551, 248148, 3713, 266, 10294, 772, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

